@@ -17,7 +17,7 @@ coneActor.SetMapper(coneMapper)
 ren1 = vtkMantaRenderer()
 ren1.AddActor(coneActor)
 ren1.SetBackground(0.1, 0.2, 0.4)
-renWin = vtkMantaRenderWindow()
+renWin = vtkRenderWindow()
 renWin.AddRenderer(ren1)
 renWin.SetSize(300, 300)
 iren = vtkRenderWindowInteractor()
