@@ -92,6 +92,9 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <Model/Groups/Group.h>
 #include <Model/Lights/HeadLight.h>
 
+#include "vtkImageData.h"
+#include "vtkPNGWriter.h"
+
 
 #include <vtkstd/string>
 
@@ -162,7 +165,7 @@ vtkMantaRenderer::vtkMantaRenderer() :
 //----------------------------------------------------------------------------
 vtkMantaRenderer::~vtkMantaRenderer()
 {
-  //cerr << "MR(" << this << ") DESTROY " << this->MantaManager << " " 
+  //cerr << "MR(" << this << ") DESTROY " << this->MantaManager << " "
   //     << this->MantaManager->GetReferenceCount() << endl;
 
   if (this->DefaultLight && this->MantaLightSet)
@@ -187,7 +190,7 @@ vtkMantaRenderer::~vtkMantaRenderer()
 //----------------------------------------------------------------------------
 void vtkMantaRenderer::InitEngine()
 {
-  //cerr << "MR(" << this << ")#" << this->GetLayer() << " INIT " 
+  //cerr << "MR(" << this << ")#" << this->GetLayer() << " INIT "
   //     << this->MantaManager << endl;
   this->MantaManager->StartEngine(this->MaxDepth,
                                   this->GetBackground(),
@@ -216,7 +219,7 @@ void vtkMantaRenderer::SetBackground(double r, double g, double b)
   this->MantaEngine->addTransaction
     ( "set background",
       Manta::Callback::create(this, &vtkMantaRenderer::InternalSetBackground));
-  }; 
+  };
 }
 
 //----------------------------------------------------------------------------
@@ -272,15 +275,16 @@ int vtkMantaRenderer::UpdateLights()
       noneOn = false;
       }
     //manta lights set intensity to 0.0 if switched off, so render regardless
-    vLight->Render( this, 0 /* not used */ ); 
+    vLight->Render( this, 0 /* not used */ );
     }
-    
+
   if (noneOn)
     {
     if (this->MantaLightSet->numLights()==0 )
       {
       // there is no VTK light nor MantaLight defined, create a Manta headlight
-      cerr << "No light defined, creating a headlight at camera position" << endl;      
+      cerr
+        << "No light defined, creating a headlight at camera position" << endl;
       this->DefaultLight =
         new Manta::HeadLight( 0, Manta::Color( Manta::RGBColor( 1, 1, 1 ) ) );
       this->MantaEngine->addTransaction
@@ -308,9 +312,47 @@ vtkCamera* vtkMantaRenderer::MakeCamera()
   return vtkMantaCamera::New();
 }
 
+//----------------------------------------------------------------------------
+void vtkMantaRenderer::UpdateSize()
+{
+  if (this->EngineStarted)
+    {
+    int     mantaSize[2];
+    int*    renderSize  = NULL;
+    bool    stereoDummyArg;
+
+    renderSize = this->GetSize();
+    this->GetSyncDisplay()->getCurrentImage()->
+      getResolution( stereoDummyArg, mantaSize[0], mantaSize[1] );
+
+    if (mantaSize[0] != renderSize[0] ||
+        mantaSize[1] != renderSize[1])
+      {
+      /*
+      cerr << "MR(" << this << ") "
+           << "Layer: " << this->GetLayer() << ", "
+           << "Props: " << this->NumberOfPropsRendered << endl
+           << "  MantaSize: " << mantaSize[0] << ", " << mantaSize[1] << ", "
+           << "  renderSize: " << renderSize[0] << ", " << renderSize[1] << endl;
+      */
+      this->GetMantaEngine()->addTransaction
+        ("resize",
+         Manta::Callback::create
+         (this->GetMantaEngine(),
+          &Manta::MantaInterface::changeResolution,
+          0, renderSize[0], renderSize[1],
+          true));
+
+      this->GetSyncDisplay()->doneRendering();
+      this->GetSyncDisplay()->waitOnFrameReady();
+      }
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkMantaRenderer::DeviceRender()
 {
+  //cerr << "MR(" << this << ") DeviceRender" << endl;
 
   // In ParaView, we are wasting time in rendering the "sync layer" with
   // empty background image just to be dropped in LayerRender(). We just
@@ -330,6 +372,10 @@ void vtkMantaRenderer::DeviceRender()
 
   vtkTimerLog::MarkStartEvent("Geometry");
 
+  this->Clear();
+
+  this->UpdateSize();
+
   // call camera::Render()
   this->UpdateCamera();
 
@@ -351,10 +397,7 @@ void vtkMantaRenderer::DeviceRender()
   vtkTimerLog::MarkEndEvent("Geometry");
 
   vtkTimerLog::MarkStartEvent("Total LayerRender");
-  if ( this->EngineStarted )
-    {
-    this->LayerRender();
-    }
+  this->LayerRender();
   vtkTimerLog::MarkEndEvent("Total LayerRender");
 
   vtkTimerLog::MarkEndEvent("Manta Dev Render");
@@ -364,6 +407,10 @@ void vtkMantaRenderer::DeviceRender()
 // let the renderer display itself appropriately based on its layer index
 void vtkMantaRenderer::LayerRender()
 {
+  //TODO:
+  //this needs to be simplified. Now that UpdateSize happens before this
+  //vtk's size and manta's size should always be the same so the ugly
+  //conversion and minsize safety check should go away
   int     i, j;
   int     rowLength,  mantaSize[2];
   int     minWidth,   minHeight;
@@ -376,12 +423,6 @@ void vtkMantaRenderer::LayerRender()
   double* renViewport = NULL;
   const   Manta::SimpleImageBase* mantaBase = NULL;
 
-  vtkTimerLog::MarkStartEvent("ThreadSync");
-  // let the render threads draw what we've asked them to
-  this->GetSyncDisplay()->doneRendering();
-  this->GetSyncDisplay()->waitOnFrameReady();
-  vtkTimerLog::MarkEndEvent("ThreadSync");
-
   // collect some useful info
   renderSize = this->GetSize();
   renWinSize = this->GetRenderWindow()->GetActualSize();
@@ -389,29 +430,24 @@ void vtkMantaRenderer::LayerRender()
   renderPos0[0] = int( renViewport[0] * renWinSize[0] + 0.5f );
   renderPos0[1] = int( renViewport[1] * renWinSize[1] + 0.5f );
   this->GetSyncDisplay()->getCurrentImage()->
-        getResolution( stereoDumy, mantaSize[0], mantaSize[1] );
+    getResolution( stereoDumy, mantaSize[0], mantaSize[1] );
   mantaBase = dynamic_cast< const Manta::SimpleImageBase * >
-              ( this->GetSyncDisplay()->getCurrentImage() );
+    ( this->GetSyncDisplay()->getCurrentImage() );
   rowLength = mantaBase->getRowLength();
 
   // for window re-sizing
   minWidth    = ( mantaSize[0] < renderSize[0] )
-                ? mantaSize[0] : renderSize[0];
+    ? mantaSize[0] : renderSize[0];
   minHeight   = ( mantaSize[1] < renderSize[1] )
-                ? mantaSize[1] : renderSize[1];
+    ? mantaSize[1] : renderSize[1];
   hMantaDiff  = mantaSize[1] - minHeight;
   hRenderDiff = renderSize[1] - minHeight;
-  if (hMantaDiff != 0 || hRenderDiff != 0)
-    {
-/*
-    cerr << "MR(" << this << ") " 
-         << "Layer: " << this->GetLayer() << ", "
-         << "Props: " << this->NumberOfPropsRendered << endl
-         << "  MantaSize: " << mantaSize[0] << ", " << mantaSize[1] << ", "
-         << "  renWinSize: " << renWinSize[0] << ", " << renWinSize[1] << ", "
-         << "  renderSize: " << renderSize[0] << ", " << renderSize[1] << endl;
-*/
-    }
+
+  vtkTimerLog::MarkStartEvent("ThreadSync");
+  // let the render threads draw what we've asked them to
+  this->GetSyncDisplay()->doneRendering();
+  this->GetSyncDisplay()->waitOnFrameReady();
+  vtkTimerLog::MarkEndEvent("ThreadSync");
 
   // memory allocation and acess to the Manta image
   int size = renderSize[0]*renderSize[1];
@@ -431,8 +467,6 @@ void vtkMantaRenderer::LayerRender()
   double depthScale  = 1.0f / ( clipValues[1] - clipValues[0] );
 
   vtkTimerLog::MarkStartEvent("Image Conversion");
-  // This double for loop costs about 0.01 seconds per frames on the
-  // 8 cores machine. This can be fixed with RGBA8ZFloatP
   for ( j = 0; j < minHeight; j ++ )
     {
     // there are two floats in each pixel in Manta buffer
@@ -455,6 +489,67 @@ void vtkMantaRenderer::LayerRender()
       }
     }
 
+  // let layer #0 initialize GL depth buffer
+  if ( this->GetLayer() == 0 )
+    {
+    this->GetRenderWindow()->
+      SetZbufferData( renderPos0[0],  renderPos0[1],
+                      renderPos0[0] + renderSize[0] - 1,
+                      renderPos0[1] + renderSize[1] - 1,
+                      this->DepthBuffer );
+
+    this->GetRenderWindow()->
+      SetRGBACharPixelData( renderPos0[0],  renderPos0[1],
+                            renderPos0[0] + renderSize[0] - 1,
+                            renderPos0[1] + renderSize[1] - 1,
+                            (unsigned char*)this->ColorBuffer, 0, 0 );
+    glFinish();
+    }
+  else
+    {
+    //layers on top add the colors of their non background pixels
+    unsigned char*  GLbakBuffer = NULL;
+    GLbakBuffer = this->GetRenderWindow()->
+      GetRGBACharPixelData( renderPos0[0],  renderPos0[1],
+                            renderPos0[0] + renderSize[0] - 1,
+                            renderPos0[1] + renderSize[1] - 1, 0 );
+
+    bool anyhit = false;
+    unsigned char *optr = GLbakBuffer;
+    unsigned char *iptr = (unsigned char*)this->ColorBuffer;
+    float *zptr = this->DepthBuffer;
+    for ( j = 0; j < renderSize[1]; j++)
+    {
+      for ( i = 0; i < renderSize[0]; i++)
+        {
+        const float z = *zptr;
+        if (z > 0 && z < 1.0)
+          {
+          anyhit = true;
+          *(optr+0) = *(iptr+0);
+          *(optr+1) = *(iptr+1);
+          *(optr+2) = *(iptr+2);
+          *(optr+3) = *(iptr+3);
+          }
+        optr+=4;
+        iptr+=4;
+        zptr++;
+        }
+    }
+
+    if (anyhit)
+      {
+      // submit the modified RGB colors to GL BACK buffer
+      this->GetRenderWindow()->
+        SetRGBACharPixelData( renderPos0[0],  renderPos0[1],
+          renderPos0[0] + renderSize[0] - 1,
+          renderPos0[1] + renderSize[1] - 1,
+          GLbakBuffer, 0, 0 );
+      }
+
+    delete [] GLbakBuffer;
+    }
+
   //cerr << "MR(" << this << ") release" << endl;
   vtkTimerLog::MarkEndEvent("Image Conversion");
 
@@ -476,7 +571,8 @@ void vtkMantaRenderer::SetNumberOfWorkers( int newval )
   this->NumberOfWorkers = newval;
   this->MantaEngine->addTransaction
     ( "set max depth",
-      Manta::Callback::create(this, &vtkMantaRenderer::InternalSetNumberOfWorkers));
+      Manta::Callback::create
+      (this, &vtkMantaRenderer::InternalSetNumberOfWorkers));
   this->Modified();
 }
 
@@ -566,4 +662,3 @@ void vtkMantaRenderer::InternalSetMaxDepth()
 {
   this->MantaScene->getRenderParameters().setMaxDepth( this->MaxDepth );
 }
-
