@@ -113,6 +113,10 @@ pqPointSpriteDisplayPanelDecorator::pqPointSpriteDisplayPanelDecorator(
     return;
     }
 
+  // This is not advisable, but we do it nonetheless since that's what the old
+  // code was doing. At some point we need to clean this up.
+  vtkSMPointSpriteRepresentationProxy::InitializeDefaultValues(reprProxy);
+
   this->Internals = new pqInternals(this);
   QVBoxLayout* vlayout = dynamic_cast<QVBoxLayout*> (panel->layout());
   if (vlayout)
@@ -401,6 +405,7 @@ void pqPointSpriteDisplayPanelDecorator::onRadiusArrayChanged(
   svp->SetElement(4, name.toAscii().data()); //name
 
   this->Internals->TransferFunctionDialog->radiusEditor()->needReloadGUI();
+  this->Internals->ScaleBy->reloadGUI();
 
   reprProxy->UpdateVTKObjects();
   this->updateAllViews();
@@ -450,6 +455,7 @@ void pqPointSpriteDisplayPanelDecorator::onOpacityArrayChanged(
   svp->SetElement(4, name.toAscii().data()); //name
 
   this->Internals->TransferFunctionDialog->opacityEditor()->needReloadGUI();
+  this->Internals->OpacityBy->reloadGUI();
 
   reprProxy->UpdateVTKObjects();
   this->updateAllViews();
