@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: PrismDisplayPanelsImplementation.h,v $
+   Module:    PrismDisplayPanelsImplementation.h
 
 =========================================================================*/
 #ifndef _PrismDisplayPanelsImplementation_h
