@@ -62,6 +62,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMIntVectorProperty.h"
 #include "vtkSMInputProperty.h"
 #include "vtkSMProxyManager.h"
+#include "vtkSMPropertyHelper.h"
 
 // ParaView widget includes
 #include "pqSignalAdaptors.h"
@@ -85,6 +86,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqObjectBuilder.h"
 #include "PrismCubeAxesEditorDialog.h"
 
+#include "PrismCore.h"
 class PrismDisplayProxyEditorInternal : public Ui::PrismDisplayProxyEditor
 {
 public:
@@ -153,103 +155,47 @@ PrismDisplayProxyEditor::PrismDisplayProxyEditor(pqPipelineRepresentation* repr,
     this, SLOT(volumeBlockSelected()));
 
   this->DisableSpecularOnScalarColoring = true;
-
-
-
-  this->CubeAxesActor = NULL;
   this->Representation= repr;
 
-  pqApplicationCore* core = pqApplicationCore::instance();
-  pqObjectBuilder* builder = core->getObjectBuilder();
-  pqServer* server = this->getActiveServer();
-  if(!server)
+  this->CubeAxesActor=NULL;
+  PrismCore* core=PrismCore::instance();
+
+  QMap<pqDataRepresentation*,vtkSMPrismCubeAxesRepresentationProxy*>::iterator iter;
+  iter=core->CubeAxesRepMap.find(repr);
+  if(iter!=core->CubeAxesRepMap.end())
   {
-    qCritical() << "Cannot create reader without an active server.";
-    return ;
-  }
 
-  this->CubeAxesActor=vtkSMPrismCubeAxesRepresentationProxy::SafeDownCast(builder->createProxy("props",
-    "PrismCubeAxesRepresentation", server,
-    "props"));
+    this->CubeAxesActor =iter.value();
 
 
-  vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(
-    this->CubeAxesActor->GetProperty("Input"));
-  vtkSMInputProperty* ip = vtkSMInputProperty::SafeDownCast(pp);
-  if (!pp)
-  {
-    vtkErrorWithObjectMacro(this->CubeAxesActor,"Failed to locate property " << "Input"
-      << " on the consumer " <<  (this->CubeAxesActor->GetXMLName()));
-    return;
-  }
 
-  if (ip)
-  {
-    ip->RemoveAllProxies();
-    ip->AddInputConnection(repr->getInput()->getProxy(),repr->getOutputPortFromInput()->getPortNumber() );
-  }
-  else
-  {
-    pp->RemoveAllProxies();
-    pp->AddProxy(repr->getInput()->getProxy());
-  }
-  this->CubeAxesActor->UpdateProperty("Input");
+    vtkSMProperty* prop = 0;
 
 
-  vtkSMProperty* prop = 0;
-
-
-  if ((prop = this->CubeAxesActor->GetProperty("Visibility")) != 0)
+    if ((prop = this->CubeAxesActor->GetProperty("Visibility")) != 0)
     {
-     QObject::connect(this->Internal->ShowCubeAxes, SIGNAL(toggled(bool)),
-       this, SLOT(cubeAxesVisibilityChanged()));
+      QObject::connect(this->Internal->ShowCubeAxes, SIGNAL(toggled(bool)),
+        this, SLOT(cubeAxesVisibilityChanged()));
 
-     //needed so the undo / redo properly activate the checkbox
-     this->Internal->Links->addPropertyLink(this->Internal->ShowCubeAxes,
-    "checked", SIGNAL(stateChanged(int)),
-    this->CubeAxesActor,  this->CubeAxesActor->GetProperty("Visibility"));
-    this->Internal->AnnotationGroup->show();
+      //needed so the undo / redo properly activate the checkbox
+      this->Internal->Links->addPropertyLink(this->Internal->ShowCubeAxes,
+        "checked", SIGNAL(stateChanged(int)),
+        this->CubeAxesActor,  this->CubeAxesActor->GetProperty("Visibility"));
+      this->Internal->AnnotationGroup->show();
     }
-  else
+    else
     {
-    this->Internal->AnnotationGroup->hide();
+      this->Internal->AnnotationGroup->hide();
     }
 
 
-  pqRenderView * view= qobject_cast<pqRenderView*>(this->Representation->getView());
-  if(view)
-  {
-    vtkSMViewProxy* renv= view->getViewProxy();
-    renv->AddRepresentation(this->CubeAxesActor);
   }
-
 }
 
 //-----------------------------------------------------------------------------
 /// destructor
 PrismDisplayProxyEditor::~PrismDisplayProxyEditor()
 {
-
-
-
-  if (this->CubeAxesActor)
-  {
-
-    pqRenderView * view= qobject_cast<pqRenderView*>(this->Representation->getView());
-    if(view)
-    {
-      vtkSMViewProxy* renv= view->getViewProxy();
-      renv->RemoveRepresentation(this->CubeAxesActor);
-      view->getProxy()->UpdateVTKObjects();
-    }
-
-
-
-    vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
-    pxm->UnRegisterProxy(this->CubeAxesActor->GetXMLGroup(),this->CubeAxesActor->GetClassName(),this->CubeAxesActor);
-  }
-
-
   delete this->Internal;
 }
 
@@ -883,14 +829,13 @@ void PrismDisplayProxyEditor::updateEnableState()
     this->Internal->BackfaceStyleGroupOptions->setEnabled(!backFollowsFront);
     }
 
-  vtkSMDataRepresentationProxy* display =
+  vtkSMRepresentationProxy* display =
     this->Internal->Representation->getRepresentationProxy();
   if (display)
     {
     QVariant scalarMode = pqSMAdaptor::getEnumerationProperty(
       display->GetProperty("ColorAttributeType"));
-    vtkPVDataInformation* geomInfo =
-      display->GetRepresentedDataInformation(/*update=*/false);
+    vtkPVDataInformation* geomInfo = display->GetRepresentedDataInformation();
     if (!geomInfo)
       {
       return;
@@ -953,18 +898,13 @@ void PrismDisplayProxyEditor::zoomToData()
     return;
     }
 
-  double bounds[6];
-  this->Internal->Representation->getRepresentationProxy()->GetBounds(bounds);
-  if (bounds[0]<=bounds[1] && bounds[2]<=bounds[3] && bounds[4]<=bounds[5])
+  pqRenderView* renModule = qobject_cast<pqRenderView*>(
+    this->Internal->Representation->getView());
+  if (renModule)
     {
-    pqRenderView* renModule = qobject_cast<pqRenderView*>(
-      this->Internal->Representation->getView());
-    if (renModule)
-      {
-      vtkSMRenderViewProxy* rm = renModule->getRenderViewProxy();
-      rm->ResetCamera(bounds);
-      renModule->render();
-      }
+    vtkSMRenderViewProxy* rm = renModule->getRenderViewProxy();
+    rm->ZoomTo(this->Internal->Representation->getProxy());
+    renModule->render();
     }
 }
 
@@ -1063,8 +1003,10 @@ void PrismDisplayProxyEditor::updateMaterial(int vtkNotUsed(idx))
 //-----------------------------------------------------------------------------
 void PrismDisplayProxyEditor::cubeAxesVisibilityChanged()
 {
-  this->CubeAxesActor->SetCubeAxesVisibility(this->isCubeAxesVisible());
+  vtkSMPropertyHelper(this->CubeAxesActor, "Visibility").Set(this->isCubeAxesVisible());
+  this->CubeAxesActor->UpdateVTKObjects();
   this->Representation->renderViewEventually();
+//this->updateAllViews();
 
 
   //vtkSMProxy* reprProxy = (this->Internal->Representation)? this->Internal->Representation->getProxy() : NULL;
@@ -1123,7 +1065,7 @@ void PrismDisplayProxyEditor::volumeBlockSelected()
       this->Internal->CompositeTreeAdaptor->getCurrentFlatIndex(&valid);
     if (valid && selectedIndex > 0)
       {
-      vtkSMDataRepresentationProxy* repr =
+      vtkSMRepresentationProxy* repr =
         this->Internal->Representation->getRepresentationProxy();
       pqSMAdaptor::setElementProperty(
         repr->GetProperty("ExtractedBlockIndex"), selectedIndex);
