@@ -28,6 +28,10 @@ Module:    vtkPrismFilter.cxx
 #include "vtkCompositeDataIterator.h"
 #include "vtkTransformFilter.h"
 #include "vtkTransform.h"
+#include "vtkExtractGeometry.h"
+#include "vtkBox.h"
+#include "vtkDataObject.h"
+
 #include <math.h>
 
 vtkStandardNewMacro(vtkPrismFilter);
@@ -36,12 +40,17 @@ class vtkPrismFilter::MyInternal
 {
 public:
 
+    bool SimulationDataThreshold;
+
+    vtkSmartPointer<vtkExtractGeometry > ExtractGeometry;
+    vtkSmartPointer<vtkBox> Box;
     vtkSmartPointer<vtkTransformFilter> TransformFilter;
     vtkPrismSurfaceReader *Reader;
     vtkSmartPointer<vtkDoubleArray> RangeArray;
     vtkstd::string AxisVarName[3];
     MyInternal()
     {
+        this->SimulationDataThreshold=false;
         this->RangeArray = vtkSmartPointer<vtkDoubleArray>::New();
         this->RangeArray->Initialize();
         this->RangeArray->SetNumberOfComponents(1);
@@ -54,6 +63,15 @@ public:
 
         this->TransformFilter=vtkSmartPointer<vtkTransformFilter>::New(); 
 
+
+        this->ExtractGeometry=vtkSmartPointer<vtkExtractGeometry >::New();
+
+        this->Box=  vtkSmartPointer<vtkBox>::New();
+        this->ExtractGeometry->SetImplicitFunction(this->Box);
+        this->ExtractGeometry->ExtractInsideOn();
+        this->ExtractGeometry->ExtractBoundaryCellsOn();
+
+
     }
     ~MyInternal()
     {
@@ -71,9 +89,24 @@ vtkPrismFilter::vtkPrismFilter()
     this->Internal = new MyInternal();
 
     this->SetNumberOfInputPorts(1);
-    this->SetNumberOfOutputPorts(3);
+    this->SetNumberOfOutputPorts(4);
 
 }
+vtkPrismFilter::~vtkPrismFilter()
+{
+  delete this->Internal;
+}
+
+void vtkPrismFilter::SetSimulationDataThreshold(bool b)
+{
+    this->Internal->SimulationDataThreshold=b;
+    this->Modified();
+}
+
+bool vtkPrismFilter::GetSimulationDataThreshold()
+{
+    return this->Internal->SimulationDataThreshold;
+}
 
 unsigned long vtkPrismFilter::GetMTime()
 {
@@ -275,19 +308,306 @@ int vtkPrismFilter::RequestSESAMEData(
     vtkPointSet *input= this->Internal->Reader->GetOutput(0);
     output->ShallowCopy(input);
 
+    vtkInformation *curveOutInfo = outputVector->GetInformationObject(1);
+    vtkPointSet *curveOutput = vtkPointSet::SafeDownCast(
+        curveOutInfo->Get(vtkDataObject::DATA_OBJECT()));
+
+    vtkPointSet *curveInput= this->Internal->Reader->GetOutput(1);
+    curveOutput->ShallowCopy(curveInput);
 
 
-    vtkInformation *contourOutInfo = outputVector->GetInformationObject(1);
+    vtkInformation *contourOutInfo = outputVector->GetInformationObject(2);
     vtkPointSet *contourOutput = vtkPointSet::SafeDownCast(
         contourOutInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-
-    contourOutput->ShallowCopy(this->Internal->Reader->GetOutput(1));
+    contourOutput->ShallowCopy(this->Internal->Reader->GetOutput(2));
 
 
 
     return 1;
 }
+
+int vtkPrismFilter::CreateGeometry(vtkDataSet *inputData,
+                                   unsigned int index,
+                                   vtkMultiBlockDataSet *output)
+{
+
+  double weight       = 0.0;
+  double *weights     = NULL;
+  vtkIdType cellId, ptId;
+  vtkIdType numCells, numPts;
+  vtkIdList *cellPts  = NULL;
+  vtkDataArray *inputScalars[3];
+
+
+  vtkSmartPointer<vtkPolyData> polydata = vtkSmartPointer<vtkPolyData>::New();
+  // construct new points at the centers of the cells
+  vtkPoints *newPoints = vtkPoints::New();
+
+
+  vtkPointData  *outPD = polydata->GetPointData();
+  vtkCellData  *outCD = polydata->GetCellData();
+  vtkPointData *inPD  = inputData->GetPointData();
+  vtkCellData  *inCD  = inputData->GetCellData();
+  int maxCellSize     = inputData->GetMaxCellSize();
+
+  vtkDebugMacro( << "Mapping point data to new cell center point..." );
+
+  bool isCellData[3]={true,true,true};
+
+
+  inputScalars[0] = inCD->GetScalars( this->GetXAxisVarName() );
+  if(!inputScalars[0])
+  {
+    inputScalars[0] = inPD->GetScalars( this->GetXAxisVarName() );
+    if(inputScalars[0])
+    {
+      isCellData[0]=false;
+    }
+  }
+  inputScalars[1] = inCD->GetScalars( this->GetYAxisVarName() );
+  if(!inputScalars[1])
+  {
+    inputScalars[1] = inPD->GetScalars( this->GetYAxisVarName() );
+    if(inputScalars[1])
+    {
+      isCellData[1]=false;
+    }
+  }
+  inputScalars[2] = inCD->GetScalars( this->GetZAxisVarName() );
+  if(!inputScalars[2])
+  {
+    inputScalars[2] = inPD->GetScalars( this->GetZAxisVarName() );
+    if(inputScalars[2])
+    {
+      isCellData[2]=false;
+    }
+  }
+
+  vtkIdType newIDs[1] = {0};
+  if ( (numCells=inputData->GetNumberOfCells()) < 1 )
+  {
+    vtkDebugMacro(<< "No input cells, nothing to do." );
+    return 0;
+  }
+
+  if(!isCellData[0] && !isCellData[1] && !isCellData[2])
+  {
+    //All Point Data.
+    weights = new double[maxCellSize];
+    cellPts = vtkIdList::New();
+    cellPts->Allocate( maxCellSize );
+
+    // Pass cell data (note that this passes current cell data through to the
+    // new points that will be created at the cell centers)
+    outCD->PassData( inCD );
+
+    // create space for the newly interpolated values
+    outPD->CopyAllocate( inPD,numCells );
+
+    int abort=0;
+    //double funcArgs[3]  = { 0.0, 0.0, 0.0 };
+    double newPt[3] = {0.0, 0.0, 0.0};
+    vtkIdType progressInterval=numCells/20 + 1;
+    polydata->Allocate( numCells );
+    for ( cellId=0; cellId < numCells && !abort; cellId++ )
+    {
+      if ( !(cellId % progressInterval) )
+      {
+        this->UpdateProgress( (double)cellId/numCells );
+        abort = GetAbortExecute();
+      }
+
+      inputData->GetCellPoints( cellId, cellPts );
+      numPts = cellPts->GetNumberOfIds();
+      if ( numPts > 0 )
+      {
+        weight = 1.0 / numPts;
+        for (ptId=0; ptId < numPts; ptId++)
+        {
+          weights[ptId] = weight;
+        }
+        outPD->InterpolatePoint(inPD, cellId, cellPts, weights);
+      }
+
+      inputScalars[0] = outPD->GetScalars( this->GetXAxisVarName() );
+      inputScalars[1] = outPD->GetScalars( this->GetYAxisVarName() );
+      inputScalars[2] = outPD->GetScalars( this->GetZAxisVarName() );
+
+
+      newPt[0] = inputScalars[0]->GetTuple1( cellId );
+      newPt[1] = inputScalars[1]->GetTuple1( cellId );
+      newPt[2] = inputScalars[2]->GetTuple1( cellId );
+      newIDs[0] = newPoints->InsertNextPoint( newPt );
+
+
+      polydata->InsertNextCell( VTK_VERTEX, 1, newIDs );
+    }
+  }
+  else if(isCellData[0] && isCellData[1] && isCellData[2])
+  {
+    //All Cell Data.
+
+    weights = new double[maxCellSize];
+    cellPts = vtkIdList::New();
+    cellPts->Allocate( maxCellSize );
+
+    // Pass cell data (note that this passes current cell data through to the
+    // new points that will be created at the cell centers)
+    outCD->PassData( inCD );
+
+    // create space for the newly interpolated values
+    outPD->CopyAllocate( inPD,numCells );
+
+    int abort=0;
+    //double funcArgs[3]  = { 0.0, 0.0, 0.0 };
+    double newPt[3] = {0.0, 0.0, 0.0};
+    vtkIdType progressInterval=numCells/20 + 1;
+    polydata->Allocate( numCells );
+    for ( cellId=0; cellId < numCells && !abort; cellId++ )
+    {
+      if ( !(cellId % progressInterval) )
+      {
+        this->UpdateProgress( (double)cellId/numCells );
+        abort = GetAbortExecute();
+      }
+
+      inputData->GetCellPoints( cellId, cellPts );
+      numPts = cellPts->GetNumberOfIds();
+      if ( numPts > 0 )
+      {
+        weight = 1.0 / numPts;
+        for (ptId=0; ptId < numPts; ptId++)
+        {
+          weights[ptId] = weight;
+        }
+        outPD->InterpolatePoint(inPD, cellId, cellPts, weights);
+      }
+
+
+      newPt[0] = inputScalars[0]->GetTuple1( cellId );
+      newPt[1] = inputScalars[1]->GetTuple1( cellId );
+      newPt[2] = inputScalars[2]->GetTuple1( cellId );
+      newIDs[0] = newPoints->InsertNextPoint( newPt );
+
+
+      polydata->InsertNextCell( VTK_VERTEX, 1, newIDs );
+    }
+
+  }
+  else
+  {
+    //Mixed input array types between cell and point. We can't handle this right now.
+    vtkDebugMacro(<< "Error: Prism can't handle mixed cell and point data" );
+    return 0;
+
+  }
+
+  vtkIdType pointId;
+  vtkIdType numberPts = newPoints->GetNumberOfPoints();
+
+
+  for(pointId=0;pointId<numberPts;pointId++)
+  {
+
+    double coords[3];
+
+    newPoints->GetPoint(pointId,coords);
+
+
+    int tID=this->GetTable();
+    if(tID==502 ||
+      tID==503 ||
+      tID==504 ||
+      tID==505 ||
+      tID==601 ||
+      tID==602 ||
+      tID==603 ||
+      tID==604 ||
+      tID==605)
+    {
+      if(!this->GetSESAMEXLogScaling())
+      {
+      coords[0]=pow(10.0,coords[0]);
+      }
+
+      if(!this->GetSESAMEYLogScaling())
+      {
+        coords[1]=pow(10.0,coords[1]);
+      }
+
+      if(!this->GetSESAMEZLogScaling())
+      {
+        coords[2]=pow(10.0,coords[2]);
+      }
+    }
+    else
+    {
+      if(this->GetSESAMEXLogScaling())
+      {
+        if(coords[0]>0)
+        {
+          coords[0]=log(coords[0]);
+        }
+        else
+        {
+          coords[0]=0.0;
+        }
+      }
+
+      if(this->GetSESAMEYLogScaling())
+      {
+        if(coords[1]>0)
+        {
+          coords[1]=log(coords[1]);
+        }
+        else
+        {
+          coords[1]=0.0;
+        }
+      }
+
+      if(this->GetSESAMEZLogScaling())
+      {
+        if(coords[2]>0)
+        {
+          coords[2]=log(coords[2]);
+        }
+        else
+        {
+          coords[2]=0.0;
+        }
+      }
+    }
+
+    newPoints->InsertPoint(pointId,coords);
+
+  }
+
+  polydata->SetPoints( newPoints );
+  newPoints->Delete();
+  polydata->Squeeze();
+  cellPts->Delete();
+  delete [] weights;
+
+
+  this->Internal->TransformFilter->SetInput(polydata);
+
+
+
+  double scale[3];
+  this->Internal->Reader->GetAspectScale(scale);
+  vtkSmartPointer<vtkTransform> transform= vtkSmartPointer<vtkTransform>::New();
+  transform->Scale(scale);
+  this->Internal->TransformFilter->SetTransform(transform);
+  this->Internal->TransformFilter->Update();
+
+  polydata->ShallowCopy(this->Internal->TransformFilter->GetOutput());
+
+  output->SetBlock(index,polydata);
+
+  return 1;
+}
 int vtkPrismFilter::RequestGeometryData(
                                         vtkInformation *vtkNotUsed(request),
                                         vtkInformationVector **inputVector,
@@ -299,9 +619,7 @@ int vtkPrismFilter::RequestGeometryData(
         return 1;
     }
 
-
-
-    vtkInformation *info = outputVector->GetInformationObject(2);
+    vtkInformation *info = outputVector->GetInformationObject(3);
     vtkMultiBlockDataSet *output = vtkMultiBlockDataSet::SafeDownCast(
         info->Get(vtkDataObject::DATA_OBJECT()));
     if ( !output ) 
@@ -311,184 +629,43 @@ int vtkPrismFilter::RequestGeometryData(
     }
 
     vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-    vtkMultiBlockDataSet *input = vtkMultiBlockDataSet::SafeDownCast(
-        inInfo->Get(vtkDataObject::DATA_OBJECT()));
-    if ( !input ) 
-    {
-        vtkDebugMacro( << "No input found." );
-        return 0;
-    }
-
-
-    double weight       = 0.0;
-    double *weights     = NULL;
-    vtkIdType cellId, ptId;
-    vtkIdType numCells, numPts;
-    vtkIdList *cellPts  = NULL;
-    vtkDataArray *inputScalars[3];
-
-    unsigned int j=0;
-    vtkCompositeDataIterator* iter= input->NewIterator();
-    iter->SkipEmptyNodesOn();
-    iter->TraverseSubTreeOn();
-    iter->VisitOnlyLeavesOn();
-    iter->GoToFirstItem();
-    while(!iter->IsDoneWithTraversal())
+    vtkMultiBlockDataSet *inputMB = vtkMultiBlockDataSet::SafeDownCast(
+      inInfo->Get(vtkDataObject::DATA_OBJECT()));
+    if (inputMB )
     {
+      unsigned int j=0;
+      vtkCompositeDataIterator* iter= inputMB->NewIterator();
+      iter->SkipEmptyNodesOn();
+      iter->TraverseSubTreeOn();
+      iter->VisitOnlyLeavesOn();
+      iter->GoToFirstItem();
+      while(!iter->IsDoneWithTraversal())
+      {
         vtkDataSet *inputData=NULL;
         inputData=vtkDataSet::SafeDownCast(iter->GetCurrentDataObject());
         iter->GoToNextItem();
         if(inputData)
         {
-            vtkSmartPointer<vtkPolyData> polydata = vtkSmartPointer<vtkPolyData>::New(); 
-
-            vtkPointData  *outPD = polydata->GetPointData();
-            vtkCellData  *outCD = polydata->GetCellData();
-            vtkPointData *inPD  = inputData->GetPointData();
-            vtkCellData  *inCD  = inputData->GetCellData();
-            int maxCellSize     = inputData->GetMaxCellSize();
-
-            vtkDebugMacro( << "Mapping point data to new cell center point..." );
-
-            // construct new points at the centers of the cells 
-            vtkPoints *newPoints = vtkPoints::New();
-
-            inputScalars[0] = inCD->GetScalars( this->GetXAxisVarName() );
-            inputScalars[1] = inCD->GetScalars( this->GetYAxisVarName() );
-            inputScalars[2] = inCD->GetScalars( this->GetZAxisVarName() );
-
-            vtkIdType newIDs[1] = {0};
-            if ( (numCells=inputData->GetNumberOfCells()) < 1 )
-            {
-                vtkDebugMacro(<< "No input cells, nothing to do." );
-                return 0;
-            }
-
-            weights = new double[maxCellSize];
-            cellPts = vtkIdList::New();
-            cellPts->Allocate( maxCellSize );
-
-            // Pass cell data (note that this passes current cell data through to the
-            // new points that will be created at the cell centers)
-            outCD->PassData( inCD );
-
-            // create space for the newly interpolated values
-            outPD->CopyAllocate( inPD,numCells );
-
-            int abort=0;
-            //double funcArgs[3]  = { 0.0, 0.0, 0.0 };
-            double newPt[3] = {0.0, 0.0, 0.0};
-            vtkIdType progressInterval=numCells/20 + 1;
-            polydata->Allocate( numCells ); 
-            for ( cellId=0; cellId < numCells && !abort; cellId++ )
-            {
-                if ( !(cellId % progressInterval) )
-                {
-                    this->UpdateProgress( (double)cellId/numCells );
-                    abort = GetAbortExecute();
-                }
-
-                inputData->GetCellPoints( cellId, cellPts );
-                numPts = cellPts->GetNumberOfIds();
-                if ( numPts > 0 )
-                {
-                    weight = 1.0 / numPts;
-                    for (ptId=0; ptId < numPts; ptId++)
-                    {
-                        weights[ptId] = weight;
-                    }
-                    outPD->InterpolatePoint(inPD, cellId, cellPts, weights);
-                }
-
-
-                newPt[0] = inputScalars[0]->GetTuple1( cellId );
-                newPt[1] = inputScalars[1]->GetTuple1( cellId );
-                newPt[2] = inputScalars[2]->GetTuple1( cellId );
-                newIDs[0] = newPoints->InsertNextPoint( newPt );
-
-
-                polydata->InsertNextCell( VTK_VERTEX, 1, newIDs );
-            }
-
-            vtkIdType pointId;
-            vtkIdType numberPts = newPoints->GetNumberOfPoints();
-
-
-            for(pointId=0;pointId<numberPts;pointId++)
-            {
-
-              double coords[3];
-
-              newPoints->GetPoint(pointId,coords);
-
-
-              if(this->GetSESAMEXLogScaling())
-              {
-                if(coords[0]>0)
-                {
-                  coords[0]=log(coords[0]);
-                }
-                else
-                {
-                  coords[0]=0.0;
-                }
-              }
-
-              if(this->GetSESAMEYLogScaling())
-              {
-                if(coords[1]>0)
-                {
-                  coords[1]=log(coords[1]);
-                }
-                else
-                {
-                  coords[1]=0.0;
-                }
-              }
-
-              if(this->GetSESAMEZLogScaling())
-              {
-                if(coords[2]>0)
-                {
-                  coords[2]=log(coords[2]);
-                }
-                else
-                {
-                  coords[2]=0.0;
-                }
-              }
-
-              newPoints->InsertPoint(pointId,coords);
-
-            }
-
-            polydata->SetPoints( newPoints );
-            newPoints->Delete();
-            polydata->Squeeze();
-            cellPts->Delete();
-            delete [] weights;
-
-
-            double scale[3];
-            this->Internal->Reader->GetAspectScale(scale);
-            vtkSmartPointer<vtkTransform> transform= vtkSmartPointer<vtkTransform>::New();
-            transform->Scale(scale);
-            this->Internal->TransformFilter->SetTransform(transform);
-            this->Internal->TransformFilter->SetInput(polydata);
-            this->Internal->TransformFilter->Update();
-
-            polydata->ShallowCopy(this->Internal->TransformFilter->GetOutput());
-
-            output->SetBlock(j,polydata);
-            j++;
-
-
-
+          this->CreateGeometry(inputData,j,output);
+          j++;
         }
+      }
+      iter->Delete();
+      return 1;
     }
 
-    iter->Delete();
-
+    vtkDataSet *inputDS = vtkDataSet::SafeDownCast(
+      inInfo->Get(vtkDataObject::DATA_OBJECT()));
+    if(inputDS)
+    {
+      this->CreateGeometry(inputDS,0,output);
+      return 1;
+    }
+    else
+    {
+        vtkDebugMacro( << "Incorrect input type." );
+        return 0;
+    }
     return 1;
 }
 
@@ -536,25 +713,37 @@ const char * vtkPrismFilter::GetZAxisVarName()
 int vtkPrismFilter::FillOutputPortInformation(
     int port, vtkInformation* info)
 {
-    if(port==0)
-    {
-        // now add our info
-        info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
-    }
-       if(port==1)
-    {
-        // now add our info
-        info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
-    }
-    if(port==2)
-    {
-        info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkMultiBlockDataSet");
-    }
+  if(port==0)
+  {
+    // now add our info
+    info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
+  }
+  if(port==1)
+  {
+    // now add our info
+    info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
+  }
+  if(port==2)
+  {
+    // now add our info
+    info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
+  }
+  if(port==3)
+  {
+    info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkMultiBlockDataSet");
+  }
 
     return 1;
 }
 
-
+//----------------------------------------------------------------------------
+int vtkPrismFilter::FillInputPortInformation(
+  int vtkNotUsed(port), vtkInformation* info)
+{
+  // now add our info
+  info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataObject");
+  return 1;
+}
 //----------------------------------------------------------------------------
 void vtkPrismFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -595,6 +784,45 @@ const char* vtkPrismFilter::GetSESAMEZAxisVarName()
     return this->Internal->Reader->GetZAxisVarName();
 }
 
+void vtkPrismFilter::SetShowCold(bool b)
+{
+  this->Internal->Reader->SetShowCold(b);
+  this->Modified();
+
+}
+void vtkPrismFilter::SetShowVaporization(bool b)
+{
+  this->Internal->Reader->SetShowVaporization(b);
+  this->Modified();
+
+}
+void vtkPrismFilter::SetShowSolidMelt(bool b)
+{
+  this->Internal->Reader->SetShowSolidMelt(b);
+  this->Modified();
+}
+void vtkPrismFilter::SetShowLiquidMelt(bool b)
+{
+  this->Internal->Reader->SetShowLiquidMelt(b);
+  this->Modified();
+}
+bool vtkPrismFilter::GetShowCold()
+{
+  return this->Internal->Reader->GetShowCold();
+}
+bool vtkPrismFilter::GetShowVaporization()
+{
+  return this->Internal->Reader->GetShowVaporization();
+}
+bool vtkPrismFilter::GetShowSolidMelt()
+{
+  return this->Internal->Reader->GetShowSolidMelt();
+
+}
+bool vtkPrismFilter::GetShowLiquidMelt()
+{
+  return this->Internal->Reader->GetShowLiquidMelt();
+}
 
 void vtkPrismFilter::SetSESAMEXLogScaling(bool b)
 {
@@ -626,25 +854,33 @@ bool vtkPrismFilter::GetSESAMEZLogScaling()
     return this->Internal->Reader->GetZLogScaling();
 }
 
-
-void vtkPrismFilter::SetSESAMEConversions(double d,double t,double p,double e)
+void vtkPrismFilter::SetSESAMEVariableConversionValues(int i, double value)
 {
-    this->Internal->Reader->SetConversions(d,t,p,e);
+  this->Internal->Reader->SetVariableConversionValues(i,value);
+    this->Modified();
+}
+void vtkPrismFilter::SetNumberOfSESAMEVariableConversionValues(int v)
+{
+  this->Internal->Reader->SetNumberOfVariableConversionValues(v);
+}
+double vtkPrismFilter::GetSESAMEVariableConversionValue(int i)
+{
+  return this->Internal->Reader->GetVariableConversionValue(i);
 }
 
-double* vtkPrismFilter::GetSESAMEConversions()
+void vtkPrismFilter::AddSESAMEVariableConversionNames(char*  value)
 {
-    return this->Internal->Reader->GetConversions();
+  this->Internal->Reader->AddVariableConversionNames(value);
+    this->Modified();
 }
-
-void vtkPrismFilter::GetSESAMEConversions (double &_arg1, double &_arg2,double &_arg3,double &_arg4)
+void vtkPrismFilter::RemoveAllSESAMEVariableConversionNames()
 {
-    return this->Internal->Reader->GetConversions(_arg1,_arg2,_arg3,_arg4);
+  this->Internal->Reader->RemoveAllVariableConversionNames();
+    this->Modified();
 }
-
-void vtkPrismFilter::GetSESAMEConversions (double _arg[4])
+const char * vtkPrismFilter::GetSESAMEVariableConversionName(int i)
 {
-    this->Internal->Reader->GetConversions(_arg);
+  return this->Internal->Reader->GetVariableConversionName(i);
 }
 
 vtkDoubleArray* vtkPrismFilter:: GetSESAMEXRange()
