@@ -81,6 +81,18 @@ public:
         }
       }
     }
+
+  void removeProxy(const QString& pgroup, const QString& pname)
+    {
+    if (!pname.isEmpty() && !pgroup.isEmpty())
+      {
+      QPair<QString, QString> pair(pgroup, pname);
+      if (this->Proxies.contains(pair) )
+        {
+        this->Proxies.remove(pair);
+        }
+      }
+    }
  
   // Proxies and Categories is what gets shown in the menu.
   ProxyInfoMap Proxies;
@@ -118,6 +130,14 @@ void pqProxyGroupMenuManager::addProxy(
     xmlname.toAscii().data(), QString());
 }
 
+//-----------------------------------------------------------------------------
+void pqProxyGroupMenuManager::removeProxy(
+  const QString& xmlgroup, const QString& xmlname)
+{
+  this->Internal->removeProxy(xmlgroup.toAscii().data(),
+    xmlname.toAscii().data());
+}
+
 //-----------------------------------------------------------------------------
 namespace
 {
@@ -325,13 +345,11 @@ void pqProxyGroupMenuManager::populateMenu()
     }
   _menu->clear();
 
-//#ifdef Q_WS_MAC
-//  _menu->addAction("Search...", this, SLOT(quickLaunch()),
-//    QKeySequence(Qt::Key_Space | Qt::ALT));
-//#else
-//  _menu->addAction("Search...", this, SLOT(quickLaunch()),
-//    QKeySequence(Qt::Key_Space | Qt::CTRL));
-//#endif
+#ifdef Q_WS_MAC
+  _menu->addAction("Search...\tAlt+Space", this, SLOT(quickLaunch()));
+#else
+  _menu->addAction("Search...\tCtrl+Space", this, SLOT(quickLaunch()));
+#endif
 
   if (this->RecentlyUsedMenuSize > 0)
     {
