@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqCloseViewUndoElement.h,v $
+   Module:    pqCloseViewUndoElement.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -47,7 +47,7 @@ class VTK_EXPORT pqCloseViewUndoElement : public vtkSMUndoElement
 {
 public:
   static pqCloseViewUndoElement* New();
-  vtkTypeRevisionMacro(pqCloseViewUndoElement, vtkSMUndoElement);
+  vtkTypeMacro(pqCloseViewUndoElement, vtkSMUndoElement);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   /// Description:
