@@ -210,6 +210,11 @@ void pqDisplayProxyEditor::setRepresentation(pqPipelineRepresentation* repr)
     {
      QObject::connect(this->Internal->ShowCubeAxes, SIGNAL(toggled(bool)),
        this, SLOT(cubeAxesVisibilityChanged()));
+     
+     //needed so the undo / redo properly activate the checkbox
+     this->Internal->Links->addPropertyLink(this->Internal->ShowCubeAxes,
+    "checked", SIGNAL(stateChanged(int)),
+    reprProxy, reprProxy->GetProperty("CubeAxesVisibility"));
     this->Internal->AnnotationGroup->show();
     }
   else
@@ -385,6 +390,15 @@ void pqDisplayProxyEditor::setRepresentation(pqPipelineRepresentation* repr)
     "value", SIGNAL(editingFinished()),
     reprProxy, reprProxy->GetProperty("Opacity"));
 
+  // setup of nonlinear subdivision
+  if (reprProxy->GetProperty("NonlinearSubdivisionLevel"))
+    {
+    this->Internal->Links->addPropertyLink(
+                this->Internal->NonlinearSubdivisionLevel,
+                "value", SIGNAL(valueChanged(int)),
+                reprProxy, reprProxy->GetProperty("NonlinearSubdivisionLevel"));
+    }
+
   // setup for map scalars
   this->Internal->Links->addPropertyLink(
     this->Internal->ColorMapScalars, "checked", SIGNAL(stateChanged(int)),
@@ -461,19 +475,19 @@ void pqDisplayProxyEditor::setRepresentation(pqPipelineRepresentation* repr)
         pqSignalAdaptorCompositeTreeWidget::INDEX_MODE_FLAT, false, true);
     }
 
-  if (reprProxy->GetProperty("SelectedMapperIndex"))
+  if (reprProxy->GetProperty("SelectMapper"))
     {
     QList<QVariant> mapperNames =
       pqSMAdaptor::getEnumerationPropertyDomain(
-        reprProxy->GetProperty("SelectedMapperIndex"));
+        reprProxy->GetProperty("SelectMapper"));
     foreach(QVariant item, mapperNames)
       {
-      this->Internal->SelectedMapperIndex->addItem(item.toString());
+      this->Internal->SelectMapper->addItem(item.toString());
       }
     this->Internal->Links->addPropertyLink(
       this->Internal->SelectedMapperAdaptor,
       "currentText", SIGNAL(currentTextChanged(const QString&)),
-      reprProxy, reprProxy->GetProperty("SelectedMapperIndex"));
+      reprProxy, reprProxy->GetProperty("SelectMapper"));
     }
 
   this->Internal->BackfaceStyleRepresentation->clear();
@@ -677,7 +691,7 @@ void pqDisplayProxyEditor::setupGUIConnections()
     this, SLOT(sliceDirectionChanged()), Qt::QueuedConnection);
 
   this->Internal->SelectedMapperAdaptor = new pqSignalAdaptorComboBox(
-    this->Internal->SelectedMapperIndex);
+    this->Internal->SelectMapper);
   QObject::connect(this->Internal->SelectedMapperAdaptor,
     SIGNAL(currentTextChanged(const QString&)),
     this, SLOT(selectedMapperChanged()), Qt::QueuedConnection);
@@ -763,9 +777,9 @@ void pqDisplayProxyEditor::updateEnableState()
    this->Internal->CompositeTreeAdaptor &&
    (reprType == vtkSMPVRepresentationProxy::VOLUME));
 
-  this->Internal->SelectedMapperIndex->setEnabled(
+  this->Internal->SelectMapper->setEnabled(
     reprType == vtkSMPVRepresentationProxy::VOLUME
-    && this->Internal->Representation->getProxy()->GetProperty("SelectedMapperIndex"));
+    && this->Internal->Representation->getProxy()->GetProperty("SelectMapper"));
 
   vtkSMProperty *backfaceRepProperty = this->Internal->Representation
     ->getRepresentationProxy()->GetProperty("BackfaceRepresentation");
@@ -791,14 +805,14 @@ void pqDisplayProxyEditor::updateEnableState()
     this->Internal->BackfaceStyleGroupOptions->setEnabled(!backFollowsFront);
     }
 
-  vtkSMDataRepresentationProxy* display =
+  vtkSMRepresentationProxy* display =
     this->Internal->Representation->getRepresentationProxy();
   if (display)
     {
     QVariant scalarMode = pqSMAdaptor::getEnumerationProperty(
       display->GetProperty("ColorAttributeType"));
     vtkPVDataInformation* geomInfo =
-      display->GetRepresentedDataInformation(/*update=*/false);
+      display->GetRepresentedDataInformation();
     if (!geomInfo)
       {
       return;
@@ -861,18 +875,13 @@ void pqDisplayProxyEditor::zoomToData()
     return;
     }
 
-  double bounds[6];
-  this->Internal->Representation->getRepresentationProxy()->GetBounds(bounds);
-  if (bounds[0]<=bounds[1] && bounds[2]<=bounds[3] && bounds[4]<=bounds[5])
+  pqRenderView* renModule = qobject_cast<pqRenderView*>(
+    this->Internal->Representation->getView());
+  if (renModule)
     {
-    pqRenderView* renModule = qobject_cast<pqRenderView*>(
-      this->Internal->Representation->getView());
-    if (renModule)
-      {
-      vtkSMRenderViewProxy* rm = renModule->getRenderViewProxy();
-      rm->ResetCamera(bounds);
-      renModule->render();
-      }
+    vtkSMRenderViewProxy* rm = renModule->getRenderViewProxy();
+    rm->ZoomTo(this->Internal->Representation->getProxy());
+    renModule->render();
     }
 }
 
@@ -1021,7 +1030,7 @@ void pqDisplayProxyEditor::volumeBlockSelected()
       this->Internal->CompositeTreeAdaptor->getCurrentFlatIndex(&valid);
     if (valid && selectedIndex > 0)
       {
-      vtkSMDataRepresentationProxy* repr =
+      vtkSMRepresentationProxy* repr =
         this->Internal->Representation->getRepresentationProxy();
       pqSMAdaptor::setElementProperty(
         repr->GetProperty("ExtractedBlockIndex"), selectedIndex);
@@ -1076,7 +1085,7 @@ void pqDisplayProxyEditor::setAutoAdjustSampleDistances(bool flag)
 //-----------------------------------------------------------------------------
 void pqDisplayProxyEditor::selectedMapperChanged()
 {
-  if(!this->Internal->SelectedMapperIndex->currentText().compare(
+  if(!this->Internal->SelectMapper->currentText().compare(
       QString("Fixed Point"), Qt::CaseInsensitive))
     {
     // Fixed point does not uses sample distance.
@@ -1084,7 +1093,7 @@ void pqDisplayProxyEditor::selectedMapperChanged()
     this->Internal->SampleDistanceValue->setEnabled(0);
     this->Internal->AutoAdjustSampleDistances->setEnabled(0);
     }
-  else if(!this->Internal->SelectedMapperIndex->currentText().compare(
+  else if(!this->Internal->SelectMapper->currentText().compare(
       QString("GPU"), Qt::CaseInsensitive))
     {
     this->Internal->SampleDistance->setEnabled(1);
