@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDisplayRepresentationWidget.cxx,v $
+   Module:    pqDisplayRepresentationWidget.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -78,14 +78,7 @@ pqDisplayRepresentationWidget::pqDisplayRepresentationWidget(
     SIGNAL(qtWidgetChanged()),
     this, SLOT(onQtWidgetChanged()));
 
-  pqUndoStack* ustack = pqApplicationCore::instance()->getUndoStack();
-  if (ustack)
-    {
-    QObject::connect(this, SIGNAL(beginUndo(const QString&)),
-      ustack, SLOT(beginUndoSet(const QString&)));
-    QObject::connect(this, SIGNAL(endUndo()),
-      ustack, SLOT(endUndoSet()));
-    }
+  this->updateLinks();
 }
 
 //-----------------------------------------------------------------------------
@@ -97,7 +90,7 @@ pqDisplayRepresentationWidget::~pqDisplayRepresentationWidget()
 //-----------------------------------------------------------------------------
 void pqDisplayRepresentationWidget::setRepresentation(pqDataRepresentation* display)
 {
-  if(display != this->Internal->Display)
+  if(!display || display != this->Internal->Display)
     {
     this->Internal->Display = qobject_cast<pqPipelineRepresentation*>(display);
     this->updateLinks();
@@ -157,8 +150,12 @@ void pqDisplayRepresentationWidget::reloadGUI()
 //-----------------------------------------------------------------------------
 void pqDisplayRepresentationWidget::onQtWidgetChanged()
 {
-  emit this->beginUndo("Changed 'Representation'");
-
+  if ( !this->Internal->Display )
+    {
+    //
+    return;
+    }
+  BEGIN_UNDO_SET("Changed 'Representation'");
   QString text = this->Internal->Adaptor->currentText();
 
   vtkSMProperty* repProperty =
@@ -177,7 +174,7 @@ void pqDisplayRepresentationWidget::onQtWidgetChanged()
     //this->Internal->Links.accept();
     this->Internal->Links.blockSignals(false);
     }
-  emit this->endUndo();
+  END_UNDO_SET();
 }
 
 //-----------------------------------------------------------------------------
