@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqImplicitPlaneWidget.h,v $
+   Module:    pqImplicitPlaneWidget.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -55,7 +55,9 @@ public:
 
 public slots:
   /// Resets the bounds of the 3D widget to the reference proxy bounds.
-  virtual void resetBounds();
+  virtual void resetBounds()
+    { this->Superclass::resetBounds(); }
+  virtual void resetBounds(double bounds[6]);
 
   /// accept the changes
   void accept();
