@@ -500,122 +500,6 @@ QWidget* pqMultiView::widgetOfIndex(Index index)
   return w;
 }
 
-//-----------------------------------------------------------------------------
-//
-// This method computes values of ViewPosition and ViewSize for each
-// frame in the multiview.  The values are computed so that gaps
-// created by splitter handles and view titlebars are eliminated. 
-// This method calls the recursive method computeCompactSizesHelper.
-//
-// ViewPosition is stored as a QPoint and ViewSize is stored as a QSize.
-//
-void pqMultiView::computeCompactSizes(
-  QMap<pqMultiViewFrame*, QPair<QPoint,QSize> >& ViewInfo) const
-{
-  // Call the recursive helper method
-  this->computeCompactSizesHelper(
-    ViewInfo,
-    qobject_cast<QSplitter*>(this->getMultiViewWidget()),
-    0, 0, 0, 0);
-}
-
-//-----------------------------------------------------------------------------
-//
-// A recursive method to compute ViewSize and ViewPosition for each frame
-// in the multiview.  The multiview contains nested splitters which can
-// be thought of as a tree.  The strategy is to keep track of splitter handle
-// locations while visiting each node in depth first order.
-//
-// If there is a splitter handle on the right or bottom, then padding is added
-// to the right or bottom side.  If there is a splitter handle on the left
-// or top, then padding is added on the left or top and ViewPosition is adjusted
-// the same number of pixels as the padding.
-//
-void pqMultiView::computeCompactSizesHelper(
-  QMap<pqMultiViewFrame*, QPair<QPoint,QSize> >& ViewInfo,
-  QSplitter* splitter, int lflag, int rflag, int tflag, int bflag) const
-{
-  if (!splitter) // Check for null just in case
-    {
-    return;
-    }
-
-  // Get info about this splitter
-  int numFrames = splitter->count();
-  int handlePadding = splitter->handleWidth()/2;
-  Qt::Orientation orientation = splitter->orientation();
-
-  // For each widget in the splitter
-  for (int i = 0; i < numFrames; ++i)
-    {
-
-    // This is the logic that tracks splitter handle
-    // locations.  The flags rflag and bflag are
-    // incremented/decremented, while lflag and bflag
-    // are either 1 or 0.
-    if (i == 0)
-      {
-      if (orientation == Qt::Horizontal) rflag++;
-      if (orientation == Qt::Vertical) bflag++;
-      }
-    else if (i == 1)
-      {
-      if (orientation == Qt::Horizontal) lflag=1;
-      if (orientation == Qt::Vertical) tflag=1;
-      }
-    if (i == numFrames-1)
-      {
-      if (orientation == Qt::Horizontal) rflag--;
-      if (orientation == Qt::Vertical) bflag--;
-      }
-
-    // Get the child widget
-    QWidget * child = splitter->widget(i);
-
-    // The widget is either a splitter of a multi view frame
-    QSplitter * childSplitter = qobject_cast<QSplitter*>(child);
-    pqMultiViewFrame * childFrame = qobject_cast<pqMultiViewFrame*>(child);
-
-    if (childSplitter) // It's a splitter
-      {
-      // Recurse!
-      this->computeCompactSizesHelper(ViewInfo, childSplitter, lflag, rflag, tflag, bflag);
-      }
-    else if (childFrame)  // It's a multi view frame
-      {
-      // Get size of frame
-      QSize viewSize = childFrame->size();
-
-      // Get the position of the frame
-      QPoint position =
-        childFrame->mapTo(this->getMultiViewWidget(), QPoint(0,0));
-
-      // Expand size and adjust position as needed
-      if (rflag)
-        {
-        viewSize.rwidth() += handlePadding;
-        }
-      if (bflag)
-        {
-        viewSize.rheight() += handlePadding;
-        }
-      if (lflag)
-        {
-        viewSize.rwidth() += handlePadding;
-        position.rx() -= handlePadding;
-        }
-      if (tflag)
-        {
-        viewSize.rheight() += handlePadding;
-        position.ry() -= handlePadding;
-        }
-
-      // Store the size and position in the map
-      ViewInfo[childFrame] = qMakePair(position, viewSize);
-      }
-    }
-}
-
 //-----------------------------------------------------------------------------
 // Returns the top level splitter widget
 QWidget* pqMultiView::getMultiViewWidget() const
