@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqMultiView.h,v $
+   Module:    pqMultiView.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -45,6 +45,7 @@ class QSplitter;
 class PQCOMPONENTS_EXPORT pqMultiView : public QStackedWidget
 {
   Q_OBJECT
+  typedef QStackedWidget Superclass;
 public:
   class PQCOMPONENTS_EXPORT Index: public QList<int>
   {
@@ -107,6 +108,10 @@ public:
   /// Given the clientSize compute the size for this widget. This will take
   /// into consideration the padding around frames.
   QSize computeSize(QSize clientSize) const;
+
+  /// Overridden to handle full-screen mode.
+  virtual void setCurrentWidget(QWidget* widget);
+
 signals:
   /// signal for new frame added
   void frameAdded(pqMultiViewFrame*);
@@ -137,13 +142,20 @@ public slots:
   /// shows the frame decorations.
   void showDecorations();
 
-protected slots:
-  void maximizeWidget(QWidget*);
-  void restoreWidget(QWidget*);
+  /// Show the view as a fullscreen window.
+  void toggleFullScreen();
 
+protected slots:
+  virtual void maximizeWidget(QWidget*);
+  virtual void restoreWidget(QWidget*);
+
+  /// As frames are added/removed/moved around, we may end up with duplicate
+  /// frame names. We don't want to simply use a static int for uniquifying the
+  /// names since then writing tests becomes really hard. So, whenever frames
+  /// are added/removed, we ensure that they have valid names.
+  void updateFrameNames();
 
 protected:
-
  // bool eventFilter(QObject*, QEvent* e);
   pqMultiViewFrame* splitWidget(QWidget*, Qt::Orientation);
   void setup(pqMultiViewFrame*);
@@ -152,11 +164,15 @@ protected:
   QFrame* MaximizeFrame;
   pqMultiViewFrame* FillerFrame;
 
+  QWidget* getMultiViewWidget() const;
 private:
   void saveSplitter(vtkPVXMLElement *element, QSplitter *splitter, int index);
   void restoreSplitter(QWidget *widget, vtkPVXMLElement *element);
   void cleanSplitter(QSplitter *splitter, QList<QWidget*> &removed);
   pqMultiViewFrame* CurrentMaximizedFrame;
+
+  QWidget* FullScreenParent;
+  QWidget* FullScreenWidget;
 };
 
 
