@@ -77,6 +77,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqFileChooserWidget.h"
 #include "pqIntRangeWidget.h"
 #include "pqListWidgetItemObject.h"
+#include "pqObjectBuilder.h"
 #include "pqObjectPanel.h"
 #include "pqPipelineFilter.h"
 #include "pqPropertyManager.h"
@@ -815,7 +816,6 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
   bool row_streched = false; // when set, the extra setRowStretch() at the end
                              // is skipped
   int rowCount = 0;
-  int skippedFirstFileProperty = 0;
   bool isCompoundProxy = pxy->IsA("vtkSMCompoundSourceProxy");
 
   // query for proxy properties, and create widgets
@@ -848,6 +848,16 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
   QStringList propertiesToHide;
   QStringList propertiesToShow;
   processHints(panelLayout, pxy, propertiesToHide, propertiesToShow);
+
+  // Skip the filename property, unless the user has indicated that the filename
+  // should be shown on the property panel.
+  QString filenameProperty = pqObjectBuilder::getFileNamePropertyName(pxy);
+  if (!filenameProperty.isEmpty() &&
+    !propertiesToShow.contains(filenameProperty))
+    {
+    propertiesToHide.push_back(filenameProperty);
+    }
+
   rowCount = panelLayout->rowCount();
   for(iter->Begin(); !iter->IsAtEnd(); iter->Next())
     {
@@ -879,32 +889,6 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
       {
       continue;
       }
-    
-    if (!propertiesToShow.contains(propertyName))
-      {
-      if (SMProperty->IsA("vtkSMStringVectorProperty") && !skippedFirstFileProperty)
-        {
-        // Do not show the first file property. We do not allow changing of
-        // the main filename from the gui. The user has to create another
-        // instance of the reader and reconnect the pipeline.
-        vtkSmartPointer<vtkSMDomainIterator> diter;
-        diter.TakeReference(SMProperty->NewDomainIterator());
-        diter->Begin();
-        while(!diter->IsAtEnd())
-          {
-          if (diter->GetDomain()->IsA("vtkSMFileListDomain"))
-            {
-            break;
-            }
-          diter->Next();
-          }
-        if (!diter->IsAtEnd())
-          {
-          skippedFirstFileProperty = 1;
-          continue;
-          }
-        }
-      }
 
     // update domains we might ask for
     SMProperty->UpdateDependentDomains();
@@ -1336,11 +1320,14 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
       {
       pqFileChooserWidget* chooser;
       chooser = new pqFileChooserWidget(panelLayout->parentWidget());
-      if(informationOnly)
+      if (informationOnly)
         {
         chooser->setEnabled(false);
         }
-     
+
+      // decide whether to allow multiple files
+      chooser->setForceSingleFile((SMProperty->GetRepeatable() == 0));
+
       // If there's a hint on the property indicating that this property expects a
       // directory name, then, we will use the directory mode.
       if (SMProperty->IsA("vtkSMStringVectorProperty") && SMProperty->GetHints() && 
@@ -1348,7 +1335,7 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
         {
         chooser->setUseDirectoryMode(1);
         }
-        
+
       pqServerManagerModel* m =
         pqApplicationCore::instance()->getServerManagerModel();
       chooser->setServer(m->findServer(pxy->GetConnectionID()));
@@ -1356,7 +1343,7 @@ void pqNamedWidgets::createWidgets(QGridLayout* panelLayout, vtkSMProxy* pxy)
       QLabel* label = createPanelLabel(panelLayout->parentWidget(),
                                        propertyLabel,
                                        propertyName);
-      
+
       panelLayout->addWidget(label, rowCount, 0, 1, 1);
       panelLayout->addWidget(chooser, rowCount, 1, 1, 1);
       rowCount++;
