@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPluginDialog.h,v $
+   Module:    pqPluginDialog.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -34,9 +34,15 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define _pqPluginDialog_h
 
 #include <QDialog>
+#include <QPointer>
 #include "pqComponentsExport.h"
 #include "ui_pqPluginDialog.h"
+
+class QTreeWidget;
+class QTreeWidgetItem;
+class QPushButton;
 class pqServer;
+class vtkPVPluginInformation;
 
 class PQCOMPONENTS_EXPORT pqPluginDialog :
   public QDialog, private Ui::pqPluginDialog
@@ -50,22 +56,48 @@ public:
   ~pqPluginDialog();
 
 public slots:
-  void loadRemotePlugin();
   void loadLocalPlugin();
-
+  void loadRemotePlugin();
+  
 protected slots:
-  void loadRecentRemotePlugin(int idx);
-  void loadRecentLocalPlugin(int idx);
-
-protected:
+  void onPluginItemChanged(QTreeWidgetItem*, int);
+  void onRefresh();
   void refresh();
+  void onLoadSelectedRemotePlugin();
+  void onLoadSelectedLocalPlugin();
+  void onRemoveSelectedRemotePlugin();
+  void onRemoveSelectedLocalPlugin();
+  void onRemoteSelectionChanged();
+  void onLocalSelectionChanged();
+  void resizeColumn(QTreeWidgetItem*);
+ 
+protected:
   void refreshLocal();
   void refreshRemote();
-  QString loadPlugin(pqServer* server);
-  QString loadPlugin(pqServer* server, const QString& file);
+  QString loadPlugin(pqServer* server, bool remote);
+  QString loadPlugin(pqServer* server, const QString& file, bool remote);
+  void removePlugin(pqServer* server, const QString& file, bool remote);
+  
+  void setupTreeWidget(QTreeWidget* pluginTree);
+  void populatePluginTree(QTreeWidget* pluginTree,
+    QList< vtkPVPluginInformation* >& pluginList, bool remote);
+  void createPluginNode(QTreeWidget* pluginTree,
+    vtkPVPluginInformation* pluginInfo, bool remote);
+  void addPluginInfo(QTreeWidgetItem* pluginNode, bool remote);
+  void addInfoNodes(
+    QTreeWidgetItem* pluginNode, vtkPVPluginInformation* plInfo, bool remote);
+  vtkPVPluginInformation* getPluginInfo(QTreeWidgetItem* pluginNode)    ;
+  void updateEnableState(QTreeWidget*, QPushButton* removeButton, QPushButton* loadButton);
+  void loadSelectedPlugins(QList<QTreeWidgetItem*> selItems,
+    pqServer* server, bool remote);
+  void removeSelectedPlugins(QList<QTreeWidgetItem*> selItems,
+    pqServer* server, bool remote);
+  QString getStatusText(vtkPVPluginInformation* plInfo);
 
+private:      
+  
   pqServer* Server;
-
+  bool LoadingMultiplePlugins;
 };
 
 #endif
