@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqSimpleServerStartup.cxx,v $
+   Module:    pqSimpleServerStartup.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -404,18 +404,29 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
   vtkstd::map<QString, QString> true_values;
   vtkstd::map<QString, QString> false_values;
 
-  int num = xml_options->GetNumberOfNestedElements();
-  for (int i=0; i<num; i++)
+  int number_of_elements = xml_options->GetNumberOfNestedElements();
+  for (int i=0; i<number_of_elements; i++)
     {
     vtkPVXMLElement* xml_option = xml_options->GetNestedElement(i);
-    if (QString(xml_option->GetName()) == "Option")
+    if (QString(xml_option->GetName()) == "Set")
+      {
+      const char* option_name = xml_option->GetAttribute("name");
+      const char* option_value = xml_option->GetAttribute("value");
+      if (option_name && option_value)
+        {
+        this->Implementation->Options[option_name] = option_value;
+        }
+      }
+    else if (QString(xml_option->GetName()) == "Option")
       {
       const QString option_name = xml_option->GetAttribute("name");
       const QString option_label = xml_option->GetAttribute("label");
       const bool option_readonly = 
         (QString(xml_option->GetAttribute("readonly")) == "true");
-      const bool save_option =
-        QVariant(xml_option->GetAttribute("save")).toBool();
+      const bool save_option = xml_option->GetAttribute("save") ? 
+        QVariant(xml_option->GetAttribute("save")).toBool() : true;
+      QString settings_key = QString("SERVER_STARTUP/%1.%2").arg(
+        this->Implementation->Startup->getName()).arg(option_name);
 
       vtkPVXMLElement* xml_type = xml_option->GetNestedElement(0);
       if (!xml_type)
@@ -431,13 +442,15 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
         {
         // if save="true" is set on the Option, then try to get the value from
         // the settings if available.
-        if (settings->contains(QString("SERVER_STARUP/%1").arg(option_name)))
+
+        if (settings->contains(settings_key))
           {
-          widget_default =
-            settings->value(QString("SERVER_STARUP/%1").arg(option_name)).toString();
+          widget_default = settings->value(settings_key).toString();
           }
         }
-      if (widget_default.isEmpty())
+      if (widget_default.isEmpty() || (
+        xml_type->GetAttribute("default") &&
+        strcmp(xml_type->GetAttribute("default"), "random") == 0))
         {
         widget_default = xml_type->GetAttribute("default");
         }
@@ -511,8 +524,9 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
       else if (QString(xml_type->GetName()) == "File")
         {
         pqFileChooserWidget* const widget = new pqFileChooserWidget();
+        widget->setForceSingleFile(true);
         widget->setEnabled(!option_readonly);
-        widget->setFilename(widget_default);
+        widget->setSingleFilename(widget_default);
         layout->addWidget(widget, row, widget_column,
           Qt::AlignLeft | Qt::AlignVCenter);
         widgets[xml_option] = widget;
@@ -610,7 +624,7 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
     else if (pqFileChooserWidget* const widget6 =
       qobject_cast<pqFileChooserWidget*>(option_widget))
       {
-      val = widget6->filename();
+      val = widget6->singleFilename();
       }
 
     bool option_readonly;
@@ -623,11 +637,13 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
         val.toAscii().data());
       }
 
-    const bool save_option =
-      QVariant(xml_option->GetAttribute("save")).toBool();
+    const bool save_option = xml_option->GetAttribute("save")?
+      QVariant(xml_option->GetAttribute("save")).toBool() : true;
     if (save_option && !option_readonly)
       {
-      settings->setValue(QString("SERVER_STARUP/%1").arg(option_name), val);
+      QString settings_key = QString("SERVER_STARTUP/%1.%2").arg(
+        this->Implementation->Startup->getName()).arg(option_name);
+      settings->setValue(settings_key, val);
       }
     }
 
@@ -658,6 +674,71 @@ bool pqSimpleServerStartup::promptRuntimeArguments()
       }
     }
 
+  // Handle any Switch-es in the configuration. This has to happen after the
+  // Options have been updated with user-selected values so that we can pick the
+  // right case.
+  for (int cc=0; cc < number_of_elements; cc++)
+    {
+    vtkPVXMLElement* switchXML = xml_options->GetNestedElement(cc);
+    if (!switchXML->GetName() || strcmp(switchXML->GetName(), "Switch") != 0)
+      {
+      continue;
+      }
+    const char* variable = switchXML->GetAttribute("name");
+    if (!variable)
+      {
+      qWarning("Missing attribute 'name' in 'Switch' statement");
+      continue;
+      }
+    if (!this->Implementation->Options.contains(variable))
+      {
+      qWarning() << "'Switch' statement has no effect since no variable named " 
+        << variable << " is defined. ";
+      continue;
+      }
+    QString value = this->Implementation->Options[variable];
+    bool handled = false;
+    for (unsigned int kk=0;
+      !handled && kk < switchXML->GetNumberOfNestedElements(); kk++)
+      {
+      vtkPVXMLElement* caseXML = switchXML->GetNestedElement(kk);
+      if (!caseXML->GetName() || strcmp(caseXML->GetName(), "Case") != 0)
+        {
+        continue;
+        }
+      const char* case_value = caseXML->GetAttribute("value");
+      if (!case_value || value != case_value)
+        {
+        continue;
+        }
+      handled = true;
+      for (unsigned int i=0; i < caseXML->GetNumberOfNestedElements(); i++)
+        {
+        vtkPVXMLElement* setXML= caseXML->GetNestedElement(i);
+        if (QString(setXML->GetName()) == "Set")
+          {
+          const char* option_name = setXML->GetAttribute("name");
+          const char* option_value = setXML->GetAttribute("value");
+          if (option_name && option_value)
+            {
+            this->Implementation->Options[option_name] = option_value;
+            }
+          }
+        else
+          {
+          qWarning()
+            << "'Case' element can only contain 'Set' elements as children and not '"
+            << setXML->GetName() << "'";
+          }
+        }
+      }
+    if (!handled)
+      {
+      qWarning() << "Case '"<< value << "' not handled in 'Switch' for variable "
+        "'" << variable << "'";
+      }
+    }
+
   return true;
 }
 
