@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqSplitViewUndoElement.cxx,v $
+   Module:    pqSplitViewUndoElement.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -37,7 +37,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqApplicationCore.h"
 
 vtkStandardNewMacro(pqSplitViewUndoElement);
-vtkCxxRevisionMacro(pqSplitViewUndoElement, "$Revision: 1.4 $");
 //-----------------------------------------------------------------------------
 pqSplitViewUndoElement::pqSplitViewUndoElement()
 {
