@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program:   ParaQ
-   Module:    $RCSfile: pqStreamTracerPanel.cxx,v $
+   Module:    pqStreamTracerPanel.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -18,7 +18,7 @@
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
@@ -49,7 +49,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkPVXMLElement.h>
 #include <vtkSMDoubleVectorProperty.h>
 #include <vtkSMIntVectorProperty.h>
-#include <vtkSMProxyProperty.h>
+#include <vtkSMInputProperty.h>
 #include <vtkSMSourceProxy.h>
 
 #include <QVBoxLayout>
@@ -94,15 +94,17 @@ pqStreamTracerPanel::pqStreamTracerPanel(pqProxy* object_proxy, QWidget* p) :
   double proxy_center[3] = {0.0, 0.0, 0.0};
   double proxy_size[3] = {0.0, 0.0, 0.0};
 
-  if(vtkSMProxyProperty* const input_property =
-    vtkSMProxyProperty::SafeDownCast(
+  if(vtkSMInputProperty* const input_property =
+    vtkSMInputProperty::SafeDownCast(
       this->proxy()->GetProperty("Input")))
     {
     if(vtkSMSourceProxy* const input_proxy = vtkSMSourceProxy::SafeDownCast(
         input_property->GetProxy(0)))
       {
       double input_bounds[6];
-      input_proxy->GetDataInformation()->GetBounds(input_bounds);
+      input_proxy->GetDataInformation(
+        input_property->GetOutputPortForConnection(0))->GetBounds(
+        input_bounds);
 
       proxy_center[0] = (input_bounds[0] + input_bounds[1]) / 2.0;
       proxy_center[1] = (input_bounds[2] + input_bounds[3]) / 2.0;
@@ -402,9 +404,7 @@ void pqStreamTracerPanel::onIntegratorTypeChanged(int index)
     {
     enabled = true;
     }
-  this->Implementation->UI.MinimumIntegrationStepUnit->setEnabled(enabled);
-  this->Implementation->UI.MinimumIntegrationStep->setEnabled(enabled);
-  this->Implementation->UI.MaximumIntegrationStepUnit->setEnabled(enabled);
+  this->Implementation->UI.MinimumIntegrationStep->setEnabled(enabled); 
   this->Implementation->UI.MaximumIntegrationStep->setEnabled(enabled);
   this->Implementation->UI.MaximumError->setEnabled(enabled);
 }
