@@ -32,15 +32,18 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqXYChartDisplayPanel.h"
 #include "ui_pqXYChartDisplayPanel.h"
 
-#include "vtkSMXYChartRepresentationProxy.h"
+#include "vtkChart.h"
 #include "vtkDataArray.h"
 #include "vtkDataObject.h"
 #include "vtkSMArraySelectionDomain.h"
-#include "vtkSMIntVectorProperty.h"
-#include "vtkSMProxy.h"
 #include "vtkSmartPointer.h"
+#include "vtkSMChartRepresentationProxy.h"
+#include "vtkChartRepresentation.h"
+#include "vtkSMIntVectorProperty.h"
+#include "vtkSMPropertyHelper.h"
+#include "vtkSMProxy.h"
 #include "vtkTable.h"
-#include "vtkChart.h"
+#include "vtkWeakPointer.h"
 
 #include <QColorDialog>
 #include <QHeaderView>
@@ -84,7 +87,7 @@ public:
     delete this->AttributeModeAdaptor;
     }
 
-  vtkWeakPointer<vtkSMXYChartRepresentationProxy> ChartRepresentation;
+  vtkWeakPointer<vtkSMChartRepresentationProxy> ChartRepresentation;
   pqPlotSettingsModel* SettingsModel;
   pqComboBoxDomain* XAxisArrayDomain;
   pqSignalAdaptorComboBox* AttributeModeAdaptor;
@@ -105,6 +108,9 @@ pqXYChartDisplayPanel::pqXYChartDisplayPanel(
 
   this->Internal->SettingsModel = new pqPlotSettingsModel(this);
   this->Internal->SeriesList->setModel(this->Internal->SettingsModel);
+  QObject::connect(this->Internal->SeriesList->header(),
+    SIGNAL(checkStateChanged()),
+    this, SLOT(headerCheckStateChanged()));
 
   this->Internal->XAxisArrayAdaptor = new pqSignalAdaptorComboBox(
     this->Internal->XAxisArray);
@@ -127,6 +133,8 @@ pqXYChartDisplayPanel::pqXYChartDisplayPanel(
     this, SLOT(updateAllViews()));
   QObject::connect(this->Internal->XAxisArray, SIGNAL(currentIndexChanged(int)),
     this, SLOT(updateAllViews()));
+  QObject::connect(this->Internal->SettingsModel, SIGNAL(rescaleChart()),
+    this, SLOT(rescaleChart()));
 
   QObject::connect(this->Internal->UseArrayIndex, SIGNAL(toggled(bool)),
     this, SLOT(useArrayIndexToggled(bool)));
@@ -166,13 +174,23 @@ void pqXYChartDisplayPanel::reloadSeries()
   this->updateOptionsWidgets();
 }
 
+//-----------------------------------------------------------------------------
+void pqXYChartDisplayPanel::rescaleChart()
+{
+  vtkSMChartRepresentationProxy* proxy = this->Internal->ChartRepresentation;
+  if (proxy)
+    {
+    proxy->GetRepresentation()->RescaleChart();
+    }
+}
+
 //-----------------------------------------------------------------------------
 void pqXYChartDisplayPanel::setDisplay(pqRepresentation* disp)
 {
   this->setEnabled(false);
 
-  vtkSMXYChartRepresentationProxy* proxy =
-    vtkSMXYChartRepresentationProxy::SafeDownCast(disp->getProxy());
+  vtkSMChartRepresentationProxy* proxy =
+    vtkSMChartRepresentationProxy::SafeDownCast(disp->getProxy());
   this->Internal->ChartRepresentation = proxy;
   if (!this->Internal->ChartRepresentation)
     {
@@ -183,7 +201,7 @@ void pqXYChartDisplayPanel::setDisplay(pqRepresentation* disp)
 
   // this is essential to ensure that when you undo-redo, the representation is
   // indeed update-to-date, thus ensuring correct domains etc.
-  proxy->Update();
+  proxy->UpdatePipeline();
 
   // The model for the plot settings
   this->Internal->SettingsModel->setRepresentation(
@@ -228,10 +246,10 @@ void pqXYChartDisplayPanel::setDisplay(pqRepresentation* disp)
 //-----------------------------------------------------------------------------
 void pqXYChartDisplayPanel::changeDialog(pqRepresentation* disp)
 {
-  vtkSMXYChartRepresentationProxy* proxy =
-    vtkSMXYChartRepresentationProxy::SafeDownCast(disp->getProxy());
+  vtkSMChartRepresentationProxy* proxy =
+    vtkSMChartRepresentationProxy::SafeDownCast(disp->getProxy());
   bool visible = true;
-  if (proxy->GetChartType() == vtkChart::BAR)
+  if (QString("Bar") == vtkSMPropertyHelper(proxy,"ChartType").GetAsString())
     {
     visible = false;
     }
@@ -435,3 +453,26 @@ void pqXYChartDisplayPanel::useDataArrayToggled(bool toggle)
   this->Internal->UseArrayIndex->setChecked(!toggle);
   this->updateAllViews();
 }
+
+//-----------------------------------------------------------------------------
+void pqXYChartDisplayPanel::headerCheckStateChanged()
+{
+  // get current check state/
+  QHeaderView* header = this->Internal->SeriesList->header();
+  QAbstractItemModel* headerModel = header->model();
+  bool checkable = false;
+  int cs = headerModel->headerData(
+    0, header->orientation(), Qt::CheckStateRole).toInt(&checkable);
+  if (checkable)
+    {
+    if (cs ==  Qt::Checked)
+      {
+      cs = Qt::Unchecked;
+      }
+    else
+      {
+      cs = Qt::Checked;
+      }
+    headerModel->setHeaderData(0, header->orientation(), cs, Qt::CheckStateRole);
+    }
+}
