@@ -38,16 +38,6 @@ def runTests():
   QtTesting.playCommand(fdMsgOk, 'activate', '')
   checkFile('Filea.png')
   QtTesting.playCommand(filter, 'set_string', '*.png')
-  QtTesting.playCommand(openDialog, 'activate', '')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/0|0')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/1|0')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/2|0')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/3|0')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/4|0')
-  QtTesting.playCommand(fdFiles, 'currentChanged', '/5|0')
-  QtTesting.playCommand(fdOk, 'activate', '')
-  QtTesting.playCommand(fdMsgOk, 'activate', '')
-  checkFile('Filec.png')
   QtTesting.playCommand(mode, 'set_string', 'Existing File')
   QtTesting.playCommand(openDialog, 'activate', '')
   QtTesting.playCommand(fdFiles, 'currentChanged', '/0|0')
@@ -68,23 +58,28 @@ def runTests():
   QtTesting.playCommand(fdFiles, 'currentChanged', '/5|0')
   QtTesting.playCommand(fdName, 'set_string', 'Filec')
   QtTesting.playCommand(fdOk, 'activate', '')
-  QtTesting.playCommand(fdOk, 'activate', '')
-  QtTesting.playCommand(fdName, 'set_string', 'Filec.png')
-  QtTesting.playCommand(fdOk, 'activate', '')
   checkFile('Filec.png')
   QtTesting.playCommand(mode, 'set_string', 'Existing File')
   QtTesting.playCommand(openDialog, 'activate', '')
   QtTesting.playCommand(fdName, 'set_string', 'Filea')
   QtTesting.playCommand(fdOk, 'activate', '')
-  QtTesting.playCommand(fdName, 'set_string', 'Filea.png')
-  QtTesting.playCommand(fdOk, 'activate', '')
   QtTesting.playCommand(filter, 'set_string', 'Images (*.png;*.bmp)')
   QtTesting.playCommand(openDialog, 'activate', '')
   QtTesting.playCommand(fdFiles, 'currentChanged', '/0|0')
   QtTesting.playCommand(fdFiles, 'currentChanged', '/7|0')
   QtTesting.playCommand(fdOk, 'activate', '')
   checkFile('Filec.bmp')
-
+  # switch to directory mode
+  QtTesting.playCommand(filter, 'set_string', '')
+  QtTesting.playCommand(mode, 'set_string', 'Directory')
+  QtTesting.playCommand(openDialog, 'activate', '')
+  QtTesting.playCommand(fdFiles, 'currentChanged', '/0|0')
+  QtTesting.playCommand(fdFiles, 'currentChanged', '/3|0')
+  QtTesting.playCommand(fdFiles, 'currentChanged', '/4|0')
+  QtTesting.playCommand(fdOk, 'activate', '')
+  QtTesting.playCommand(fdFiles, 'currentChanged', '/2|0')
+  QtTesting.playCommand(fdOk, 'activate', '')
+  checkFile('SubDir3')
 
 
 QtTesting.playCommand(connection, 'set_string', 'Local')
