@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAnimationScene.h,v $
+   Module:    pqAnimationScene.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -92,6 +92,17 @@ public:
   /// Returns the current animation time.
   double getAnimationTime() const;
 
+  /// Returns the timesteps from the timekeeper for the animation scene.
+  QList<double> getTimeSteps() const;
+
+  /// Application settings for caching.  When caching is on, polygonal geometry
+  /// will be saved at every time step up to the given limit.  The limit is
+  /// given in kilobytes.
+  static void setCacheGeometrySetting(bool flag);
+  static bool getCacheGeometrySetting();
+  static void setCacheLimitSetting(int kilobytes);
+  static int getCacheLimitSetting();
+
 signals:
   /// Fired before a new cue is added to the scene.
   void preAddedCue(pqAnimationCue*);
@@ -148,15 +159,19 @@ public slots:
   /// Set the animation time.
   void setAnimationTime(double time);
 
+  /// Refreshes state of the scene to the current application settings.  Should
+  /// be called when the application settings change.
+  void updateApplicationSettings();
+
 private slots:
   /// Called when the "Cues" property on the AnimationScene proxy
   /// is changed. Updates the internal datastructure to reflect the current
   /// state of the scene.
   void onCuesChanged();
 
-  /// Called when timekeeper's timesteps change,
-  /// we synchronize the ClockTimeRange on the scene proxy.
-  void updateTimeRanges();  
+  /// Called when timekeeper's timesteps are changed. We determine the play mode
+  /// based on the availability of timesteps.
+  void updateTimeSteps();  
 
   /// Called on animation tick.
   void onTick(vtkObject* caller, unsigned long, void*, void* info);
@@ -164,6 +179,12 @@ private slots:
   /// called when "AnimationTime" property changes. We fire the animationTime()
   /// signal.
   void onAnimationTimePropertyChanged();
+
+protected:
+  /// Initializes the newly create animation cue with default keyframes.
+  void initializeCue(
+    vtkSMProxy* proxy, const char* propertyname, int index,
+    pqAnimationCue* cue);
 private:
   pqAnimationScene(const pqAnimationScene&); // Not implemented.
   void operator=(const pqAnimationScene&); // Not implemented.
