@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqCoreTestUtility.cxx,v $
+   Module:    pqCoreTestUtility.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -50,18 +50,20 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkPNGReader.h"
 #include "vtkImageDifference.h"
 #include "vtkImageShiftScale.h"
-#include "vtkPQConfig.h"
+#include "vtkPVConfig.h"
 #include "vtkRenderWindow.h"
 #include "vtkTesting.h"
 
+#include "pqColorButtonEventPlayer.h"
+#include "pqColorButtonEventTranslator.h"
 #include "pqFileDialogEventPlayer.h"
 #include "pqFileDialogEventTranslator.h"
 #include "pqFlatTreeViewEventPlayer.h"
 #include "pqFlatTreeViewEventTranslator.h"
 #include "pqOptions.h"
-#include "pqProcessModuleGUIHelper.h"
 #include "pqQVTKWidgetEventPlayer.h"
 #include "pqQVTKWidgetEventTranslator.h"
+
 #ifdef QT_TESTING_WITH_PYTHON
 # include "pqPythonEventSourceImage.h"
 #endif
@@ -102,6 +104,8 @@ pqCoreTestUtility::pqCoreTestUtility(QObject* p) :
        new pqFileDialogEventTranslator(this));
   this->eventTranslator()->addWidgetEventTranslator(
        new pqFlatTreeViewEventTranslator(this));
+  this->eventTranslator()->addWidgetEventTranslator(
+       new pqColorButtonEventTranslator(this));
 
   this->eventPlayer()->addWidgetEventPlayer(
        new pqQVTKWidgetEventPlayer(this));
@@ -109,6 +113,8 @@ pqCoreTestUtility::pqCoreTestUtility(QObject* p) :
        new pqFileDialogEventPlayer(this));
   this->eventPlayer()->addWidgetEventPlayer(
        new pqFlatTreeViewEventPlayer(this));
+  this->eventPlayer()->addWidgetEventPlayer(
+       new pqColorButtonEventPlayer(this));
 }
 
 pqCoreTestUtility::~pqCoreTestUtility()
@@ -209,34 +215,6 @@ bool pqCoreTestUtility::CompareImage(vtkImageData* testImage,
   return false;
 }
 
-void pqCoreTestUtility::playTests(const QStringList& filenames)
-{
-  this->TestFilenames = filenames;
-  if (this->TestFilenames.size() > 0)
-    {
-    QString filename = this->TestFilenames[0];
-    this->TestFilenames.pop_front();
-    this->pqTestUtility::playTests(filename);
-    }
-  else
-    {
-    this->testSucceeded();
-    }
-}
-
-void pqCoreTestUtility::playTests(const QString& filename)
-{
-  this->TestFilenames.clear();
-  if(!filename.isEmpty())
-    {
-    pqTestUtility::playTests(filename);
-    }
-  else
-    {
-    this->testSucceeded();
-    }
-}
-
 QString pqCoreTestUtility::TestDirectory()
 {
   if (pqOptions* const options = pqOptions::SafeDownCast(
@@ -247,51 +225,4 @@ QString pqCoreTestUtility::TestDirectory()
   return QString();
 }
 
-void pqCoreTestUtility::testSucceeded()
-{
-  if (this->TestFilenames.size() > 0)
-    {
-    QString filename = this->TestFilenames[0];
-    this->TestFilenames.pop_front();
-    this->pqTestUtility::playTests(filename);
-    return;
-    }
-  if(pqOptions* const options = pqOptions::SafeDownCast(
-    vtkProcessModule::GetProcessModule()->GetOptions())
-    )
-    {
-    // TODO: image comparisons probably ought to be done the same
-    //       way widget validation is done (when that gets implemented)
-    //       That is, check that the text of a QLineEdit is a certain value
-    //       Referencing a QVTKWidget can then be done the same way as referencing
-    //       any other widget, instead of relying on the "active" view.
-    bool comparison_succeeded = true;
-    if(options->GetBaselineImage())
-      {
-      pqProcessModuleGUIHelper * helper;
-      helper = pqProcessModuleGUIHelper::SafeDownCast(
-           vtkProcessModule::GetProcessModule()->GetGUIHelper());
-
-      comparison_succeeded = helper->compareView(options->GetBaselineImage(),
-        options->GetImageThreshold(), cout, options->GetTestDirectory());
-      }
-      
-    if(options->GetExitAppWhenTestsDone())
-      {
-      QApplication::instance()->exit(comparison_succeeded ? 0 : 1);
-      }
-    }
-}
-
-void pqCoreTestUtility::testFailed()
-{
-  if(pqOptions* const options = pqOptions::SafeDownCast(
-    vtkProcessModule::GetProcessModule()->GetOptions()))
-    {
-    if(options->GetExitAppWhenTestsDone())
-      {
-      QApplication::instance()->exit(1);
-      }
-    }
-}
 
