@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqCoreTestUtility.h,v $
+   Module:    pqCoreTestUtility.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -41,7 +41,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class QString;
 class pqEventPlayer;
 class pqEventTranslator;
-class pqProcessModuleGUIHelper;
 class vtkRenderWindow;
 class vtkImageData;
 
@@ -49,6 +48,7 @@ class vtkImageData;
 class PQCORE_EXPORT pqCoreTestUtility : public pqTestUtility
 {
   Q_OBJECT
+  typedef pqTestUtility Superclass;
 
 public:
   pqCoreTestUtility(QObject* parent = 0);
@@ -83,14 +83,6 @@ public:
                            ostream& Output, 
                            const QString& TempDirectory);
 
-public slots:
-  void playTests(const QString& filename);
-  void playTests(const QStringList& filenames); 
-
-protected slots:
-  void testSucceeded();
-  void testFailed();
-
 private:
   QStringList TestFilenames;
 };
