@@ -7,7 +7,7 @@
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -37,6 +37,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqFileDialogFilter.h"
 #include "pqServer.h"
 
+#include <QCompleter>
 #include <QDir>
 #include <QMessageBox>
 #include <QtDebug>
@@ -48,6 +49,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QComboBox>
 #include <QAbstractItemView>
 
+#include <QKeyEvent>
+#include <QMouseEvent>
+#include <QShowEvent>
+
 #include <vtkstd/string>
 #include <vtksys/SystemTools.hxx>
 
@@ -69,17 +74,17 @@ namespace {
   QStringList MakeFilterList(const QString &filter)
   {
     QString f(filter);
-    
+
     if (f.isEmpty())
       {
       return QStringList();
       }
-    
+
     QString sep(";;");
     int i = f.indexOf(sep, 0);
-    if (i == -1) 
+    if (i == -1)
       {
-      if (f.indexOf("\n", 0) != -1) 
+      if (f.indexOf("\n", 0) != -1)
         {
         sep = "\n";
         i = f.indexOf(sep, 0);
@@ -128,36 +133,66 @@ public:
   pqFileDialogFavoriteModel* const FavoriteModel;
   pqFileDialogRecentDirsModel* const RecentModel;
   pqFileDialogFilter FileFilter;
-  FileMode Mode;
+  QStringList FileNames; //list of file names in the FileName ui text edit
+  QCompleter *Completer;
+  pqFileDialog::FileMode Mode;
   Ui::pqFileDialog Ui;
-  QStringList SelectedFiles;
+  QList<QStringList> SelectedFiles;
   QStringList Filters;
   bool SupressOverwriteWarning;
-  
+  bool ShowMultipleFileHelp;
+  QString FileNamesSeperator;  
+
   // remember the last locations we browsed
   static QMap<QPointer<pqServer>, QString> ServerFilePaths;
   static QString LocalFilePath;
 
-  pqImplementation(pqFileDialog* p, pqServer* server) : 
+  pqImplementation(pqFileDialog* p, pqServer* server) :
     QObject(p),
     Model(new pqFileDialogModel(server, NULL)),
     FavoriteModel(new pqFileDialogFavoriteModel(server, NULL)),
     RecentModel(new pqFileDialogRecentDirsModel(Model, server, NULL)),
     FileFilter(this->Model),
+    Completer(new QCompleter(&this->FileFilter, NULL)),
     Mode(ExistingFile),
-    SupressOverwriteWarning(false)
+    SupressOverwriteWarning(false),
+    ShowMultipleFileHelp(false),
+    FileNamesSeperator(";")
   {
-  QObject::connect(p, SIGNAL(filesSelected(const QStringList&)),
-    this->RecentModel, SLOT(setChosenFiles(const QStringList&)));
+  QObject::connect(p, SIGNAL(filesSelected(const QList<QStringList> &)),
+    this->RecentModel, SLOT(setChosenFiles(const QList<QStringList> &)));
   }
-  
+
   ~pqImplementation()
   {
     delete this->RecentModel;
     delete this->FavoriteModel;
     delete this->Model;
+    delete this->Completer;
   }
-  
+
+  bool eventFilter(QObject *obj, QEvent *anEvent )
+    {
+    if ( obj == this->Ui.Files )
+      {
+      if ( anEvent->type() == QEvent::KeyPress )
+        {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent*>(anEvent);
+        if (keyEvent->key() == Qt::Key_Backspace ||
+          keyEvent->key() == Qt::Key_Delete )
+          {
+          this->Ui.FileName->setFocus(Qt::OtherFocusReason);
+          //send out a backspace event to the file name now
+          QKeyEvent replicateDelete(keyEvent->type(), keyEvent->key(), keyEvent->modifiers());
+          QApplication::sendEvent( this->Ui.FileName, &replicateDelete);
+          return true;
+          }
+        }
+      return false;
+      }
+    return QObject::eventFilter(obj, anEvent);
+    }
+
   QString getStartPath()
     {
     pqServer* s = this->Model->server();
@@ -189,8 +224,11 @@ public:
       {
       this->LocalFilePath = p;
       }
+    this->Ui.Favorites->clearSelection();
+    this->Ui.Recent->clearSelection();
+    this->Ui.Files->setFocus(Qt::OtherFocusReason);
     }
-  
+
   void addHistory(const QString& p)
     {
     this->BackHistory.append(p);
@@ -227,13 +265,13 @@ public:
       }
     return path;
     }
-  
+
 protected:
   QStringList BackHistory;
   QStringList ForwardHistory;
 
 };
-  
+
 QMap<QPointer<pqServer>, QString> pqFileDialog::pqImplementation::ServerFilePaths;
 QString pqFileDialog::pqImplementation::LocalFilePath;
 
@@ -242,19 +280,25 @@ QString pqFileDialog::pqImplementation::LocalFilePath;
 
 pqFileDialog::pqFileDialog(
     pqServer* server,
-    QWidget* p, 
-    const QString& title, 
-    const QString& startDirectory, 
+    QWidget* p,
+    const QString& title,
+    const QString& startDirectory,
     const QString& nameFilter) :
   Superclass(p),
   Implementation(new pqImplementation(this, server))
 {
   this->Implementation->Ui.setupUi(this);
+  this->setWindowTitle(title);
 
   this->Implementation->Ui.Files->setEditTriggers(QAbstractItemView::EditKeyPressed);
 
-  this->setWindowTitle(title);
-  
+  //install the event filter
+  this->Implementation->Ui.Files->installEventFilter(this->Implementation);
+
+  //install the autocompleter
+  this->Implementation->Ui.FileName->setCompleter(this->Implementation->Completer);
+
+
   QPixmap back = style()->standardPixmap(QStyle::SP_FileDialogBack);
   this->Implementation->Ui.NavigateBack->setIcon(back);
   this->Implementation->Ui.NavigateBack->setEnabled(false);
@@ -279,7 +323,7 @@ pqFileDialog::pqFileDialog(
 
   this->Implementation->Ui.Files->setContextMenuPolicy(Qt::CustomContextMenu);
   QObject::connect(this->Implementation->Ui.Files,
-                  SIGNAL(customContextMenuRequested(const QPoint &)), 
+                  SIGNAL(customContextMenuRequested(const QPoint &)),
                   this, SLOT(onContextMenuRequested(const QPoint &)));
   this->Implementation->Ui.CreateFolder->setEnabled( true );
 
@@ -294,69 +338,69 @@ pqFileDialog::pqFileDialog(
   this->setFileMode(ExistingFile);
 
   QObject::connect(this->Implementation->Model,
-                   SIGNAL(modelReset()), 
-                   this, 
+                   SIGNAL(modelReset()),
+                   this,
                    SLOT(onModelReset()));
 
-  QObject::connect(this->Implementation->Ui.NavigateUp, 
-                   SIGNAL(clicked()), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.NavigateUp,
+                   SIGNAL(clicked()),
+                   this,
                    SLOT(onNavigateUp()));
 
-  QObject::connect(this->Implementation->Ui.CreateFolder, 
-                   SIGNAL(clicked()), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.CreateFolder,
+                   SIGNAL(clicked()),
+                   this,
                    SLOT(onCreateNewFolder()));
 
-  QObject::connect(this->Implementation->Ui.Parents, 
-                   SIGNAL(activated(const QString&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.Parents,
+                   SIGNAL(activated(const QString&)),
+                   this,
                    SLOT(onNavigate(const QString&)));
 
-  QObject::connect(this->Implementation->Ui.FileType, 
-                   SIGNAL(currentIndexChanged(const QString&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.FileType,
+                   SIGNAL(currentIndexChanged(const QString&)),
+                   this,
                    SLOT(onFilterChange(const QString&)));
-  
-  QObject::connect(this->Implementation->Ui.Favorites, 
-                   SIGNAL(clicked(const QModelIndex&)), 
-                   this, 
+
+  QObject::connect(this->Implementation->Ui.Favorites,
+                   SIGNAL(clicked(const QModelIndex&)),
+                   this,
                    SLOT(onClickedFavorite(const QModelIndex&)));
 
-  QObject::connect(this->Implementation->Ui.Recent, 
-                   SIGNAL(clicked(const QModelIndex&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.Recent,
+                   SIGNAL(clicked(const QModelIndex&)),
+                   this,
                    SLOT(onClickedRecent(const QModelIndex&)));
 
-  QObject::connect(this->Implementation->Ui.Files, 
-                   SIGNAL(clicked(const QModelIndex&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.Files,
+                   SIGNAL(clicked(const QModelIndex&)),
+                   this,
                    SLOT(onClickedFile(const QModelIndex&)));
 
   QObject::connect(this->Implementation->Ui.Files->selectionModel(),
                   SIGNAL(
                     selectionChanged(const QItemSelection&, const QItemSelection&)),
-                  this, 
+                  this,
                   SLOT(fileSelectionChanged()));
 
-  QObject::connect(this->Implementation->Ui.Favorites, 
-                   SIGNAL(activated(const QModelIndex&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.Favorites,
+                   SIGNAL(activated(const QModelIndex&)),
+                   this,
                    SLOT(onActivateFavorite(const QModelIndex&)));
 
-  QObject::connect(this->Implementation->Ui.Recent, 
-                   SIGNAL(activated(const QModelIndex&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.Recent,
+                   SIGNAL(activated(const QModelIndex&)),
+                   this,
                    SLOT(onActivateRecent(const QModelIndex&)));
 
-  QObject::connect(this->Implementation->Ui.Files, 
-                   SIGNAL(activated(const QModelIndex&)), 
-                   this, 
-                   SLOT(onActivateFile(const QModelIndex&)));
+    QObject::connect(this->Implementation->Ui.Files,
+                   SIGNAL(doubleClicked(const QModelIndex&)),
+                   this,
+                   SLOT(onDoubleClickFile(const QModelIndex&)));
 
-  QObject::connect(this->Implementation->Ui.FileName, 
-                   SIGNAL(textEdited(const QString&)), 
-                   this, 
+  QObject::connect(this->Implementation->Ui.FileName,
+                   SIGNAL(textChanged(const QString&)),
+                   this,
                    SLOT(onTextEdited(const QString&)));
 
   QStringList filterList = MakeFilterList(nameFilter);
@@ -371,7 +415,7 @@ pqFileDialog::pqFileDialog(
     this->Implementation->Filters = filterList;
     }
   this->onFilterChange(this->Implementation->Ui.FileType->currentText());
-  
+
   QString startPath = startDirectory;
   if(startPath.isEmpty())
     {
@@ -390,11 +434,11 @@ pqFileDialog::~pqFileDialog()
 //-----------------------------------------------------------------------------
 void pqFileDialog::onCreateNewFolder()
 {
-  // Add a directory entry with a default name to the model 
-  // This actually creates a directory with the given name, 
-  //   but this temporary direectory will be deleted and a new one created 
-  //   once the user provides a new name for it. 
-  //   FIXME: I guess we could insert an item into the model without 
+  // Add a directory entry with a default name to the model
+  // This actually creates a directory with the given name,
+  //   but this temporary direectory will be deleted and a new one created
+  //   once the user provides a new name for it.
+  //   FIXME: I guess we could insert an item into the model without
   //    actually creating a new directory but this way I could reuse code.
   QString dirName = QString("New Folder");
   int i=0;
@@ -444,19 +488,24 @@ void pqFileDialog::onCreateNewFolder()
 //-----------------------------------------------------------------------------
 void pqFileDialog::onContextMenuRequested(const QPoint &menuPos)
 {
-  // Only display new dir option if we're saving, not opening
-  if (this->Implementation->Mode != pqFileDialog::AnyFile)
-    {
-    return;
-    }
-
   QMenu menu;
   menu.setObjectName("FileDialogContextMenu");
 
-  QAction *actionNewDir = new QAction("Create New Folder",this);
-  QObject::connect(actionNewDir, SIGNAL(triggered()), 
-      this, SLOT(onCreateNewFolder()));
-  menu.addAction(actionNewDir);
+  // Only display new dir option if we're saving, not opening
+  if (this->Implementation->Mode == pqFileDialog::AnyFile)
+    {
+    QAction *actionNewDir = new QAction("Create New Folder",this);
+      QObject::connect(actionNewDir, SIGNAL(triggered()),
+          this, SLOT(onCreateNewFolder()));
+    menu.addAction(actionNewDir);
+    }
+
+  QAction *actionHiddenFiles = new QAction("Show Hidden Files",this);
+  actionHiddenFiles->setCheckable( true );
+  actionHiddenFiles->setChecked( this->Implementation->FileFilter.getShowHidden());
+  QObject::connect(actionHiddenFiles, SIGNAL(triggered(bool)),
+    this, SLOT(onShowHiddenFiles(bool)));
+  menu.addAction(actionHiddenFiles);
 
   menu.exec(this->Implementation->Ui.Files->mapToGlobal(menuPos));
 }
@@ -464,32 +513,33 @@ void pqFileDialog::onContextMenuRequested(const QPoint &menuPos)
 //-----------------------------------------------------------------------------
 void pqFileDialog::setFileMode(pqFileDialog::FileMode mode)
 {
+  //this code is only needed for the 3.10 release as
+  //after that the user should know that the dialog support multiple file open
+  bool setupMutlipleFileHelp = false;
   this->Implementation->Mode = mode;
-  
+  QAbstractItemView::SelectionMode selectionMode;
   switch(this->Implementation->Mode)
     {
     case AnyFile:
     case ExistingFile:
     case Directory:
-        {
-        this->Implementation->Ui.Files->setSelectionMode(
-             QAbstractItemView::SingleSelection);
-        this->Implementation->Ui.Favorites->setSelectionMode(
-             QAbstractItemView::SingleSelection);
-        }
+    default:
+      selectionMode=QAbstractItemView::SingleSelection;
       break;
     case ExistingFiles:
-        {
-        // Currently, we can only support limited series files, 
-        // so SingleSelection mode is used here, and when a *group*
-        // file is selected, we internally get all series files in
-        // this group, and pass them along.
-        this->Implementation->Ui.Files->setSelectionMode(
-          QAbstractItemView::SingleSelection);
-        this->Implementation->Ui.Favorites->setSelectionMode(
-          QAbstractItemView::ExtendedSelection);
-        }
+      setupMutlipleFileHelp = (this->Implementation->ShowMultipleFileHelp != true);
+      selectionMode=QAbstractItemView::ExtendedSelection;
+      break;
     }
+  if (setupMutlipleFileHelp)
+    {
+    //only set the tooltip and window title the first time through
+    this->Implementation->ShowMultipleFileHelp = true;
+    this->setWindowTitle(this->windowTitle() + "  (open multiple files with <ctrl> key.)");
+    this->setToolTip("open multiple files with <ctrl> key.");
+    }
+  this->Implementation->Ui.Files->setSelectionMode(selectionMode);
+  this->Implementation->Ui.Favorites->setSelectionMode(selectionMode);
 }
 
 //-----------------------------------------------------------------------------
@@ -513,81 +563,153 @@ void pqFileDialog::setRecentlyUsedExtension(const QString& fileExtension)
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::emitFilesSelected(const QStringList& files)
+void pqFileDialog::addToFilesSelected(const QStringList& files)
 {
   // Ensure that we are hidden before broadcasting the selection,
   // so we don't get caught by screen-captures
   this->setVisible(false);
-  this->Implementation->SelectedFiles = files;
+  this->Implementation->SelectedFiles.append(files);
+  }
+
+//-----------------------------------------------------------------------------
+void pqFileDialog::emitFilesSelectionDone( )
+{
   emit filesSelected(this->Implementation->SelectedFiles);
+  if (this->Implementation->Mode != this->ExistingFiles
+    && this->Implementation->SelectedFiles.size() > 0)
+    {
+    emit filesSelected(this->Implementation->SelectedFiles[0]);
+    }
   this->done(QDialog::Accepted);
 }
-  
+
 //-----------------------------------------------------------------------------
-QStringList pqFileDialog::getSelectedFiles()
+QList<QStringList> pqFileDialog::getAllSelectedFiles()
 {
   return this->Implementation->SelectedFiles;
 }
 
+//-----------------------------------------------------------------------------
+QStringList pqFileDialog::getSelectedFiles(int index)
+{
+  if ( index < 0 || index >= this->Implementation->SelectedFiles.size())
+    {
+    return QStringList();
+    }
+  return this->Implementation->SelectedFiles[index];
+}
+
 //-----------------------------------------------------------------------------
 void pqFileDialog::accept()
 {
-  /* TODO:  handle pqFileDialog::ExistingFiles mode */
+  bool loadedFile = false;
+  switch(this->Implementation->Mode)
+  {
+  case AnyFile:
+  case Directory:
+    loadedFile = this->acceptDefault(false);
+    break;
+  case ExistingFiles:
+  case ExistingFile:
+    loadedFile = this->acceptExistingFiles();
+    break;
+  }
+  if (loadedFile)
+    {
+    emit this->emitFilesSelectionDone();
+    }
+}
+
+//-----------------------------------------------------------------------------
+bool pqFileDialog::acceptExistingFiles()
+{
+  bool loadedFiles = false;
+  QString filename;
+  if(this->Implementation->FileNames.size() == 0)
+    {
+    //when we have nothing selected in the current selection model, we will
+    //attempt to use the default way
+    return this->acceptDefault(true);
+    }
+  foreach(filename,this->Implementation->FileNames)
+    {
+    filename = filename.trimmed();
+
+    QString fullFilePath = this->Implementation->Model->absoluteFilePath(filename);
+    emit this->fileAccepted(fullFilePath);
+    loadedFiles = (this->acceptInternal(this->buildFileGroup(filename),false)
+        || loadedFiles);
+    }
+  return loadedFiles;
+}
+
+//-----------------------------------------------------------------------------
+bool pqFileDialog::acceptDefault(const bool &checkForGrouping)
+{
   QString filename = this->Implementation->Ui.FileName->text();
   filename = filename.trimmed();
 
   QString fullFilePath = this->Implementation->Model->absoluteFilePath(filename);
   emit this->fileAccepted(fullFilePath);
-  
+
   QStringList files;
-  if(this->Implementation->Mode != pqFileDialog::AnyFile)
+  if (checkForGrouping)
     {
-    // if we got a group, let's expand it.
-    QAbstractProxyModel* m = &this->Implementation->FileFilter;
-    int numrows = m->rowCount(QModelIndex());
-    for(int i=0; i<numrows; i++)
-      {
-      QModelIndex idx = m->index(i, 0, QModelIndex());
-      QString cmp = m->data(idx, Qt::DisplayRole).toString();
-      if(filename == cmp)
-        {
-        QModelIndex sidx = m->mapToSource(idx);
-        QStringList sel_files = this->Implementation->Model->getFilePaths(sidx);
-        for(int j=0; j<sel_files.count();j++)
-          {
-          files.push_back(sel_files.at(j));
-          if(this->Implementation->Mode == pqFileDialog::ExistingFile)
-            {
-            break;
-            }
-          }
-        }
-      }
+    files = this->buildFileGroup(filename);
     }
   else
     {
-    files.push_back(fullFilePath);
+    files = QStringList(fullFilePath);
     }
+  return this->acceptInternal(files,false);
 
+}
+
+//-----------------------------------------------------------------------------
+QStringList pqFileDialog::buildFileGroup(const QString &filename)
+{
+  QStringList files;
+
+  // if we find the file passed in is the parent of a group,
+  // add the entire group to the return QList
+  QAbstractProxyModel* m = &this->Implementation->FileFilter;
+  int numrows = m->rowCount(QModelIndex());
+  for(int i=0; i<numrows; i++)
+    {
+    QModelIndex idx = m->index(i, 0, QModelIndex());
+    QString cmp = m->data(idx, Qt::DisplayRole).toString();
+    if(filename == cmp)
+      {
+      QModelIndex sidx = m->mapToSource(idx);
+      QStringList sel_files = this->Implementation->Model->getFilePaths(sidx);
+      for(int j=0; j < sel_files.count(); ++j)
+        {
+        files.push_back(sel_files.at(j));
+        }
+      }
+    }
   if(files.empty())
     {
-    filename = this->Implementation->Model->absoluteFilePath(filename);
-    files.append(filename);
+    files.append(this->Implementation->Model->absoluteFilePath(filename));
     }
-
-  this->acceptInternal(files);
+  return files;
 }
 
 //-----------------------------------------------------------------------------
 void pqFileDialog::onModelReset()
 {
   this->Implementation->Ui.Parents->clear();
-  
+
   QString currentPath = this->Implementation->Model->getCurrentPath();
-  QChar separator = this->Implementation->Model->separator();
+  //clean the path to always look like a unix path
+  currentPath = QDir::cleanPath( currentPath );
+
+  //the separator is always the unix separator
+  QChar separator = '/';
+
   QStringList parents = currentPath.split(separator, QString::SkipEmptyParts);
-  
-  // put our root back in,  could be \\ (UNC), \ (Windows), / (Unix)
+
+  // put our root back in
   if(parents.count())
     {
     int idx = currentPath.indexOf(parents[0]);
@@ -614,8 +736,8 @@ void pqFileDialog::onModelReset()
       }
     this->Implementation->Ui.Parents->addItem(str);
     }
-    
-  this->Implementation->Ui.Parents->setCurrentIndex(parents.size() - 1);
+   this->Implementation->Ui.Parents->setCurrentIndex(parents.size() - 1);
+
 }
 
 //-----------------------------------------------------------------------------
@@ -638,16 +760,16 @@ void pqFileDialog::onNavigateDown(const QModelIndex& idx)
 {
   if(!this->Implementation->Model->isDir(idx))
     return;
-    
+
   const QStringList paths = this->Implementation->Model->getFilePaths(idx);
 
   if(1 != paths.size())
     return;
-    
+
   this->Implementation->addHistory(this->Implementation->Model->getCurrentPath());
   this->Implementation->setCurrentPath(paths[0]);
 }
-  
+
 //-----------------------------------------------------------------------------
 void pqFileDialog::onNavigateBack()
 {
@@ -665,11 +787,9 @@ void pqFileDialog::onNavigateForward()
 //-----------------------------------------------------------------------------
 void pqFileDialog::onFilterChange(const QString& filter)
 {
-  QStringList fs = GetWildCardsFromFilter(filter);
-
   // set filter on proxy
-  this->Implementation->FileFilter.setFilter(fs);
-  
+  this->Implementation->FileFilter.setFilter(filter);
+
   // update view
   this->Implementation->FileFilter.clear();
 }
@@ -687,7 +807,7 @@ void pqFileDialog::onClickedRecent(const QModelIndex&)
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::onClickedFile(const QModelIndex&)
+void pqFileDialog::onClickedFile(const QModelIndex& vtkNotUsed(index))
 {
   this->Implementation->Ui.Favorites->clearSelection();
 }
@@ -712,23 +832,67 @@ void pqFileDialog::onActivateRecent(const QModelIndex& index)
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::onActivateFile(const QModelIndex& index)
+void pqFileDialog::onDoubleClickFile(const QModelIndex& index)
 {
-  QModelIndex actual_index = index;
-  if(actual_index.model() == &this->Implementation->FileFilter)
-    actual_index = this->Implementation->FileFilter.mapToSource(actual_index);
-    
-  QStringList selected_files;
-  selected_files << this->Implementation->Model->getFilePaths(actual_index);
+  if ( this->Implementation->Mode == Directory)
+    {
+    QModelIndex actual_index = index;
+    if(actual_index.model() == &this->Implementation->FileFilter)
+      actual_index = this->Implementation->FileFilter.mapToSource(actual_index);
 
-  this->acceptInternal(selected_files);
+    QStringList selected_files;
+    QStringList paths;
+    QString path;
+
+    paths = this->Implementation->Model->getFilePaths(actual_index);
+    foreach(path, paths)
+      {
+      selected_files <<
+        this->Implementation->Model->absoluteFilePath( path );
+      }
+    this->acceptInternal(selected_files,true);
+    }
+  else
+    {
+    this->accept();
+    }
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::onTextEdited(const QString&)
+void pqFileDialog::onShowHiddenFiles( const bool &hidden )
+{
+  this->Implementation->FileFilter.setShowHidden(hidden);
+}
+
+
+//-----------------------------------------------------------------------------
+void pqFileDialog::setShowHidden( const bool &hidden )
+{
+  this->onShowHiddenFiles(hidden);
+}
+
+//-----------------------------------------------------------------------------
+bool pqFileDialog::getShowHidden()
+{
+  return this->Implementation->FileFilter.getShowHidden();
+}
+
+//-----------------------------------------------------------------------------
+void pqFileDialog::onTextEdited(const QString &str)
 {
   this->Implementation->Ui.Favorites->clearSelection();
-  this->Implementation->Ui.Files->clearSelection();
+  if (str.size() > 0 )
+    {
+    pqFileDialog::FileMode realMode = this->Implementation->Mode;    
+    this->setFileMode(pqFileDialog::ExistingFile);
+    this->Implementation->Ui.Files->keyboardSearch(str);
+    this->setFileMode(realMode);
+    }
+  else
+    {
+    this->Implementation->Ui.Files->clearSelection();
+    this->Implementation->FileNames.clear();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -769,7 +933,7 @@ QString pqFileDialog::fixFileExtension(
       else
         {
         // we have a filter which does not specify any rule for the extension.
-        // In that case, just assume the extension matched. 
+        // In that case, just assume the extension matched.
         pass = true;
         break;
         }
@@ -795,13 +959,14 @@ QString pqFileDialog::fixFileExtension(
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::acceptInternal(QStringList& selected_files)
+bool pqFileDialog::acceptInternal(const QStringList& selected_files,
+  const bool &doubleclicked)
 {
   if(selected_files.empty())
     {
-    return;
+    return false;
     }
-    
+
   QString file = selected_files[0];
   // User chose an existing directory
   if(this->Implementation->Model->dirExists(file, file))
@@ -809,9 +974,12 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
     switch(this->Implementation->Mode)
       {
       case Directory:
-        this->emitFilesSelected(QStringList(file));
-        break;
-
+        if ( !doubleclicked )
+          {
+          this->addToFilesSelected(QStringList(file));
+          this->onNavigate(file);
+          return true;
+          }
       case ExistingFile:
       case ExistingFiles:
       case AnyFile:
@@ -819,7 +987,7 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
         this->Implementation->Ui.FileName->clear();
         break;
       }
-    return;
+    return false;
     }
 
   // User choose and existing file or a brand new filename.
@@ -836,7 +1004,7 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
       {
       this->onNavigate(file);
       this->Implementation->Ui.FileName->clear();
-      return;
+      return false;
       }
     }
 
@@ -848,17 +1016,11 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
       case Directory:
         // User chose a file in directory mode, do nothing
         this->Implementation->Ui.FileName->clear();
-        return;
+        break;
       case ExistingFile:
       case ExistingFiles:
-        {
-        // TODO: we need to verify that all selected files are indeed
-        // "existing".
-        // User chose an existing file-or-files, we're done
-        QStringList files(selected_files);
-        this->emitFilesSelected(files);
-        }
-        return;
+        this->addToFilesSelected(selected_files);
+        break;
       case AnyFile:
         // User chose an existing file, prompt before overwrite
         if(!this->Implementation->SupressOverwriteWarning)
@@ -870,12 +1032,13 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
             QMessageBox::Yes,
             QMessageBox::No))
             {
-            return;
+            return false;
             }
           }
-        this->emitFilesSelected(QStringList(file));
-        return;
+        this->addToFilesSelected(QStringList(file));
+        break;
       }
+    return true;
     }
   else // User choose non-existent file.
     {
@@ -885,13 +1048,14 @@ void pqFileDialog::acceptInternal(QStringList& selected_files)
     case ExistingFile:
     case ExistingFiles:
       this->Implementation->Ui.FileName->selectAll();
-      return;
+      return false;
 
     case AnyFile:
-      this->emitFilesSelected(QStringList(file));
-      return;
+      this->addToFilesSelected(QStringList(file));
+      return true;
       }
     }
+  return false;
 }
 
 //-----------------------------------------------------------------------------
@@ -900,16 +1064,16 @@ void pqFileDialog::fileSelectionChanged()
   // Selection changed, update the FileName entry box
   // to reflect the current selection.
   QString fileString;
-
   const QModelIndexList indices =
     this->Implementation->Ui.Files->selectionModel()->selectedIndexes();
-
   if(indices.isEmpty())
     {
     // do not change the FileName text if no selections
     return;
     }
+  QStringList fileNames;
 
+  QString name;
   for(int i = 0; i != indices.size(); ++i)
     {
     QModelIndex index = indices[i];
@@ -917,18 +1081,48 @@ void pqFileDialog::fileSelectionChanged()
       {
       continue;
       }
-      
     if(index.model() == &this->Implementation->FileFilter)
       {
-      fileString += this->Implementation->FileFilter.data(index).toString() +
-                    " ";
+      name = this->Implementation->FileFilter.data(index).toString();
+      fileString += name;
+      if ( i != indices.size()-1 )
+        {
+        fileString += this->Implementation->FileNamesSeperator;
+        }
+      fileNames.append(name);
       }
     }
 
+  //if we are in directory mode we have to enable / disable the OK button
+  //based on if the user has selected a file.
+  if ( this->Implementation->Mode == pqFileDialog::Directory &&
+    indices[0].model() == &this->Implementation->FileFilter)
+    {
+    QModelIndex idx = this->Implementation->FileFilter.mapToSource(indices[0]);
+    bool enabled = this->Implementation->Model->isDir(idx);
+    this->Implementation->Ui.OK->setEnabled( enabled );
+    if ( enabled )
+      {
+      this->Implementation->Ui.FileName->setText(fileString);
+      }
+    else
+      {
+      this->Implementation->Ui.FileName->clear();
+      }
+    return;
+    }
 
-  this->Implementation->Ui.FileName->setText(fileString);
+  if (!this->Implementation->Ui.FileName->hasFocus())
+    {
+    //user is currently editing a name, don't change the text
+    this->Implementation->Ui.FileName->blockSignals(true);
+    this->Implementation->Ui.FileName->setText(fileString);
+    this->Implementation->Ui.FileName->blockSignals(false);
+    }
+  this->Implementation->FileNames = fileNames;
 }
 
+//-----------------------------------------------------------------------------
 bool pqFileDialog::selectFile(const QString& f)
 {
   // We don't use QFileInfo here since it messes the paths up if the client and
@@ -961,3 +1155,13 @@ bool pqFileDialog::selectFile(const QString& f)
   return true;
 }
 
+//-----------------------------------------------------------------------------
+void pqFileDialog::showEvent(QShowEvent *_showEvent )
+{  
+  QDialog::showEvent(_showEvent);
+  //Qt sets the default keyboard focus to the last item in the tab order
+  //which is determined by the creation order. This means that we have 
+  //to explicitly state that the line edit has the focus on showing no 
+  //matter the tab order
+  this->Implementation->Ui.FileName->setFocus(Qt::OtherFocusReason);
+}
