@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqHelperProxyRegisterUndoElement.h,v $
+   Module:    pqHelperProxyRegisterUndoElement.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -52,7 +52,7 @@ class PQCORE_EXPORT pqHelperProxyRegisterUndoElement : public vtkSMUndoElement
 {
 public:
   static pqHelperProxyRegisterUndoElement* New();
-  vtkTypeRevisionMacro(pqHelperProxyRegisterUndoElement, vtkSMUndoElement);
+  vtkTypeMacro(pqHelperProxyRegisterUndoElement, vtkSMUndoElement);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   /// Description:
