@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program:   ParaView
-   Module:    $RCSfile: pqLinksModel.cxx,v $
+   Module:    pqLinksModel.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -68,7 +68,8 @@ public:
     vtkSMProxyManager::RegisteredProxyInformation *info =
       reinterpret_cast<vtkSMProxyManager::RegisteredProxyInformation *>(callData);
 
-    if(!info || !info->IsLink)
+    if(!info ||
+      info->Type != vtkSMProxyManager::RegisteredProxyInformation::LINK)
       {
       return;
       }
