@@ -385,6 +385,7 @@ pqView* pqObjectBuilder::createView(const QString& type,
     }
 
   proxy->SetConnectionID(server->GetConnectionID());
+  proxy->UpdateVTKObjects();
 
   QString name = ::pqObjectBuilderGetName(proxy, this->NameGenerator);
   pxm->RegisterProxy("views", name.toAscii().data(), proxy);
@@ -509,13 +510,16 @@ pqDataRepresentation* pqObjectBuilder::createDataRepresentation(
   pqApplicationCore* core= pqApplicationCore::instance();
   pqDataRepresentation* repr = core->getServerManagerModel()->
     findItem<pqDataRepresentation*>(reprProxy);
-  if (repr)
+  if (repr )
     {
+    //hack for text representations
+    if (strcmp(repr->metaObject()->className(),"pqTextRepresentation") != 0 )
+      {
+      // inherit properties from the representation for the input if applicable.
+      this->initializeInheritedProperties(repr);
+      }
     repr->setDefaultPropertyValues();
 
-    // inherit properties from the representation for the input if applicable.
-    this->initializeInheritedProperties(repr);
-
     emit this->dataRepresentationCreated(repr);
     emit this->proxyCreated(repr);
     }
@@ -793,6 +797,18 @@ void pqObjectBuilder::destroyProxyInternal(pqProxy* proxy)
 //-----------------------------------------------------------------------------
 QString pqObjectBuilder::getFileNamePropertyName(vtkSMProxy* proxy)
 {
+  if (proxy->GetHints())
+    {
+    vtkPVXMLElement* filenameHint =
+      proxy->GetHints()->FindNestedElementByName("DefaultFileNameProperty");
+    if (filenameHint &&
+      filenameHint->GetAttribute("name") &&
+      proxy->GetProperty(filenameHint->GetAttribute("name")))
+      {
+      return filenameHint->GetAttribute("name");
+      }
+    }
+
   // Find the first property that has a vtkSMFileListDomain. Assume that
   // it is the property used to set the filename.
   vtkSmartPointer<vtkSMPropertyIterator> piter;
@@ -932,36 +948,35 @@ void pqObjectBuilder::destroy(pqAnimationCue* cue)
 //-----------------------------------------------------------------------------
 void pqObjectBuilder::initializeInheritedProperties(pqDataRepresentation* repr)
 {
- vtkPVXMLElement* hints = repr->getProxy()->GetHints();
- hints = hints? hints->FindNestedElementByName("InheritRepresentationProperties") : 0;
- if (hints == 0)
-   {
-   return;
-   }
-
- pqDataRepresentation* input_repr = 
-   repr->getRepresentationForUpstreamSource();
- if (!input_repr)
-   {
-   return;
-   }
-
- vtkSMProxy* reprProxy = repr->getProxy();
- vtkSMProxy* inputReprProxy = input_repr->getProxy();
-  unsigned int num_children = hints->GetNumberOfNestedElements();
-  for (unsigned int cc=0; cc < num_children; cc++)
+  pqDataRepresentation* input_repr =
+    repr->getRepresentationForUpstreamSource();
+  if (!input_repr)
     {
-    vtkPVXMLElement* child = hints->GetNestedElement(cc);
-    if (child && child->GetName() && strcmp(child->GetName(), "Property") == 0)
+    return;
+    }
+
+  QSet<QString> exceptions;
+  exceptions.insert("Representation");
+
+  vtkSMProxy* reprProxy = repr->getProxy();
+  vtkSMProxy* inputReprProxy = input_repr->getProxy();
+  vtkSMPropertyIterator* iter = inputReprProxy->NewPropertyIterator();
+  for (iter->Begin(); !iter->IsAtEnd(); iter->Next())
+    {
+    const char* pname = iter->GetKey();
+    if (exceptions.contains(pname))
       {
-      const char* propname = child->GetAttribute("name");
-      if (propname && reprProxy->GetProperty(propname) &&
-        inputReprProxy->GetProperty(propname))
-        {
-        reprProxy->GetProperty(propname)->Copy(
-          inputReprProxy->GetProperty(propname));
-        }
+      continue;
+      }
+    vtkSMProperty* dest = reprProxy->GetProperty(pname);
+    vtkSMProperty* source = iter->GetProperty();
+    if (dest && source &&
+      strcmp(dest->GetClassName(), source->GetClassName())==0 &&
+      !dest->IsA("vtkSMProxyProperty"))
+      {
+      dest->Copy(source);
       }
     }
+  iter->Delete();
   reprProxy->UpdateVTKObjects();
 }
