@@ -2,7 +2,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqOptions.cxx,v $
+   Module:    pqOptions.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -37,31 +37,57 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkstd/string>
 
 vtkStandardNewMacro(pqOptions);
-vtkCxxRevisionMacro(pqOptions, "$Revision: 1.8 $");
+
+static int AddTestScript(const char*, const char* value, void* call_data)
+{
+  pqOptions* self = reinterpret_cast<pqOptions*>(call_data);
+  if (self)
+    {
+    return self->AddTestScript(value);
+    }
+  return 0;
+}
+
+static int AddTestBaseline(const char*, const char* value, void* call_data)
+{
+  pqOptions* self = reinterpret_cast<pqOptions*>(call_data);
+  if (self)
+    {
+    return self->SetLastTestBaseline(value);
+    }
+  return 0;
+}
+
+static int AddTestImageThreshold(const char*, const char* value, void* call_data)
+{
+  pqOptions* self = reinterpret_cast<pqOptions*>(call_data);
+  if (self)
+    {
+    return self->SetLastTestImageThreshold(QString(value).toInt());
+    }
+  return 0;
+}
 
 //-----------------------------------------------------------------------------
 pqOptions::pqOptions()
 {
-  this->BaselineImage = 0;
   this->TestDirectory = 0;
   this->DataDirectory = 0;
-  this->ImageThreshold = 12;
   this->ExitAppWhenTestsDone = 0;
   this->DisableRegistry = 0;
-  this->TestFileName = 0;
-  this->TestInitFileName = 0;
   this->ServerResourceName = 0;
+  this->DisableLightKit = 0;
+  this->CurrentImageThreshold = 12;
+  this->PythonScript = 0;
 }
 
 //-----------------------------------------------------------------------------
 pqOptions::~pqOptions()
 {
-  this->SetBaselineImage(0);
   this->SetTestDirectory(0);
   this->SetDataDirectory(0);
-  this->SetTestFileName(0);
-  this->SetTestInitFileName(0);
   this->SetServerResourceName(0);
+  this->SetPythonScript(0);
 }
 
 //-----------------------------------------------------------------------------
@@ -69,10 +95,6 @@ void pqOptions::Initialize()
 {
   this->Superclass::Initialize();
   
-  this->AddArgument("--compare-view", NULL, 
-    &this->BaselineImage,
-    "Compare the viewport to a reference image, and exit.");
-  
   this->AddArgument("--test-directory", NULL,
     &this->TestDirectory,
     "Set the temporary directory where test-case output will be stored.");
@@ -81,15 +103,6 @@ void pqOptions::Initialize()
     &this->DataDirectory,
     "Set the data directory where test-case data are.");
  
-  this->AddArgument("--run-test", NULL,
-    &this->TestFileName,  "Run a recorded test case.");
-
-  this->AddArgument("--run-test-init", NULL,
-    &this->TestInitFileName,  "Run a recorded test initialization case.");
-  
-  this->AddArgument("--image-threshold", NULL, &this->ImageThreshold,
-    "Set the threshold beyond which viewport-image comparisons fail.");
-
   this->AddBooleanArgument("--exit", NULL, &this->ExitAppWhenTestsDone,
     "Exit application when testing is done. Use for testing.");
 
@@ -99,50 +112,87 @@ void pqOptions::Initialize()
   this->AddArgument("--server", "-s",
     &this->ServerResourceName,
     "Set the name of the server resource to connect with when the client starts.");
+
+  this->AddBooleanArgument("--disable-light-kit", 0,
+    &this->DisableLightKit,
+    "When present, disables light kit by default. Useful for dashboard tests.");
+
+  this->AddCallback("--test-script", NULL,
+    &::AddTestScript, this, "Add test script. Can be used multiple times to "
+    "specify multiple tests.");
+  this->AddCallback("--test-baseline", NULL,
+    &::AddTestBaseline, this,
+    "Add test baseline. Can be used multiple times to specify "
+    "multiple baselines for multiple tests, in order.");
+  this->AddCallback("--test-threshold", NULL,
+    &::AddTestImageThreshold, this,
+    "Add test image threshold. "
+    "Can be used multiple times to specify multiple image thresholds for "
+    "multiple tests in order.");
+
+  this->AddArgument("--script", NULL,
+    &this->PythonScript,
+    "Set a python script to be evaluated on startup.");
+}
+
+//-----------------------------------------------------------------------------
+QStringList pqOptions::GetTestScripts()
+{
+  QStringList list;
+  for (int cc=0; cc < this->GetNumberOfTestScripts(); cc++)
+    {
+    list << this->GetTestScript(cc);
+    }
+  return list;
 }
 
 //-----------------------------------------------------------------------------
 int pqOptions::PostProcess(int argc, const char * const *argv)
 {
-  this->TestFiles.clear();
-  if (this->TestInitFileName)
-    {
-    this->TestFiles << QString(this->TestInitFileName);
-    }
-  if (this->TestFileName)
-    {
-    this->TestFiles << QString(this->TestFileName);
-    }
   return this->Superclass::PostProcess(argc, argv);
 }
 
 //-----------------------------------------------------------------------------
 int pqOptions::WrongArgument(const char* arg)
 {
-  vtkstd::string argument = arg;
-  int index = argument.find('=');
-  if ( index != -1)
-    {
-    vtkstd::string key = argument.substr(0, index);
-    vtkstd::string value = argument.substr(index+1);
-    if (key == "--run-test")
-      {
-      this->TestFiles.push_back(value.c_str());
-      return 1;
-      }
-    }
   return this->Superclass::WrongArgument(arg);
 }
 
+//-----------------------------------------------------------------------------
+int pqOptions::AddTestScript(const char* script)
+{
+  TestInfo info;
+  info.TestFile = script;
+  this->TestScripts.push_back(info);
+  return 1;
+}
+//-----------------------------------------------------------------------------
+int pqOptions::SetLastTestBaseline(const char* image)
+{
+  if (this->TestScripts.size() == 0)
+    {
+    this->AddTestScript("-not-specified");
+    }
+  this->TestScripts.last().TestBaseline = image;
+  return 1;
+}
+
+//-----------------------------------------------------------------------------
+int pqOptions::SetLastTestImageThreshold(int threshold)
+{
+  if (this->TestScripts.size() == 0)
+    {
+    this->AddTestScript("-not-specified");
+    }
+  this->TestScripts.last().ImageThreshold = threshold;
+  return 1;
+}
+
 //-----------------------------------------------------------------------------
 void pqOptions::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "ImageThreshold: " << this->ImageThreshold
-    << endl;
-  os << indent << "BaselineImage: " << (this->BaselineImage?
-    this->BaselineImage : "(none)") << endl;
   os << indent << "TestDirectory: " << (this->TestDirectory?
     this->TestDirectory : "(none)") << endl;
   os << indent << "DataDirectory: " << (this->DataDirectory?
@@ -150,4 +200,7 @@ void pqOptions::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "ServerResourceName: " 
     << (this->ServerResourceName? this->ServerResourceName : "(none)") << endl;
+
+  os << indent << "PythonScript: " << 
+    (this->PythonScript? this->PythonScript : "(none)") << endl;
 }
