@@ -38,7 +38,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // ParaView Server Manager includes.
 #include "vtkCommand.h"
+#include "vtkDataObject.h"
 #include "vtkEventQtSlotConnect.h"
+#include "vtkGeometryRepresentation.h"
 #include "vtkMath.h"
 #include "vtkProcessModule.h"
 #include "vtkProperty.h"
@@ -47,15 +49,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkPVGeometryInformation.h"
 #include "vtkPVTemporalDataInformation.h"
 #include "vtkScalarsToColors.h"
-#include "vtkSmartPointer.h" 
+#include "vtkSmartPointer.h"
 #include "vtkSMDoubleVectorProperty.h"
 #include "vtkSMGlobalPropertiesManager.h"
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMProxyProperty.h"
 #include "vtkSMPVRepresentationProxy.h"
-#include "vtkSMSourceProxy.h"
-#include "vtkSMSurfaceRepresentationProxy.h"
 
 // Qt includes.
 #include <QList>
@@ -86,7 +86,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqPipelineRepresentation::pqInternal
 {
 public:
-  vtkSmartPointer<vtkSMPropRepresentationProxy> RepresentationProxy;
+  vtkSmartPointer<vtkSMRepresentationProxy> RepresentationProxy;
   vtkSmartPointer<vtkEventQtSlotConnect> VTKConnect;
 //  pqScalarOpacityFunction *Opacity;
 
@@ -96,36 +96,33 @@ public:
 //    this->Opacity = 0;
     }
 
-  // Convenience method to get array information.
-  vtkPVArrayInformation* getArrayInformation(
-    const char* arrayname, int fieldType, vtkPVDataInformation* argInfo=0)
+  static vtkPVArrayInformation* getArrayInformation(const pqPipelineRepresentation* repr,
+    const char* arrayname, int fieldType)
     {
-    if (!arrayname || !arrayname[0] || !this->RepresentationProxy)
+    if (!arrayname || !arrayname[0] || !repr)
       {
-      return 0; 
-      }
-    vtkSMDataRepresentationProxy* repr = this->RepresentationProxy;
-    vtkPVDataInformation* dataInfo = argInfo? argInfo: repr->GetRepresentedDataInformation();
-    if(!dataInfo)
-      {
-      return 0;
+      return NULL;
       }
 
-    vtkPVArrayInformation* info = NULL;
-    if(fieldType == vtkSMDataRepresentationProxy::CELL_DATA)
+    vtkPVDataInformation* dataInformation = repr->getInputDataInformation();
+    vtkPVArrayInformation* arrayInfo = NULL;
+    if (dataInformation)
       {
-      vtkPVDataSetAttributesInformation* cellinfo = 
-        dataInfo->GetCellDataInformation();
-      info = cellinfo->GetArrayInformation(arrayname);
+      arrayInfo = dataInformation->GetAttributeInformation(fieldType)->
+        GetArrayInformation(arrayname);
       }
-    else
+    if (!arrayInfo)
       {
-      vtkPVDataSetAttributesInformation* pointinfo = 
-        dataInfo->GetPointDataInformation();
-      info = pointinfo->GetArrayInformation(arrayname);
+      dataInformation = repr->getRepresentedDataInformation();
+      if (dataInformation)
+        {
+        arrayInfo = dataInformation->GetAttributeInformation(fieldType)->
+          GetArrayInformation(arrayname);
+        }
       }
-    return info;
+    return arrayInfo;
     }
+
 };
 
 //-----------------------------------------------------------------------------
@@ -138,11 +135,11 @@ pqPipelineRepresentation::pqPipelineRepresentation(
 {
   this->Internal = new pqPipelineRepresentation::pqInternal();
   this->Internal->RepresentationProxy
-    = vtkSMPropRepresentationProxy::SafeDownCast(display);
+    = vtkSMRepresentationProxy::SafeDownCast(display);
 
   if (!this->Internal->RepresentationProxy)
     {
-    qFatal("Display given is not a vtkSMPropRepresentationProxy.");
+    qFatal("Display given is not a vtkSMRepresentationProxy.");
     }
 
   // If any of these properties change, we know that the coloring for the
@@ -189,7 +186,7 @@ pqPipelineRepresentation::~pqPipelineRepresentation()
 }
 
 //-----------------------------------------------------------------------------
-vtkSMPropRepresentationProxy* pqPipelineRepresentation::getRepresentationProxy() const
+vtkSMRepresentationProxy* pqPipelineRepresentation::getRepresentationProxy() const
 {
   return this->Internal->RepresentationProxy;
 }
@@ -284,7 +281,7 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
   // created from LookupTableManager (Bug# 0008876)
   // this->createHelperProxies();
 
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   if (!repr)
     {
     return;
@@ -386,6 +383,24 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
         "Outline");
       }
     }
+  // Locate input display.
+  pqPipelineRepresentation* upstreamDisplay =
+    qobject_cast<pqPipelineRepresentation*>(
+      this->getRepresentationForUpstreamSource());
+  if (upstreamDisplay &&
+    vtkSMPropertyHelper(repr, "Representation").GetAsInt() == vtkSMPVRepresentationProxy::OUTLINE)
+    {
+    // try to preserve the upstream representation type (except for volume
+    // rendering).
+    int reprType = upstreamDisplay->getRepresentationType();
+    if (reprType != vtkSMPVRepresentationProxy::VOLUME)
+      {
+      pqSMAdaptor::setElementProperty(repr->GetProperty("Representation"),
+        reprType);
+      }
+    }
+
+
   if (repr->GetProperty("ScalarOpacityUnitDistance"))
     {
     double bounds[6];
@@ -412,16 +427,19 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     }
   repr->UpdateVTKObjects();
 
-  geomInfo = repr->GetRepresentedDataInformation(/*update=*/true);
+  if (pqSMAdaptor::getEnumerationProperty(repr->GetProperty("Representation"))
+    == "Outline")
+    {
+    // no need to determine scalar coloring for outline representation.
+    return;
+    }
 
-  // Locate input display.
-  pqPipelineRepresentation* upstreamDisplay = 
-    qobject_cast<pqPipelineRepresentation*>(
-      this->getRepresentationForUpstreamSource());
+  // update the input using the current application time.
+  this->getInput()->updatePipeline();
+  geomInfo = this->getInputDataInformation();
   if (upstreamDisplay)
     {
-    inGeomInfo = upstreamDisplay->getRepresentationProxy()->
-      GetRepresentedDataInformation();
+    inGeomInfo = upstreamDisplay->getInputDataInformation();
     }
 
   vtkPVArrayInformation* chosenArrayInfo = 0;
@@ -437,11 +455,11 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     pqPipelineRepresentation::getColorArray(attrInfo, inAttrInfo, arrayInfo);
     if (arrayInfo)
       {
-      chosenFieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+      chosenFieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
       chosenArrayInfo = arrayInfo;
       }
     }
-    
+
   // Check for new cell scalars.
   if (!chosenArrayInfo && geomInfo)
     {
@@ -450,11 +468,11 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     pqPipelineRepresentation::getColorArray(attrInfo, inAttrInfo, arrayInfo);
     if (arrayInfo)
       {
-      chosenFieldType = vtkSMDataRepresentationProxy::CELL_DATA;
+      chosenFieldType = vtkDataObject::FIELD_ASSOCIATION_CELLS;
       chosenArrayInfo = arrayInfo;
       }
     }
-   
+
   if (!chosenArrayInfo && geomInfo)
     {
     // Check for scalars in geometry
@@ -463,7 +481,7 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     if (arrayInfo)
       {
       chosenArrayInfo = arrayInfo;
-      chosenFieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+      chosenFieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
       }
     }
 
@@ -475,7 +493,7 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     if(arrayInfo)
       {
       chosenArrayInfo = arrayInfo;
-      chosenFieldType = vtkSMDataRepresentationProxy::CELL_DATA;
+      chosenFieldType = vtkDataObject::FIELD_ASSOCIATION_CELLS;
       }
     }
 
@@ -489,20 +507,25 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     this->colorByArray(chosenArrayInfo->GetName(), chosenFieldType);
     return;
     }
-  
-  QList<QString> myColorFields = this->getColorFields();
 
   // Try to inherit the same array selected by the input.
   if (upstreamDisplay)
     {
-    const QString &upstreamColorField = upstreamDisplay->getColorField(false);
-    if (myColorFields.contains(upstreamColorField))
+    vtkSMPropertyHelper colorAttrType(upstreamDisplay->getProxy(),
+      "ColorAttributeType");
+    vtkSMPropertyHelper colorArrayName(upstreamDisplay->getProxy(),
+      "ColorArrayName");
+    if (pqInternal::getArrayInformation(
+        this, colorArrayName.GetAsString(), colorAttrType.GetAsInt()))
       {
-      this->setColorField(upstreamColorField);
+      this->colorByArray(
+        colorArrayName.GetAsString(), colorAttrType.GetAsInt());
       return;
       }
     }
 
+  QList<QString> myColorFields = this->getColorFields();
+
   // We are going to set the default color mode to use solid color i.e. not use
   // scalar coloring at all. However, for some representations (eg. slice/volume)
   // this is an error, we have to color by some array. Since no active scalar
@@ -525,15 +548,29 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
 int pqPipelineRepresentation::getNumberOfComponents(
   const char* arrayname, int fieldtype)
 {
-  vtkPVArrayInformation* info = this->Internal->getArrayInformation(
+  vtkPVArrayInformation* info = pqInternal::getArrayInformation(this,
     arrayname, fieldtype);
   return (info? info->GetNumberOfComponents() : 0);
 }
+//-----------------------------------------------------------------------------
+QString pqPipelineRepresentation::getComponentName(
+  const char* arrayname, int fieldtype, int component)
+{
+  vtkPVArrayInformation* info = pqInternal::getArrayInformation(this,
+    arrayname, fieldtype);
 
+   if ( info )
+     {
+     return QString (info->GetComponentName( component ) );     
+     }  
+
+   //failed to find info, return empty string
+  return QString();
+}
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype)
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   if (!repr)
     {
     return;
@@ -638,7 +675,7 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
       old_stc->hideUnusedScalarBars();
       }
 
-  if(fieldtype == vtkSMDataRepresentationProxy::CELL_DATA)
+  if(fieldtype == vtkDataObject::FIELD_ASSOCIATION_CELLS)
     {
     pqSMAdaptor::setEnumerationProperty(
       repr->GetProperty("ColorAttributeType"), "CELL_DATA");
@@ -658,8 +695,7 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
   
   if (current_scalar_bar_visibility && lut_mgr && this->getLookupTable())
     {
-    lut_mgr->setScalarBarVisibility(this->getView(),
-      this->getLookupTable(),
+    lut_mgr->setScalarBarVisibility(this,
       current_scalar_bar_visibility);
     }
 }
@@ -688,7 +724,7 @@ int pqPipelineRepresentation::getRepresentationType() const
     case VTK_WIREFRAME:
       return vtkSMPVRepresentationProxy::WIREFRAME;
 
-    case VTK_SURFACE_WITH_EDGES:
+    case vtkGeometryRepresentation::SURFACE_WITH_EDGES:
       return vtkSMPVRepresentationProxy::SURFACE_WITH_EDGES;
 
     case VTK_SURFACE:
@@ -755,7 +791,7 @@ void pqPipelineRepresentation::resetLookupTableScalarRange()
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::resetLookupTableScalarRangeOverTime()
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   pqScalarsToColors* lut = this->getLookupTable();
   QString colorField = this->getColorField(true);
 
@@ -885,7 +921,7 @@ void pqPipelineRepresentation::getColorArray(
 //-----------------------------------------------------------------------------
 QList<QString> pqPipelineRepresentation::getColorFields()
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
 
   QList<QString> ret;
   if(!repr)
@@ -904,7 +940,7 @@ QList<QString> pqPipelineRepresentation::getColorFields()
     }
 
   vtkPVDataInformation* geomInfo = NULL;
-  geomInfo = repr->GetRepresentedDataInformation(true);
+  geomInfo = repr->GetRepresentedDataInformation();
   if(!geomInfo)
     {
     return ret;
@@ -975,7 +1011,7 @@ QList<QString> pqPipelineRepresentation::getColorFields()
 int pqPipelineRepresentation::getColorFieldNumberOfComponents(const QString& array)
 {
   QString field = array;
-  int fieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+  int fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
 
   if(field == pqPipelineRepresentation::solidColor())
     {
@@ -984,23 +1020,47 @@ int pqPipelineRepresentation::getColorFieldNumberOfComponents(const QString& arr
   if(field.right(strlen(" (cell)")) == " (cell)")
     {
     field.chop(strlen(" (cell)"));
-    fieldType = vtkSMDataRepresentationProxy::CELL_DATA;
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_CELLS;
     }
   else if(field.right(strlen(" (point)")) == " (point)")
     {
     field.chop(strlen(" (point)"));
-    fieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
     }
 
   return this->getNumberOfComponents(field.toAscii().data(),
     fieldType);
 }
 
+//-----------------------------------------------------------------------------
+QString pqPipelineRepresentation::getColorFieldComponentName( const QString& array, const int &component )
+{
+  QString field = array;
+  int fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
+
+  if(field == pqPipelineRepresentation::solidColor())
+    {
+    return 0;
+    }
+  if(field.right(strlen(" (cell)")) == " (cell)")
+    {
+    field.chop(strlen(" (cell)"));
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_CELLS;
+    }
+  else if(field.right(strlen(" (point)")) == " (point)")
+    {
+    field.chop(strlen(" (point)"));
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
+    }
+
+   return this->getComponentName(field.toAscii().data(), fieldType, component );
+}
+
 //-----------------------------------------------------------------------------
 bool pqPipelineRepresentation::isPartial(const QString& array, int fieldType) const
 {
-  vtkPVArrayInformation* info = this->Internal->getArrayInformation(
-    array.toAscii().data(), fieldType, this->getInputDataInformation());
+  vtkPVArrayInformation* info = pqInternal::getArrayInformation(this,
+    array.toAscii().data(), fieldType);
   return (info? (info->GetIsPartial()==1) : false);
 }
 
@@ -1011,7 +1071,7 @@ pqPipelineRepresentation::getColorFieldRange(const QString& array, int component
   QPair<double,double>ret(0.0, 1.0);
 
   QString field = array;
-  int fieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+  int fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
 
   if(field == pqPipelineRepresentation::solidColor())
     {
@@ -1020,45 +1080,25 @@ pqPipelineRepresentation::getColorFieldRange(const QString& array, int component
   if(field.right(strlen(" (cell)")) == " (cell)")
     {
     field.chop(strlen(" (cell)"));
-    fieldType = vtkSMDataRepresentationProxy::CELL_DATA;
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_CELLS;
     }
   else if(field.right(strlen(" (point)")) == " (point)")
     {
     field.chop(strlen(" (point)"));
-    fieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+    fieldType = vtkDataObject::FIELD_ASSOCIATION_POINTS;
     }
 
-  vtkPVArrayInformation* representedInfo = this->Internal->getArrayInformation(
+  vtkPVArrayInformation* arrayInfo = pqInternal::getArrayInformation(this,
     field.toAscii().data(), fieldType);
-
-  vtkPVDataInformation* inputInformation = this->getInputDataInformation();
-  vtkPVArrayInformation* inputInfo = this->Internal->getArrayInformation(
-    field.toAscii().data(), fieldType, inputInformation);
-
-  // Try to use full input data range is possible. Sometimes, the data array is
-  // only provided by some pre-processing filter added by the representation
-  // (and is not present in the original input), in that case we use the range
-  // provided by the representation.
-  if (inputInfo)
+  if (arrayInfo)
     {
-    if (component < inputInfo->GetNumberOfComponents())
+    if (component < arrayInfo->GetNumberOfComponents())
       {
       double range[2];
-      inputInfo->GetComponentRange(component, range);
+      arrayInfo->GetComponentRange(component, range);
       return QPair<double,double>(range[0], range[1]);
       }
     }
-
-  if (representedInfo)
-    {
-    if (component <representedInfo->GetNumberOfComponents())
-      {
-      double range[2];
-      representedInfo->GetComponentRange(component, range);
-      return QPair<double,double>(range[0], range[1]);
-      }
-    }
-
   return ret;
 }
 
@@ -1087,7 +1127,7 @@ QPair<double, double> pqPipelineRepresentation::getColorFieldRange()
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::setColorField(const QString& value)
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
 
   if(!repr)
     {
@@ -1106,13 +1146,13 @@ void pqPipelineRepresentation::setColorField(const QString& value)
       {
       field.chop(strlen(" (cell)"));
       this->colorByArray(field.toAscii().data(), 
-                         vtkSMDataRepresentationProxy::CELL_DATA);
+                         vtkDataObject::FIELD_ASSOCIATION_CELLS);
       }
     else if(field.right(strlen(" (point)")) == " (point)")
       {
       field.chop(strlen(" (point)"));
       this->colorByArray(field.toAscii().data(), 
-                         vtkSMDataRepresentationProxy::POINT_DATA);
+                         vtkDataObject::FIELD_ASSOCIATION_POINTS);
       }
     }
 }
@@ -1121,7 +1161,7 @@ void pqPipelineRepresentation::setColorField(const QString& value)
 //-----------------------------------------------------------------------------
 QString pqPipelineRepresentation::getColorField(bool raw)
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   if (!repr)
     {
     return pqPipelineRepresentation::solidColor();
@@ -1155,7 +1195,7 @@ QString pqPipelineRepresentation::getColorField(bool raw)
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::setRepresentation(int representation)
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   pqSMAdaptor::setElementProperty(
     repr->GetProperty("Representation"), representation);
   repr->UpdateVTKObjects();
@@ -1165,7 +1205,7 @@ void pqPipelineRepresentation::setRepresentation(int representation)
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::onRepresentationChanged()
 {
-  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  vtkSMRepresentationProxy* repr = this->getRepresentationProxy();
   if (!repr)
     {
     return;
@@ -1286,7 +1326,7 @@ double pqPipelineRepresentation::getUnstructuredGridOutlineThreshold()
 
 //-----------------------------------------------------------------------------
 vtkSMProxy* pqPipelineRepresentation::createOpacityFunctionProxy(
-  vtkSMPropRepresentationProxy* repr)
+  vtkSMRepresentationProxy* repr)
 {
   if (!repr || !repr->GetProperty("ScalarOpacityFunction"))
     {
