@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPipelineSource.h,v $
+   Module:    pqPipelineSource.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -70,6 +70,9 @@ public:
   /// Returns the pqOutputPort given the name of the port.
   pqOutputPort* getOutputPort(const QString& portName) const;
 
+  /// Returns all the output ports.
+  QList<pqOutputPort*> getOutputPorts() const;
+
   /// Returns the number of consumers connected to the given output port.
   int getNumberOfConsumers(int outputport) const;
 
