@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPropertyManager.cxx,v $
+   Module:    pqPropertyManager.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -287,6 +287,7 @@ void pqPropertyManager::removeAllLinks()
 //-----------------------------------------------------------------------------
 void pqPropertyManager::accept()
 {
+  emit this->aboutToAccept();
   this->Internal->Links.accept();
   emit this->accepted();
   this->Internal->Modified = false;
