@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqProxyUnRegisterUndoElement.h,v $
+   Module:    pqProxyUnRegisterUndoElement.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -39,7 +39,7 @@ class PQCORE_EXPORT pqProxyUnRegisterUndoElement : public vtkSMProxyUnRegisterUn
 {
 public:
   static pqProxyUnRegisterUndoElement* New();
-  vtkTypeRevisionMacro(pqProxyUnRegisterUndoElement, vtkSMProxyUnRegisterUndoElement);
+  vtkTypeMacro(pqProxyUnRegisterUndoElement, vtkSMProxyUnRegisterUndoElement);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
