@@ -81,7 +81,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqServerManagerModel.h"
 #include "pqSettings.h"
 #include "pqSMAdaptor.h"
-#include "vtkPVAxesWidget.h"
 
 pqRenderView::ManipulatorType pqRenderView::DefaultManipulatorTypes[] = 
 {
@@ -99,8 +98,6 @@ pqRenderView::ManipulatorType pqRenderView::DefaultManipulatorTypes[] =
 class pqRenderView::pqInternal
 {
 public:
-  vtkSmartPointer<vtkPVAxesWidget> OrientationAxesWidget;
-  vtkSmartPointer<vtkSMProxy> CenterAxesProxy;
 
   vtkSmartPointer<vtkSMUndoStack> InteractionUndoStack;
   vtkSmartPointer<vtkSMInteractionUndoStackBuilder> UndoStackBuilder;
@@ -113,7 +110,6 @@ public:
     {
     this->UpdatingStack = false;
     this->InitializedWidgets = false;
-    this->OrientationAxesWidget = vtkSmartPointer<vtkPVAxesWidget>::New();
 
     this->InteractionUndoStack = vtkSmartPointer<vtkSMUndoStack>::New();
     this->InteractionUndoStack->SetClientOnly(true);
@@ -184,12 +180,6 @@ vtkSMRenderViewProxy* pqRenderView::getRenderViewProxy() const
 QWidget* pqRenderView::createWidget() 
 {
   QWidget* vtkwidget = this->Superclass::createWidget();
-
-  // add a link view menu
-  QAction* act = new QAction("Link Camera...", this);
-  vtkwidget->addAction(act);
-  QObject::connect(act, SIGNAL(triggered(bool)),
-    this, SLOT(linkToOtherView()));
   return vtkwidget;
 }
 
@@ -214,17 +204,6 @@ void pqRenderView::initializeWidgets()
     vtkwidget->SetRenderWindow(renModule->GetRenderWindow());
     }
 
-  vtkPVGenericRenderWindowInteractor* iren = renModule->GetInteractor();
-
-  // Init axes actor.
-  // FIXME: Convert OrientationAxesWidget to a first class representation.
-  this->Internal->OrientationAxesWidget->SetParentRenderer(
-    renModule->GetRenderer());
-  this->Internal->OrientationAxesWidget->SetViewport(0, 0, 0.25, 0.25);
-  this->Internal->OrientationAxesWidget->SetInteractor(iren);
-  this->Internal->OrientationAxesWidget->SetEnabled(1);
-  this->Internal->OrientationAxesWidget->SetInteractive(0);
-
   // Set up some global property links by default.
   vtkSMGlobalPropertiesManager* globalPropertiesManager =
     pqApplicationCore::instance()->getGlobalPropertiesManager();
@@ -233,9 +212,6 @@ void pqRenderView::initializeWidgets()
     vtkCommand::ModifiedEvent, this, SLOT(textAnnotationColorChanged()));
   this->textAnnotationColorChanged();
 
-  // setup the center axes.
-  this->initializeCenterAxes();
-  
   // ensure that center axis visibility etc. is updated as per user's
   // preferences.
   this->restoreAnnotationSettings();
@@ -273,43 +249,6 @@ void pqRenderView::restoreDefaultLightSettings()
     }
 }
 
-//-----------------------------------------------------------------------------
-// Create a center axes if one doesn't already exist.
-void pqRenderView::initializeCenterAxes()
-{
-  if (this->Internal->CenterAxesProxy.GetPointer())
-    {
-    // sanity check.
-    return;
-    }
-
-  vtkSMProxyManager* pxm = vtkSMObject::GetProxyManager();
-  vtkSMProxy* centerAxes = pxm->NewProxy("representations", "AxesRepresentation");
-  centerAxes->SetConnectionID(this->getServer()->GetConnectionID());
-  QList<QVariant> scaleValues;
-  scaleValues << .25 << .25 << .25;
-  pqSMAdaptor::setMultipleElementProperty(
-    centerAxes->GetProperty("Scale"), scaleValues);
-  pqSMAdaptor::setElementProperty(centerAxes->GetProperty("Pickable"), 0);
-  centerAxes->UpdateVTKObjects();
-  this->Internal->CenterAxesProxy = centerAxes;
-
-  vtkSMViewProxy* renView = this->getViewProxy();
-
-  // Update the center axes position whenever the center of rotation changes.
-  this->getConnector()->Connect(
-    renView->GetProperty("CenterOfRotation"), 
-    vtkCommand::ModifiedEvent, this, SLOT(updateCenterAxes()));
-  
-  // Add to render module without using properties. That way it does not
-  // get saved in state.
-  renView->AddRepresentation(
-    vtkSMRepresentationProxy::SafeDownCast(centerAxes));
-  centerAxes->Delete();
-
-  this->updateCenterAxes();
-}
-
 //-----------------------------------------------------------------------------
 void pqRenderView::onResetCameraEvent()
 {
@@ -317,17 +256,13 @@ void pqRenderView::onResetCameraEvent()
     {
     this->resetCenterOfRotation();
     }
-
-  // Ensures that the scale factor is correctly set for the center axes
-  // on reset camera.
-  this->updateCenterAxes();
 }
 
 //-----------------------------------------------------------------------------
 void pqRenderView::resetCamera()
 {
   this->fakeInteraction(true);
-  this->getRenderViewProxy()->ResetCamera();
+  this->getRenderViewProxy()->InvokeCommand("ResetCamera");
   this->fakeInteraction(false);
   this->render();
 }
@@ -367,39 +302,52 @@ const int* pqRenderView::defaultBackgroundColor() const
 //-----------------------------------------------------------------------------
 void pqRenderView::setOrientationAxesVisibility(bool visible)
 {
-  this->Internal->OrientationAxesWidget->SetEnabled(visible? 1: 0);
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesVisibility", true).Set(
+    visible? 1 : 0);
+  this->getProxy()->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
 bool pqRenderView::getOrientationAxesVisibility() const
 {
-  return this->Internal->OrientationAxesWidget->GetEnabled();
+  return vtkSMPropertyHelper(this->getProxy(),
+    "OrientationAxesVisibility", true).GetAsInt() == 0? false : true;
 }
 
 //-----------------------------------------------------------------------------
 void pqRenderView::setOrientationAxesInteractivity(bool interactive)
 {
-  this->Internal->OrientationAxesWidget->SetInteractive(interactive? 1: 0);
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesInteractivity").Set(
+    interactive? 1 : 0);
+  this->getProxy()->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
 bool pqRenderView::getOrientationAxesInteractivity() const
 {
-  return this->Internal->OrientationAxesWidget->GetInteractive();
+  return vtkSMPropertyHelper(this->getProxy(),
+    "OrientationAxesInteractivity").GetAsInt() == 0? false : true;
 }
 
 //-----------------------------------------------------------------------------
 void pqRenderView::setOrientationAxesOutlineColor(const QColor& color)
 {
-  this->Internal->OrientationAxesWidget->SetOutlineColor(
-    color.redF(), color.greenF(), color.blueF());
+  double colorf[3];
+  colorf[0] = color.redF();
+  colorf[1] = color.greenF();
+  colorf[2] = color.blueF();
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesOutlineColor").Set(
+    colorf, 3);
+  this->getProxy()->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
 QColor pqRenderView::getOrientationAxesOutlineColor() const
 {
   QColor color;
-  double* dcolor = this->Internal->OrientationAxesWidget->GetOutlineColor();
+  double dcolor[3];
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesOutlineColor").Get(
+    dcolor, 3);
   color.setRgbF(dcolor[0], dcolor[1], dcolor[2]);
   return color;
 }
@@ -407,73 +355,31 @@ QColor pqRenderView::getOrientationAxesOutlineColor() const
 //-----------------------------------------------------------------------------
 void pqRenderView::setOrientationAxesLabelColor(const QColor& color)
 {
-  this->Internal->OrientationAxesWidget->SetAxisLabelColor(
-    color.redF(), color.greenF(), color.blueF());
+  double colorf[3];
+  colorf[0] = color.redF();
+  colorf[1] = color.greenF();
+  colorf[2] = color.blueF();
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesLabelColor", true).Set(
+    colorf, 3);
+  this->getProxy()->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
 QColor pqRenderView::getOrientationAxesLabelColor() const
 {
   QColor color;
-  double* dcolor = this->Internal->OrientationAxesWidget->GetAxisLabelColor();
+  double dcolor[3] = {1, 1, 1};
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesLabelColor", true).Get(
+    dcolor, 3);
   color.setRgbF(dcolor[0], dcolor[1], dcolor[2]);
   return color;
 }
 
-//-----------------------------------------------------------------------------
-void pqRenderView::updateCenterAxes()
-{
-  if (!this->getCenterAxesVisibility())
-    {
-    return;
-    }
-
-  double center[3];
-  QList<QVariant> val =
-    pqSMAdaptor::getMultipleElementProperty(
-      this->getProxy()->GetProperty("CenterOfRotation"));
-  center[0] = val[0].toDouble();
-  center[1] = val[1].toDouble();
-  center[2] = val[2].toDouble();
-
-  QList<QVariant> positionValues;
-  positionValues << center[0] << center[1] << center[2];
-
-  pqSMAdaptor::setMultipleElementProperty(
-    this->Internal->CenterAxesProxy->GetProperty("Position"),
-    positionValues);
-
-  // Reset size of the axes.
-  double bounds[6];
-  this->getRenderViewProxy()->ComputeVisiblePropBounds(bounds);
-  double widths[3];
-  widths[0] = (bounds[1]-bounds[0]);
-  widths[1] = (bounds[3]-bounds[2]);
-  widths[2] = (bounds[5]-bounds[4]);
-  // lets make some thickness in all directions
-  double diameterOverTen = qMax(widths[0], qMax(widths[1], widths[2])) / 10.0;
-  widths[0] = widths[0] < diameterOverTen ? diameterOverTen : widths[0];
-  widths[1] = widths[1] < diameterOverTen ? diameterOverTen : widths[1];
-  widths[2] = widths[2] < diameterOverTen ? diameterOverTen : widths[2];
-
-  QList<QVariant> scaleValues;
-  scaleValues << (widths[0])*0.25 << (widths[1])*0.25 << (widths[2])*0.25;
-
-  pqSMAdaptor::setMultipleElementProperty(
-    this->Internal->CenterAxesProxy->GetProperty("Scale"),
-    scaleValues);
-
-  this->Internal->CenterAxesProxy->UpdateVTKObjects();
-}
-
 //-----------------------------------------------------------------------------
 void pqRenderView::setCenterOfRotation(double x, double y, double z)
 {
   QList<QVariant> positionValues;
   positionValues << x << y << z;
-
-  // this modifies the CenterOfRotation property resulting to a call
-  // to updateCenterAxes().
   vtkSMProxy* viewproxy = this->getProxy();
   pqSMAdaptor::setMultipleElementProperty(
     viewproxy->GetProperty("CenterOfRotation"),
@@ -496,29 +402,16 @@ void pqRenderView::getCenterOfRotation(double center[3]) const
 void pqRenderView::setCenterAxesVisibility(bool visible)
 {
   pqSMAdaptor::setElementProperty(
-    this->Internal->CenterAxesProxy->GetProperty("Visibility"),
+    this->getProxy()->GetProperty("CenterAxesVisibility"),
     visible? 1 : 0);
-  this->Internal->CenterAxesProxy->UpdateVTKObjects();
-  this->getProxy()->MarkModified(0);
-  if (visible)
-    {
-    // since updateCenterAxes does not do anything unless the axes is visible,
-    // we update the center when the axes becomes visible so that we are assured
-    // that the correct center of rotation is used.
-    this->updateCenterAxes();
-    }
+  this->getProxy()->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
 bool pqRenderView::getCenterAxesVisibility() const
 {
-  if (this->Internal->CenterAxesProxy.GetPointer()==0)
-    {
-    return false;
-    }
-
   return pqSMAdaptor::getElementProperty(
-    this->Internal->CenterAxesProxy->GetProperty("Visibility")).toBool();
+    this->getProxy()->GetProperty("CenterAxesVisibility")).toBool();
 }
 
 //-----------------------------------------------------------------------------
@@ -527,37 +420,8 @@ void pqRenderView::restoreAnnotationSettings()
   pqSettings* settings = pqApplicationCore::instance()->settings();
   QString sgroup = this->viewSettingsGroup();
   settings->beginGroup(sgroup);
-  // Orientation Axes settings.
-  settings->beginGroup("OrientationAxes");
-  if (settings->contains("Visibility"))
-    {
-    this->setOrientationAxesVisibility(
-      settings->value("Visibility").toBool());
-    }
-  if (settings->contains("Interactivity"))
-    {
-    this->setOrientationAxesInteractivity(
-      settings->value("Interactivity").toBool());
-    }
-  if (settings->contains("OutlineColor"))
-    {
-    this->setOrientationAxesOutlineColor(
-      settings->value("OutlineColor").value<QColor>());
-    }
-  if (settings->contains("LabelColor"))
-    {
-    this->setOrientationAxesLabelColor(
-      settings->value("LabelColor").value<QColor>());
-    }
-  settings->endGroup();
-
   // Center Axes settings.
   settings->beginGroup("CenterAxes");
-  if (settings->contains("Visibility"))
-    {
-    this->setCenterAxesVisibility(
-      settings->value("Visibility").toBool());
-    }
   if (settings->contains("ResetCenterWithCamera"))
     {
     this->ResetCenterWithCamera =
@@ -586,22 +450,8 @@ void pqRenderView::saveSettings()
   QString sgroup = this->viewSettingsGroup();
   settings->beginGroup(sgroup);
 
-  // Orientation Axes settings.
-  settings->beginGroup("OrientationAxes");
-  settings->setValue("Visibility", 
-    this->getOrientationAxesVisibility());
-  settings->setValue("Interactivity",
-    this->getOrientationAxesInteractivity());
-  settings->setValue("OutlineColor",
-    this->getOrientationAxesOutlineColor());
-  settings->setValue("LabelColor",
-    this->getOrientationAxesLabelColor());
-  settings->endGroup();
-
   // Center Axes settings.
   settings->beginGroup("CenterAxes");
-  settings->setValue("Visibility",
-    this->getCenterAxesVisibility());
   settings->setValue("ResetCenterWithCamera",
     this->ResetCenterWithCamera);
   settings->endGroup();
@@ -766,29 +616,13 @@ void pqRenderView::resetViewDirection(
     double up_x, double up_y, double up_z)
 {
   vtkSMProxy* proxy = this->getProxy();
-
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraPosition"), 0, 0);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraPosition"), 1, 0);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraPosition"), 2, 0);
-
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraFocalPoint"), 0, look_x);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraFocalPoint"), 1, look_y);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraFocalPoint"), 2, look_z);
-
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraViewUp"), 0, up_x);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraViewUp"), 1, up_y);
-  pqSMAdaptor::setMultipleElementProperty(
-    proxy->GetProperty("CameraViewUp"), 2, up_z);
+  double pos[3] = {0, 0, 0};
+  double focal_point[3] = { look_x, look_y, look_z };
+  double view_up[3] = { up_x, up_y, up_z };
+  vtkSMPropertyHelper(proxy, "CameraPosition").Set(pos, 3);
+  vtkSMPropertyHelper(proxy, "CameraFocalPoint").Set(focal_point, 3);
+  vtkSMPropertyHelper(proxy, "CameraViewUp").Set(view_up, 3);
   proxy->UpdateVTKObjects();
-
   this->resetCamera();
   this->render();
 }
@@ -821,6 +655,24 @@ void pqRenderView::emitSelectionSignal(QList<pqOutputPort*> opPorts)
     }
 }
 
+//-----------------------------------------------------------------------------
+pqDataRepresentation* pqRenderView::pick(int pos[2])
+{
+  vtkSMRenderViewProxy* renderView = this->getRenderViewProxy();
+  vtkSMRepresentationProxy* repr = renderView->Pick(pos[0], pos[1]);
+  pqDataRepresentation* pq_repr = NULL;
+  if (repr)
+    {
+    pq_repr =
+      pqApplicationCore::instance()->getServerManagerModel()->findItem<pqDataRepresentation*>(repr);
+    if (pq_repr)
+      {
+      emit this->picked(pq_repr->getOutputPortFromInput());
+      }
+    }
+  return pq_repr;
+}
+
 //-----------------------------------------------------------------------------
 void pqRenderView::collectSelectionPorts(
   vtkCollection* selectedRepresentations,
@@ -896,20 +748,30 @@ void pqRenderView::selectOnSurfaceInternal(
 {
   vtkSMRenderViewProxy* renderModuleP = this->getRenderViewProxy();
 
-  vtkSmartPointer<vtkCollection> selectedRepresentations = 
+  vtkSmartPointer<vtkCollection> selectedRepresentations =
     vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> surfaceSelections = 
+  vtkSmartPointer<vtkCollection> selectionSources =
     vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> selectionSources = 
-    vtkSmartPointer<vtkCollection>::New();
-  if (!renderModuleP->SelectOnSurface(rect[0], rect[1], rect[2], rect[3], 
-      selectedRepresentations, selectionSources, surfaceSelections, 
-      this->UseMultipleRepresentationSelection, select_points))
+  if (select_points)
     {
-    return;
+    if (!renderModuleP->SelectSurfacePoints(rect,
+        selectedRepresentations, selectionSources,
+        this->UseMultipleRepresentationSelection))
+      {
+      return;
+      }
+    }
+  else
+    {
+    if (!renderModuleP->SelectSurfaceCells(rect,
+        selectedRepresentations, selectionSources,
+        this->UseMultipleRepresentationSelection))
+      {
+      return;
+      }
     }
 
-  this->collectSelectionPorts(selectedRepresentations, 
+  this->collectSelectionPorts(selectedRepresentations,
     selectionSources, pqOutputPorts, expand, select_blocks);
 }
 
@@ -928,23 +790,20 @@ void pqRenderView::selectFrustum(int rect[4])
 {
   vtkSMRenderViewProxy* renderModuleP = this->getRenderViewProxy();
 
-  vtkSmartPointer<vtkCollection> selectedRepresentations = 
+  vtkSmartPointer<vtkCollection> selectedRepresentations =
     vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> frustumSelections = 
+  vtkSmartPointer<vtkCollection> selectionSources =
     vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> selectionSources = 
-    vtkSmartPointer<vtkCollection>::New();
-  
   QList<pqOutputPort*> output_ports;
-  if (!renderModuleP->SelectFrustum(rect[0], rect[1], rect[2], rect[3], 
-    selectedRepresentations, selectionSources, frustumSelections, 
+  if (!renderModuleP->SelectFrustumCells(rect,
+    selectedRepresentations, selectionSources,
     this->UseMultipleRepresentationSelection))
     {
     this->emitSelectionSignal(output_ports);
     return;
     }
 
-  this->collectSelectionPorts(selectedRepresentations, 
+  this->collectSelectionPorts(selectedRepresentations,
     selectionSources, output_ports, false, false);
 
   // Fire selection event to let the world know that this view selected
@@ -957,23 +816,21 @@ void pqRenderView::selectFrustumPoints(int rect[4])
 {
   vtkSMRenderViewProxy* renderModuleP = this->getRenderViewProxy();
 
-  vtkSmartPointer<vtkCollection> selectedRepresentations = 
+  vtkSmartPointer<vtkCollection> selectedRepresentations =
     vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> frustumSelections = 
-    vtkSmartPointer<vtkCollection>::New();
-  vtkSmartPointer<vtkCollection> selectionSources = 
+  vtkSmartPointer<vtkCollection> selectionSources =
     vtkSmartPointer<vtkCollection>::New();
 
   QList<pqOutputPort*> output_ports;
-  if (!renderModuleP->SelectFrustum(rect[0], rect[1], rect[2], rect[3], 
-    selectedRepresentations, selectionSources, frustumSelections, 
-    this->UseMultipleRepresentationSelection, true))
+  if (!renderModuleP->SelectFrustumPoints(rect,
+    selectedRepresentations, selectionSources,
+    this->UseMultipleRepresentationSelection))
     {
     this->emitSelectionSignal(output_ports);
     return;
     }
 
-  this->collectSelectionPorts(selectedRepresentations, 
+  this->collectSelectionPorts(selectedRepresentations,
     selectionSources, output_ports, false, false);
 
   // Fire selection event to let the world know that this view selected
@@ -1000,6 +857,7 @@ void pqRenderView::textAnnotationColorChanged()
   double value[3];
   vtkSMPropertyHelper(globalPropertiesManager, "TextAnnotationColor").Get(
     value, 3);
-  this->Internal->OrientationAxesWidget->SetAxisLabelColor(value[0], value[1],
-    value[2]);
+  vtkSMPropertyHelper(this->getProxy(), "OrientationAxesLabelColor", true).Set(
+    value, 3);
+  this->getProxy()->UpdateProperty("OrientationAxesLabelColor");
 }
