@@ -32,17 +32,20 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqRenderViewBase.h"
 
 // Server Manager Includes.
-#include "QVTKWidget.h"
 #include "vtkErrorCode.h"
 #include "vtkEventQtSlotConnect.h"
 #include "vtkImageData.h"
 #include "vtkProcessModule.h"
 #include "vtkPVDataInformation.h"
+#include "vtkPVGenericRenderWindowInteractor.h"
 #include "vtkPVXMLElement.h"
 #include "vtkSMGlobalPropertiesManager.h"
 #include "vtkSMProperty.h"
+#include "vtkSMIntVectorProperty.h"
 #include "vtkSMProxyManager.h"
+#include "vtkSMRenderViewProxy.h"
 #include "vtkSMSourceProxy.h"
+#include "vtkRenderWindow.h"
 
 // Qt Includes.
 #include <QList>
@@ -51,12 +54,17 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QPoint>
 #include <QPointer>
 #include <QtDebug>
+#include <QTimer>
+#include <QMainWindow>
+#include <QStatusBar>
 
 // ParaView Includes.
 #include "pqApplicationCore.h"
+#include "pqCoreUtilities.h"
 #include "pqImageUtil.h"
 #include "pqOutputPort.h"
 #include "pqPipelineSource.h"
+#include "pqQVTKWidget.h"
 #include "pqServer.h"
 #include "pqServerManagerModel.h"
 #include "pqSettings.h"
@@ -68,6 +76,8 @@ public:
   QPointer<QWidget> Viewport;
   QPoint MouseOrigin;
   bool InitializedAfterObjectsCreated;
+  bool IsInteractiveDelayActive;
+  double TimeLeftBeforeFullResolution;
 
   pqInternal()
     {
@@ -77,6 +87,46 @@ public:
     {
     delete this->Viewport;
     }
+
+  void writeToStatusBar(const char* txt)
+    {
+    QMainWindow *mainWindow = qobject_cast<QMainWindow *>(pqCoreUtilities::mainWidget());
+    if(mainWindow)
+      {
+      mainWindow->statusBar()->showMessage(txt);
+      }
+    }
+
+  void startInteractiveRenderDelay(double timeLeft)
+    {
+    this->IsInteractiveDelayActive = true;
+    this->TimeLeftBeforeFullResolution = timeLeft;
+    tick();
+    }
+
+  //-----------------------------------------------------------------------------
+  void interactiveRenderDelayTimeOut()
+  {
+    this->IsInteractiveDelayActive = false;
+    tick();
+  }
+
+  //-----------------------------------------------------------------------------
+  void tick()
+  {
+    if(this->IsInteractiveDelayActive)
+      {
+      QString txt = "Full resolution render in: ";
+      txt += QString::number(this->TimeLeftBeforeFullResolution);
+      txt += " s";
+      this->writeToStatusBar( txt.toAscii().data() );
+      this->TimeLeftBeforeFullResolution -= 0.1;
+      }
+    else
+      {
+      this->writeToStatusBar("");
+      }
+  }
 };
 
 //-----------------------------------------------------------------------------
@@ -90,6 +140,8 @@ pqRenderViewBase::pqRenderViewBase(
   Superclass(type, group, name, renViewProxy, server, _parent)
 {
   this->Internal = new pqRenderViewBase::pqInternal();
+  this->InteractiveDelayUpdateTimer = new QTimer(this);
+  this->AllowCaching = true;
 }
 
 //-----------------------------------------------------------------------------
@@ -115,21 +167,26 @@ QWidget* pqRenderViewBase::getWidget()
 }
 
 //-----------------------------------------------------------------------------
-QWidget* pqRenderViewBase::createWidget() 
+QWidget* pqRenderViewBase::createWidget()
 {
-  QVTKWidget* vtkwidget = new QVTKWidget();
+  pqQVTKWidget* vtkwidget = new pqQVTKWidget();
+  vtkwidget->setViewProxy(this->getProxy());
 
   // do image caching for performance
   // For now, we are doing this only on Apple because it can render
   // and capture a frame buffer even when it is obstructred by a
   // window. This does not work as well on other platforms.
-#if defined(__APPLE__)
-  vtkwidget->setAutomaticImageCacheEnabled(true);
 
-  // help the QVTKWidget know when to clear the cache
-  this->getConnector()->Connect(
-    this->getProxy(), vtkCommand::ModifiedEvent,
-    vtkwidget, SLOT(markCachedImageAsDirty()));
+#if defined(__APPLE__)
+  if (this->AllowCaching)
+    {
+    vtkwidget->setAutomaticImageCacheEnabled(true);
+
+    // help the QVTKWidget know when to clear the cache
+    this->getConnector()->Connect(
+      this->getProxy(), vtkCommand::ModifiedEvent,
+      vtkwidget, SLOT(markCachedImageAsDirty()));
+    }
 #endif
 
   return vtkwidget;
@@ -174,8 +231,35 @@ void pqRenderViewBase::initializeAfterObjectsCreated()
     this->initializeInteractors();
     this->restoreSettings(/*only_global=*/true);
     }
-}
 
+  // Attach Qt Signal to VTK interactor Delay event
+  vtkSMRenderViewProxy* renderViewProxy;
+  renderViewProxy = vtkSMRenderViewProxy::SafeDownCast(this->getProxy());
+  if( renderViewProxy != NULL )
+    {
+    pqProgressManager* progressManager;
+    progressManager = pqApplicationCore::instance()->getProgressManager();
+    // Generate Signals when interaction event occurs ??? Here ???
+    this->getConnector()->Connect(
+        renderViewProxy->GetInteractor(),
+        vtkPVGenericRenderWindowInteractor::EndDelayNonInteractiveRenderEvent,
+        this, SLOT(endDelayInteractiveRender()));
+    this->getConnector()->Connect( renderViewProxy->GetInteractor(),
+                                   vtkCommand::StartInteractionEvent,
+                                   this,
+                                   SLOT(endDelayInteractiveRender()));
+    this->getConnector()->Connect( renderViewProxy->GetInteractor(),
+                                   vtkPVGenericRenderWindowInteractor::BeginDelayNonInteractiveRenderEvent,
+                                   this,
+                                   SLOT(beginDelayInteractiveRender()));
+
+    this->InteractiveDelayUpdateTimer->setSingleShot(false);
+    QObject::connect( this->InteractiveDelayUpdateTimer,
+                      SIGNAL(timeout()),
+                      this,
+                      SLOT(updateStatusMessage()));
+    }
+}
 //-----------------------------------------------------------------------------
 // Sets default values for the underlying proxy.  This is during the 
 // initialization stage of the pqProxy for proxies created by the GUI itself 
@@ -246,6 +330,7 @@ bool pqRenderViewBase::setCameraManipulators(const QList<pqSMProxy>& manipulator
     }
 
   vtkSMProxy* viewproxy = this->getProxy();
+
   pqSMAdaptor::setProxyListProperty(
     viewproxy->GetProperty("CameraManipulators"),
     manipulators);
@@ -310,7 +395,6 @@ vtkSMProxy* pqRenderViewBase::createCameraManipulator(
     return NULL;
     }
   manip->SetConnectionID(cid);
-  manip->SetServers(vtkProcessModule::CLIENT);
   pqSMAdaptor::setElementProperty(manip->GetProperty("Button"), mouse);
   pqSMAdaptor::setElementProperty(manip->GetProperty("Shift"), shift);
   pqSMAdaptor::setElementProperty(manip->GetProperty("Control"), control);
@@ -334,43 +418,42 @@ void pqRenderViewBase::resetDisplay()
 
 //-----------------------------------------------------------------------------
 static const char* pqRenderViewModuleLightSettings [] = {
-  "LightSwitch",
-  "LightIntensity",
-  "UseLight",
-  "KeyLightWarmth",
-  "KeyLightIntensity",
-  "KeyLightElevation",
-  "KeyLightAzimuth",
-  "FillLightWarmth",
-  "FillLightK:F Ratio",
-  "FillLightElevation",
-  "FillLightAzimuth",
-  "BackLightWarmth",
-  "BackLightK:B Ratio",
-  "BackLightElevation",
   "BackLightAzimuth",
-  "HeadLightWarmth",
+  "BackLightElevation",
+  "BackLightK:B Ratio",
+  "BackLightWarmth",
+  "FillLightAzimuth",
+  "FillLightElevation",
+  "FillLightK:F Ratio",
+  "FillLightWarmth",
   "HeadLightK:H Ratio",
+  "HeadLightWarmth",
+  "KeyLightAzimuth",
+  "KeyLightElevation",
+  "KeyLightIntensity",
+  "KeyLightWarmth",
+  "LightIntensity",
+  "LightSwitch",
   "MaintainLuminance",
+  "UseLight",
   NULL
   };
 
 static const char* pqGlobalRenderViewModuleMiscSettings [] = {
-  "LODThreshold",
-  "LODResolution",
-  "UseImmediateMode",
-  "UseTriangleStrips",
-  "RenderInterruptsEnabled",
-  "RemoteRenderThreshold",
-  "TileDisplayCompositeThreshold",
-  "ImageReductionFactor",
-  "CompressorConfig",
-  "CompressionEnabled",
-  "OrderedCompositing",
-  "StillRenderImageReductionFactor",
   "CollectGeometryThreshold",
+  "CompressionEnabled",
+  "CompressorConfig",
   "DepthPeeling",
+  "ImageReductionFactor",
+  "LODResolution",
+  "LODThreshold",
   "MaximumNumberOfPeels",
+  "NonInteractiveRenderDelay",
+  "OrderedCompositing",
+  "RemoteRenderThreshold",
+  "RenderInterruptsEnabled",
+  "StillRenderImageReductionFactor",
+  "TileDisplayCompositeThreshold",
   "UseOffscreenRenderingForScreenshots",
   NULL
   };
@@ -378,6 +461,11 @@ static const char* pqGlobalRenderViewModuleMiscSettings [] = {
 static const char* pqRenderViewModuleMiscSettings [] = {
   "CacheLimit",
   "CameraParallelProjection",
+  "CenterAxesVisibility",
+  "OrientationAxesInteractivity",
+  "OrientationAxesVisibility",
+  "OrientationAxesLabelColor",
+  "OrientationAxesOutlineColor",
   NULL
   };
 
@@ -712,13 +800,36 @@ void pqRenderViewBase::setStereo(int mode)
   foreach (pqView* view, views)
     {
     vtkSMProxy* viewProxy = view->getProxy();
+    pqSMAdaptor::setElementProperty(viewProxy->GetProperty("StereoType"),
+      mode!=0? mode : VTK_STEREO_RED_BLUE);
     pqSMAdaptor::setElementProperty(viewProxy->GetProperty("StereoRender"),
-      mode != 0);
-    if (mode)
-      {
-      pqSMAdaptor::setElementProperty(viewProxy->GetProperty("StereoType"),
-        mode);
-      }
+      mode != 0? 1 : 0);
     viewProxy->UpdateVTKObjects();
+    if (mode != 0)
+      {
+      view->forceRender();
+      }
     }
 }
+
+//-----------------------------------------------------------------------------
+void pqRenderViewBase::beginDelayInteractiveRender()
+{
+  vtkSMIntVectorProperty *prop =
+      vtkSMIntVectorProperty::SafeDownCast(
+          this->getProxy()->GetProperty("NonInteractiveRenderDelay"));
+  double value = prop ? static_cast<double>(prop->GetElement(0)) : 2;
+  this->Internal->startInteractiveRenderDelay(value);
+  this->InteractiveDelayUpdateTimer->start(100);
+}
+//-----------------------------------------------------------------------------
+void pqRenderViewBase::endDelayInteractiveRender()
+{
+  this->Internal->interactiveRenderDelayTimeOut();
+  this->InteractiveDelayUpdateTimer->stop();
+}
+//-----------------------------------------------------------------------------
+void pqRenderViewBase::updateStatusMessage()
+{
+  this->Internal->tick();
+}
