@@ -35,6 +35,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqView.h"
 #include "pqSMProxy.h" //needed for pqSMProxy.
 
+class QTimer;
+
 /// pqRenderViewBase is an abstract base class for all render-view based views.
 /// It encapuslates some of the commonly needed functionality for all such
 /// views.
@@ -137,6 +139,13 @@ protected slots:
   /// don't change any render module properties here.
   virtual void initializeWidgets()=0;
 
+  /// Triggered by DelayNonInteractiveRenderEvent
+  void beginDelayInteractiveRender();
+  void endDelayInteractiveRender();
+
+  /// Triggered by internal timer to update the status bar message
+  void updateStatusMessage();
+
 protected:
   /// Overridden to popup the context menu, if some actions have been added
   /// using addMenuAction.
@@ -178,12 +187,17 @@ protected:
   /// settings.
   virtual const char* interactorStyleSettingsGroup() const=0;
 
+  /// On Mac, we usually try to cache the front buffer to avoid unecessary
+  //  updates.
+  bool AllowCaching;
+
 private: 
   pqRenderViewBase(const pqRenderViewBase&); // Not implemented.
   void operator=(const pqRenderViewBase&); // Not implemented.
 
   class pqInternal;
   pqInternal* Internal;
+  QTimer* InteractiveDelayUpdateTimer;
 };
 
 #endif
