@@ -1,13 +1,13 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqRubberBandHelper.cxx,v $
+   Module:    pqRubberBandHelper.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -32,83 +32,49 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqRubberBandHelper.h"
 
 // ParaView Server Manager includes.
+#include "pqApplicationCore.h"
+#include "pqDataRepresentation.h"
+#include "pqOutputPort.h"
 #include "pqRenderView.h"
+#include "pqServerManagerSelectionModel.h"
 
 // Qt Includes.
 #include <QCursor>
 #include <QPointer>
 #include <QTimer>
 #include <QWidget>
+#include <QMouseEvent>
 
 // ParaView includes.
-#include "vtkCommand.h"
+#include "vtkPVRenderView.h"
+#include "vtkInteractorStyleRubberBandZoom.h"
 #include "vtkPVGenericRenderWindowInteractor.h"
-#include "vtkInteractorObserver.h"
-#include "vtkInteractorStyleRubberBandPick.h"
-#include "vtkSMRenderViewProxy.h"
-#include "vtkRenderWindowInteractor.h"
+#include "vtkMemberFunctionCommand.h"
 #include "vtkSmartPointer.h"
+#include "vtkSMPropertyHelper.h"
+#include "vtkSMRenderViewProxy.h"
 
-//---------------------------------------------------------------------------
-// Observer for the start and end interaction events
-class pqRubberBandHelper::vtkPQSelectionObserver : public vtkCommand
-{
-public:
-  static vtkPQSelectionObserver *New() 
-    { return new vtkPQSelectionObserver; }
-
-  virtual void Execute(vtkObject*, unsigned long event, void* )
-    {
-      if (this->RubberBandHelper)
-        {
-        this->RubberBandHelper->processEvents(event);
-        }
-    }
-
-  vtkPQSelectionObserver() : RubberBandHelper(0) 
-    {
-    }
-
-  pqRubberBandHelper* RubberBandHelper;
-};
-
-//-----------------------------------------------------------------------------
-void pqRubberBandHelper::ReorderBoundingBox(int src[4], int dest[4])
-{
-  dest[0] = (src[0] < src[2])? src[0] : src[2];
-  dest[1] = (src[1] < src[3])? src[1] : src[3];
-  dest[2] = (src[0] < src[2])? src[2] : src[0];
-  dest[3] = (src[1] < src[3])? src[3] : src[1];
-}
+#include "zoom.xpm"
 
 //---------------------------------------------------------------------------
 class pqRubberBandHelper::pqInternal
 {
 public:
-  //the style I use to draw the rubber band
-  vtkSmartPointer<vtkInteractorStyleRubberBandPick> RubberBandStyle;
-
-  // Saved style to return to after rubber band finishes
-  vtkSmartPointer<vtkInteractorObserver> SavedStyle;
-
-  // Observer for mouse clicks.
-  vtkSmartPointer<vtkPQSelectionObserver> SelectionObserver;
-
   // Current render view.
   QPointer<pqRenderView> RenderView;
+  vtkSmartPointer<vtkCommand> Observer;
+  int StartPosition[2];
 
-  pqInternal(pqRubberBandHelper* parent)
+  QCursor ZoomCursor;
+
+  pqInternal(pqRubberBandHelper*) :
+    ZoomCursor(QPixmap(zoom_xpm), 11, 11)
     {
-    this->RubberBandStyle = 
-      vtkSmartPointer<vtkInteractorStyleRubberBandPick>::New();
-    this->SelectionObserver = 
-      vtkSmartPointer<vtkPQSelectionObserver>::New();
-    this->SelectionObserver->RubberBandHelper = parent;
+    this->StartPosition[0] = this->StartPosition[1] = -1000;
     }
-  
+
   ~pqInternal()
     {
-    this->SelectionObserver->RubberBandHelper = 0;
     }
 };
 
@@ -117,6 +83,10 @@ pqRubberBandHelper::pqRubberBandHelper(QObject* _parent/*=null*/)
 : QObject(_parent)
 {
   this->Internal = new pqInternal(this);
+  this->Internal->Observer.TakeReference(
+    vtkMakeMemberFunctionCommand(
+      *this, &pqRubberBandHelper::onSelectionChanged));
+
   this->Mode = INTERACT;
   this->DisableCount = 0;
   QObject::connect(this, SIGNAL(enableSurfaceSelection(bool)),
@@ -146,13 +116,14 @@ void pqRubberBandHelper::DisabledPop()
     }
 }
 
-
 //-----------------------------------------------------------------------------
 void pqRubberBandHelper::emitEnabledSignals()
 {
   if (this->DisableCount == 1 || !this->Internal->RenderView)
     {
     emit this->enableSurfaceSelection(false);
+    emit this->enableZoom(false);
+    emit this->enablePick(false);
     emit this->enableSurfacePointsSelection(false);
     emit this->enableFrustumSelection(false);
     emit this->enableFrustumPointSelection(false);
@@ -161,14 +132,14 @@ void pqRubberBandHelper::emitEnabledSignals()
 
   if (this->DisableCount == 0 && this->Internal->RenderView)
     {
-    vtkSMRenderViewProxy* proxy = 
+    vtkSMRenderViewProxy* proxy =
       this->Internal->RenderView->getRenderViewProxy();
-    emit this->enableSurfaceSelection(
-      proxy->IsSelectVisibleCellsAvailable() == NULL);
-    emit this->enableSurfacePointsSelection(
-      proxy->IsSelectVisiblePointsAvailable() == NULL);
+    emit this->enableSurfaceSelection(proxy->IsSelectionAvailable());
+    emit this->enableSurfacePointsSelection(proxy->IsSelectionAvailable());
+    emit this->enablePick(proxy->IsSelectionAvailable());
     emit this->enableFrustumSelection(true);
     emit this->enableFrustumPointSelection(true);
+    emit this->enableZoom(true);
     }
 }
 
@@ -214,25 +185,30 @@ int pqRubberBandHelper::setRubberBandOn(int selectionMode)
     return 0;
     }
 
-  vtkRenderWindowInteractor* rwi = rmp->GetInteractor();
-  if (!rwi)
+  if (selectionMode == ZOOM)
     {
-    qDebug("No interactor specified. Cannot switch to selection");
-    return 0;
+    vtkSMPropertyHelper(rmp, "InteractionMode").Set(
+      vtkPVRenderView::INTERACTION_MODE_ZOOM);
+    rmp->UpdateVTKObjects();
+    this->Internal->RenderView->getWidget()->setCursor(
+      this->Internal->ZoomCursor);
+    this->Internal->RenderView->getWidget()->installEventFilter(this);
+    }
+  else if (selectionMode == PICK_ON_CLICK)
+    {
+    // we don't use render-window-interactor for picking-on-clicking since we
+    // don't want to change the default interaction style. Instead we install an
+    // event filter to listen to mouse click events.
+    this->Internal->RenderView->getWidget()->installEventFilter(this);
+    }
+  else
+    {
+    vtkSMPropertyHelper(rmp, "InteractionMode").Set(
+      vtkPVRenderView::INTERACTION_MODE_SELECTION);
+    rmp->AddObserver(vtkCommand::SelectionChangedEvent, this->Internal->Observer);
+    rmp->UpdateVTKObjects();
+    this->Internal->RenderView->getWidget()->setCursor(Qt::CrossCursor);
     }
-
-  //start watching left mouse actions to get a begin and end pixel
-  this->Internal->SavedStyle = rwi->GetInteractorStyle();
-  rwi->SetInteractorStyle(this->Internal->RubberBandStyle);
-  
-  rwi->AddObserver(vtkCommand::LeftButtonPressEvent, 
-                   this->Internal->SelectionObserver);
-  rwi->AddObserver(vtkCommand::LeftButtonReleaseEvent, 
-                   this->Internal->SelectionObserver);
-
-  this->Internal->RubberBandStyle->StartSelect();
-
-  this->Internal->RenderView->getWidget()->setCursor(Qt::CrossCursor);
 
   this->Mode = selectionMode;
   emit this->selectionModeChanged(this->Mode);
@@ -257,22 +233,12 @@ int pqRubberBandHelper::setRubberBandOff()
     return 0;
     }
 
-  vtkRenderWindowInteractor* rwi = rmp->GetInteractor();
-  if (!rwi)
-    {
-    qDebug("No interactor specified. Cannot switch to interaction");
-    return 0;
-    }
+  vtkSMPropertyHelper(rmp, "InteractionMode").Set(
+    vtkPVRenderView::INTERACTION_MODE_3D);
+  rmp->UpdateVTKObjects();
+  rmp->RemoveObserver(this->Internal->Observer);
 
-  if (!this->Internal->SavedStyle)
-    {
-    qDebug("No previous style defined. Cannot switch to interaction.");
-    return 0;
-    }
-
-  rwi->SetInteractorStyle(this->Internal->SavedStyle);
-  rwi->RemoveObserver(this->Internal->SelectionObserver);
-  this->Internal->SavedStyle = 0;
+  this->Internal->RenderView->getWidget()->removeEventFilter(this);
 
   // set the interaction cursor
   this->Internal->RenderView->getWidget()->setCursor(QCursor());
@@ -283,6 +249,56 @@ int pqRubberBandHelper::setRubberBandOff()
   return 1;
 }
 
+//-----------------------------------------------------------------------------
+bool pqRubberBandHelper::eventFilter(QObject *watched, QEvent *_event)
+{
+  if (this->Mode == PICK_ON_CLICK &&
+    watched == this->Internal->RenderView->getWidget())
+    {
+    if (_event->type() == QEvent::MouseButtonPress)
+      {
+      QMouseEvent& mouseEvent = (*static_cast<QMouseEvent*>(_event));
+      if (mouseEvent.button() == Qt::LeftButton)
+        {
+        this->Internal->StartPosition[0] = mouseEvent.x();
+        this->Internal->StartPosition[1] = mouseEvent.y();
+        }
+      }
+    else if (_event->type() == QEvent::MouseButtonRelease)
+      {
+      QMouseEvent& mouseEvent = (*static_cast<QMouseEvent*>(_event));
+      if (mouseEvent.button() == Qt::LeftButton)
+        {
+        if (this->Internal->StartPosition[0] == mouseEvent.x() &&
+          this->Internal->StartPosition[1] == mouseEvent.y())
+          {
+          // we need to flip Y.
+          int height = this->Internal->RenderView->getWidget()->size().height();
+          int region[4] = {mouseEvent.x(), height - mouseEvent.y(),
+            mouseEvent.x(), height - mouseEvent.y()};
+          this->onSelectionChanged(NULL, 0, region);
+          }
+        }
+      this->Internal->StartPosition[0] = -1000;
+      this->Internal->StartPosition[1] = -1000;
+      }
+    }
+  else if (this->Mode == ZOOM &&
+    watched == this->Internal->RenderView->getWidget())
+    {
+    if (_event->type() == QEvent::MouseButtonRelease)
+      {
+      QMouseEvent& mouseEvent = (*static_cast<QMouseEvent*>(_event));
+      if (mouseEvent.button() == Qt::LeftButton)
+        {
+        QTimer::singleShot(0, this, SLOT(delayedSelectionChanged()));
+        }
+      }
+    }
+
+  return this->Superclass::eventFilter(watched, _event);
+}
+
 //-----------------------------------------------------------------------------
 pqRenderView* pqRubberBandHelper::getRenderView() const
 {
@@ -319,6 +335,24 @@ void pqRubberBandHelper::beginBlockSelection()
   this->setRubberBandOn(BLOCKS);
 }
 
+//-----------------------------------------------------------------------------
+void pqRubberBandHelper::beginZoom()
+{
+  this->setRubberBandOn(ZOOM);
+}
+
+//-----------------------------------------------------------------------------
+void pqRubberBandHelper::beginPick()
+{
+  this->setRubberBandOn(PICK);
+}
+
+//-----------------------------------------------------------------------------
+void pqRubberBandHelper::beginPickOnClick()
+{
+  this->setRubberBandOn(PICK_ON_CLICK);
+}
+
 //-----------------------------------------------------------------------------
 void pqRubberBandHelper::endSelection()
 {
@@ -326,7 +360,9 @@ void pqRubberBandHelper::endSelection()
 }
 
 //-----------------------------------------------------------------------------
-void pqRubberBandHelper::processEvents(unsigned long eventId)
+void pqRubberBandHelper::onSelectionChanged(vtkObject*, unsigned long,
+  void* vregion)
+
 {
   if (!this->Internal->RenderView)
     {
@@ -334,7 +370,7 @@ void pqRubberBandHelper::processEvents(unsigned long eventId)
     return;
     }
 
-  vtkSMRenderViewProxy* rmp = 
+  vtkSMRenderViewProxy* rmp =
     this->Internal->RenderView->getRenderViewProxy();
   if (!rmp)
     {
@@ -342,71 +378,63 @@ void pqRubberBandHelper::processEvents(unsigned long eventId)
     return;
     }
 
-  vtkRenderWindowInteractor* rwi = rmp->GetInteractor();
-  if (!rwi)
+  bool ctrl = (rmp->GetInteractor()->GetControlKey() == 1);
+  int* region = reinterpret_cast<int*>(vregion);
+  switch (this->Mode)
     {
-    qDebug("No interactor specified. Cannot switch to selection");
-    return;
+  case SELECT:
+    this->Internal->RenderView->selectOnSurface(region, ctrl);
+    break;
+
+  case SELECT_POINTS:
+    this->Internal->RenderView->selectPointsOnSurface(region, ctrl);
+    break;
+
+  case FRUSTUM:
+    this->Internal->RenderView->selectFrustum(region);
+    break;
+
+  case FRUSTUM_POINTS:
+    this->Internal->RenderView->selectFrustumPoints(region);
+    break;
+
+  case BLOCKS:
+    this->Internal->RenderView->selectBlock(region, ctrl);
+    break;
+
+  case ZOOM:
+    // nothing to do.
+    this->setRubberBandOff();
+    this->Internal->RenderView->resetCenterOfRotationIfNeeded();
+    break;
+
+  case PICK:
+      {
+      pqDataRepresentation* picked = this->Internal->RenderView->pick(region);
+      pqApplicationCore::instance()->getSelectionModel()->setCurrentItem(
+        picked? picked->getOutputPortFromInput(): NULL,
+        pqServerManagerSelectionModel::ClearAndSelect);
+      }
+    break;
+
+  case PICK_ON_CLICK:
+    if (region[0] == region[2] && region[1] == region[3])
+      {
+      pqDataRepresentation* picked = this->Internal->RenderView->pick(region);
+      // in pick-on-click, we don't change the current item when user clicked on
+      // a blank area. BUG #11428.
+      if (picked)
+        {
+        pqApplicationCore::instance()->getSelectionModel()->setCurrentItem(
+          picked->getOutputPortFromInput(),
+          pqServerManagerSelectionModel::ClearAndSelect);
+        }
+      }
+    break;
     }
-
-  bool ctrl = rwi->GetControlKey();
-  int* eventpos = rwi->GetEventPosition();
-  switch(eventId)
+  if (region)
     {
-    case vtkCommand::LeftButtonPressEvent:
-      this->Xs = eventpos[0];
-      if (this->Xs < 0) 
-        {
-        this->Xs = 0;
-        }
-      this->Ys = eventpos[1];
-      if (this->Ys < 0) 
-        {
-        this->Ys = 0;
-        }
-      break;
-    case vtkCommand::LeftButtonReleaseEvent:
-      this->Xe = eventpos[0];
-      if (this->Xe < 0) 
-        {
-        this->Xe = 0;
-        }
-      this->Ye = eventpos[1];
-      if (this->Ye < 0) 
-        {
-        this->Ye = 0;
-        }
-  
-      int rect[4] = {this->Xs, this->Ys, this->Xe, this->Ye};
-      int rectOut[4];
-      this->ReorderBoundingBox(rect, rectOut);
-      if (this->Internal->RenderView) 
-        {
-        switch (this->Mode)
-          {
-        case SELECT:
-          this->Internal->RenderView->selectOnSurface(rectOut, ctrl);
-          break;
-
-        case SELECT_POINTS:
-          this->Internal->RenderView->selectPointsOnSurface(rectOut, ctrl);
-          break;
-
-        case FRUSTUM:
-          this->Internal->RenderView->selectFrustum(rectOut);
-          break;
-
-        case FRUSTUM_POINTS:
-          this->Internal->RenderView->selectFrustumPoints(rectOut);
-          break;
-
-        case BLOCKS:
-          this->Internal->RenderView->selectBlock(rectOut, ctrl);
-          break;
-          }
-        }
-      emit this->selectionFinished(rectOut[0], rectOut[1], rectOut[2], rectOut[3]);
-      break;
+    emit this->selectionFinished(region[0], region[1], region[2], region[3]);
     }
 }
 
