@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqServerManagerSelectionModel.h,v $
+   Module:    pqServerManagerSelectionModel.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -43,13 +43,20 @@ class pqServerManagerModel;
 class pqServerManagerModelItem;
 class pqServerManagerSelection;
 class pqServerManagerSelectionModelInternal;
+class vtkSMProxy;
 
 /// This is a QItemSelectionModel-like selection model for the
 /// pqServerManagerModel. pqServerManagerSelectionModel is part
 /// of the "Synchronized Selection" mechanism, which makes it 
 /// possible for different Qt views based on different Qt models, all
-/// of which are based on thq pqServerManagerModel to coordintae selection
+/// of which are based on the pqServerManagerModel to coordinate selection
 /// state.
+/// .SECTION Update
+/// This has been updated to internally use vtkSMProxySelectionModel register
+/// with the proxy manager under the name "ActiveSources" to keep track for the
+/// selection/current proxy. This makes it possible to synchronize proxy
+/// selections with python shell.
+
 class PQCORE_EXPORT pqServerManagerSelectionModel : public QObject
 {
   Q_OBJECT
@@ -78,7 +85,7 @@ public:
   /// if the current item should be selected/deselected, or
   /// all selection cleared.
   void setCurrentItem(pqServerManagerModelItem* item, 
-    pqServerManagerSelectionModel::SelectionFlags command);
+    const pqServerManagerSelectionModel::SelectionFlags& command);
 
   /// Returns true if the item is selected.
   bool isSelected(pqServerManagerModelItem* item) const;
@@ -89,21 +96,38 @@ public:
   /// Returns the list of selected items.
   const pqServerManagerSelection* selectedItems() const;
 
+  /// Convenience method to get the data bounds for all sources/filters
+  /// currently selected. Returns true if the bounds were computed correctly,
+  /// false if no items are selected or selected items are not data sources.
+  bool getSelectionDataBounds(double bounds[6]) const;
+
 public slots:
   void select(pqServerManagerModelItem* item, 
-    pqServerManagerSelectionModel::SelectionFlags command);
+    const pqServerManagerSelectionModel::SelectionFlags& command);
   void select(const pqServerManagerSelection& items,
-    pqServerManagerSelectionModel::SelectionFlags command);
+    const pqServerManagerSelectionModel::SelectionFlags& command);
+
+protected:
+  /// convert SelectionFlags to vtkSMProxySelectionModel::ProxySelectionFlag
+  int getCommand(const SelectionFlags& command);
+
+  /// get vtkSMProxy for the item.
+  vtkSMProxy* getProxy(pqServerManagerModelItem* item);
 
 signals:
   void currentChanged(pqServerManagerModelItem* item);
   void selectionChanged(const pqServerManagerSelection& selected,
     const pqServerManagerSelection& deselected);
 
+private slots:
+  /// called when vtkSMProxySelectionModel's selection changes.
+  void smSelectionChanged();
+
+  /// called when vtkSMProxySelectionModel's current changes.
+  void smCurrentChanged();
+
 private:
   pqServerManagerSelectionModelInternal* Internal;
-  /// Cleans up QPointers pointing to null objects in the selection.
-  void purge();
 };
 
 inline bool operator==(const QPointer<pqServerManagerModelItem>& lhs, 
@@ -115,7 +139,7 @@ inline bool operator==(const QPointer<pqServerManagerModelItem>& lhs,
 
 inline uint qHash(const QPointer<pqServerManagerModelItem>& index)
 {
-  return reinterpret_cast<size_t>(static_cast<pqServerManagerModelItem*>(index));
+  return qHash(static_cast<pqServerManagerModelItem*>(index));
 }
 
 /// This is a selection set. For now, it's simply a QList.
