@@ -1,13 +1,13 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqServerStartups.cxx,v $
+   Module:    pqServerStartups.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -59,7 +59,7 @@ public:
     vtkSmartPointer<vtkPVXMLElement> configuration =
       vtkSmartPointer<vtkPVXMLElement>::New();
     configuration->SetName("ManualStartup");
-    
+
     // Setup a builtin server as a hard-coded default ...
     Startups["builtin"] = new pqManualServerStartup(
       "builtin",
@@ -67,7 +67,7 @@ public:
       "builtin",
       configuration);
   }
-  
+
   ~pqImplementation()
   {
     for(
@@ -78,7 +78,7 @@ public:
       delete startup->second;
       }
   }
-  
+
   void deleteStartup(const QString& startup)
   {
     if(this->Startups.count(startup))
@@ -87,7 +87,7 @@ public:
     this->Startups.erase(startup);
     }
   }
-  
+
   static vtkSmartPointer<vtkPVXMLElement> save(const QString& name, pqServerStartup& startup)
   {
     vtkSmartPointer<vtkPVXMLElement> xml_server =
@@ -99,39 +99,16 @@ public:
     xml_server->AddNestedElement(startup.getConfiguration());
     return xml_server;
   }
-  
-  static vtkSmartPointer<vtkPVXMLElement> saveDefaults(const QString& name, pqServerStartup& startup)
-  {
-    vtkPVXMLElement* config = startup.getConfiguration();
-    vtkPVXMLElement* xml_options = config->FindNestedElementByName("Options");
-    if(!xml_options)
-      {
-      return NULL;
-      }
-
-    vtkSmartPointer<vtkPVXMLElement> xml_server =
-      vtkSmartPointer<vtkPVXMLElement>::New();
-    xml_server->SetName("Server");
-    xml_server->AddAttribute("name", name.toAscii().data());
-    xml_server->AddAttribute("resource",
-      startup.getServer().toURI().toAscii().data());
-    vtkSmartPointer<vtkPVXMLElement> config2 = 
-      vtkSmartPointer<vtkPVXMLElement>::New();
-    config2->SetName("SavedOptions");
-    config2->AddNestedElement(xml_options);
-    xml_server->AddNestedElement(config2);
-    return xml_server;
-  }
 
   pqServerStartup* load(vtkPVXMLElement* xml_server, bool userPrefs)
   {
     const QString name = xml_server->GetAttribute("name");
-  
+
     const pqServerResource server =
       pqServerResource(xml_server->GetAttribute("resource"));
-      
+
     int num = xml_server->GetNumberOfNestedElements();
-    for(int i=0; i<num; i++)
+    for (int i=0; i<num; i++)
       {
       vtkPVXMLElement* xml_startup = xml_server->GetNestedElement(i);
       if(QString(xml_startup->GetName()) == "ManualStartup")
@@ -142,24 +119,6 @@ public:
         {
         return new pqCommandServerStartup(name, server, userPrefs, xml_startup);
         }
-      else if(QString(xml_startup->GetName()) == "SavedOptions")
-        {
-        // find an existing server with this name, and append the option values
-        if(this->Startups.count(name))
-          {
-          pqServerStartup* su = this->Startups[name];
-          vtkPVXMLElement* config = su->getConfiguration();
-          vtkPVXMLElement* xml_options = config->FindNestedElementByName("Options");
-          vtkPVXMLElement* xml_options2 = xml_startup->FindNestedElementByName("Options");
-          if(xml_options && xml_options2)
-            {
-            xml_options->Merge(xml_options2, "name");
-            }
-          }
-
-        // we made changes in place, so we don't make a new one here
-        return NULL;
-        }
       }
 
     return 0;
@@ -178,7 +137,7 @@ static QString userSettings()
 #if defined(Q_OS_WIN)
   settingsRoot = QString::fromLocal8Bit(getenv("APPDATA"));
 #else
-  settingsRoot = QString::fromLocal8Bit(getenv("HOME")) + 
+  settingsRoot = QString::fromLocal8Bit(getenv("HOME")) +
                  QDir::separator() + QString::fromLocal8Bit(".config");
 #endif
   QString settingsPath = QString("%2%1%3%1%4");
@@ -220,6 +179,11 @@ pqServerStartups::pqServerStartups(QObject* p) :
     // load user settings
     this->load(userSettings(), true);
     }
+  else if (options && options->GetDisableRegistry())
+    {
+    // load the testing servers resource.
+    this->load(":/pqCoreTesting/pqTestingServers.pvsc", false);
+    }
 }
 
 pqServerStartups::~pqServerStartups()
@@ -244,7 +208,7 @@ const pqServerStartups::StartupsT pqServerStartups::getStartups() const
     {
     results.push_back(startup->first);
     }
-    
+
   return results;
 }
 
@@ -262,7 +226,7 @@ const pqServerStartups::StartupsT pqServerStartups::getStartups(const pqServerRe
       results.push_back(startup->first);
       }
     }
-    
+
   return results;
 }
 
@@ -280,7 +244,7 @@ void pqServerStartups::setManualStartup(
   vtkSmartPointer<vtkPVXMLElement> configuration =
     vtkSmartPointer<vtkPVXMLElement>::New();
   configuration->SetName("ManualStartup");
-  
+
   this->Implementation->deleteStartup(name);
   this->Implementation->Startups.insert(
     vtkstd::make_pair(name, new pqManualServerStartup(name, server, true, configuration)));
@@ -298,7 +262,7 @@ void pqServerStartups::setCommandStartup(
   vtkSmartPointer<vtkPVXMLElement> configuration =
     vtkSmartPointer<vtkPVXMLElement>::New();
   configuration->SetName("CommandStartup");
-  
+
   vtkSmartPointer<vtkPVXMLElement> xml_command =
     vtkSmartPointer<vtkPVXMLElement>::New();
   xml_command->SetName("Command");
@@ -307,9 +271,9 @@ void pqServerStartups::setCommandStartup(
   xml_command->AddAttribute("exec", executable.toAscii().data());
   xml_command->AddAttribute("timeout", timeout);
   xml_command->AddAttribute("delay", delay);
-  
+
   xml_command->AddAttribute("Arguments", delay);
-  
+
   vtkSmartPointer<vtkPVXMLElement> xml_arguments =
     vtkSmartPointer<vtkPVXMLElement>::New();
   xml_arguments->SetName("Arguments");
@@ -339,16 +303,16 @@ void pqServerStartups::deleteStartups(const StartupsT& startups)
     {
     this->Implementation->deleteStartup(*startup);
     }
-    
+
   emit this->changed();
 }
 
 void pqServerStartups::save(vtkPVXMLElement* xml, bool userPrefs) const
 {
-  vtkSmartPointer<vtkPVXMLElement> xml_servers =
-    vtkSmartPointer<vtkPVXMLElement>::New();
+  vtkPVXMLElement* xml_servers = vtkPVXMLElement::New();
   xml_servers->SetName("Servers");
   xml->AddNestedElement(xml_servers);
+  xml_servers->Delete();
 
   for(
     pqImplementation::StartupsT::iterator startup = this->Implementation->Startups.begin();
@@ -357,17 +321,7 @@ void pqServerStartups::save(vtkPVXMLElement* xml, bool userPrefs) const
     {
     const QString startup_name = startup->first;
     pqServerStartup* const startup_command = startup->second;
-    if(userPrefs && !startup_command->shouldSave())
-      {
-      // for read only server settings, we'll save the users value's for the options
-      vtkSmartPointer<vtkPVXMLElement> s =
-        pqImplementation::saveDefaults(startup_name, *startup_command);
-      if(s)
-        {
-        xml_servers->AddNestedElement(s);
-        }
-      }
-    else
+    if ( (userPrefs && startup_command->shouldSave()) || !userPrefs)
       {
       xml_servers->AddNestedElement(pqImplementation::save(startup_name, *startup_command));
       }
@@ -409,7 +363,7 @@ void pqServerStartups::load(vtkPVXMLElement* xml_servers, bool userPrefs)
     if(QString(xml_server->GetName()) == "Server")
       {
       const QString name = xml_server->GetAttribute("name");
-      if(pqServerStartup* const startup = 
+      if(pqServerStartup* const startup =
         this->Implementation->load(xml_server, userPrefs))
         {
         this->Implementation->deleteStartup(name);
@@ -424,12 +378,12 @@ void pqServerStartups::load(vtkPVXMLElement* xml_servers, bool userPrefs)
 void pqServerStartups::load(const QString& path, bool userPrefs)
 {
   QFile file(path);
-  if(file.exists())
+  if (file.open(QIODevice::ReadOnly))
     {
+    QByteArray dat = file.readAll();
     vtkSmartPointer<vtkPVXMLParser> parser =
       vtkSmartPointer<vtkPVXMLParser>::New();
-    parser->SetFileName(path.toAscii().data());
-    if(parser->Parse())
+    if (parser->Parse(dat.data()))
       {
       this->load(parser->GetRootElement(), userPrefs);
       }
@@ -437,7 +391,7 @@ void pqServerStartups::load(const QString& path, bool userPrefs)
       {
       QString warn("Failed to parse ");
       warn += path;
-      qWarning(warn.toAscii().data());
+      qWarning() << warn;
       }
     }
 }
