@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqTextRepresentation.cxx,v $
+   Module:    pqTextRepresentation.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -33,6 +33,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "vtkSMProxy.h"
 #include "pqSMAdaptor.h"
+#include "pqApplicationCore.h"
+#include "vtkSMGlobalPropertiesManager.h"
 
 //-----------------------------------------------------------------------------
 pqTextRepresentation::pqTextRepresentation(const QString& group, 
@@ -60,16 +62,12 @@ void pqTextRepresentation::setDefaultPropertyValues()
   // Set default arrays and lookup table.
   vtkSMProxy* proxy = this->getProxy();
   
-  pqSMAdaptor::setElementProperty(
-    proxy->GetProperty("Selectable"), 0);
   pqSMAdaptor::setElementProperty(
     proxy->GetProperty("Enabled"),1);
-  pqSMAdaptor::setElementProperty(
-    proxy->GetProperty("TextScaleMode"),2);
-  pqSMAdaptor::setElementProperty(
-    proxy->GetProperty("Resizable"),0);
-  pqSMAdaptor::setElementProperty(
-    proxy->GetProperty("FontSize"),18);
 
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "TextAnnotationColor", proxy, "Color");
   proxy->UpdateVTKObjects();
 }
