@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqViewModuleInterface.h,v $
+   Module:    pqViewModuleInterface.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -33,6 +33,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifndef _pqViewModuleInterface_h
 #define _pqViewModuleInterface_h
 
+#include "pqCoreExport.h"
+
 #include <QtPlugin>
 #include <QStringList>
 class vtkSMProxy;
@@ -42,11 +44,11 @@ class pqView;
 class pqDataRepresentation;
 
 /// interface class for plugins that create view modules
-class pqViewModuleInterface
+class PQCORE_EXPORT pqViewModuleInterface
 {
 public:
-  /// destructor
-  virtual ~pqViewModuleInterface() {}
+  pqViewModuleInterface();
+  virtual ~pqViewModuleInterface();
   
   /// Return a list of view types supported by this interface
   virtual QStringList viewTypes() const = 0;
@@ -62,16 +64,19 @@ public:
 
   /// Returns true if this can create a view of a given name
   /// The name corresponds to the Server Manager XML Hint such as
+  /// @verbatim
   /// <SourceProxy name="MyCustomFilter" class="vtkMyCustomFilter">
   ///  ...
   ///  <Hints>
   ///   <View type="MyCustom" />
   ///  </Hints>
   /// </SourceProxy>
+  /// @endverbatim
   virtual bool canCreateView(const QString& viewtype) const = 0;
   
   /// Creates the Server Manager view module
   /// For example:
+  /// @verbatim
   /// <ProxyGroup name="plotmodules">
   ///  <ViewModuleProxy name="MyCustomViewModule">
   ///    base_proxygroup="rendermodules"
@@ -79,6 +84,7 @@ public:
   ///    display_name="MyCustomViewDisplay"
   ///  </ViewModuleProxy>
   /// </ProxyGroup>
+  /// @endverbatim
   ///
   /// implement this to call 
   /// vtkSMProxyManager::NewProxy("plotmodules", "MyCustomViewModule")
