@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAbstractItemViewEventPlayer.cxx,v $
+   Module:    pqAbstractItemViewEventPlayer.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -38,6 +38,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QMouseEvent>
 #include <QKeyEvent>
 #include <QtDebug>
+#include <QList>
+#include <QListWidget>
 
 #include "pqEventDispatcher.h"
 
@@ -62,6 +64,26 @@ static QModelIndex OldGetIndex(QAbstractItemView& View, const QString& Name)
     return index;
 }
 
+static QModelIndex GetIndexByItemName(QAbstractItemView& View, const QString& Name)
+{
+  QListWidget* const listWidget = qobject_cast<QListWidget*>(&View);
+
+  QModelIndex index;
+  if(!listWidget)
+    {
+    return index;
+    }
+  QList<QListWidgetItem *> findResult = listWidget->findItems(Name,Qt::MatchExactly);
+  if(findResult.count() > 0)
+    {
+    // in theory more than one item could match? Only return the index for
+    // the first instance.
+    index = View.model()->index(listWidget->row(findResult.first()), 0, index);
+    }
+    
+  return index;
+}
+
 static QModelIndex GetIndex(QAbstractItemView* View, const QString& Name)
 {
   QStringList idxs = Name.split('/', QString::SkipEmptyParts);
@@ -98,6 +120,15 @@ bool pqAbstractItemViewEventPlayer::playEvent(QObject* Object, const QString& Co
     if(!index.isValid())
       return false;
       
+    object->setCurrentIndex(index);
+    return true;
+    }
+  else if(Command == "currentChangedbyItemName")
+    {
+    const QModelIndex index = GetIndexByItemName(*object, Arguments);
+    if(!index.isValid())
+      return false;
+      
     object->setCurrentIndex(index);
     return true;
     }
@@ -133,11 +164,11 @@ bool pqAbstractItemViewEventPlayer::playEvent(QObject* Object, const QString& Co
         int idx = args[5].toInt();
         if(header->orientation() == Qt::Horizontal)
           {
-          pt = QPoint(header->sectionPosition(idx), 4);
+          pt = QPoint(header->sectionPosition(idx)+4, 4);
           }
         else
           {
-          pt = QPoint(4, header->sectionPosition(idx));
+          pt = QPoint(4, header->sectionPosition(idx)+4);
           }
         }
       else
@@ -153,7 +184,6 @@ bool pqAbstractItemViewEventPlayer::playEvent(QObject* Object, const QString& Co
       type = Command == "mouseDblClick" ? QEvent::MouseButtonDblClick : type;
       QMouseEvent e(type, pt, button, buttons, keym);
       QCoreApplication::sendEvent(object->viewport(), &e);
-      pqEventDispatcher::processEventsAndWait(1);
       return true;
       }
     }
