@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAnimationWidget.cxx,v $
+   Module:    pqAnimationWidget.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -32,11 +32,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "pqAnimationWidget.h"
 
-#include <QResizeEvent>
 #include <QGraphicsView>
 #include <QHBoxLayout>
 #include <QHeaderView>
+#include <QResizeEvent>
 #include <QScrollBar>
+#include <QStyle>
+#include <QStyleOptionButton>
 
 #include "pqAnimationModel.h"
 #include "pqAnimationTrack.h"
@@ -63,6 +65,15 @@ pqAnimationWidget::pqAnimationWidget(QWidget* p)
   this->CreateDeleteHeader->setResizeMode(QHeaderView::Fixed);
   this->CreateDeleteHeader->setModel(&this->CreateDeleteModel);
 
+  this->EnabledHeader = new QHeaderView(Qt::Vertical, this);
+  this->EnabledHeader->setObjectName("EnabledHeader");
+  this->EnabledHeader->viewport()->setBackgroundRole(QPalette::Window);
+  this->EnabledHeader->setClickable(true);
+  this->EnabledHeader->setSizePolicy(QSizePolicy::Preferred,
+    QSizePolicy::MinimumExpanding);
+  this->EnabledHeader->setResizeMode(QHeaderView::Fixed);
+  this->EnabledHeader->setModel(this->Model->enabledHeader());
+
   this->Header = new QHeaderView(Qt::Vertical, this);
   this->Header->viewport()->setBackgroundRole(QPalette::Window);
   this->Header->setObjectName("TrackHeader");
@@ -76,6 +87,7 @@ pqAnimationWidget::pqAnimationWidget(QWidget* p)
   this->Model->setRowHeight(this->Header->defaultSectionSize());
   
   this->CreateDeleteWidget = new QWidget(this);
+  this->CreateDeleteWidget->setObjectName("CreateDeleteWidget");
 
   QObject::connect(this->Header->model(),
                    SIGNAL(rowsInserted(QModelIndex,int,int)),
@@ -95,6 +107,9 @@ pqAnimationWidget::pqAnimationWidget(QWidget* p)
   QObject::connect(this->CreateDeleteHeader,
                    SIGNAL(sectionClicked(int)),
                    this, SLOT(headerDeleteClicked(int)));
+  QObject::connect(this->EnabledHeader,
+                   SIGNAL(sectionClicked(int)),
+                   this, SLOT(headerEnabledClicked(int)));
 }
 
 pqAnimationWidget::~pqAnimationWidget()
@@ -111,6 +126,11 @@ QHeaderView* pqAnimationWidget::createDeleteHeader() const
   return this->CreateDeleteHeader;
 }
 
+QHeaderView* pqAnimationWidget::enabledHeader() const
+{
+  return this->EnabledHeader;
+}
+
 QWidget* pqAnimationWidget::createDeleteWidget() const
 {
   return this->CreateDeleteWidget;
@@ -149,11 +169,12 @@ void pqAnimationWidget::headerDblClicked(int which)
     emit this->trackSelected(this->Model->track(which-1));
     }
 }
-  
+
 void pqAnimationWidget::updateGeometries()
 {
   int width1 = 0;
   int width2 = 0;
+  int width3 = 0;
   
   if(!this->CreateDeleteHeader->isHidden())
     {
@@ -167,12 +188,22 @@ void pqAnimationWidget::updateGeometries()
                  this->Header->sizeHint().width());
     width2 = qMin(tmp, this->Header->maximumWidth());
     }
+  if (!this->EnabledHeader->isHidden())
+    {
+    // get the size of a checkbox in pixels. That's the width we want 
+    // (+ padding) for the EnabledHeader.
+    QStyleOptionButton option;
+    QRect r = this->style()->subElementRect(
+      QStyle::SE_CheckBoxIndicator, &option, this);
+    width3 = r.width()+8;
+    }
 
-  this->setViewportMargins(width1 + width2, 0, 0, 0);
+  this->setViewportMargins(width1 + width2 + width3, 0, 0, 0);
 
   QRect vg = this->contentsRect();
   this->CreateDeleteHeader->setGeometry(vg.left(), vg.top(), width1, vg.height());
-  this->Header->setGeometry(vg.left() + width1, vg.top(), width2, vg.height());
+  this->EnabledHeader->setGeometry(vg.left()+width1, vg.top(), width3, vg.height());
+  this->Header->setGeometry(vg.left() + width1 + width3, vg.top(), width2, vg.height());
 
   this->updateScrollBars();
 }
@@ -183,6 +214,7 @@ void pqAnimationWidget::scrollContentsBy(int dx, int dy)
     {
     this->CreateDeleteHeader->setOffset(this->verticalScrollBar()->value());
     this->Header->setOffset(this->verticalScrollBar()->value());
+    this->EnabledHeader->setOffset(this->verticalScrollBar()->value());
     }
   this->updateWidgetPosition();
   QAbstractScrollArea::scrollContentsBy(dx, dy);
@@ -197,6 +229,10 @@ void pqAnimationWidget::updateScrollBars()
     {
     h = qMax(h, this->CreateDeleteHeader->length());
     }
+  if (this->EnabledHeader->isVisible())
+    {
+    h = qMax(h, this->EnabledHeader->length());
+    }
   if(this->Header->isVisible())
     {
     h = qMax(h, this->Header->length());
@@ -272,3 +308,15 @@ void pqAnimationWidget::headerDeleteClicked(int which)
     }
 }
 
+void pqAnimationWidget::headerEnabledClicked(int which)
+{
+  if (which > 0)
+    {
+    pqAnimationTrack* track = this->Model->track(which-1);
+    if (track)
+      {
+      emit this->enableTrackClicked(track);
+      }
+    }
+}
+
