@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVCompositeDataInformation.cxx,v $
+  Module:    vtkPVCompositeDataInformation.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,6 @@
 #include <vtkstd/string>
 
 vtkStandardNewMacro(vtkPVCompositeDataInformation);
-vtkCxxRevisionMacro(vtkPVCompositeDataInformation, "$Revision: 1.15 $");
 
 struct vtkPVCompositeDataInformationInternals
 {
@@ -125,7 +124,7 @@ unsigned int vtkPVCompositeDataInformation::GetNumberOfChildren()
 {
   return this->DataIsMultiPiece?
     this->NumberOfPieces : 
-    this->Internal->ChildrenInformation.size();
+    static_cast<int>(this->Internal->ChildrenInformation.size());
 }
 
 //----------------------------------------------------------------------------
@@ -243,15 +242,15 @@ void vtkPVCompositeDataInformation::AddInformation(vtkPVInformation* pvi)
     return;
     }
 
-  unsigned int otherNumChildren = info->Internal->ChildrenInformation.size();
-  unsigned int numChildren = this->Internal->ChildrenInformation.size();
+  size_t otherNumChildren = info->Internal->ChildrenInformation.size();
+  size_t numChildren = this->Internal->ChildrenInformation.size();
   if ( otherNumChildren > numChildren)
     {
     numChildren = otherNumChildren;
     this->Internal->ChildrenInformation.resize(numChildren);
     }
 
-  for (unsigned int i=0; i < otherNumChildren; i++)
+  for (size_t i=0; i < otherNumChildren; i++)
     {
     vtkPVDataInformation* otherInfo = info->Internal->ChildrenInformation[i].Info;
     vtkPVDataInformation* localInfo = this->Internal->ChildrenInformation[i].Info;
@@ -276,8 +275,8 @@ void vtkPVCompositeDataInformation::AddInformation(vtkPVInformation* pvi)
       {
       if (!localName.empty() && localName != otherName)
         {
-        vtkWarningMacro("Same block is named as \'" << localName.c_str()
-          << "\' as well as \'" << otherName.c_str() << "\'");
+        //vtkWarningMacro("Same block is named as \'" << localName.c_str()
+        //  << "\' as well as \'" << otherName.c_str() << "\'");
         }
       localName = otherName;
       }
@@ -295,11 +294,10 @@ void vtkPVCompositeDataInformation::CopyToStream(
         << this->DataIsMultiPiece
         << this->NumberOfPieces;
 
-  unsigned int numChildren = this->Internal->ChildrenInformation.size();
+  unsigned int numChildren = static_cast<unsigned int>(
+    this->Internal->ChildrenInformation.size());
   *css << numChildren;
   
-  // If data is a vtkHierarchicalBoxDataSet or sub-class, do not get the
-  // information for sub-datasets. There may be a lot of them.
   for(unsigned i=0; i<numChildren; i++)
     {
     vtkPVDataInformation* dataInf = this->Internal->ChildrenInformation[i].Info;
@@ -314,7 +312,8 @@ void vtkPVCompositeDataInformation::CopyToStream(
       size_t length;
       const unsigned char* data;
       dcss.GetData(&data, &length);
-      *css << vtkClientServerStream::InsertArray(data, length);
+      *css << vtkClientServerStream::InsertArray(data,
+        static_cast<int>(length));
       }
     }
   *css << numChildren; // DONE marker
