@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVCreateProcessModule.h,v $
+  Module:    vtkPVCreateProcessModule.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -29,7 +29,7 @@ class vtkPVOptions;
 class VTK_EXPORT vtkPVCreateProcessModule : public vtkObject
 {
 public:
-  vtkTypeRevisionMacro(vtkPVCreateProcessModule,vtkObject);
+  vtkTypeMacro(vtkPVCreateProcessModule,vtkObject);
   static vtkProcessModule* CreateProcessModule(vtkPVOptions* options);
   void PrintSelf(ostream& os, vtkIndent indent);
 
