@@ -280,7 +280,7 @@ void vtkPVDataInformation::AddFromMultiPieceDataSet(vtkCompositeDataSet* data)
       dinf->SetDataClassName(dobj->GetClassName());
       dinf->DataSetType = dobj->GetDataObjectType();
       this->AddInformation(dinf, /*addingParts=*/ 1);
-      dinf->Delete();
+      dinf->FastDelete();
       }
     }
   iter->Delete();
@@ -562,6 +562,11 @@ void vtkPVDataInformation::CopyFromObject(vtkObject* object)
     vtkAlgorithmOutput* algOutput = vtkAlgorithmOutput::SafeDownCast(object);
     if (algOutput && algOutput->GetProducer())
       {
+      if (algOutput->GetProducer()->IsA("vtkPVPostFilter"))
+        {
+        algOutput = algOutput->GetProducer()->GetInputConnection(0, 0);
+        }
+
       dobj = algOutput->GetProducer()->GetOutputDataObject(
         algOutput->GetIndex());
       }
@@ -573,7 +578,7 @@ void vtkPVDataInformation::CopyFromObject(vtkObject* object)
       vtkPriorityHelper *helper = vtkPriorityHelper::SafeDownCast(object);
       if (helper)
         {
-        dobj = helper->ConditionallyGetDataObject();
+        dobj = helper->GetDataObject();
         if (!dobj)
           {
           return;
