@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVFileInformation.cxx,v $
+  Module:    vtkPVFileInformation.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -17,6 +17,7 @@
 #include "vtkClientServerStream.h"
 #include "vtkCollection.h"
 #include "vtkCollectionIterator.h"
+#include "vtkFileSequenceParser.h"
 #include "vtkObjectFactory.h"
 #include "vtkPVFileInformationHelper.h"
 #include "vtkSmartPointer.h"
@@ -51,7 +52,6 @@
 #include <vtkstd/string>
 
 vtkStandardNewMacro(vtkPVFileInformation);
-vtkCxxRevisionMacro(vtkPVFileInformation, "$Revision: 1.31 $");
 
 inline void vtkPVFileInformationAddTerminatingSlash(vtkstd::string& name)
 {
@@ -93,7 +93,7 @@ static bool IsNetworkPath(const vtkstd::string& path)
 }
 
 // returns true if path is valid, false otherwise
-// returns subdirs, if any 
+// returns subdirs, if any
 
 static bool getNetworkSubdirs(const vtkstd::string& name,
                               DWORD DisplayType,
@@ -164,13 +164,13 @@ static bool getNetworkSubdirs(const vtkstd::string& path,
 
   static DWORD DisplayType[MaxTokens] =
     {
-    RESOURCEDISPLAYTYPE_NETWORK, 
+    RESOURCEDISPLAYTYPE_NETWORK,
     RESOURCEDISPLAYTYPE_DOMAIN,
     RESOURCEDISPLAYTYPE_SERVER,
     RESOURCEDISPLAYTYPE_SHARE
     };
 
-  int tokenIndex = pathtokens.size()-1;
+  int tokenIndex = static_cast<int>(pathtokens.size())-1;
 
   if(tokenIndex >= MaxTokens)
     return false;
@@ -197,7 +197,7 @@ static bool getNetworkSubdirs(const vtkstd::string& path,
 static bool getUncSharesOnServer(const vtkstd::string& server,
                           vtkstd::vector<vtkstd::string>& ret)
 {
-  return getNetworkSubdirs(vtkstd::string("\\\\") + server, 
+  return getNetworkSubdirs(vtkstd::string("\\\\") + server,
                          RESOURCEDISPLAYTYPE_SERVER, ret);
 }
 
@@ -208,7 +208,7 @@ static int vtkPVFileInformationGetType(const char* path)
   int type = vtkPVFileInformation::INVALID;
 
   vtkstd::string realpath = path;
-  
+
   if(vtksys::SystemTools::FileExists(realpath.c_str()))
     {
     type = vtkPVFileInformation::SINGLE_FILE;
@@ -221,8 +221,8 @@ static int vtkPVFileInformationGetType(const char* path)
   // doing stat on root of devices doesn't work
 
   // is it the root of a drive?
-  if (realpath[0] && realpath[1] == ':' && (realpath[2] == '\0' || 
-      (realpath[2] == '\\' && realpath[3] == '\0')))
+  if (realpath.size() > 0 && realpath[1] == ':' && realpath.size() == 2 ||
+      (realpath.size() == 3 && realpath[2] == '\\'))
     {
     // Path may be drive letter.
     DWORD n = GetLogicalDrives();
@@ -235,7 +235,7 @@ static int vtkPVFileInformationGetType(const char* path)
 
   if(IsNetworkPath(realpath))
     {
-    // this code doesn't give out anything with 
+    // this code doesn't give out anything with
     // "Windows Network\..." unless its a directory.
     // that may change
     vtkstd::vector<vtksys::String> pathtokens;
@@ -305,15 +305,15 @@ static vtkstd::string vtkPVFileInformationResolveLink(const vtkstd::string& fnam
   bool coInit = false;
   vtkstd::string result;
 
-  hr = ::CoCreateInstance(CLSID_ShellLink, NULL, 
+  hr = ::CoCreateInstance(CLSID_ShellLink, NULL,
                           CLSCTX_INPROC_SERVER, IID_IShellLink,
                           (LPVOID*)&shellLink);
   if(hr == CO_E_NOTINITIALIZED)
     {
     coInit = true;
     ::CoInitialize(NULL);
-    hr = ::CoCreateInstance(CLSID_ShellLink, NULL, 
-                            CLSCTX_INPROC_SERVER, IID_IShellLink, 
+    hr = ::CoCreateInstance(CLSID_ShellLink, NULL,
+                            CLSCTX_INPROC_SERVER, IID_IShellLink,
                             (LPVOID*)&shellLink);
     }
   if(SUCCEEDED(hr))
@@ -361,7 +361,7 @@ vtkstd::string MakeAbsolutePath(const vtkstd::string& path,
 
 
 //-----------------------------------------------------------------------------
-class vtkPVFileInformationSet : 
+class vtkPVFileInformationSet :
   public vtkstd::set<vtkSmartPointer<vtkPVFileInformation> >
 {
 };
@@ -371,23 +371,26 @@ vtkPVFileInformation::vtkPVFileInformation()
 {
   this->RootOnly = 1;
   this->Contents = vtkCollection::New();
+  this->SequenceParser = vtkFileSequenceParser::New();
   this->Type = INVALID;
-  this->Name = 0;
-  this->FullPath = 0;
+  this->Name = NULL;
+  this->FullPath = NULL;
   this->FastFileTypeDetection = 0;
+  this->Hidden = false;
 }
 
 //-----------------------------------------------------------------------------
 vtkPVFileInformation::~vtkPVFileInformation()
 {
   this->Contents->Delete();
-  this->SetName(0);
-  this->SetFullPath(0);
+  this->SequenceParser->Delete();
+  this->SetName(NULL);
+  this->SetFullPath(NULL);
 }
 
 bool vtkPVFileInformation::IsDirectory(int t)
 {
-  return t == DIRECTORY || t == DIRECTORY_LINK || 
+  return t == DIRECTORY || t == DIRECTORY_LINK ||
          t == DRIVE || t == NETWORK_ROOT ||
          t == NETWORK_DOMAIN || t == NETWORK_SERVER ||
          t == NETWORK_SHARE;
@@ -398,7 +401,7 @@ void vtkPVFileInformation::CopyFromObject(vtkObject* object)
 {
   this->Initialize();
 
-  vtkPVFileInformationHelper* helper = 
+  vtkPVFileInformationHelper* helper =
     vtkPVFileInformationHelper::SafeDownCast(object);
   if (!helper)
     {
@@ -415,7 +418,7 @@ void vtkPVFileInformation::CopyFromObject(vtkObject* object)
 
   this->FastFileTypeDetection = helper->GetFastFileTypeDetection();
 
-  vtkstd::string working_directory = 
+  vtkstd::string working_directory =
     vtksys::SystemTools::GetCurrentWorkingDirectory().c_str();
   if (helper->GetWorkingDirectory() && helper->GetWorkingDirectory()[0])
     {
@@ -435,8 +438,8 @@ void vtkPVFileInformation::CopyFromObject(vtkObject* object)
     {
     path.replace(idx, 1, 1, '\\');
     }
-  
-  int len = path.size();
+
+  int len = static_cast<int>(path.size());
   if(len > 4 && path.compare(len-4, 4, ".lnk") == 0)
     {
     WIN32_FIND_DATA data;
@@ -457,9 +460,12 @@ void vtkPVFileInformation::CopyFromObject(vtkObject* object)
     this->Type = DIRECTORY_LINK;
     }
 
+  //determine if this is a hidden directory/file
+  this->SetHiddenFlag();
+
   if (this->IsDirectory(this->Type) && helper->GetDirectoryListing())
     {
-    // Since we want a directory listing, we now to platform specific listing 
+    // Since we want a directory listing, we now to platform specific listing
     // with intelligent pattern matching hee-haa.
 #if defined(_WIN32)
     this->GetWindowsDirectoryListing();
@@ -478,7 +484,7 @@ void vtkPVFileInformation::GetSpecialDirectories()
   // Return favorite directories ...
 
   TCHAR szPath[MAX_PATH];
-  
+
   if(SUCCEEDED(SHGetSpecialFolderPath(NULL, szPath, CSIDL_PERSONAL, false)))
     {
     vtkSmartPointer<vtkPVFileInformation> info =
@@ -526,7 +532,7 @@ void vtkPVFileInformation::GetSpecialDirectories()
       this->Contents->AddItem(info);
       }
     }
-  
+
   vtkSmartPointer<vtkPVFileInformation> info =
       vtkSmartPointer<vtkPVFileInformation>::New();
   info->SetFullPath(WindowsNetworkRoot.c_str());
@@ -537,7 +543,7 @@ void vtkPVFileInformation::GetSpecialDirectories()
 #else // _WIN32
 #if defined (__APPLE__ )
   //-------- Get the List of Mounted Volumes from the System
-  
+
   int idx = 1;
   HFSUniStr255 hfsname;
   FSRef ref;
@@ -664,7 +670,7 @@ void vtkPVFileInformation::GetSpecialDirectories()
     this->Contents->AddItem(info);
     }
 #endif
-#endif // !_WIN32  
+#endif // !_WIN32
 }
 
 //-----------------------------------------------------------------------------
@@ -683,7 +689,7 @@ void vtkPVFileInformation::GetWindowsDirectoryListing()
         {
         vtkPVFileInformation* info = vtkPVFileInformation::New();
         info->SetName(shares[i].c_str());
-        vtkstd::string fullpath = 
+        vtkstd::string fullpath =
           vtksys::SystemTools::CollapseFullPath(shares[i].c_str(), this->FullPath);
         info->SetFullPath(fullpath.c_str());
         info->Type = type;
@@ -782,8 +788,7 @@ void vtkPVFileInformation::GetWindowsDirectoryListing()
 
     DWORD isdir = data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY;
     DWORD isfile = (data.dwFileAttributes & FILE_ATTRIBUTE_NORMAL) ||
-                  (!(data.dwFileAttributes & FILE_ATTRIBUTE_HIDDEN) &&
-                   !(data.dwFileAttributes & FILE_ATTRIBUTE_SYSTEM) &&
+                   (!(data.dwFileAttributes & FILE_ATTRIBUTE_SYSTEM) &&
                    !(data.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY));
 
     FileTypes type = isdir ? DIRECTORY : SINGLE_FILE;
@@ -799,6 +804,7 @@ void vtkPVFileInformation::GetWindowsDirectoryListing()
       infoD->SetFullPath(fullpath.c_str());
       infoD->Type = type;
       infoD->FastFileTypeDetection = this->FastFileTypeDetection;
+      infoD->SetHiddenFlag(); //needs full path set first
       info_set.insert(infoD);
       infoD->Delete();
       }
@@ -837,7 +843,7 @@ void vtkPVFileInformation::GetWindowsDirectoryListing()
 }
 
 /* There is a problem with the Portland compiler, large file
-support and glibc/Linux system headers: 
+support and glibc/Linux system headers:
              http://www.pgroup.com/userforum/viewtopic.php?
              p=1992&sid=f16167f51964f1a68fe5041b8eb213b6
 */
@@ -879,6 +885,16 @@ void vtkPVFileInformation::GetDirectoryListing()
     info->SetName(d->d_name);
     info->SetFullPath((prefix + d->d_name).c_str());
     info->Type = INVALID;
+    info->SetHiddenFlag();
+
+    // fix to bug #09452 such that directories with trailing names can be
+    // shown in the file dialog
+    struct stat status;
+    if ( stat( info->FullPath, &status ) != -1 && status.st_mode & S_IFDIR)
+     {
+     info->Type = DIRECTORY;
+     }
+
     info->FastFileTypeDetection = this->FastFileTypeDetection;
     info_set.insert(info);
     info->Delete();
@@ -889,7 +905,7 @@ void vtkPVFileInformation::GetDirectoryListing()
 
   // Now we detect the file types for items.
   // We dissolve any groups that contain non-file items.
-  
+
   for (vtkPVFileInformationSet::iterator iter = info_set.begin();
     iter != info_set.end(); ++iter)
     {
@@ -915,6 +931,28 @@ void vtkPVFileInformation::GetDirectoryListing()
 #endif
 }
 
+//-----------------------------------------------------------------------------
+void vtkPVFileInformation::SetHiddenFlag( )
+{
+#if defined(_WIN32)
+  if ( !this->FullPath )
+    {
+    this->Hidden = false;
+    return;
+    }
+  LPCSTR fp = this->FullPath;
+  DWORD flags= GetFileAttributes(fp);
+  this->Hidden =( flags & FILE_ATTRIBUTE_HIDDEN) ? true: false;
+#else
+  if ( !this->Name )
+    {
+    this->Hidden = false;
+    return;
+    }
+  this->Hidden =( this->Name[0] == '.' )? true:false;
+#endif
+
+}
 
 //-----------------------------------------------------------------------------
 bool vtkPVFileInformation::DetectType()
@@ -949,7 +987,7 @@ bool vtkPVFileInformation::DetectType()
     {
     if (vtksys::SystemTools::FileExists(this->FullPath))
       {
-      this-> Type = 
+      this-> Type =
         (vtksys::SystemTools::FileIsDirectory(this->FullPath))?
         DIRECTORY : SINGLE_FILE;
       return true;
@@ -972,25 +1010,10 @@ void vtkPVFileInformation::OrganizeCollection(vtkPVFileInformationSet& info_set)
 {
   typedef vtkstd::map<vtkstd::string, vtkInfo> MapOfStringToInfo;
   MapOfStringToInfo fileGroups;
-  
+
   vtkstd::string prefix = this->FullPath;
   vtkPVFileInformationAddTerminatingSlash(prefix);
 
-  // sequence ending with numbers.
-  vtksys::RegularExpression reg_ex("^(.*)\\.([0-9.]+)$");
-  // sequence ending with extension.
-  vtksys::RegularExpression reg_ex2("^(.*)(\\.|_|-)([0-9.]+)\\.(.*)$");
-  
-  // sequence ending with extension, but with no ". or _" before
-  // the series number.
-  vtksys::RegularExpression reg_ex3("^(.*)([a-zA-Z])([0-9.]+)\\.(.*)$");
-  // sequence ending with extension, and starting with series number
-  // followed by ". or _".
-  vtksys::RegularExpression reg_ex4("^([0-9.]+)(\\.|_|-)(.*)\\.(.*)$");
-  // sequence ending with extension, and starting with series number,
-  // but not followed by ". or _".
-  vtksys::RegularExpression reg_ex5("^([0-9.]+)([a-zA-Z])(.*)\\.(.*)$");
-
   for (vtkPVFileInformationSet::iterator iter = info_set.begin();
     iter != info_set.end(); )
     {
@@ -999,41 +1022,14 @@ void vtkPVFileInformation::OrganizeCollection(vtkPVFileInformationSet& info_set)
     if (obj->Type != FILE_GROUP && !IsDirectory(obj->Type))
       {
       bool match = false;
-      vtkstd::string groupName;
-      int groupIndex = -1;
-      if (reg_ex.find(obj->GetName()))
-        {
-        groupName = reg_ex.match(1);
-        groupIndex = atoi(reg_ex.match(2).c_str());
-        match = true;
-        }
-      else if (reg_ex2.find(obj->GetName()))
-        {
-        groupName = reg_ex2.match(1) + reg_ex2.match(2) + ".." + reg_ex2.match(4);
-        groupIndex = atoi(reg_ex2.match(3).c_str());
-        match = true;
-        }
-      else if (reg_ex3.find(obj->GetName()))
-        {
-        groupName = reg_ex3.match(1) + reg_ex3.match(2) + ".." + reg_ex3.match(4);
-        groupIndex = atoi(reg_ex3.match(3).c_str());
-        match = true;
-        }
-      else if (reg_ex4.find(obj->GetName()))
-        {
-        groupName = ".." + reg_ex4.match(2) + reg_ex4.match(3) + "." + reg_ex4.match(4);
-        groupIndex = atoi(reg_ex4.match(1).c_str());
-        match = true;
-        }
-      else if (reg_ex5.find(obj->GetName()))
-        {
-        groupName = ".." + reg_ex5.match(2) + reg_ex5.match(3) + "." + reg_ex5.match(4);
-        groupIndex = atoi(reg_ex5.match(1).c_str());
-        match = true;
-        }
+
+      match = this->SequenceParser->ParseFileSequence(obj->GetName());
 
       if (match)
         {
+        vtkstd::string groupName = this->SequenceParser->GetSequenceName();
+        int groupIndex = this->SequenceParser->GetSequenceIndex();
+
         MapOfStringToInfo::iterator iter2 = fileGroups.find(groupName);
         vtkPVFileInformation* group = 0;
         if (iter2 == fileGroups.end())
@@ -1042,6 +1038,8 @@ void vtkPVFileInformation::OrganizeCollection(vtkPVFileInformationSet& info_set)
           group->SetName(groupName.c_str());
           group->SetFullPath((prefix + groupName).c_str());
           group->Type = FILE_GROUP;
+          //the group inherits the hidden flag of the first item in the group
+          group->Hidden = obj->Hidden;
           group->FastFileTypeDetection = this->FastFileTypeDetection;
           //fileGroups[groupName] = group;
           vtkInfo info;
@@ -1063,7 +1061,7 @@ void vtkPVFileInformation::OrganizeCollection(vtkPVFileInformationSet& info_set)
 
 
   // Now scan through all created groups and dissolve trivial groups
-  // i.e. groups with single entries. Add all other groups to the 
+  // i.e. groups with single entries. Add all other groups to the
   // results.
  for (MapOfStringToInfo::iterator iter2 = fileGroups.begin();
    iter2 != fileGroups.end(); ++iter2)
@@ -1099,8 +1097,9 @@ void vtkPVFileInformation::CopyToStream(vtkClientServerStream* stream)
     << this->Name
     << this->FullPath
     << this->Type
+    << this->Hidden
     << this->Contents->GetNumberOfItems();
-  
+
   vtkSmartPointer<vtkCollectionIterator> iter;
   iter.TakeReference(this->Contents->NewIterator());
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
@@ -1139,8 +1138,14 @@ void vtkPVFileInformation::CopyFromStream(const vtkClientServerStream* css)
     return;
     }
 
+  if (!css->GetArgument(0, 3, &this->Hidden))
+    {
+    vtkErrorMacro("Error parsing Hidden.");
+    return;
+    }
+
   int num_of_children =0;
-  if (!css->GetArgument(0, 3, &num_of_children))
+  if (!css->GetArgument(0, 4, &num_of_children))
     {
     vtkErrorMacro("Error parsing Number of children.");
     return;
@@ -1149,7 +1154,7 @@ void vtkPVFileInformation::CopyFromStream(const vtkClientServerStream* css)
     {
     vtkPVFileInformation* child = vtkPVFileInformation::New();
     vtkClientServerStream childStream;
-    if (!css->GetArgument(0, 4+cc, &childStream))
+    if (!css->GetArgument(0, 5+cc, &childStream))
       {
       vtkErrorMacro("Error parsing child #" << cc);
       return;
@@ -1166,6 +1171,7 @@ void vtkPVFileInformation::Initialize()
   this->SetName(0);
   this->SetFullPath(0);
   this->Type = INVALID;
+  this->Hidden = false;
   this->Contents->RemoveAllItems();
 }
 
@@ -1174,7 +1180,7 @@ void vtkPVFileInformation::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Name: " << (this->Name? this->Name: "(null)") << endl;
-  os << indent << "FullPath: " 
+  os << indent << "FullPath: "
     << (this->FullPath? this->FullPath : "(null)") << endl;
   os << indent << "Type: " ;
   switch (this->Type)
@@ -1194,6 +1200,7 @@ void vtkPVFileInformation::PrintSelf(ostream& os, vtkIndent indent)
   case FILE_GROUP:
     os << "FILE_GROUP" << endl;
     }
+  os << indent << "Hidden: "<< this->Hidden << endl;
   os << indent << "FastFileTypeDetection: " << this->FastFileTypeDetection << endl;
 
   for (int cc=0; cc < this->Contents->GetNumberOfItems(); cc++)
