@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVServerSocket.h,v $
+  Module:    vtkPVServerSocket.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,7 @@ class VTK_EXPORT vtkPVServerSocket : public vtkServerSocket
 {
 public:
   static vtkPVServerSocket* New();
-  vtkTypeRevisionMacro(vtkPVServerSocket, vtkServerSocket);
+  vtkTypeMacro(vtkPVServerSocket, vtkServerSocket);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
