@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkProcessModule.cxx,v $
+  Module:    vtkProcessModule.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,10 +22,12 @@
 #include "vtkClientServerInterpreter.h"
 #include "vtkClientServerStream.h"
 #include "vtkCommand.h"
+#include "vtkCompositeDataPipeline.h"
 #include "vtkConnectionIterator.h"
 #include "vtkDataObject.h"
 #include "vtkInstantiator.h"
 #include "vtkKWProcessStatistics.h"
+#include "vtkMapper.h"
 #include "vtkMultiProcessController.h"
 #include "vtkMultiThreader.h"
 #include "vtkObjectFactory.h"
@@ -46,6 +48,7 @@
 #include "vtkStringList.h"
 #include "vtkTimerLog.h"
 #include "vtkToolkits.h" // For VTK_USE_MPI
+#include "vtkProcessModuleAutoMPI.h"
 
 #ifdef VTK_USE_MPI
 # include "vtkMPIController.h"
@@ -66,13 +69,13 @@ ostream* vtkProcessModule::DebugLogStream = 0;
 class vtkProcessModuleInternals
 {
 public:
-  typedef 
+  typedef
   vtkstd::map<vtkStdString, vtkSmartPointer<vtkDataObject> > DataTypesType;
   typedef vtkstd::map<vtkStdString, vtkStdString> MapStringToString;
-  
+
   DataTypesType DataTypes;
   MapStringToString Paths;
-  
+
   // Flag indicating on which servers the SendPrepareProgress
   // was sent. This is used to determine where to send the
   // CleanupPendingProgress request.
@@ -80,7 +83,7 @@ public:
 };
 
 //*****************************************************************************
-class vtkProcessModule::vtkInterpreterInitializationCallbackVector : 
+class vtkProcessModule::vtkInterpreterInitializationCallbackVector :
   public vtkstd::vector<vtkProcessModule::InterpreterInitializationCallback>
 {
 };
@@ -136,7 +139,6 @@ protected:
 
 
 vtkStandardNewMacro(vtkProcessModule);
-vtkCxxRevisionMacro(vtkProcessModule, "$Revision: 1.86.2.1 $");
 vtkCxxSetObjectMacro(vtkProcessModule, ActiveRemoteConnection, vtkRemoteConnection);
 vtkCxxSetObjectMacro(vtkProcessModule, GUIHelper, vtkProcessModuleGUIHelper);
 
@@ -148,16 +150,15 @@ vtkProcessModule::vtkProcessModule()
   this->Internals = new vtkProcessModuleInternals;
   this->ConnectionManager = 0;
   this->Interpreter = 0;
-  
+
   this->Observer = vtkProcessModuleObserver::New();
   this->Observer->SetProcessModule(this);
 
   this->InterpreterObserver = 0;
   this->ReportInterpreterErrors = 1;
 
-  this->UniqueID.ID = 3;
+  this->UniqueID.ID = 100;
 
-  this->ProgressHandler = vtkPVProgressHandler::New();
   this->ProgressRequests = 0;
 
   this->Options = 0;
@@ -172,7 +173,7 @@ vtkProcessModule::vtkProcessModule()
   this->SupportMultipleConnections = 0;
   this->DisableNewConnections = false;
   this->ExceptionRaised = 0;
-  
+
   this->MemoryInformation = vtkKWProcessStatistics::New();
 
   this->ServerInformation = vtkPVServerInformation::New();
@@ -187,16 +188,30 @@ vtkProcessModule::vtkProcessModule()
   this->LastProgress = -1;
   this->LastProgressName = 0;
 
+
 #ifdef VTK_USE_MPI
+# ifdef PARAVIEW_USE_MPI_SSEND
   // ParaView uses Ssend for all Trigger RMI calls. This helps in overcoming
   // bufferring issues with send on some implementations.
   vtkMPIController::SetUseSsendForRMI(1);
+# endif
 #endif
+
+  vtkMapper::SetResolveCoincidentTopologyToShiftZBuffer();
+  vtkMapper::SetResolveCoincidentTopologyZShift(2.0e-3);
+
+  this->AutoMPI = vtkProcessModuleAutoMPI::New();
+  this->IsAutoMPI = 0;
+
+  vtkCompositeDataPipeline* cddp = vtkCompositeDataPipeline::New();
+  vtkAlgorithm::SetDefaultExecutivePrototype(cddp);
+  cddp->Delete();
 }
 
 //-----------------------------------------------------------------------------
 vtkProcessModule::~vtkProcessModule()
 {
+  vtkAlgorithm::SetDefaultExecutivePrototype(NULL);
   this->SetActiveRemoteConnection(0);
   this->Observer->SetProcessModule(0);
   this->Observer->Delete();
@@ -215,7 +230,6 @@ vtkProcessModule::~vtkProcessModule()
     this->InterpreterObserver = 0;
     }
 
-  this->ProgressHandler->Delete();
   this->SetOptions(0);
   this->SetGUIHelper(0);
 
@@ -232,23 +246,13 @@ vtkProcessModule::~vtkProcessModule()
 
   this->CacheSizeKeeper->Delete();
   this->SetLastProgressName(0);
+  this->AutoMPI->Delete();
 }
 
 //-----------------------------------------------------------------------------
 void vtkProcessModule::SetOptions(vtkPVOptions* op)
 {
   this->Options = op;
-  if (this->Options)
-    {
-    if (this->Options->GetServerMode())
-      {
-      this->ProgressHandler->SetServerMode(1);
-      }
-    if (this->Options->GetClientMode())
-      {
-      this->ProgressHandler->SetClientMode(1);
-      }
-    }
 }
 
 //-----------------------------------------------------------------------------
@@ -301,7 +305,7 @@ vtkDataObject* vtkProcessModule::GetDataObjectOfType(const char* classname)
 void vtkProcessModule::GatherInformation(vtkIdType connectionID,
   vtkTypeUInt32 serverFlags, vtkPVInformation* info, vtkClientServerID id)
 {
-  vtkIdType rootId = 
+  vtkIdType rootId =
     vtkProcessModuleConnectionManager::GetRootConnection(connectionID);
   this->ConnectionManager->GatherInformation(rootId, serverFlags, info, id);
 }
@@ -324,31 +328,30 @@ int vtkProcessModule::Start(int argc, char** argv)
   this->ConnectionManager->AddObserver(vtkCommand::ConnectionClosedEvent,
     this->Observer);
 
+  // fill up ServerInformation with local information.
+  // This just comes in handy on the server-processes, if needed.
+  this->ServerInformation->CopyFromObject(this);
+
   int myId;
   // This call blocks on the Satellite nodes (never on root node).
-  if (this->ConnectionManager->Initialize(argc, argv, 
+  if (this->ConnectionManager->Initialize(argc, argv,
       this->Options->GetClientMode(), &myId) != 0)
     {
     return 1;
     }
 
-
-  if (myId != 0)
+  if (myId == 0)
     {
-    // Satellite node. The control reaches here on a satellite node only on 
-    // exit.
-    return 0;
+    // Should only be called on root nodes.
+    int ret = this->InitializeConnections();
+    if (!ret)
+      {
+      // Failed.
+      return 1;
+      }
     }
 
-  // Should only be called on root nodes.
-  int ret = this->InitializeConnections();
-  if (!ret)
-    {
-    // Failed.
-    return 1;
-    }
-
-  if (this->Options->GetClientMode() || 
+  if (this->Options->GetClientMode() ||
     (!this->Options->GetServerMode() && !this->Options->GetRenderServerMode()))
     {
     // Starts the client event loop.
@@ -362,7 +365,8 @@ int vtkProcessModule::Start(int argc, char** argv)
   //  }
 
   // Running in server mode.
-  return this->StartServer(0);
+  // StartServer() needs to be called only on the root node.
+  return (this->GetPartitionId() == 0)? this->StartServer(0) : 0;
 }
 
 //-----------------------------------------------------------------------------
@@ -372,7 +376,7 @@ int vtkProcessModule::StartClient(int argc, char** argv)
     {
     vtkErrorMacro("GUIHelper must be set on the client.");
     return 1;
-    }  
+    }
 
   if (!this->SupportMultipleConnections)
     {
@@ -417,7 +421,9 @@ int vtkProcessModule::StartClient(int argc, char** argv)
 
   // if the PM supports multiple connections, its the responsibility of the GUI
   // to connect to the server.
-  return this->GUIHelper->RunGUIStart(argc, argv, 1, 0);
+  return this->GUIHelper->RunGUIStart(argc, argv,
+    vtkMultiProcessController::GetGlobalController()->GetNumberOfProcesses(),
+    vtkMultiProcessController::GetGlobalController()->GetLocalProcessId());
 }
 
 //-----------------------------------------------------------------------------
@@ -437,19 +443,19 @@ int vtkProcessModule::StartServer(unsigned long msec)
   else
     {
     // Server in reverse connect mode, connect to the client.
-    // When in reverse connect mode, the server can connect to 
-    // one and only one client. 
+    // When in reverse connect mode, the server can connect to
+    // one and only one client.
     // When the client disconnects, the server terminates.
     if (!this->ConnectToRemote())
       {
-      // failed -- in reverse connect mode, the client must be 
+      // failed -- in reverse connect mode, the client must be
       // up and running before the server tries to connect.
       return 1;
       }
     support_multiple_connections = 0;
     }
 
-  while (!this->ExceptionRaised && 
+  while (!this->ExceptionRaised &&
     (ret = this->ConnectionManager->MonitorConnections(msec)) >= 0)
     {
     if (ret == 2)
@@ -491,7 +497,7 @@ int vtkProcessModule::InitializeConnections()
   case vtkPVOptions::ALLPROCESS:
     return 1; // nothing to do here.
     }
-  
+
   if (this->ShouldWaitForConnection())
     {
     return this->SetupWaitForConnection();
@@ -539,7 +545,7 @@ int vtkProcessModule::SetupWaitForConnection()
         {
         return 0;
         }
-      cout << "Listen on render server port:" << 
+      cout << "Listen on render server port:" <<
         this->Options->GetRenderServerPort() << endl;
       cout << "Listen on data server port:" <<
         this->Options->GetDataServerPort() << endl;
@@ -550,7 +556,7 @@ int vtkProcessModule::SetupWaitForConnection()
       port = this->Options->GetServerPort();
       }
     break;
-    
+
   case vtkPVOptions::PVSERVER:
     port = this->Options->GetServerPort();
     break;
@@ -566,7 +572,7 @@ int vtkProcessModule::SetupWaitForConnection()
   default:
     return 0;
     }
-  
+
   cout << "Listen on port: " << port << endl;
   int ret = this->ConnectionManager->AcceptConnectionsOnPort(
     port, vtkProcessModuleConnectionManager::RENDER_AND_DATA_SERVER);
@@ -585,7 +591,7 @@ int vtkProcessModule::AcceptConnectionsOnPort(int port)
 }
 
 //-----------------------------------------------------------------------------
-void vtkProcessModule::AcceptConnectionsOnPort(int data_server_port, 
+void vtkProcessModule::AcceptConnectionsOnPort(int data_server_port,
   int render_server_port, int &ds_id, int &rs_id)
 {
   ds_id = this->ConnectionManager->AcceptConnectionsOnPort(
@@ -620,11 +626,12 @@ vtkIdType vtkProcessModule::ConnectToRemote(const char* servername, int port)
     vtkErrorMacro("Cannot create new connections.");
     return 0;
     }
+  this->IsAutoMPI = 0;
   return this->ConnectionManager->OpenConnection(servername, port);
 }
 
 //-----------------------------------------------------------------------------
-vtkIdType vtkProcessModule::ConnectToRemote(const char* dataserver_host, 
+vtkIdType vtkProcessModule::ConnectToRemote(const char* dataserver_host,
   int dataserver_port, const char* renderserver_host, int renderserver_port)
 {
   if (this->DisableNewConnections)
@@ -632,6 +639,7 @@ vtkIdType vtkProcessModule::ConnectToRemote(const char* dataserver_host,
     vtkErrorMacro("Cannot create new connections.");
     return 0;
     }
+  this->IsAutoMPI = 0;
   return this->ConnectionManager->OpenConnection(
     dataserver_host, dataserver_port, renderserver_host, renderserver_port);
 }
@@ -644,7 +652,19 @@ vtkIdType vtkProcessModule::ConnectToSelf()
     vtkErrorMacro("Cannot create new connections.");
     return 0;
     }
-  return this->ConnectionManager->OpenSelfConnection();
+  // if there are multiple inputs then start server and connect else
+  // connect to self
+  if(this->AutoMPI->IsPossible())
+    {
+    this->IsAutoMPI = 1;
+    int port = this->AutoMPI->ConnectToRemoteBuiltInSelf();
+    return this->ConnectionManager->OpenConnection("localhost",port);
+    }
+  else
+    {
+    this->IsAutoMPI = 0;
+    return this->ConnectionManager->OpenSelfConnection();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -653,9 +673,23 @@ void vtkProcessModule::Disconnect(vtkIdType id)
   this->ConnectionManager->CloseConnection(id);
 }
 
+//-----------------------------------------------------------------------------
+void vtkProcessModule::AddManagedSocket(vtkSocket* soc,
+  vtkProcessModuleConnection* conn)
+{
+  this->ConnectionManager->AddManagedSocket(soc, conn);
+}
+
+//-----------------------------------------------------------------------------
+void vtkProcessModule::RemoveManagedSocket(vtkSocket* soc)
+{
+  this->ConnectionManager->RemoveManagedSocket(soc);
+}
+
 //-----------------------------------------------------------------------------
 int vtkProcessModule::ConnectToRemote()
 {
+  this->IsAutoMPI = 0;
   const char* message = "client";
   while (1)
     {
@@ -704,14 +738,14 @@ int vtkProcessModule::ConnectToRemote()
       vtkErrorMacro("Invalid mode!");
       return 0;
       }
-    
+
     if (id)
       {
       // connection successful.
       cout << "Connected to " << message << endl;
       return 1;
       }
-    
+
     if (!this->GUIHelper)
       {
       // Probably a server. Just flag error and exit.
@@ -755,7 +789,7 @@ vtkIdType vtkProcessModule::MonitorConnections(unsigned long msec)
       this->LastConnectionID = -1;
       return connid;
     }
-    
+
   return 0;
 }
 
@@ -764,7 +798,7 @@ vtkIdType vtkProcessModule::MonitorConnections(unsigned long msec)
 // Will establish server connections.
 int vtkProcessModule::ClientWaitForConnection()
 {
-  
+
   cout << "Waiting for server..." << endl;
   this->GUIHelper->PopupDialog("Waiting for server",
     "Waiting for server to connect to this client via the reverse connection.");
@@ -779,7 +813,7 @@ int vtkProcessModule::ClientWaitForConnection()
       {
       this->GUIHelper->ClosePopup();
       }
-    
+
     if (res < 0)
       {
       // Error !
@@ -827,9 +861,10 @@ vtkClientServerID vtkProcessModule::NewStreamObject(
 }
 
 //-----------------------------------------------------------------------------
-vtkObjectBase* vtkProcessModule::GetObjectFromID(vtkClientServerID id)
+vtkObjectBase* vtkProcessModule::GetObjectFromID(vtkClientServerID id,
+  bool silent)
 {
-  return this->Interpreter->GetObjectFromID(id);
+  return this->Interpreter->GetObjectFromID(id, silent);
 }
 //-----------------------------------------------------------------------------
 vtkClientServerID vtkProcessModule::GetIDFromObject(vtkObjectBase *obj)
@@ -845,31 +880,12 @@ void vtkProcessModule::DeleteStreamObject(
          <<  vtkClientServerStream::End;
 }
 
-
 //-----------------------------------------------------------------------------
 const vtkClientServerStream& vtkProcessModule::GetLastResult(
   vtkIdType connectionID, vtkTypeUInt32 server)
 {
   return this->ConnectionManager->GetLastResult(connectionID, server);
 }
-//-----------------------------------------------------------------------------
-vtkClientServerID vtkProcessModule::GetConnectionClientServerID(
-  vtkIdType id)
-{
-  return this->ConnectionManager->GetConnectionClientServerID(id);
-}
-
-//-----------------------------------------------------------------------------
-vtkIdType vtkProcessModule::GetConnectionID(vtkClientServerID id)
-{
-  vtkProcessModuleConnection* conn = vtkProcessModuleConnection::SafeDownCast(
-    this->GetObjectFromID(id));
-  if (conn)
-    {
-    return this->ConnectionManager->GetConnectionID(conn);
-    }
-  return vtkProcessModuleConnectionManager::GetNullConnectionID();
-}
 
 //-----------------------------------------------------------------------------
 vtkIdType vtkProcessModule::GetConnectionID(vtkProcessModuleConnection* conn)
@@ -878,14 +894,14 @@ vtkIdType vtkProcessModule::GetConnectionID(vtkProcessModuleConnection* conn)
 }
 
 //-----------------------------------------------------------------------------
-int vtkProcessModule::SendStream(vtkIdType connectionID, 
+int vtkProcessModule::SendStream(vtkIdType connectionID,
   vtkTypeUInt32 server, vtkClientServerStream& stream, int resetStream/*=1*/)
 {
   if (stream.GetNumberOfMessages() < 1)
     {
     return 0;
     }
-  
+
   if (this->SendStreamToClientOnly)
     {
     server &= vtkProcessModule::CLIENT;
@@ -901,10 +917,10 @@ int vtkProcessModule::SendStream(vtkIdType connectionID,
 
   int ret = this->ConnectionManager->SendStream(connectionID,
     server, stream, resetStream);
- 
+
   // If send failed on a Client, it means that the server connection was closed.
   // So currently, we exit the client.
- 
+
   if (ret != 0 && this->GUIHelper)
     {
     cout << "Connection Error: Server connection closed!" << endl;
@@ -929,6 +945,7 @@ void vtkProcessModule::Finalize()
     this->ConnectionManager->Finalize();
     }
   this->FinalizeInterpreter();
+  this->InvokeEvent(vtkCommand::ExitEvent);
 }
 
 //-----------------------------------------------------------------------------
@@ -969,39 +986,38 @@ void vtkProcessModule::InitializeInterpreter()
   this->Interpreter->AddObserver(vtkCommand::UserEvent,
     this->InterpreterObserver);
 
-
-
-  bool needLog = false;
-  if(getenv("VTK_CLIENT_SERVER_LOG"))
+  if (!this->Options)
     {
-    needLog = true;
-    if (!this->Options)
-      {
-      vtkErrorMacro("Options must be set before calling "
-        "InitializeInterpreter().");
-      }
-    else
-      {
-      if(this->Options->GetClientMode())
-        {
-        needLog = false;
-        this->GetInterpreter()->SetLogFile("paraviewClient.log");
-        }
-      if(this->Options->GetServerMode())
-        {
-        needLog = false;
-        this->GetInterpreter()->SetLogFile("paraviewServer.log");
-        }
-      if(this->Options->GetRenderServerMode())
-        {
-        needLog = false;
-        this->GetInterpreter()->SetLogFile("paraviewRenderServer.log");
-        }
-      }
-    } 
-  if(needLog)
+    vtkErrorMacro("Options must be set before calling "
+      "InitializeInterpreter().");
+    }
+
+  if (getenv("VTK_CLIENT_SERVER_LOG") ||
+    this->Options->GetLogFileName())
     {
-    this->GetInterpreter()->SetLogFile("paraview.log");
+    const char* logfilename = this->Options->GetLogFileName();
+    if (!logfilename && this->Options->GetClientMode())
+      {
+      logfilename = "paraviewClient.log";
+      }
+    if (!logfilename && this->Options->GetServerMode())
+      {
+      logfilename = "paraviewServer.log";
+      }
+    if (!logfilename && this->Options->GetRenderServerMode())
+      {
+      logfilename = "paraviewRenderServer.log";
+      }
+    if (!logfilename)
+      {
+      logfilename = "paraview.log";
+      }
+
+    // TODO: would be nice if each process could write the log to a separate
+    // file, however InitializeInterpreter() is called before the multi process
+    // controller is initialized hence we cannot really get the information
+    // about number of processes etc.
+    this->Interpreter->SetLogFile(logfilename);
     }
 
   // Assign standard IDs.
@@ -1009,12 +1025,12 @@ void vtkProcessModule::InitializeInterpreter()
   css << vtkClientServerStream::Assign
     << this->GetProcessModuleID() << this
     << vtkClientServerStream::End;
-  this->Interpreter->ProcessStream(css); 
+  this->Interpreter->ProcessStream(css);
 
   // If any initialization callbacks were registered, call them.
   if (this->InitializationCallbacks)
     {
-    vtkInterpreterInitializationCallbackVector& callbacks = 
+    vtkInterpreterInitializationCallbackVector& callbacks =
       (*this->InitializationCallbacks);
    vtkInterpreterInitializationCallbackVector::iterator iter;
    for (iter = callbacks.begin(); iter != callbacks.end(); ++iter)
@@ -1117,7 +1133,7 @@ int vtkProcessModule::GetNumberOfLocalPartitions()
 //-----------------------------------------------------------------------------
 int vtkProcessModule::GetNumberOfPartitions(vtkIdType id)
 {
-  if (this->Options && this->Options->GetClientMode() && 
+  if (this->Options && this->Options->GetClientMode() &&
     id != vtkProcessModuleConnectionManager::GetSelfConnectionID())
     {
     return this->ConnectionManager->GetNumberOfPartitions(id);
@@ -1170,10 +1186,21 @@ void vtkProcessModule::RegisterProgressEvent(vtkObject* po, int id)
 {
   // We do this check to avoid registering progress events for
   // objects that don't report any progress at all.
-  if (po->IsA("vtkAlgorithm") || po->IsA("vtkKdTree"))
+  //if (po->IsA("vtkAlgorithm") || po->IsA("vtkKdTree"))
+  //  {
+  //  //po->AddObserver(vtkCommand::ProgressEvent, this->Observer);
+  //  //this->ProgressHandler->RegisterProgressEvent(po, id);
+  //  }
+  if (this->ActiveRemoteConnection)
     {
-    po->AddObserver(vtkCommand::ProgressEvent, this->Observer);
-    this->ProgressHandler->RegisterProgressEvent(po, id);
+    this->ActiveRemoteConnection->GetProgressHandler()->
+      RegisterProgressEvent(po, id);
+    }
+  else
+    {
+    this->ConnectionManager->GetConnectionFromID(
+      vtkProcessModuleConnectionManager::GetSelfConnectionID())->
+      GetProgressHandler()->RegisterProgressEvent(po, id);
     }
 }
 
@@ -1191,6 +1218,7 @@ void vtkProcessModule::SendPrepareProgress(vtkIdType connectionId,
     {
     this->Internals->ProgressServersFlag = servers;
     this->GUIHelper->SendPrepareProgress();
+    this->InvokeEvent(vtkCommand::StartEvent);
     }
   else
     {
@@ -1203,8 +1231,9 @@ void vtkProcessModule::SendPrepareProgress(vtkIdType connectionId,
   if (servers)
     {
     vtkClientServerStream stream;
-    stream << vtkClientServerStream::Invoke 
-           << this->GetProcessModuleID() << "PrepareProgress" 
+    stream << vtkClientServerStream::Invoke
+           << this->GetProcessModuleID()
+           << "PrepareProgress"
            << vtkClientServerStream::End;
     this->SendStream(connectionId, servers, stream);
     }
@@ -1232,12 +1261,13 @@ void vtkProcessModule::SendCleanupPendingProgress(vtkIdType connectionId)
     return;
     }
   vtkClientServerStream stream;
-  stream << vtkClientServerStream::Invoke 
-         << this->GetProcessModuleID() << "CleanupPendingProgress" 
-         << vtkClientServerStream::End;
+    stream << vtkClientServerStream::Invoke
+           << this->GetProcessModuleID()
+           << "CleanupPendingProgress"
+           << vtkClientServerStream::End;
   this->SendStream(connectionId, this->Internals->ProgressServersFlag, stream);
   this->Internals->ProgressServersFlag = 0;
-  
+
   this->GUIHelper->SendCleanupPendingProgress();
 
   if (this->LastProgress < 100 && this->LastProgressName)
@@ -1247,18 +1277,48 @@ void vtkProcessModule::SendCleanupPendingProgress(vtkIdType connectionId)
     this->InvokeEvent(vtkCommand::ProgressEvent, &fprog);
     this->SetLastProgressName(0);
     }
+  this->InvokeEvent(vtkCommand::EndEvent);
 }
 
-//----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+vtkPVProgressHandler* vtkProcessModule::GetActiveProgressHandler()
+{
+  if (this->ActiveRemoteConnection)
+    {
+    return this->ActiveRemoteConnection->GetProgressHandler();
+    }
+  return this->ConnectionManager->GetConnectionFromID(
+    vtkProcessModuleConnectionManager::GetSelfConnectionID())->GetProgressHandler();
+}
+
+//-----------------------------------------------------------------------------
 void vtkProcessModule::PrepareProgress()
 {
-  this->ProgressHandler->PrepareProgress(this);
+  if (this->ActiveRemoteConnection)
+    {
+    this->ActiveRemoteConnection->GetProgressHandler()->PrepareProgress();
+    }
+  else
+    {
+    this->ConnectionManager->GetConnectionFromID(
+      vtkProcessModuleConnectionManager::GetSelfConnectionID())->
+      GetProgressHandler()->PrepareProgress();
+    }
 }
 
-//----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 void vtkProcessModule::CleanupPendingProgress()
 {
-  this->ProgressHandler->CleanupPendingProgress(this);
+  if (this->ActiveRemoteConnection)
+    {
+    this->ActiveRemoteConnection->GetProgressHandler()->CleanupPendingProgress();
+    }
+  else
+    {
+    this->ConnectionManager->GetConnectionFromID(
+      vtkProcessModuleConnectionManager::GetSelfConnectionID())->
+      GetProgressHandler()->CleanupPendingProgress();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -1291,26 +1351,12 @@ void vtkProcessModule::ExceptionEvent(int type)
     }
 }
 
-//-----------------------------------------------------------------------------
-void vtkProcessModule::ProgressEvent(vtkObject *o, int val, const char* str)
-{
-  this->ProgressHandler->InvokeProgressEvent(this, o, val, str);
-}
-
 //-----------------------------------------------------------------------------
 void vtkProcessModule::ExecuteEvent(
   vtkObject* o, unsigned long event, void* calldata)
 {
   switch (event)
     {
-  case vtkCommand::ProgressEvent:
-      {
-      int progress = static_cast<int>(*reinterpret_cast<double*>(calldata) *
-        100.0);
-      this->ProgressEvent(o, progress, 0);
-      }
-    break;
-
   case vtkCommand::AbortCheckEvent:
     this->InvokeEvent(vtkCommand::AbortCheckEvent);
     break;
@@ -1331,7 +1377,7 @@ void vtkProcessModule::ExecuteEvent(
       const char* data = reinterpret_cast<const char*>(calldata);
       if (data && re.find(data))
         {
-        // We throw an exception instead of calling 
+        // We throw an exception instead of calling
         // this->ExceptionEvent() directly so that the the calls
         // unwind. This makes it possible for the server to exit gracefully
         // (although there might be some leaks). Otherwise, the server most
@@ -1348,8 +1394,8 @@ void vtkProcessModule::SetLocalProgress(const char* filter, int progress)
 {
   if (!this->GUIHelper)
     {
-    vtkErrorMacro("GUIHelper must be set for SetLocalProgress " << filter
-      << " " << progress);
+    //vtkErrorMacro("GUIHelper must be set for SetLocalProgress " << filter
+    //  << " " << progress);
     return;
     }
   this->LastProgress = progress;
@@ -1393,7 +1439,7 @@ void vtkProcessModule::CreateLogFile()
     {
     return;
     }
-  
+
   vtksys_ios::ostringstream fileName;
   fileName << prefix << this->GetPartitionId() << ".txt"
     << ends;
@@ -1416,15 +1462,15 @@ int vtkProcessModule::GetDirectoryListing(vtkIdType connectionID,
 {
   // Get the listing from the server.
   vtkClientServerStream stream;
-  vtkClientServerID lid = 
+  vtkClientServerID lid =
     this->NewStreamObject("vtkPVServerFileListing", stream);
   stream << vtkClientServerStream::Invoke
     << lid << "GetFileListing" << dir << save
     << vtkClientServerStream::End;
   this->SendStream(connectionID, vtkProcessModule::DATA_SERVER_ROOT, stream);
-  
+
   vtkClientServerStream result;
-  if(!this->GetLastResult(connectionID, 
+  if(!this->GetLastResult(connectionID,
       vtkProcessModule::DATA_SERVER_ROOT).GetArgument(0, 0, &result))
     {
     vtkErrorMacro("Error getting file list result from server.");
@@ -1497,9 +1543,9 @@ int vtkProcessModule::LoadModule(vtkIdType connectionID,
     << this->GetProcessModuleID()
     << "LoadModuleInternal" << name << directory
     << vtkClientServerStream::End;
-  
+
   this->SendStream(connectionID, serverFlags, stream);
-  
+
   int result = 0;
   if(!this->GetLastResult(connectionID,
       this->GetRootId(serverFlags)).GetArgument(0, 0, &result))
@@ -1526,7 +1572,7 @@ void vtkProcessModule::LogStartEvent(const char* str)
   vtkTimerLog::MarkStartEvent(str);
   this->Timer->StartTimer();
 }
-  
+
 //-----------------------------------------------------------------------------
 void vtkProcessModule::LogEndEvent(const char* str)
 {
@@ -1604,7 +1650,7 @@ void vtkProcessModule::SetEnableLog(int flag)
 }
 
 //----------------------------------------------------------------------------
-void vtkProcessModule::SetLogThreshold(vtkIdType connectionID, 
+void vtkProcessModule::SetLogThreshold(vtkIdType connectionID,
                                        vtkTypeUInt32 servers,
                                        double threshold)
 {
@@ -1620,7 +1666,7 @@ void vtkProcessModule::SetLogThreshold(vtkIdType connectionID,
 //============================================================================
 // Stuff that is a part of render-process module.
 //-----------------------------------------------------------------------------
-const char* vtkProcessModule::GetPath(const char* tag, 
+const char* vtkProcessModule::GetPath(const char* tag,
   const char* relativePath, const char* file)
 {
   if ( !tag || !relativePath || !file )
@@ -1756,62 +1802,30 @@ const char* vtkProcessModule::GetMachineName(unsigned int idx)
 vtkPVServerInformation* vtkProcessModule::GetServerInformation(
   vtkIdType id)
 {
-  vtkPVServerInformation* info = 
+  vtkPVServerInformation* info =
     this->ConnectionManager->GetServerInformation(id);
   return (info)? info : this->ServerInformation;
 }
 
 //-----------------------------------------------------------------------------
 vtkClientServerID vtkProcessModule::GetMPIMToNSocketConnectionID(
-  vtkIdType id)
+  vtkIdType vtkNotUsed(id))
 {
-  return this->ConnectionManager->GetMPIMToNSocketConnectionID(id);
+  return vtkClientServerID(3);
 }
 
-
 //----------------------------------------------------------------------------
-// This method leaks memory.  It is a quick and dirty way to set different 
-// DISPLAY environment variables on the render server.  I think the string 
-// cannot be deleted until paraview exits.  The var should have the form:
-// "DISPLAY=amber1"
+// The var should have the form: "DISPLAY=amber1"
 void vtkProcessModule::SetProcessEnvironmentVariable(int processId,
                                                      const char* var)
 {
   if (this->GetPartitionId() == processId)
     {
-    char* envstr = vtksys::SystemTools::DuplicateString(var);
-    putenv(envstr);
+    // PutEnv() avoids memory leak.
+    vtksys::SystemTools::PutEnv(var);
     }
 }
 
-//-----------------------------------------------------------------------------
-vtkSocketController* vtkProcessModule::GetSocketController(
-  vtkProcessModuleConnection* conn)
-{
-  vtkRemoteConnection* rconn = vtkRemoteConnection::SafeDownCast(conn);
-  if (rconn)
-    {
-    return rconn->GetSocketController();
-    }
-  return 0;
-}
-
-//-----------------------------------------------------------------------------
-vtkSocketController* vtkProcessModule::GetRenderServerSocketController(
-  vtkProcessModuleConnection* conn)
-{
-  vtkServerConnection* sconn = vtkServerConnection::SafeDownCast(conn);
-  if (sconn)
-    {
-    vtkSocketController* sc = sconn->GetRenderServerSocketController();
-    if (sc)
-      {
-      return sc;
-      }
-    }
-  return this->GetSocketController(conn);
-}
-
 //-----------------------------------------------------------------------------
 vtkSocketController* vtkProcessModule::GetActiveSocketController()
 {
@@ -1842,10 +1856,10 @@ vtkSocketController* vtkProcessModule::GetActiveRenderServerSocketController()
 }
 
 //-----------------------------------------------------------------------------
-void vtkProcessModule::PushUndo(vtkIdType id, const char* label, 
+void vtkProcessModule::PushUndo(vtkIdType id, const char* label,
   vtkPVXMLElement* root)
 {
-  this->ConnectionManager->PushUndo(id, label, root); 
+  this->ConnectionManager->PushUndo(id, label, root);
 }
 
 //-----------------------------------------------------------------------------
@@ -1906,11 +1920,11 @@ void vtkProcessModule::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "SupportMultipleConnections: " << this->SupportMultipleConnections
     << endl;
   os << indent << "UseMPI: " << this->UseMPI << endl;
-  os << indent << "SendStreamToClientOnly: " 
+  os << indent << "SendStreamToClientOnly: "
     << this->SendStreamToClientOnly << endl;
-  os << indent 
+  os << indent
     << (this->LastProgressName? this->LastProgressName : "(none)") << endl;
- 
+
   os << indent << "Interpreter: " ;
   if (this->Interpreter)
     {
@@ -1921,16 +1935,6 @@ void vtkProcessModule::PrintSelf(ostream& os, vtkIndent indent)
     os << "(none)" << endl;
     }
 
-  os << indent << "ProgressHandler: " ;
-  if (this->ProgressHandler)
-    {
-    this->ProgressHandler->PrintSelf(os, indent.GetNextIndent());
-    }
-  else
-    {
-    os << "(none)" << endl;
-    }
-
   os << indent << "ActiveRemoteConnection: " ;
   if (this->ActiveRemoteConnection)
     {
@@ -1940,7 +1944,7 @@ void vtkProcessModule::PrintSelf(ostream& os, vtkIndent indent)
     {
     os << "(none)" << endl;
     }
-  
+
   os << indent << "Options: ";
   if (this->Options)
     {
