@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkProcessModule.h,v $
+  Module:    vtkProcessModule.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -16,10 +16,10 @@
 // .SECTION Description
 // This is the class that encapsulates all the process initialization.
 // The processes module creates a vtkProcessModuleConnectionManager which
-// is used to setup connections to self, and remote machines (either client or 
+// is used to setup connections to self, and remote machines (either client or
 // servers). The Self connection manages MPI process communication, if any.
 // Each connection is assigned a Unique ID. SendStream etc are expected to
-// provide the ID of the connection on which the stream is to be sent. 
+// provide the ID of the connection on which the stream is to be sent.
 
 #ifndef __vtkProcessModule_h
 #define __vtkProcessModule_h
@@ -49,16 +49,18 @@ class vtkRemoteConnection;
 class vtkSocketController;
 class vtkStringList;
 class vtkTimerLog;
+class vtkSocket;
+class vtkProcessModuleAutoMPI;
 
 class VTK_EXPORT vtkProcessModule : public vtkObject
 {
 public:
   static vtkProcessModule* New();
-  vtkTypeRevisionMacro(vtkProcessModule, vtkObject);
+  vtkTypeMacro(vtkProcessModule, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 //BTX
-  // Description: 
+  // Description:
   // These flags are used to specify destination servers for the
   // SendStream function.
   enum ServerFlags
@@ -90,12 +92,12 @@ public:
       {
       return CLIENT;
       }
-    
+
     if (serverId == DATA_SERVER_ROOT || serverId == RENDER_SERVER_ROOT)
       {
       return serverId;
       }
-    
+
     if (serverId == (DATA_SERVER | RENDER_SERVER) )
       {
       return DATA_SERVER_ROOT;
@@ -107,17 +109,17 @@ public:
   // Description:
   // Get a directory listing for the given directory.  Returns 1 for
   // success, and 0 for failure (when the directory does not exist).
-  virtual int GetDirectoryListing(vtkIdType connectionID, const char* dir, 
+  virtual int GetDirectoryListing(vtkIdType connectionID, const char* dir,
     vtkStringList* dirs, vtkStringList* files, int save);
- 
+
 //BTX
   // Description:
   // Load a ClientServer wrapper module dynamically in the server
   // processes.  Returns 1 if all server nodes loaded the module and 0
-  // otherwise.  connectionID identifies the connection. 
+  // otherwise.  connectionID identifies the connection.
   // serverFlags can be used to indicate if this is a data server module
-  // or a render server module. The directory argument may be used 
-  // to specify a directory in which to look for the module. 
+  // or a render server module. The directory argument may be used
+  // to specify a directory in which to look for the module.
   virtual int LoadModule(vtkIdType connectionID,
     vtkTypeUInt32 serverFlags, const char* name, const char* directory);
 //ETX
@@ -145,10 +147,10 @@ public:
   virtual void GatherInformation(vtkIdType connectionID,
     vtkTypeUInt32 serverFlags, vtkPVInformation* info, int id)
   {
-    this->GatherInformation(connectionID, serverFlags, info, 
+    this->GatherInformation(connectionID, serverFlags, info,
                             vtkClientServerID(id));
   }
-  
+
   // Description:
   // Start the process modules. It will create the application
   // and start the event loop. Returns 0 on success.
@@ -157,10 +159,11 @@ public:
   // Description:
   // Return the vtk object associated with the given id for the
   // client.  If the id is for an object on another node then 0 is
-  // returned.
-  virtual vtkObjectBase* GetObjectFromID(int id)
+  // returned. If the second argument is set to true, no error
+  // is reported when the ID is invalid / does not exist.
+  virtual vtkObjectBase* GetObjectFromID(int id, bool silent=false)
   {
-    return this->GetObjectFromID(vtkClientServerID(id));
+    return this->GetObjectFromID(vtkClientServerID(id), silent);
   }
 
 //BTX
@@ -175,22 +178,28 @@ public:
   void DeleteStreamObject(vtkClientServerID, vtkClientServerStream& stream);
 
   // Description:
-  // This method is an overload for the 
+  // This method is an overload for the
   // NewStreamObject(const char*, vtkClientServerStream&). It is similar to the other
   // since is also creates a new vtkobject, however, it does not assign a new
-  // object ID for it, instead the id passed as argument is used. 
-  // Additionally, it updates the internal ID count, so that next UniqueID 
+  // object ID for it, instead the id passed as argument is used.
+  // Additionally, it updates the internal ID count, so that next UniqueID
   // requested from the process module will certainly be greater than the one
   // passed to this method.
   vtkClientServerID NewStreamObject(const char*, vtkClientServerStream& stream,
     vtkClientServerID id);
 
-  
+
   // Description:
   // Return the vtk object associated with the given id for the
   // client.  If the id is for an object on another node then 0 is
   // returned.
-  virtual vtkObjectBase* GetObjectFromID(vtkClientServerID);
+  // If the second argument is set to true, no error
+  // is reported when the ID is invalid / does not exist.
+  virtual vtkObjectBase* GetObjectFromID(vtkClientServerID, bool silent=true);
+
+  // Description:
+  // Given a vtk object, returns its client-server ID if that object
+  // is registered. Returns a NULL ID otherwise.
   virtual vtkClientServerID GetIDFromObject(vtkObjectBase*);
 
   // Description:
@@ -208,7 +217,7 @@ public:
   // use the bitwise or operator to combine servers.  The resetStream
   // flag determines if Reset is called to clear the stream after it
   // is sent.
-  int SendStream(vtkIdType connectionID, vtkTypeUInt32 server, 
+  int SendStream(vtkIdType connectionID, vtkTypeUInt32 server,
     vtkClientServerStream& stream, int resetStream=1);
 
   // Description:
@@ -226,7 +235,7 @@ public:
   // Initialize and finalize process module.
   void Initialize();
   void Finalize();
-  
+
   // Description:
   // Set/Get whether to report errors from the Interpreter.
   vtkGetMacro(ReportInterpreterErrors, int);
@@ -235,7 +244,7 @@ public:
 
   // Description:
   // This is the controller used to communicate with the MPI nodes
-  // by the SelfConnection. 
+  // by the SelfConnection.
   vtkMultiProcessController* GetController();
 
   // Description:
@@ -247,10 +256,10 @@ public:
   // it returns the number of client process partitions (which is always 1),
   // while on any server node, it returns the number of server partitions.
   virtual int GetNumberOfLocalPartitions();
-  
+
   // Description:
   // Get the number of processes participating in sharing the data for
-  // the given connection id. This is only called 
+  // the given connection id. This is only called
   // on the client to get the number of partitions on of server
   // the client is connected to.
   // On server side, the connection id is ignored
@@ -286,13 +295,9 @@ public:
   // Description:
   // Register object with progress handler.
   void RegisterProgressEvent(vtkObject* po, int id);
- 
-  // Description:
-  // Internal method--called when a progress event is received.
-  void ProgressEvent(vtkObject *o, int val, const char* filter);
 
   // Description:
-  // Internal method- called when an exception Tag is received 
+  // Internal method- called when an exception Tag is received
   // from the server.
   void ExceptionEvent(const char* message);
   // Description:
@@ -305,15 +310,12 @@ public:
   virtual void SendPrepareProgress(vtkIdType connectionID,
     vtkTypeUInt32 servers=CLIENT|DATA_SERVER);
   virtual void SendCleanupPendingProgress(vtkIdType connectionID);
+  vtkPVProgressHandler* GetActiveProgressHandler();
   //ETX
 
   // Description:
-  // This method is called before progress reports start comming.
+  // Internal methods. Do not call directly.
   void PrepareProgress();
-
-  // Description:
-  // This method is called after force update to clenaup all the pending
-  // progresses.
   void CleanupPendingProgress();
 
   // Description:
@@ -322,7 +324,6 @@ public:
   void SetLocalProgress(const char* filter, int progress);
   vtkGetMacro(ProgressRequests, int);
   vtkSetMacro(ProgressRequests, int);
-  vtkGetObjectMacro(ProgressHandler, vtkPVProgressHandler);
 
   // Description:
   // Set and get the application options
@@ -345,7 +346,7 @@ public:
   void LogEndEvent(const char* str);
 
   // Description:
-  // More timer log access methods. 
+  // More timer log access methods.
   void SetLogBufferLength(int length);
   void SetLogBufferLength(vtkIdType connectionID,
                           vtkTypeUInt32 servers,
@@ -366,10 +367,10 @@ public:
   // Description:
   // We need to get the data path for the demo on the server.
   const char* GetPath(const char* tag, const char* relativePath, const char* file);
-  
-  // Description:  
-  // This method leaks memory.  It is a quick and dirty way to set different 
-  // DISPLAY environment variables on the render server.  I think the string 
+
+  // Description:
+  // This method leaks memory.  It is a quick and dirty way to set different
+  // DISPLAY environment variables on the render server.  I think the string
   // cannot be deleted until paraview exits.  The var should have the form:
   // "DISPLAY=amber1"
   virtual void SetProcessEnvironmentVariable(int processId, const char* var);
@@ -384,26 +385,14 @@ public:
 
   // Description:
   // Returns the information about command line arguments on the server for the
-  // given connection.  This returns 0 if the connection is not a remote 
+  // given connection.  This returns 0 if the connection is not a remote
   // connection.
   vtkPVServerInformation* GetServerInformation(vtkIdType id);
 
 //BTX
   // Description:
   // Get the ID used for MPIMToNSocketConnection for the given connection.
-  vtkClientServerID GetMPIMToNSocketConnectionID(vtkIdType id);
-  
-  // Description:
-  // Given a connection ID, this call returns the ClientServer ID
-  // assigned to that connection. For now, only vtkRemoteConnections are
-  // assigned valid ClientServer IDs. If needed, we can add these IDs 
-  // to SelfConnection also.
-  vtkClientServerID GetConnectionClientServerID(vtkIdType);
-
-  // Description:
-  // Given a ClientServer ID for a connection, it returns the connection ID
-  // assigned to it on this process.
-  vtkIdType GetConnectionID(vtkClientServerID id);
+  vtkClientServerID GetMPIMToNSocketConnectionID(vtkIdType id=-1);
 //ETX
 
 
@@ -419,24 +408,17 @@ public:
 
   // Description:
   // Get the socket controller associated with the ActiveRemoteConnection;
-  // The notion of active conntion
-  // is here only for the sake of ProgressHandler.
+  // ActiveRemoteConnection is the connection which is processing the current
+  // stream.
   vtkSocketController* GetActiveSocketController();
 
   // Description:
   // Get the render-server socket controlled for the ActiveRemoteConnection,
-  // if any. The notion of active conntion
-  // is here only for the sake of ProgressHandler.
+  // if any.
+  // ActiveRemoteConnection is the connection which is processing the current
+  // stream.
   vtkSocketController* GetActiveRenderServerSocketController();
 
-  // Description:
-  // This is the way to get the socket controllers on all
-  // partitions/server/client etc.  using the client server stream. This
-  // works because each connection (for now, each Remote connection) is
-  // assigned a ClientServerId.
-  vtkSocketController* GetSocketController(vtkProcessModuleConnection* conn);
-  vtkSocketController* GetRenderServerSocketController(vtkProcessModuleConnection* conn);
-
   // Description:
   // For the given connection, returns 1 if the connection is
   // a remote server connection with separate socket connections
@@ -474,7 +456,7 @@ public:
   };
 
 //ETX
-  
+
   // Description:
   // When this flag is set, it implies that the server (or client) can
   // accept multiple remote connections. This class only affects when
@@ -482,7 +464,7 @@ public:
   vtkSetMacro(SupportMultipleConnections, int);
   vtkGetMacro(SupportMultipleConnections, int);
   vtkBooleanMacro(SupportMultipleConnections, int);
-  
+
   // Description:
   // Connect to remote process. Returns the connection Id for the newly
   // created connection, on failure, NullConnectionID is returned.  This
@@ -504,18 +486,18 @@ public:
   // Description:
   // Setups up a server socket on the given port. On success, returns a non-zero
   // identifier for the server socket which can be used to close the socket
-  // using StopAcceptingConnections(). 
+  // using StopAcceptingConnections().
   int AcceptConnectionsOnPort(int port);
 
   // Description:
-  // Setups up a server socket on the given port. On success, 
+  // Setups up a server socket on the given port. On success,
   // ds_id and rs_id are set to non-zero identifiers for the data and render
   // server sockets, respectively.
   void AcceptConnectionsOnPort(int data_server_port, int render_server_port,
     int &ds_id, int &rs_id);
 
   // Description:
-  // Closes a server socket with the given id. The id is the same id returned 
+  // Closes a server socket with the given id. The id is the same id returned
   // by AcceptConnectionsOnPort().
   void StopAcceptingConnections(int id);
   void StopAcceptingAllConnections();
@@ -533,11 +515,11 @@ public:
   // Description:
   // Returns the number of connections (including the SelfConnection).
   int GetNumberOfConnections();
-  
+
   // Description:
   // Close the connection. The connection must be a remote connection.
   void Disconnect(vtkIdType id);
- 
+
   // Description:
   // Returns 1 is the connection is a connection with a remote server (or client).
   int IsRemote(vtkIdType id);
@@ -554,7 +536,7 @@ public:
   // new connections are pending.  Return value: -1 on error, 0 on timeout,
   // 1 if a new connection has been established.
   vtkIdType MonitorConnections(unsigned long msec);
-  
+
   // Description:
   // Clear this flag to override using of MPI for self connection.  This
   // flag should be changed, if at all, only before calling
@@ -566,21 +548,27 @@ public:
   vtkSetMacro(UseMPI, int);
   vtkGetMacro(UseMPI, int);
 
+  // Description:
+  // This flag if set indicates that the current process
+  // module has automatically started "pvservers" as MPI processes as
+  // default pipeline.
+  vtkGetMacro(IsAutoMPI, int);
+
   // Description:
   // Push an undo set xml state on the undo stack for the given connection.
   void PushUndo(vtkIdType id, const char* label, vtkPVXMLElement* root);
 
   // Description:
   // Get the next undo  xml from the connection.
-  // This method allocates  a new vtkPVXMLElement. It is the responsibility 
-  // of caller to \c Delete it. 
+  // This method allocates  a new vtkPVXMLElement. It is the responsibility
+  // of caller to \c Delete it.
   // \returns NULL on failure, otherwise the XML element is returned.
   vtkPVXMLElement* NewNextUndo(vtkIdType id);
- 
+
   // Description:
   // Get the next redo  xml from the connection.
-  // This method allocates  a new vtkPVXMLElement. It is the responsibility 
-  // of caller to \c Delete it. 
+  // This method allocates  a new vtkPVXMLElement. It is the responsibility
+  // of caller to \c Delete it.
   // \returns NULL on failure, otherwise the XML element is returned.
   vtkPVXMLElement* NewNextRedo(vtkIdType id);
 
@@ -628,6 +616,20 @@ public:
   // invoked once the process module is created. This is generally necessary for
   // plugins.
   static void InitializeInterpreter(InterpreterInitializationCallback callback);
+
+  // Description:
+  // Add a socket to be managed. conn is the connection is any,
+  // associated with the socket.
+  // INTENDED FOR SPECIALIST USE ONLY. IF YOU ARE WONDERING WHAT DOES METHOD
+  // DOES THEN YOU SHOULDN'T BE USING THIS METHOD.
+  void AddManagedSocket(vtkSocket* soc, vtkProcessModuleConnection* conn);
+
+  // Description:
+  // Remove a socket from being managed.
+  // INTENDED FOR SPECIALIST USE ONLY. IF YOU ARE WONDERING WHAT DOES METHOD
+  // DOES THEN YOU SHOULDN'T BE USING THIS METHOD.
+  void RemoveManagedSocket(vtkSocket* soc);
+
 protected:
   vtkProcessModule();
   ~vtkProcessModule();
@@ -654,7 +656,7 @@ protected:
   virtual int StartClient(int argc, char** argv);
 
   // Description:
-  // Starts the server node event loop. Return 0 on success. This method is 
+  // Starts the server node event loop. Return 0 on success. This method is
   // called only on the server root node.
   // msec is the inactivity timeout. If no socket activity happens on the server
   // for msec milliseconds, the server exists. Timeout of 0 implies no timeout, the
@@ -683,17 +685,17 @@ protected:
   // Description:
   // Return 1 if the connection should wait, and 0 otherwise.
   int ShouldWaitForConnection();
- 
+
   // Description:
   // Called on client in reverse connection mode. Returns after the
-  // client has connected to a RenderServer/DataServer (in case of 
+  // client has connected to a RenderServer/DataServer (in case of
   // client-render-server) or Server.
   int ClientWaitForConnection();
-  
+
   // Description:
-  // ProcessModule runs on a SingleThread. Hence, we have the notion 
+  // ProcessModule runs on a SingleThread. Hence, we have the notion
   // of which connection has some activity at a given time. This "active"
-  // connection is identified by ActiveRemoteConnection. This only applies 
+  // connection is identified by ActiveRemoteConnection. This only applies
   // to remote connections. A remote connection is active
   // when it is processing some stream on the SelfConnection.
   // It is the responsibility of vtkRemoteConnection (and subclasses)
@@ -702,9 +704,9 @@ protected:
   void SetActiveRemoteConnection(vtkRemoteConnection*);
   // so that this class can access SetActiveConnection.
   friend class vtkRemoteConnection;
-  
+
   vtkClientServerID UniqueID;
-  
+
   vtkClientServerInterpreter* Interpreter;
   vtkCallbackCommand* InterpreterObserver;
   int ReportInterpreterErrors;
@@ -714,14 +716,13 @@ protected:
   vtkProcessModuleObserver* Observer;
   vtkProcessModuleConnectionManager* ConnectionManager;
 
-  vtkPVProgressHandler* ProgressHandler;
   int ProgressRequests;
 
   vtkPVOptions* Options;
   vtkProcessModuleGUIHelper* GUIHelper;
 
   // Description:
-  // This is an empty server information object used when 
+  // This is an empty server information object used when
   // no actual server exists.
   vtkPVServerInformation* ServerInformation;
   double LogThreshold;
@@ -768,7 +769,10 @@ private:
   friend class vtkProcessModuleCleanup;
   class vtkInterpreterInitializationCallbackVector;
   static vtkInterpreterInitializationCallbackVector* InitializationCallbacks;
-//ETX
+
+  int IsAutoMPI;
+  vtkProcessModuleAutoMPI *AutoMPI;
+  //ETX
 };
 
 
