@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: TestMPI.cxx,v $
+  Module:    TestMPI.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
