@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkHierarchicalFractal.h,v $
+  Module:    vtkHierarchicalFractal.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -33,12 +33,17 @@ class vtkRectilinearGrid;
 class vtkDataSet;
 class vtkHierarchicalBoxDataSet;
 
+
+
+
+
+
 class VTK_EXPORT vtkHierarchicalFractal : public vtkCompositeDataSetAlgorithm
 {
 public:
   static vtkHierarchicalFractal *New();
 
-  vtkTypeRevisionMacro(vtkHierarchicalFractal,vtkCompositeDataSetAlgorithm);
+  vtkTypeMacro(vtkHierarchicalFractal,vtkCompositeDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -91,6 +96,12 @@ public:
   vtkSetMacro(Asymetric,int);
   vtkGetMacro(Asymetric,int);
 
+  // Description:
+  // Test with lower levels overlapping higher levels.
+  // This is what I assume flash is like.
+  vtkSetMacro(Overlap,int);
+  vtkGetMacro(Overlap,int);
+
 protected:
   vtkHierarchicalFractal();
   ~vtkHierarchicalFractal();
@@ -175,6 +186,7 @@ protected:
   
   void InternalImageDataCopy(vtkHierarchicalFractal *src);
 
+  int Overlap;
   int Asymetric;
   int MaximumLevel;
   int Dimensions;
