@@ -78,6 +78,8 @@ vtkIceTRenderer::vtkIceTRenderer()
   // Disable the gradient and texuted background color for now.
   this->Superclass::TexturedBackgroundOff();
   this->Superclass::GradientBackgroundOff();
+
+  this->DisableIceT = false;
 }
 
 vtkIceTRenderer::~vtkIceTRenderer()
@@ -150,6 +152,12 @@ void vtkIceTRenderer::SetDataReplicationGroupColor(int color)
 void vtkIceTRenderer::GetTiledSizeAndOrigin(int *width, int *height,
                                             int *lowerLeftX, int *lowerLeftY)
 {
+  if (this->DisableIceT)
+    {
+    this->Superclass::GetTiledSizeAndOrigin(width, height, lowerLeftX,
+      lowerLeftY);
+    return;
+    }
   if (this->InIceTRender)
     {
     // If this method is being called during an IceT render, then IceT has
@@ -182,6 +190,12 @@ void vtkIceTRenderer::GetTiledSizeAndOrigin(int *width, int *height,
 
 void vtkIceTRenderer::DeviceRender()
 {
+  if (this->DisableIceT)
+    {
+    this->Superclass::DeviceRender();
+    return;
+    }
+
   vtkDebugMacro("In vtkIceTRenderer::DeviceRender");
   vtkTimerLog::MarkStartEvent("IceT Dev Render");
 
@@ -362,7 +376,7 @@ void vtkIceTRenderer::DeviceRender()
 
 void vtkIceTRenderer::Clear()
 {
-  if (!this->InIceTRender)
+  if (!this->InIceTRender || this->DisableIceT)
     {
     this->Superclass::Clear();
     return;
@@ -399,6 +413,11 @@ void vtkIceTRenderer::RenderWithoutCamera()
 //ICE-T set the correct projection.
 int vtkIceTRenderer::UpdateCamera()
 {
+  if (this->DisableIceT)
+    {
+    return this->Superclass::UpdateCamera();
+    }
+
   vtkDebugMacro("In vtkIceTRenderer::UpdateCamera()");
 
   //Push the modelview matrix, because the vktOpenGLRenderer::DeviceRender()
@@ -442,6 +461,10 @@ static inline void UpdateViewParams(GLdouble vert[3], GLdouble transform[16],
 //overall viewing volume.
 int vtkIceTRenderer::UpdateGeometry()
 {
+  if (this->DisableIceT)
+    {
+    return this->Superclass::UpdateGeometry();
+    }
   vtkDebugMacro("In vtkIceTRenderer::UpdateGeometry()");
 
   if (this->Selector)
@@ -571,6 +594,11 @@ int vtkIceTRenderer::UpdateGeometry()
 //-----------------------------------------------------------------------------
 int vtkIceTRenderer::UpdateTranslucentPolygonalGeometry()
 {
+  if (this->DisableIceT)
+    {
+    return this->Superclass::UpdateTranslucentPolygonalGeometry();
+    }
+
   int result=0;
   // loop through props and give them a chance to
   // render themselves as translucent geometry
