@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVJoystickFly.h,v $
+  Module:    vtkPVJoystickFly.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,7 @@ class vtkRenderer;
 class VTK_EXPORT vtkPVJoystickFly : public vtkCameraManipulator
 {
 public:
-  vtkTypeRevisionMacro(vtkPVJoystickFly, vtkCameraManipulator);
+  vtkTypeMacro(vtkPVJoystickFly, vtkCameraManipulator);
   void PrintSelf(ostream& os, vtkIndent indent);
   
   // Description:
