@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVLinearExtrusionFilter.h,v $
+  Module:    vtkPVLinearExtrusionFilter.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,7 @@ class VTK_EXPORT vtkPVLinearExtrusionFilter : public vtkPLinearExtrusionFilter
 {
 public:
   static vtkPVLinearExtrusionFilter *New();
-  vtkTypeRevisionMacro(vtkPVLinearExtrusionFilter, vtkPLinearExtrusionFilter);
+  vtkTypeMacro(vtkPVLinearExtrusionFilter, vtkPLinearExtrusionFilter);
   void PrintSelf(ostream &os, vtkIndent indent);
   
 protected:
