@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPythonProgrammableFilter.h,v $
+  Module:    vtkPythonProgrammableFilter.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -12,14 +12,14 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkPythonProgrammableFilter - Executes a user supplied python script 
+// .NAME vtkPythonProgrammableFilter - Executes a user supplied python script
 // on its input dataset to produce an output dataset.
 // .SECTION Description
 // This filter will execute a python script to produce an output dataset.
 // An new interpretor is created at the beginning of RequestInformation().
 // The state of the python interpretor is preserved until the
 // next execution of RequestInformation().
-// After the interpretor is creates the vtk module is imported with 
+// After the interpretor is creates the vtk module is imported with
 // "from paraview import vtk".
 //
 // Then the interpretor runs the InformationScript during RequestInformation().
@@ -44,25 +44,32 @@
 
 #include "vtkProgrammableFilter.h"
 
+class vtkPVPythonInterpretor;
+
 class vtkPythonProgrammableFilterImplementation;
 
 class VTK_EXPORT vtkPythonProgrammableFilter : public vtkProgrammableFilter
 {
 public:
-  vtkTypeRevisionMacro(vtkPythonProgrammableFilter,vtkProgrammableFilter);
+  vtkTypeMacro(vtkPythonProgrammableFilter,vtkProgrammableFilter);
   void PrintSelf(ostream& os, vtkIndent indent);
   static vtkPythonProgrammableFilter *New();
 
-  // Description: 
+  // Description:
   // Set the text of the python script to execute.
   vtkSetStringMacro(Script)
   vtkGetStringMacro(Script)
 
-  // Description: 
+  // Description:
   // Set the text of the python script to execute in RequestInformation().
   vtkSetStringMacro(InformationScript)
   vtkGetStringMacro(InformationScript)
 
+  // Description:
+  // Set the text of the python script to execute in RequestUpdateExtent().
+  vtkSetStringMacro(UpdateExtentScript)
+  vtkGetStringMacro(UpdateExtentScript)
+
   // Description:
   // Set a name-value parameter that will be available to the script
   // when it is run
@@ -72,7 +79,7 @@ public:
   // Clear all name-value parameters
   void ClearParameters();
 
-  // Description: 
+  // Description:
   // For internal use only.
   static void ExecuteScript(void *);
 
@@ -88,6 +95,14 @@ public:
   vtkSetStringMacro(PythonPath);
   vtkGetStringMacro(PythonPath);
 
+  // Description:
+  // Returns the Python interp that should be used by all pipeline objects.
+  // The interp is created this first time this function is called and it
+  // is destroyed when vtkProcessModule invokes the ConnectionClosedEvent
+  // event.
+//BTX
+  static vtkPVPythonInterpretor* GetGlobalPipelineInterpretor();
+//ETX
 protected:
   vtkPythonProgrammableFilter();
   ~vtkPythonProgrammableFilter();
@@ -103,16 +118,21 @@ protected:
 
   // Description:
   // Creates whatever output data set type is selected.
-  virtual int RequestDataObject(vtkInformation* request, 
-                                vtkInformationVector** inputVector, 
+  virtual int RequestDataObject(vtkInformation* request,
+                                vtkInformationVector** inputVector,
                                 vtkInformationVector* outputVector);
 
-  virtual int RequestInformation(vtkInformation* request, 
-                                 vtkInformationVector** inputVector, 
+  virtual int RequestInformation(vtkInformation* request,
+                                 vtkInformationVector** inputVector,
+                                 vtkInformationVector* outputVector);
+
+  virtual int RequestUpdateExtent(vtkInformation* request,
+                                 vtkInformationVector** inputVector,
                                  vtkInformationVector* outputVector);
 
   char *Script;
   char *InformationScript;
+  char *UpdateExtentScript;
   char *PythonPath;
   int OutputDataSetType;
 
@@ -120,7 +140,10 @@ private:
   vtkPythonProgrammableFilter(const vtkPythonProgrammableFilter&);  // Not implemented.
   void operator=(const vtkPythonProgrammableFilter&);  // Not implemented.
 
+  static vtkPVPythonInterpretor* GlobalPipelineInterpretor;
+
 //BTX
+  friend class vtkPythonProgrammableFilterObserver;
   vtkPythonProgrammableFilterImplementation* const Implementation;
 //ETX
 };
