@@ -29,7 +29,6 @@
 
 #include <vtkstd/list>
 
-vtkCxxRevisionMacro(vtkTransferFunctionEditorWidgetSimple1D, "$Revision: 1.35 $");
 vtkStandardNewMacro(vtkTransferFunctionEditorWidgetSimple1D);
 
 // The vtkNodeList is a PIMPLed list<T>.
@@ -558,12 +557,24 @@ void vtkTransferFunctionEditorWidgetSimple1D::OnChar()
 
   const char DelKey = 127;
   const char BackSpaceKey = 8;
-
+  const char TabKey = 9;
+  
   if(keyCode == 'd' || keyCode == 'D' ||
      keyCode == DelKey || keyCode == BackSpaceKey)
     {
     this->RemoveNode(rep->GetActiveHandle());
     }
+  else if(keyCode == TabKey)
+    {
+    if(this->Interactor->GetShiftKey())
+      {
+      this->MoveToPreviousElement();
+      }
+    else
+      {
+      this->MoveToNextElement();
+      }
+    }
 }
 
 //-------------------------------------------------------------------------
@@ -1132,7 +1143,7 @@ void vtkTransferFunctionEditorWidgetSimple1D::SetElementHSVColor(
 void vtkTransferFunctionEditorWidgetSimple1D::SetElementScalar(
   unsigned int idx, double value)
 {
-  unsigned int size = this->Nodes->size();
+  unsigned int size = static_cast<unsigned int>(this->Nodes->size());
   if (idx >= this->Nodes->size())
     {
     return;
