@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkXMLPVDWriter.cxx,v $
+  Module:    vtkXMLPVDWriter.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -15,8 +15,8 @@
 #include "vtkXMLPVDWriter.h"
 
 #include "vtkCallbackCommand.h"
-#include "vtkExecutive.h"
 #include "vtkErrorCode.h"
+#include "vtkExecutive.h"
 #include "vtkGarbageCollector.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
@@ -31,15 +31,17 @@
 #include "vtkXMLImageDataWriter.h"
 #include "vtkXMLPDataWriter.h"
 #include "vtkXMLPImageDataWriter.h"
+#include "vtkXMLPMultiBlockDataWriter.h"
+#include "vtkXMLPolyDataWriter.h"
 #include "vtkXMLPPolyDataWriter.h"
 #include "vtkXMLPRectilinearGridWriter.h"
 #include "vtkXMLPStructuredGridWriter.h"
 #include "vtkXMLPUnstructuredGridWriter.h"
-#include "vtkXMLPolyDataWriter.h"
 #include "vtkXMLRectilinearGridWriter.h"
 #include "vtkXMLStructuredGridWriter.h"
 #include "vtkXMLUnstructuredGridWriter.h"
 #include "vtkXMLWriter.h"
+
 #include <vtksys/SystemTools.hxx>
 #include <vtksys/ios/sstream>
 
@@ -48,7 +50,6 @@
 
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkXMLPVDWriter);
-vtkCxxRevisionMacro(vtkXMLPVDWriter, "$Revision: 1.16 $");
 
 class vtkXMLPVDWriterInternals
 {
@@ -481,6 +482,19 @@ void vtkXMLPVDWriter::CreateWriters()
             this->Internal->Writers[i].GetPointer())->SetInput(exec->GetInputData(0, i));
           }
         break;
+
+      case VTK_MULTIBLOCK_DATA_SET:
+        if(!this->Internal->Writers[i].GetPointer() ||
+          (strcmp(this->Internal->Writers[i]->GetClassName(),
+                  "vtkXMLPMultiBlockDataWriter") != 0))
+          {
+          vtkXMLPMultiBlockDataWriter* w = vtkXMLPMultiBlockDataWriter::New();
+          this->Internal->Writers[i] = w;
+          w->Delete();
+          }
+        vtkXMLPMultiBlockDataWriter::SafeDownCast(
+          this->Internal->Writers[i].GetPointer())->SetInput(exec->GetInputData(0, i));
+        break;
       }
     
     // Copy settings to the writer.
