@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMAnimationCueProxy.cxx,v $
+  Module:    vtkSMAnimationCueProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -24,7 +24,6 @@
 #include "vtkSMProperty.h"
 #include "vtkSMProxyProperty.h"
 
-vtkCxxRevisionMacro(vtkSMAnimationCueProxy, "$Revision: 1.26 $");
 vtkStandardNewMacro(vtkSMAnimationCueProxy);
 
 vtkCxxSetObjectMacro(vtkSMAnimationCueProxy, AnimatedProxy, vtkSMProxy);
@@ -140,8 +139,13 @@ void vtkSMAnimationCueProxy::SetManipulator(
   this->Manipulator = manipulator;
   if (this->Manipulator)
     {
+    // Listen to the manipulator's ModifiedEvent. The manipilator fires this
+    // event when the manipulator changes, its keyframes change or the values of
+    // those key frames change. We simply propagate that event out so
+    // applications can only listen to vtkSMAnimationCueProxy for modification
+    // of the entire track.
     this->Manipulator->AddObserver(
-      vtkSMAnimationCueManipulatorProxy::StateModifiedEvent,
+      vtkCommand::ModifiedEvent,
       this->Observer);
     this->Manipulator->Register(this);
     }
@@ -215,6 +219,14 @@ void vtkSMAnimationCueProxy::ExecuteEvent(vtkObject* obj, unsigned long event,
       break;
       }
     }
+
+  vtkSMAnimationCueManipulatorProxy* manip =
+    vtkSMAnimationCueManipulatorProxy::SafeDownCast(obj);
+  if (manip && event == vtkCommand::ModifiedEvent)
+    {
+    this->Modified();
+    this->MarkConsumersAsDirty(this);
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -319,6 +331,16 @@ void vtkSMAnimationCueProxy::CloneCopy(vtkSMAnimationCueProxy* src)
   this->MarkAllPropertiesAsModified();
 }
 
+//----------------------------------------------------------------------------
+void vtkSMAnimationCueProxy::MarkConsumersAsDirty(vtkSMProxy* modifiedProxy)
+{
+  this->Superclass::MarkConsumersAsDirty(modifiedProxy);
+  if (this->AnimatedProxy)
+    {
+    this->AnimatedProxy->MarkDirty(modifiedProxy);
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkSMAnimationCueProxy::PrintSelf(ostream& os, vtkIndent indent)
 {
