@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMAnimationSceneProxy.cxx,v $
+  Module:    vtkSMAnimationSceneProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,16 +14,19 @@
 =========================================================================*/
 #include "vtkSMAnimationSceneProxy.h"
 
-#include "vtkPVAnimationScene.h"
 #include "vtkClientServerStream.h"
+#include "vtkCollection.h"
 #include "vtkCommand.h"
+#include "vtkMemberFunctionCommand.h"
 #include "vtkObjectFactory.h"
 #include "vtkProcessModule.h"
+#include "vtkPVAnimationScene.h"
 #include "vtkPVCacheSizeInformation.h"
-#include "vtkPVGenericRenderWindowInteractor.h"
 #include "vtkSmartPointer.h"
-#include "vtkSMRenderViewProxy.h"
-#include "vtkCollection.h"
+#include "vtkSMProperty.h"
+#include "vtkSMPropertyHelper.h"
+#include "vtkSMViewProxy.h"
+#include "vtkSMTimeKeeperProxy.h"
 
 #include <vtksys/SystemTools.hxx>
 #include <vtkstd/vector>
@@ -63,7 +66,8 @@ public:
     VectorOfViews::iterator iter = this->ViewModules.begin();
     for (; iter != this->ViewModules.end(); ++iter)
       {
-      (*iter)->SetCacheTime(cachetime);
+      vtkSMPropertyHelper((*iter), "CacheKey").Set(cachetime);
+      iter->GetPointer()->UpdateProperty("CacheKey");
       }
     }
 
@@ -72,38 +76,10 @@ public:
     VectorOfViews::iterator iter = this->ViewModules.begin();
     for (; iter != this->ViewModules.end(); ++iter)
       {
-      (*iter)->SetUseCache(usecache);
+      vtkSMPropertyHelper((*iter), "UseCache").Set(usecache);
+      iter->GetPointer()->UpdateProperty("UseCache");
       }
     }
-
-  void DisableInteractionAllViews()
-    {
-    VectorOfViews::iterator iter = this->ViewModules.begin();
-    for (; iter != this->ViewModules.end(); ++iter)
-      {
-      vtkSMRenderViewProxy* rm = vtkSMRenderViewProxy::SafeDownCast(
-        iter->GetPointer());
-      if (rm)
-        {
-        rm->GetInteractor()->Disable();
-        }
-      }
-    }
-
-  void EnableInteractionAllViews()
-    {
-    VectorOfViews::iterator iter = this->ViewModules.begin();
-    for (; iter != this->ViewModules.end(); ++iter)
-      {
-      vtkSMRenderViewProxy* rm = vtkSMRenderViewProxy::SafeDownCast(
-        iter->GetPointer());
-      if (rm)
-        {
-        rm->GetInteractor()->Enable();
-        }
-      }
-    }
-
 };
 
 class vtkSMAnimationSceneProxy::vtkPlayerObserver : public vtkCommand
@@ -143,7 +119,6 @@ private:
 };
 
 
-vtkCxxRevisionMacro(vtkSMAnimationSceneProxy, "$Revision: 1.54 $");
 vtkStandardNewMacro(vtkSMAnimationSceneProxy);
 //----------------------------------------------------------------------------
 vtkSMAnimationSceneProxy::vtkSMAnimationSceneProxy()
@@ -156,20 +131,100 @@ vtkSMAnimationSceneProxy::vtkSMAnimationSceneProxy()
   this->PlayerObserver = vtkPlayerObserver::New();
   this->PlayerObserver->SetTarget(this);
   this->InTick = false;
+  this->TimeKeeper = 0;
+  this->LockStartTime = false;
+  this->LockEndTime = false;
+  this->TimeRangeObserver = vtkMakeMemberFunctionCommand(
+    *this, &vtkSMAnimationSceneProxy::TimeKeeperTimeRangeChanged);
+  this->TimestepValuesObserver = vtkMakeMemberFunctionCommand(
+    *this, &vtkSMAnimationSceneProxy::TimeKeeperTimestepsChanged);
 }
 
 //----------------------------------------------------------------------------
 vtkSMAnimationSceneProxy::~vtkSMAnimationSceneProxy()
 {
+  this->SetTimeKeeper(0);
   if (this->AnimationPlayer)
     {
     this->AnimationPlayer->RemoveObserver(this->PlayerObserver);
     }
   this->PlayerObserver->SetTarget(0);
   this->PlayerObserver->Delete();
+  this->TimeRangeObserver->Delete();
+  this->TimeRangeObserver = 0;
+  this->TimestepValuesObserver->Delete();
+  this->TimestepValuesObserver = 0;
   delete this->Internals;
 }
 
+//----------------------------------------------------------------------------
+void vtkSMAnimationSceneProxy::UpdateVTKObjects()
+{
+  this->Superclass::UpdateVTKObjects();
+  this->UpdatePropertyInformation(this->GetProperty("StartTimeInfo"));
+  this->UpdatePropertyInformation(this->GetProperty("EndTimeInfo"));
+}
+
+//----------------------------------------------------------------------------
+void vtkSMAnimationSceneProxy::SetTimeKeeper(vtkSMTimeKeeperProxy* tkp)
+{
+  if (this->TimeKeeper == tkp)
+    {
+    return;
+    }
+
+  if (this->TimeKeeper)
+    {
+    this->TimeKeeper->GetProperty("TimeRange")->RemoveObserver(
+      this->TimeRangeObserver);
+    this->TimeKeeper->GetProperty("TimestepValues")->RemoveObserver(
+      this->TimestepValuesObserver);
+    }
+  vtkSetObjectBodyMacro(TimeKeeper, vtkSMTimeKeeperProxy, tkp);
+  if (this->TimeKeeper)
+    {
+    this->TimeKeeper->GetProperty("TimeRange")->AddObserver(
+      vtkCommand::ModifiedEvent, this->TimeRangeObserver);
+    this->TimeKeeper->GetProperty("TimestepValues")->AddObserver(
+      vtkCommand::ModifiedEvent, this->TimestepValuesObserver);
+
+    this->TimeKeeperTimestepsChanged();
+    this->TimeKeeperTimeRangeChanged();
+    }
+}
+
+//----------------------------------------------------------------------------
+void vtkSMAnimationSceneProxy::TimeKeeperTimestepsChanged()
+{
+  this->AnimationPlayer->GetProperty("TimeSteps")->Copy(
+    this->TimeKeeper->GetProperty("TimestepValues"));
+  this->AnimationPlayer->UpdateVTKObjects();
+}
+
+//----------------------------------------------------------------------------
+void vtkSMAnimationSceneProxy::TimeKeeperTimeRangeChanged()
+{
+  // If time keeper has a non-trivial time range and the times are not locked,
+  // then we change the times to match the time range.
+  vtkPVAnimationScene* scene = vtkPVAnimationScene::SafeDownCast(
+    this->AnimationCue);
+  double min = vtkSMPropertyHelper(this->TimeKeeper,"TimeRange").GetAsDouble(0);
+  double max = vtkSMPropertyHelper(this->TimeKeeper,"TimeRange").GetAsDouble(1);
+  if (max > min)
+    {
+    if (!this->LockStartTime)
+      {
+      scene->SetStartTime(min);
+      }
+    if (!this->LockEndTime)
+      {
+      scene->SetEndTime(max);
+      }
+    }
+  this->UpdatePropertyInformation(this->GetProperty("StartTimeInfo"));
+  this->UpdatePropertyInformation(this->GetProperty("EndTimeInfo"));
+}
+
 //----------------------------------------------------------------------------
 void vtkSMAnimationSceneProxy::AddCueProxy(vtkSMAnimationCueProxy* cueProxy)
 {
@@ -329,7 +384,6 @@ void vtkSMAnimationSceneProxy::EndCueInternal(void* info)
 //-----------------------------------------------------------------------------
 void vtkSMAnimationSceneProxy::OnStartPlay()
 {
-  this->Internals->DisableInteractionAllViews();
   this->Internals->PassUseCache(this->GetCaching()>0);
 }
 
@@ -337,7 +391,6 @@ void vtkSMAnimationSceneProxy::OnStartPlay()
 void vtkSMAnimationSceneProxy::OnEndPlay()
 {
   this->Internals->PassUseCache(false);
-  this->Internals->EnableInteractionAllViews();
 }
 
 //-----------------------------------------------------------------------------
