@@ -36,11 +36,26 @@
 
 vtkStandardNewMacro(vtkSMArrayListDomain);
 
+struct vtkSMArrayListDomainInformationKey
+{
+  vtkStdString Location;
+  vtkStdString Name;
+  int Strategy;
+};
+
 struct vtkSMArrayListDomainInternals
 {
   vtkstd::map<vtkStdString, int> PartialMap;
   vtkstd::vector<int> DataTypes;
   vtkstd::vector<int> FieldAssociation;
+  vtkstd::map<int,int> DomainAssociation;
+  vtkstd::vector<vtkSMArrayListDomainInformationKey> InformationKeys;
+
+  void SetAssociations(int index, int field, int domain)
+    {
+    this->FieldAssociation[index] = field;
+    this->DomainAssociation[index] =  domain == -1 ? field : domain;
+    }
 };
 
 //---------------------------------------------------------------------------
@@ -69,6 +84,17 @@ int vtkSMArrayListDomain::IsArrayPartial(unsigned int idx)
   return this->ALDInternals->PartialMap[name];
 }
 
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::GetDomainAssociation(unsigned int idx )
+{
+if ( this->ALDInternals->DomainAssociation.find(idx) ==
+  this->ALDInternals->DomainAssociation.end() )
+  {
+  return this->GetFieldAssociation(idx);
+  }
+  return this->ALDInternals->DomainAssociation.find(idx)->second;
+}
+
 //---------------------------------------------------------------------------
 int vtkSMArrayListDomain::GetFieldAssociation(unsigned int idx)
 {
@@ -122,9 +148,9 @@ int vtkSMArrayListDomain::RemoveString(const char* string)
 //---------------------------------------------------------------------------
 void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
                                      int outputport,
-                                     vtkPVDataSetAttributesInformation* info, 
+                                     vtkPVDataSetAttributesInformation* info,
                                      vtkSMInputArrayDomain* iad,
-                                     int association)
+                                     int association, int domainAssociation)
 {
   this->DefaultElement = 0;
 
@@ -141,11 +167,14 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
       int nAcceptedTypes=static_cast<int>(this->ALDInternals->DataTypes.size());
       if ( nAcceptedTypes==0 )
         {
-        unsigned int newidx = this->AddString(arrayInfo->GetName());
-        this->ALDInternals->FieldAssociation[newidx] = association;
-        if (arrayInfo == attrInfo)
-          {
-          attrIdx = newidx;
+        if(this->CheckInformationKeys(arrayInfo))
+        {
+          unsigned int newidx = this->AddArray(arrayInfo, association,
+            domainAssociation, iad);
+          if (arrayInfo == attrInfo)
+            {
+            attrIdx = newidx;
+            }
           }
         }
       for (int i=0; i<nAcceptedTypes; ++i)
@@ -153,11 +182,14 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
         int thisDataType=this->ALDInternals->DataTypes[i];
         if (!thisDataType || (arrayInfo->GetDataType() == thisDataType))
           {
-          unsigned int newidx = this->AddString(arrayInfo->GetName());
-          this->ALDInternals->FieldAssociation[newidx] = association;
-          if (arrayInfo == attrInfo)
+          if(this->CheckInformationKeys(arrayInfo))
             {
-            attrIdx = newidx;
+            unsigned int newidx = this->AddArray(arrayInfo, association,
+              domainAssociation, iad);
+            if (arrayInfo == attrInfo)
+              {
+              attrIdx = newidx;
+              }
             }
           }
         }
@@ -171,7 +203,45 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
 }
 
 //---------------------------------------------------------------------------
-void vtkSMArrayListDomain::Update(vtkSMSourceProxy* sp, 
+unsigned int vtkSMArrayListDomain::AddArray(
+  vtkPVArrayInformation* arrayInfo, int association,int domainAssociation,
+  vtkSMInputArrayDomain* iad)
+{
+  if (iad->GetAutomaticPropertyConversion() &&
+    iad->GetNumberOfComponents() == 1 &&
+    arrayInfo->GetNumberOfComponents() > 1)
+    {
+    // add magnitude only for numeric arrays.
+    unsigned int first_index = VTK_UNSIGNED_INT_MAX;
+    if (arrayInfo->GetDataType() != VTK_STRING)
+      {
+      vtkStdString name = this->CreateMangledName(arrayInfo,
+        arrayInfo->GetNumberOfComponents());
+      first_index = this->AddString(name.c_str());
+      this->ALDInternals->SetAssociations(first_index,association,domainAssociation);
+      }
+    for (int cc=0; cc < arrayInfo->GetNumberOfComponents(); cc++)
+      {
+      vtkStdString name = this->CreateMangledName(arrayInfo,cc);
+      unsigned int newidx = this->AddString(name.c_str());
+      if (first_index == VTK_UNSIGNED_INT_MAX)
+        {
+        first_index = newidx;
+        }
+      this->ALDInternals->SetAssociations(newidx,association,domainAssociation);
+      }
+    return first_index;
+    }
+  else
+    {
+    unsigned int newidx = this->AddString(arrayInfo->GetName());
+    this->ALDInternals->SetAssociations(newidx,association,domainAssociation);
+    return  newidx;
+    }
+}
+
+//---------------------------------------------------------------------------
+void vtkSMArrayListDomain::Update(vtkSMSourceProxy* sp,
                                   vtkSMInputArrayDomain* iad,
                                   int outputport)
 {
@@ -218,12 +288,22 @@ void vtkSMArrayListDomain::Update(vtkSMSourceProxy* sp,
   case vtkSMInputArrayDomain::POINT:
     this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad,
       vtkDataObject:: FIELD_ASSOCIATION_POINTS);
+    if(vtkSMInputArrayDomain::GetAutomaticPropertyConversion())
+     {
+     this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad,
+       vtkDataObject::FIELD_ASSOCIATION_CELLS, vtkDataObject::FIELD_ASSOCIATION_POINTS);
+     }
     this->Association = vtkDataObject:: FIELD_ASSOCIATION_POINTS;
     break;
 
   case vtkSMInputArrayDomain::CELL:
     this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad,
       vtkDataObject::FIELD_ASSOCIATION_CELLS);
+    if(vtkSMInputArrayDomain::GetAutomaticPropertyConversion())
+     {
+     this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad,
+       vtkDataObject::FIELD_ASSOCIATION_POINTS, vtkDataObject::FIELD_ASSOCIATION_CELLS);
+     }
     this->Association = vtkDataObject:: FIELD_ASSOCIATION_CELLS;
     break;
 
@@ -291,11 +371,11 @@ void vtkSMArrayListDomain::Update(vtkSMProxyProperty* pp)
   unsigned int numProxs = pp->GetNumberOfUncheckedProxies();
   for (i=0; i<numProxs; i++)
     {
-    vtkSMSourceProxy* sp = 
+    vtkSMSourceProxy* sp =
       vtkSMSourceProxy::SafeDownCast(pp->GetUncheckedProxy(i));
     if (sp)
       {
-      this->Update(pp, sp, 
+      this->Update(pp, sp,
         (ip? ip->GetUncheckedOutputPortForConnection(i) : 0));
       return;
       }
@@ -306,7 +386,7 @@ void vtkSMArrayListDomain::Update(vtkSMProxyProperty* pp)
   numProxs = pp->GetNumberOfProxies();
   for (i=0; i<numProxs; i++)
     {
-    vtkSMSourceProxy* sp = 
+    vtkSMSourceProxy* sp =
       vtkSMSourceProxy::SafeDownCast(pp->GetProxy(i));
     if (sp)
       {
@@ -324,7 +404,7 @@ void vtkSMArrayListDomain::Update(vtkSMProperty*)
   if (this->NoneString)
     {
     this->AddString(this->NoneString);
-    this->ALDInternals->FieldAssociation[0] = 
+    this->ALDInternals->FieldAssociation[0] =
       vtkDataObject::NUMBER_OF_ASSOCIATIONS;
     }
 
@@ -342,7 +422,7 @@ int vtkSMArrayListDomain::ReadXMLAttributes(
 {
   this->Superclass::ReadXMLAttributes(prop, element);
 
-  const char* input_domain_name = 
+  const char* input_domain_name =
     element->GetAttribute("input_domain_name");
   if (input_domain_name)
     {
@@ -353,7 +433,54 @@ int vtkSMArrayListDomain::ReadXMLAttributes(
   const char* none_string = element->GetAttribute("none_string");
   if (none_string)
     {
-      this->SetNoneString(none_string);
+    this->SetNoneString(none_string);
+    }
+
+  const char* key_locations = element->GetAttribute("key_locations");
+  const char* key_names = element->GetAttribute("key_names");
+  const char* key_strategies = element->GetAttribute("key_strategies");
+  if(key_locations == NULL)
+    {
+    // Default value : add a needed information key vtkAbstractArray::GUI_HIDE
+    this->AddInformationKey("vtkAbstractArray", "GUI_HIDE", vtkSMArrayListDomain::REJECT_KEY);
+    }
+  else
+    {
+    vtkstd::stringstream locations(key_locations);
+    vtkstd::stringstream names(key_names);
+    vtkstd::stringstream strategies(key_strategies);
+    vtkstd::string location, name, strategy, last_strategy;
+    int strat;
+    // default value for the strategy
+    last_strategy = "need_key";
+    while(locations >> location)
+      {
+      if(! (names >> name) )
+        {
+        vtkErrorMacro("The number of key names must be equal to the number of key locations");
+        break;
+        }
+      if(! (strategies >> strategy))
+        {
+        strategy = last_strategy;
+        }
+      last_strategy = strategy;
+
+      if(strategy == "need_key" || strategy == "NEED_KEY")
+        {
+        strat = vtkSMArrayListDomain::NEED_KEY;
+        }
+      else if(strategy == "reject_key" || strategy == "REJECT_KEY")
+        {
+        strat = vtkSMArrayListDomain::REJECT_KEY;
+        }
+      else
+        {
+        // maybe the strategy was coded as an integer.
+        strat=atoi(strategy.c_str());
+        }
+      this->AddInformationKey(location.c_str(), name.c_str(), strat);
+      }
     }
 
   // Search for attribute type with matching name.
@@ -466,6 +593,26 @@ int vtkSMArrayListDomain::ReadXMLAttributes(
         {
         this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED___INT64);
         }
+      else if ( thisType=="VTK_DATA_ARRAY" )
+        {
+          this->ALDInternals->DataTypes.push_back(VTK_BIT);
+          this->ALDInternals->DataTypes.push_back(VTK_CHAR);
+          this->ALDInternals->DataTypes.push_back(VTK_SIGNED_CHAR);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED_CHAR);
+          this->ALDInternals->DataTypes.push_back(VTK_SHORT);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED_SHORT);
+          this->ALDInternals->DataTypes.push_back(VTK_INT);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED_INT);
+          this->ALDInternals->DataTypes.push_back(VTK_LONG);
+          this->ALDInternals->DataTypes.push_back(VTK_FLOAT);
+          this->ALDInternals->DataTypes.push_back(VTK_DOUBLE);
+          this->ALDInternals->DataTypes.push_back(VTK_ID_TYPE);
+          this->ALDInternals->DataTypes.push_back(VTK_LONG_LONG);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED_LONG);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED_LONG_LONG);
+          this->ALDInternals->DataTypes.push_back(VTK___INT64);
+          this->ALDInternals->DataTypes.push_back(VTK_UNSIGNED___INT64);
+        }
       else
         {
         int maybeType=atoi(thisType.c_str()); //?
@@ -518,6 +665,98 @@ int vtkSMArrayListDomain::SetDefaultValues(vtkSMProperty* prop)
   return this->Superclass::SetDefaultValues(prop);
 }
 
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::CheckInformationKeys(vtkPVArrayInformation* arrayInfo)
+{
+  for (unsigned int i=0; i< this->GetNumberOfInformationKeys(); i++)
+    {
+    vtkSMArrayListDomainInformationKey& key = this->ALDInternals->InformationKeys[i];
+    int hasInfo = arrayInfo->HasInformationKey(key.Location, key.Name);
+    if(hasInfo && key.Strategy == vtkSMArrayListDomain::REJECT_KEY)
+      {
+      return 0;
+      }
+    if(!hasInfo && key.Strategy == vtkSMArrayListDomain::NEED_KEY)
+      {
+      return 0;
+      }
+    }
+  return 1;
+}
+
+//---------------------------------------------------------------------------
+unsigned int vtkSMArrayListDomain::AddInformationKey(const char* location, const char *name, int strategy)
+{
+  vtkSMArrayListDomainInformationKey key;
+  key.Location = location;
+  key.Name = name;
+  key.Strategy = strategy;
+  this->ALDInternals->InformationKeys.push_back(key);
+  return this->ALDInternals->InformationKeys.size() - 1;
+}
+
+//---------------------------------------------------------------------------
+unsigned int vtkSMArrayListDomain::RemoveInformationKey(const char* location, const char *name)
+{
+  vtkstd::vector<vtkSMArrayListDomainInformationKey>::iterator it
+    = this->ALDInternals->InformationKeys.begin();
+  int index = 0;
+  while(it != this->ALDInternals->InformationKeys.end())
+    {
+    vtkSMArrayListDomainInformationKey& key = *it;
+    if(key.Location == location && key.Name == name)
+      {
+      this->ALDInternals->InformationKeys.erase(it);
+      return index;
+      }
+    it++;
+    index++;
+    }
+  return 0;
+}
+
+//---------------------------------------------------------------------------
+unsigned int vtkSMArrayListDomain::GetNumberOfInformationKeys()
+{
+  return static_cast<unsigned int>(this->ALDInternals->InformationKeys.size());
+}
+
+//---------------------------------------------------------------------------
+void vtkSMArrayListDomain::RemoveAllInformationKeys()
+{
+  this->ALDInternals->InformationKeys.clear();
+}
+
+//---------------------------------------------------------------------------
+const char* vtkSMArrayListDomain::GetInformationKeyLocation(unsigned int index)
+{
+  if(index < this->ALDInternals->InformationKeys.size())
+    {
+    return this->ALDInternals->InformationKeys[index].Location;
+    }
+  return NULL;
+}
+
+//---------------------------------------------------------------------------
+const char* vtkSMArrayListDomain::GetInformationKeyName(unsigned int index)
+{
+  if(index < this->ALDInternals->InformationKeys.size())
+    {
+    return this->ALDInternals->InformationKeys[index].Name;
+    }
+  return NULL;
+}
+
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::GetInformationKeyStrategy(unsigned int index)
+{
+  if(index < this->ALDInternals->InformationKeys.size())
+    {
+    return this->ALDInternals->InformationKeys[index].Strategy;
+    }
+  return -1;
+}
+
 //---------------------------------------------------------------------------
 void vtkSMArrayListDomain::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -529,4 +768,80 @@ void vtkSMArrayListDomain::PrintSelf(ostream& os, vtkIndent indent)
     {
     os << indent << "DataType: " << this->ALDInternals->DataTypes[i] << endl;
     }
+
+  for(unsigned int i=0; i<this->ALDInternals->InformationKeys.size(); i++)
+    {
+    vtkSMArrayListDomainInformationKey& key = this->ALDInternals->InformationKeys[i];
+    os << key.Location << "::" << key.Name << " ";
+    if(key.Strategy == vtkSMArrayListDomain::NEED_KEY)
+      {
+      os << "NEED_KEY";
+      }
+    else if(key.Strategy == vtkSMArrayListDomain::REJECT_KEY)
+      {
+      os << "REJECT_KEY";
+      }
+    else
+      {
+      os << "UNKNOWN KEY STRATEGY : " << key.Strategy;
+      }
+    os << endl;
+    }
+}
+
+
+//---------------------------------------------------------------------------
+vtkStdString vtkSMArrayListDomain::CreateMangledName(
+  vtkPVArrayInformation *arrayInfo, int component)
+{
+  vtksys_ios::ostringstream stream;
+  if ( component != arrayInfo->GetNumberOfComponents() )
+    {
+    stream << arrayInfo->GetName() << "_" <<
+      arrayInfo->GetComponentName(component);
+    }
+  else
+    {
+    stream << arrayInfo->GetName() << "_Magnitude";
+    }
+  return stream.str();
+}
+
+//---------------------------------------------------------------------------
+vtkStdString vtkSMArrayListDomain::ArrayNameFromMangledName(
+  const char* name)
+{
+  vtkStdString extractedName = name;
+  size_t pos = extractedName.rfind("_");
+  if (pos == vtkStdString::npos)
+    {
+    return extractedName;
+    }
+  return extractedName.substr(0,pos);
+}
+
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::ComponentIndexFromMangledName(
+  vtkPVArrayInformation *info, const char* name)
+{
+  vtkStdString extractedName = name;
+  size_t pos = extractedName.rfind("_");
+  if (pos == vtkStdString::npos)
+    {
+    return -1;
+    }
+  vtkStdString compName = extractedName.substr(pos+1,extractedName.length()-pos);
+  int numComps = info->GetNumberOfComponents();
+  if ( compName == "Magnitude" )
+    {
+    return numComps;
+    }
+  for ( int i=0; i < numComps; ++i)
+    {
+    if ( compName == info->GetComponentName(i) )
+      {
+      return i;
+      }
+    }
+  return -1;
 }
