@@ -15,6 +15,8 @@
 #include "vtkSMComparativeViewProxy.h"
 
 #include "vtkCollection.h"
+#include "vtkClientServerStream.h"
+#include "vtkProcessModule.h"
 #include "vtkMemberFunctionCommand.h"
 #include "vtkObjectFactory.h"
 #include "vtkSmartPointer.h"
@@ -33,31 +35,129 @@
 #include <vtkstd/string>
 #include <vtksys/ios/sstream>
 
+#include <assert.h>
+
+//----------------------------------------------------------------------------
+namespace
+{
+  static void vtkCopyClone(vtkSMProxy* source, vtkSMProxy* clone,
+    vtkstd::set<vtkstd::string> *exceptions=0)
+    {
+    vtkSmartPointer<vtkSMPropertyIterator> iterSource;
+    vtkSmartPointer<vtkSMPropertyIterator> iterDest;
+
+    iterSource.TakeReference(source->NewPropertyIterator());
+    iterDest.TakeReference(clone->NewPropertyIterator());
+
+    // Since source/clone are exact copies, the following is safe.
+    for (; !iterSource->IsAtEnd() && !iterDest->IsAtEnd();
+      iterSource->Next(), iterDest->Next())
+      {
+      // Skip the property if it is in the exceptions list.
+      if (exceptions &&
+        exceptions->find(iterSource->GetKey()) != exceptions->end())
+        {
+        continue;
+        }
+      vtkSMProperty* destProp = iterDest->GetProperty();
+
+      // Skip the property if it is information only or is internal.
+      if (destProp->GetInformationOnly())
+        {
+        continue;
+        }
+
+      // Copy the property from source to dest
+      destProp->Copy(iterSource->GetProperty());
+      }
+    }
+
+  static void vtkAddRepresentation(vtkSMProxy* view, vtkSMProxy* repr)
+    {
+    // We are always using cache in this view.
+    vtkSMPropertyHelper(repr, "ForceUseCache", true).Set(1);
+    vtkSMPropertyHelper(repr, "ForcedCacheKey", true).Set(1);
+    repr->UpdateVTKObjects();
+
+    vtkClientServerStream stream;
+    stream << vtkClientServerStream::Invoke
+      << view->GetID() << "AddRepresentation" << repr->GetID()
+      << vtkClientServerStream::End;
+    vtkProcessModule::GetProcessModule()->SendStream(
+      view->GetConnectionID(),
+      (view->GetServers() & repr->GetServers()), stream);
+    }
+
+  static void vtkRemoveRepresentation(vtkSMProxy* view, vtkSMProxy* repr)
+    {
+    vtkClientServerStream stream;
+    stream << vtkClientServerStream::Invoke
+      << view->GetID() << "RemoveRepresentation" << repr->GetID()
+      << vtkClientServerStream::End;
+    vtkProcessModule::GetProcessModule()->SendStream(
+      view->GetConnectionID(),
+      (view->GetServers() & repr->GetServers()), stream);
+    }
+}
+
+//----------------------------------------------------------------------------
 class vtkSMComparativeViewProxy::vtkInternal
 {
 public:
+  struct RepresentationCloneItem
+    {
+    // The clone representation proxy.
+    vtkSmartPointer<vtkSMProxy> CloneRepresentation;
+
+    // The sub-view in which this clone exists.
+    vtkSmartPointer<vtkSMViewProxy> ViewProxy;
+
+    RepresentationCloneItem() {}
+    RepresentationCloneItem(
+      vtkSMViewProxy* view, vtkSMProxy* repr)
+      : CloneRepresentation(repr), ViewProxy(view) {}
+    };
+
   struct RepresentationData
     {
-    typedef vtkstd::map<vtkSMViewProxy*, vtkSmartPointer<vtkSMRepresentationProxy> > MapOfViewToRepr;
-    MapOfViewToRepr Clones; // The clone representations created for the representations (with key  
-                            // being the view in which that representation clone
-                            // exists.
+    typedef vtkstd::vector<RepresentationCloneItem> VectorOfClones;
+    VectorOfClones Clones;
     vtkSmartPointer<vtkSMProxyLink> Link;
 
     void MarkRepresentationsModified()
       {
-      MapOfViewToRepr::iterator iter;
+      VectorOfClones::iterator iter;
       for (iter = this->Clones.begin(); iter != this->Clones.end(); ++iter)
         {
-        iter->second.GetPointer()->MarkDirty(NULL);
+        vtkSMProxy * repr = iter->CloneRepresentation;
+        vtkSMPropertyHelper helper(repr, "ForceUseCache", true);
+        helper.Set(0);
+        repr->UpdateProperty("ForceUseCache");
+        repr->MarkDirty(NULL);
+        helper.Set(1);
+        repr->UpdateProperty("ForceUseCache");
         }
       }
+
+    // Returns the representation clone in the given view.
+    VectorOfClones::iterator FindRepresentationClone(vtkSMViewProxy* view)
+      {
+      VectorOfClones::iterator iter;
+      for (iter = this->Clones.begin(); iter != this->Clones.end(); ++iter)
+        {
+        if (iter->ViewProxy == view)
+          {
+          return iter;
+          }
+        }
+      return this->Clones.end();
+      }
     };
 
   typedef vtkstd::vector<vtkSmartPointer<vtkSMViewProxy> > VectorOfViews;
   VectorOfViews Views;
 
-  typedef vtkstd::map<vtkSMRepresentationProxy*, RepresentationData> MapOfReprClones;
+  typedef vtkstd::map<vtkSMProxy*, RepresentationData> MapOfReprClones;
   MapOfReprClones RepresentationClones;
 
   typedef vtkstd::vector<vtkSmartPointer<vtkSMComparativeAnimationCueProxy> >
@@ -72,7 +172,47 @@ public:
     this->ViewLink = vtkSmartPointer<vtkSMProxyLink>::New();
     this->ViewCameraLink = vtkSmartPointer<vtkSMCameraLink>::New();
     this->ViewCameraLink->SynchronizeInteractiveRendersOff();
-   }
+    }
+
+  // Creates a new representation clone and adds it in the given view.
+  // Arguments:
+  // @repr -- representation to clone
+  // @view -- the view to which the new clone should be added.
+  vtkSMProxy* AddRepresentationClone(
+    vtkSMProxy* repr, vtkSMViewProxy* view)
+    {
+    MapOfReprClones::iterator iter = this->RepresentationClones.find(repr);
+    if (iter == this->RepresentationClones.end())
+      {
+      vtkGenericWarningMacro("This representation cannot be cloned!!!");
+      return NULL;
+      }
+
+    vtkInternal::RepresentationData& data = iter->second;
+
+    vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
+
+    // Create a new representation
+    vtkSMProxy* newRepr =
+      pxm->NewProxy(repr->GetXMLGroup(), repr->GetXMLName());
+
+    // Made the new representation a clone
+    vtkCopyClone(repr, newRepr);
+    newRepr->UpdateVTKObjects();
+    data.Link->AddLinkedProxy(newRepr, vtkSMLink::OUTPUT);
+
+    // Add the cloned representation to the view
+    vtkAddRepresentation(view, newRepr);
+
+    // Add the cloned representation to the RepresentationData struct
+    // The clone is added to a map where its view is the key.
+    data.Clones.push_back(
+      vtkInternal::RepresentationCloneItem(view, newRepr));
+
+    // Clean up this reference
+    newRepr->Delete();
+    return newRepr;
+    }
 
   unsigned int ActiveIndexX;
   unsigned int ActiveIndexY;
@@ -80,7 +220,6 @@ public:
 };
 
 //----------------------------------------------------------------------------
-
 vtkStandardNewMacro(vtkSMComparativeViewProxy);
 
 //----------------------------------------------------------------------------
@@ -91,11 +230,15 @@ vtkSMComparativeViewProxy::vtkSMComparativeViewProxy()
   this->Dimensions[1] = 0;
   this->ViewSize[0] = 400;
   this->ViewSize[1] = 400;
+  this->ViewPosition[0] = 0;
+  this->ViewPosition[1] = 0;
+  this->ViewTime = 0.0;
+  this->OverlayAllComparisons = false;
   this->Spacing[0] = this->Spacing[1] = 1;
 
   this->Outdated = true;
 
-  vtkMemberFunctionCommand<vtkSMComparativeViewProxy>* fsO = 
+  vtkMemberFunctionCommand<vtkSMComparativeViewProxy>* fsO =
     vtkMemberFunctionCommand<vtkSMComparativeViewProxy>::New();
   fsO->SetCallback(*this, &vtkSMComparativeViewProxy::MarkOutdated);
   this->MarkOutdatedObserver = fsO;
@@ -134,14 +277,24 @@ void vtkSMComparativeViewProxy::RemoveCue(vtkSMComparativeAnimationCueProxy* cue
 }
 
 //----------------------------------------------------------------------------
-bool vtkSMComparativeViewProxy::BeginCreateVTKObjects()
+void vtkSMComparativeViewProxy::CreateVTKObjects()
 {
+  if (this->ObjectsCreated)
+    {
+    return;
+    }
+  this->Superclass::CreateVTKObjects();
+  if (!this->ObjectsCreated)
+    {
+    return;
+    }
+
   vtkSMViewProxy* rootView = vtkSMViewProxy::SafeDownCast(
     this->GetSubProxy("RootView"));
   if (!rootView)
     {
     vtkErrorMacro("Subproxy \"Root\" must be defined in the xml configuration.");
-    return false;
+    return;
     }
 
   this->Dimensions[0] = 1;
@@ -161,6 +314,8 @@ bool vtkSMComparativeViewProxy::BeginCreateVTKObjects()
   // layout.
   this->Internal->ViewLink->AddException("ViewSize");
   this->Internal->ViewLink->AddException("ViewTime");
+  this->Internal->ViewLink->AddException("CacheKey");
+  this->Internal->ViewLink->AddException("UseCache");
   this->Internal->ViewLink->AddException("ViewPosition");
 
   this->Internal->ViewLink->AddException("CameraPositionInfo");
@@ -173,8 +328,20 @@ bool vtkSMComparativeViewProxy::BeginCreateVTKObjects()
   this->Internal->ViewLink->AddException("CameraClippingRange");
   this->Internal->ViewLink->AddException("CameraViewAngleInfo");
   this->Internal->ViewLink->AddException("CameraViewAngle");
+}
 
-  return this->Superclass::BeginCreateVTKObjects();
+//----------------------------------------------------------------------------
+void vtkSMComparativeViewProxy::SetOverlayAllComparisons(bool overlay)
+{
+  if (this->OverlayAllComparisons == overlay)
+    {
+    return;
+    }
+
+  this->OverlayAllComparisons = overlay;
+  this->Modified();
+
+  this->Build(this->Dimensions[0], this->Dimensions[1]);
 }
 
 //----------------------------------------------------------------------------
@@ -189,9 +356,11 @@ void vtkSMComparativeViewProxy::Build(int dx, int dy)
     return;
     }
 
-  size_t numViews = dx * dy;
+  size_t numViews = this->OverlayAllComparisons? 1 : dx * dy;
   size_t cc;
 
+  assert(numViews >= 1);
+
   // Remove extra view modules.
   for (cc=this->Internal->Views.size()-1; cc >= numViews; cc--)
     {
@@ -209,6 +378,54 @@ void vtkSMComparativeViewProxy::Build(int dx, int dy)
   this->Dimensions[0] = dx;
   this->Dimensions[1] = dy;
 
+  if (this->OverlayAllComparisons)
+    {
+    // ensure that there are enough representation clones in the root view to
+    // match the dimensions.
+
+    vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
+    vtkSMViewProxy* root_view = this->GetRootView();
+    size_t numReprs = dx * dy;
+    vtkInternal::MapOfReprClones::iterator reprIter;
+    for (reprIter = this->Internal->RepresentationClones.begin();
+      reprIter != this->Internal->RepresentationClones.end(); ++reprIter)
+      {
+      vtkSMProxy* repr = reprIter->first;
+      vtkInternal::RepresentationData& data = reprIter->second;
+
+      // remove old root-clones if extra.
+      if (data.Clones.size() > numReprs)
+        {
+        for (cc = data.Clones.size()-1; cc >= numReprs; cc--)
+          {
+          vtkSMProxy* root_clone =
+            data.Clones[cc].CloneRepresentation;
+          vtkRemoveRepresentation(root_view, root_clone);
+          data.Link->RemoveLinkedProxy(root_clone);
+          }
+        data.Clones.resize(numReprs);
+        }
+      else
+        {
+        // add new root-clones if needed.
+        for (cc = data.Clones.size(); cc < numReprs-1; cc++)
+          {
+          vtkSMProxy* newRepr =
+            pxm->NewProxy(repr->GetXMLGroup(), repr->GetXMLName());
+          vtkCopyClone(repr, newRepr); // create a clone
+          newRepr->UpdateVTKObjects(); // create objects
+          data.Link->AddLinkedProxy(newRepr, vtkSMLink::OUTPUT); // link properties
+          vtkAddRepresentation(root_view,newRepr);  // add representation to view
+
+          // Now update data structure to include this view/repr clone.
+          data.Clones.push_back(
+            vtkInternal::RepresentationCloneItem(root_view, newRepr));
+          newRepr->Delete();
+          }
+        }
+      }
+    }
+
   this->UpdateViewLayout();
 
   // Whenever the layout changes we'll fire the ConfigureEvent.
@@ -218,16 +435,17 @@ void vtkSMComparativeViewProxy::Build(int dx, int dy)
 //----------------------------------------------------------------------------
 void vtkSMComparativeViewProxy::UpdateViewLayout()
 {
+  int dx = this->OverlayAllComparisons? 1 : this->Dimensions[0];
+  int dy = this->OverlayAllComparisons? 1 : this->Dimensions[1];
+  int width =
+    (this->ViewSize[0] - (dx-1)*this->Spacing[0])/dx;
+  int height =
+    (this->ViewSize[1] - (dy-1)*this->Spacing[1])/dy;
 
-  int width = 
-    (this->ViewSize[0] - (this->Dimensions[0]-1)*this->Spacing[0])/this->Dimensions[0];
-  int height = 
-    (this->ViewSize[1] - (this->Dimensions[1]-1)*this->Spacing[1])/this->Dimensions[1];
-
-  int view_index = 0;
-  for (int y=0; y < this->Dimensions[1]; ++y)
+  size_t view_index = 0;
+  for (int y=0; y < dy; ++y)
     {
-    for (int x=0; x < this->Dimensions[0]; ++x, view_index++)
+    for (int x=0; x < dx; ++x, ++view_index)
       {
       vtkSMViewProxy* view = this->Internal->Views[view_index];
       int view_pos[2];
@@ -238,9 +456,6 @@ void vtkSMComparativeViewProxy::UpdateViewLayout()
       // Not all view classes have a ViewSize property
       vtkSMPropertyHelper(view, "ViewSize", true).Set(0, width);
       vtkSMPropertyHelper(view, "ViewSize", true).Set(1, height);
-
-      vtkSMPropertyHelper(view, "GUISize").Set(this->GUISize, 2);
-
       view->UpdateVTKObjects();
       }
     }
@@ -258,41 +473,6 @@ vtkSMViewProxy* vtkSMComparativeViewProxy::GetRootView()
     return 0;
     }
 }
-
-//----------------------------------------------------------------------------
-static void vtkCopyClone(vtkSMProxy* source, vtkSMProxy* clone,
-  vtkstd::set<vtkstd::string> *exceptions=0)
-{
-  vtkSmartPointer<vtkSMPropertyIterator> iterSource;
-  vtkSmartPointer<vtkSMPropertyIterator> iterDest;
-
-  iterSource.TakeReference(source->NewPropertyIterator());
-  iterDest.TakeReference(clone->NewPropertyIterator());
-
-  // Since source/clone are exact copies, the following is safe.
-  for (; !iterSource->IsAtEnd() && !iterDest->IsAtEnd();
-    iterSource->Next(), iterDest->Next())
-    {
-
-    // Skip the property if it is in the exceptions list.
-    if (exceptions && 
-      exceptions->find(iterSource->GetKey()) != exceptions->end())
-      {
-      continue;
-      }
-    vtkSMProperty* destProp = iterDest->GetProperty();
-
-    // Skip the property if it is information only or is internal.
-    if (destProp->GetInformationOnly() || destProp->GetIsInternal())
-      {
-      continue;
-      }
-
-    // Copy the property from source to dest
-    destProp->Copy(iterSource->GetProperty());
-    }
-}
-
 //----------------------------------------------------------------------------
 void vtkSMComparativeViewProxy::AddNewView()
 {
@@ -316,6 +496,8 @@ void vtkSMComparativeViewProxy::AddNewView()
   vtkstd::set<vtkstd::string> exceptions;
   exceptions.insert("Representations");
   exceptions.insert("ViewSize");
+  exceptions.insert("UseCache");
+  exceptions.insert("CacheKey");
   exceptions.insert("ViewPosition");
   vtkCopyClone(rootView, newView, &exceptions);
 
@@ -330,19 +512,12 @@ void vtkSMComparativeViewProxy::AddNewView()
   for (reprIter = this->Internal->RepresentationClones.begin();
     reprIter != this->Internal->RepresentationClones.end(); ++reprIter)
     {
-    vtkSMRepresentationProxy* repr = reprIter->first;
-    vtkInternal::RepresentationData& data = reprIter->second;
+    vtkSMProxy* repr = reprIter->first;
+    vtkSMProxy* clone =
+      this->Internal->AddRepresentationClone(repr, newView);
 
-    vtkSMRepresentationProxy* newRepr = vtkSMRepresentationProxy::SafeDownCast(
-      pxm->NewProxy(repr->GetXMLGroup(), repr->GetXMLName()));
-    vtkCopyClone(repr, newRepr); // create a clone
-    newRepr->UpdateVTKObjects(); // create objects
-    data.Link->AddLinkedProxy(newRepr, vtkSMLink::OUTPUT); // link properties
-    newView->AddRepresentation(newRepr);  // add representation to view
-
-    // Now update data structure to include this view/repr clone.
-    data.Clones[newView] = newRepr;
-    newRepr->Delete();
+    assert(clone != NULL);
+    static_cast<void>(clone); // unused warning in release mode.
     }
 }
 
@@ -361,14 +536,13 @@ void vtkSMComparativeViewProxy::RemoveView(vtkSMViewProxy* view)
     reprIter != this->Internal->RepresentationClones.end(); ++reprIter)
     {
     vtkInternal::RepresentationData& data = reprIter->second;
-    vtkInternal::RepresentationData::MapOfViewToRepr::iterator cloneIter
-      = data.Clones.find(view);
+    vtkInternal::RepresentationData::VectorOfClones::iterator cloneIter =
+      data.FindRepresentationClone(view);
     if (cloneIter != data.Clones.end())
       {
-      vtkSMRepresentationProxy* clone = cloneIter->second.GetPointer();
-      view->RemoveRepresentation(clone);
+      vtkSMProxy* clone = cloneIter->CloneRepresentation;
+      vtkRemoveRepresentation(view, clone);
       data.Link->RemoveLinkedProxy(clone);
-
       data.Clones.erase(cloneIter);
       }
     }
@@ -378,7 +552,7 @@ void vtkSMComparativeViewProxy::RemoveView(vtkSMViewProxy* view)
   this->Internal->ViewCameraLink->RemoveLinkedProxy(view);
 
   vtkInternal::VectorOfViews::iterator iter;
-  for (iter = this->Internal->Views.begin(); 
+  for (iter = this->Internal->Views.begin();
        iter != this->Internal->Views.end(); ++iter)
     {
     if (iter->GetPointer() == view)
@@ -390,7 +564,7 @@ void vtkSMComparativeViewProxy::RemoveView(vtkSMViewProxy* view)
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::AddRepresentation(vtkSMRepresentationProxy* repr)
+void vtkSMComparativeViewProxy::AddRepresentation(vtkSMProxy* repr)
 {
   if (!repr)
     {
@@ -401,7 +575,7 @@ void vtkSMComparativeViewProxy::AddRepresentation(vtkSMRepresentationProxy* repr
 
   // Add representation to the root view
   vtkSMViewProxy* rootView = this->GetRootView();
-  rootView->AddRepresentation(repr);
+  vtkAddRepresentation(rootView, repr);
 
   // Create clones of representation and add them to all other views.
   // We will save information about the clones we create
@@ -414,52 +588,48 @@ void vtkSMComparativeViewProxy::AddRepresentation(vtkSMRepresentationProxy* repr
   vtkSMProxyLink* reprLink = vtkSMProxyLink::New();
   data.Link.TakeReference(reprLink);
   reprLink->AddLinkedProxy(repr, vtkSMLink::INPUT);
-  reprLink->AddException("UpdateTime");
-
-  // Need the proxy manager to create new representations
-  vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
-
-
-  // For each view
-  vtkInternal::VectorOfViews::iterator iter = this->Internal->Views.begin();
-  iter++; // skip root view.
-  for (; iter != this->Internal->Views.end(); ++iter)
-    {
-
-    // Create a new representation
-    vtkSMRepresentationProxy* newRepr = vtkSMRepresentationProxy::SafeDownCast(
-      pxm->NewProxy(repr->GetXMLGroup(), repr->GetXMLName()));
-
-    // Made the new representation a clone
-    vtkCopyClone(repr, newRepr);
-    newRepr->UpdateVTKObjects();
-    reprLink->AddLinkedProxy(newRepr, vtkSMLink::OUTPUT);
-
-    // Add the cloned representation to this view
-    iter->GetPointer()->AddRepresentation(newRepr);
-    
-    // Add the cloned representation to the RepresentationData struct
-    // The clone is added to a map where its view is the key.
-    data.Clones[iter->GetPointer()] = newRepr;
-
-    // Clean up this reference
-    newRepr->Delete();
-    }
+  reprLink->AddException("ForceUseCache");
+  reprLink->AddException("ForcedCacheKey");
 
   // Add the RepresentationData struct to a map
   // with the original representation as the key
   this->Internal->RepresentationClones[repr] = data;
 
+  // Now, for all existing sub-views, create representation clones.
+  vtkInternal::VectorOfViews::iterator iter = this->Internal->Views.begin();
+  iter++; // skip root view.
+  for (; iter != this->Internal->Views.end(); ++iter)
+    {
+    // Create a new representation
+    vtkSMProxy* newRepr =
+      this->Internal->AddRepresentationClone(
+        repr, iter->GetPointer());
+    (void)newRepr;
+    assert(newRepr != NULL);
+    }
+
+  if (this->OverlayAllComparisons)
+    {
+    size_t numReprs = this->Dimensions[0] * this->Dimensions[1];
+    for (size_t cc=1; cc < numReprs; cc++)
+      {
+      // Create a new representation
+      vtkSMProxy* newRepr =
+        this->Internal->AddRepresentationClone(repr, rootView);
+      (void)newRepr;
+      assert(newRepr);
+      }
+    }
+
   // Signal that representations have changed
   this->InvokeEvent(vtkCommand::UserEvent);
 
-
   // Override superclass' AddRepresentation since  repr has already been added
   // to the rootView.
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::RemoveRepresentation(vtkSMRepresentationProxy* repr)
+void vtkSMComparativeViewProxy::RemoveRepresentation(vtkSMProxy* repr)
 {
   vtkInternal::MapOfReprClones::iterator reprDataIter
     = this->Internal->RepresentationClones.find(repr);
@@ -474,14 +644,14 @@ void vtkSMComparativeViewProxy::RemoveRepresentation(vtkSMRepresentationProxy* r
   vtkInternal::RepresentationData& data = reprDataIter->second;
 
   // Remove all clones of this representation.
-  vtkInternal::RepresentationData::MapOfViewToRepr::iterator viewReprIter;
-  for (viewReprIter = data.Clones.begin(); viewReprIter != data.Clones.end(); ++viewReprIter)
+  vtkInternal::RepresentationData::VectorOfClones::iterator cloneIter;
+  for (cloneIter = data.Clones.begin(); cloneIter != data.Clones.end(); ++cloneIter)
     {
-    vtkSMViewProxy* view = viewReprIter->first;
-    vtkSMRepresentationProxy* clone = viewReprIter->second.GetPointer();
+    vtkSMViewProxy* view = cloneIter->ViewProxy;
+    vtkSMProxy* clone = cloneIter->CloneRepresentation;
     if (view && clone)
       {
-      view->RemoveRepresentation(clone);
+      vtkRemoveRepresentation(view, clone);
       // No need to clean the clone from the proxy link since the link object
       // will be destroyed anyways.
       }
@@ -492,7 +662,7 @@ void vtkSMComparativeViewProxy::RemoveRepresentation(vtkSMRepresentationProxy* r
 
   // Remove repr from RootView.
   vtkSMViewProxy* rootView = this->GetRootView();
-  rootView->RemoveRepresentation(repr);
+  vtkRemoveRepresentation(rootView, repr);
 
   // Signal that representations have changed
   this->InvokeEvent(vtkCommand::UserEvent);
@@ -504,11 +674,11 @@ void vtkSMComparativeViewProxy::RemoveRepresentation(vtkSMRepresentationProxy* r
 //----------------------------------------------------------------------------
 void vtkSMComparativeViewProxy::RemoveAllRepresentations()
 {
-  vtkInternal::MapOfReprClones::iterator iter = 
+  vtkInternal::MapOfReprClones::iterator iter =
     this->Internal->RepresentationClones.begin();
   while (iter != this->Internal->RepresentationClones.end())
     {
-    vtkSMRepresentationProxy* repr = iter->first;
+    vtkSMProxy* repr = iter->first;
     this->RemoveRepresentation(repr);
     iter = this->Internal->RepresentationClones.begin();
     }
@@ -517,42 +687,44 @@ void vtkSMComparativeViewProxy::RemoveAllRepresentations()
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::MarkDirty(vtkSMProxy* modifiedProxy) 
+void vtkSMComparativeViewProxy::MarkDirty(vtkSMProxy* modifiedProxy)
 {
-  // The representation that gets added to this view is a consumer of it's
-  // input. While this view is a consumer of the representation. So, when the
-  // input source is modified, that call eventually leads to
-  // vtkSMComparativeViewProxy::MarkDirty(). When that happens, we need to
-  // ensure that we regenerate the comparison, so we call this->MarkOutdated().
+  if (vtkSMViewProxy::SafeDownCast(modifiedProxy) == NULL)
+    {
+    cout << "vtkSMComparativeViewProxy::MarkDirty == " << modifiedProxy << endl;
+    // The representation that gets added to this view is a consumer of it's
+    // input. While this view is a consumer of the representation. So, when the
+    // input source is modified, that call eventually leads to
+    // vtkSMComparativeViewProxy::MarkDirty(). When that happens, we need to
+    // ensure that we regenerate the comparison, so we call this->MarkOutdated().
 
-  // TODO: We can be even smarter. We may want to try to consider only those
-  // representations that are actually involved in the parameter comparison to
-  // mark this view outdated. This will save on the regeneration of cache when
-  // not needed.
+    // TODO: We can be even smarter. We may want to try to consider only those
+    // representations that are actually involved in the parameter comparison to
+    // mark this view outdated. This will save on the regeneration of cache when
+    // not needed.
 
-  // TODO: Another optimization: we can enable caching only for those
-  // representations that are invovled in parameter comparison, others we don't
-  // even need to cache.
+    // TODO: Another optimization: we can enable caching only for those
+    // representations that are invovled in parameter comparison, others we don't
+    // even need to cache.
 
-  // TODO: Need to update data ranges by collecting ranges from all views.
+    // TODO: Need to update data ranges by collecting ranges from all views.
+    this->MarkOutdated();
+    }
   this->Superclass::MarkDirty(modifiedProxy);
-  this->MarkOutdated();
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::EndStillRender()
+void vtkSMComparativeViewProxy::PostRender(bool interactive)
 {
-  // The StillRender will propagate through the ViewCameraLink to all the other
-  // views.
-  this->GetRootView()->StillRender();
-}
-
-//----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::EndInteractiveRender()
-{
-  // The InteractiveRender will propagate through the ViewCameraLink to all the 
-  // other views.
-  this->GetRootView()->InteractiveRender();
+  this->Superclass::PostRender(interactive);
+  if (interactive)
+    {
+    this->GetRootView()->InteractiveRender();
+    }
+  else
+    {
+    this->GetRootView()->StillRender();
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -563,7 +735,7 @@ vtkSMRepresentationProxy* vtkSMComparativeViewProxy::CreateDefaultRepresentation
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::UpdateAllRepresentations()
+void vtkSMComparativeViewProxy::Update()
 {
   if (!this->Outdated)
     {
@@ -589,24 +761,25 @@ void vtkSMComparativeViewProxy::UpdateAllRepresentations()
       }
     }
 
-  int view_index=0;
+  int index = 0;
   for (int y=0; y < this->Dimensions[1]; y++)
     {
     for (int x=0; x < this->Dimensions[0]; x++)
       {
+      int view_index = this->OverlayAllComparisons? 0 : index;
       vtkSMViewProxy* view = this->Internal->Views[view_index];
-      view_index++;
 
       if (timeCue)
         {
         double value = timeCue->GetValue(
           x, y, this->Dimensions[0], this->Dimensions[1]);
-        view->SetViewUpdateTime(value);
+        vtkSMPropertyHelper(view,"ViewTime").Set(value);
         }
       else
         {
-        view->SetViewUpdateTime(this->GetViewUpdateTime());
+        vtkSMPropertyHelper(view,"ViewTime").Set(this->ViewTime);
         }
+      view->UpdateVTKObjects();
 
       for (vtkInternal::VectorOfCues::iterator iter =
         this->Internal->Cues.begin();
@@ -620,28 +793,44 @@ void vtkSMComparativeViewProxy::UpdateAllRepresentations()
           x, y, this->Dimensions[0], this->Dimensions[1]);
         }
 
-      view->SetCacheTime(0);
-
-      // Make the view cache the current setup. 
-      // We do interactive render so that both the full-res as well as low-res cache
-      // is updated.
-      view->UpdateAllRepresentations();
+      // Make the view cache the current setup.
+      this->UpdateAllRepresentations(x, y);
+      index++;
       }
     }
 
   this->Outdated = false;
+  this->NeedsUpdate = false;
+}
+
+//----------------------------------------------------------------------------
+void vtkSMComparativeViewProxy::UpdateAllRepresentations(int x, int y)
+{
+  vtkSMViewProxy* view = this->OverlayAllComparisons?
+    this->Internal->Views[0] :
+    this->Internal->Views[y*this->Dimensions[0] + x];
+
+  vtkCollection* collection = vtkCollection::New();
+  this->GetRepresentations(x, y, collection);
+  collection->InitTraversal();
+  while (vtkSMRepresentationProxy* repr =
+    vtkSMRepresentationProxy::SafeDownCast(
+      collection->GetNextItemAsObject()))
+    {
+    if (vtkSMPropertyHelper(repr, "Visibility", true).GetAsInt() == 1)
+      {
+      repr->UpdatePipeline(
+        vtkSMPropertyHelper(view, "ViewTime").GetAsDouble());
+      }
+    }
+  view->Update();
+
+  collection->Delete();
 }
 
 //----------------------------------------------------------------------------
 void vtkSMComparativeViewProxy::ClearDataCaches()
 {
-  vtkInternal::VectorOfViews::iterator viter;
-  for (viter = this->Internal->Views.begin(); 
-    viter != this->Internal->Views.end(); ++viter)
-    {
-    viter->GetPointer()->SetUseCache(false);
-    }
-
   // Mark all representations modified. This clears their caches. It's essential
   // that SetUseCache(false) is called before we do this, otherwise the caches
   // are not cleared.
@@ -651,14 +840,20 @@ void vtkSMComparativeViewProxy::ClearDataCaches()
     repcloneiter != this->Internal->RepresentationClones.end();
     ++repcloneiter)
     {
-    repcloneiter->first->MarkDirty(NULL);
-    repcloneiter->second.MarkRepresentationsModified();
-    }
-
-  for (viter = this->Internal->Views.begin(); 
-    viter != this->Internal->Views.end(); ++viter)
-    {
-    viter->GetPointer()->SetUseCache(true);
+    vtkSMRepresentationProxy* repr = vtkSMRepresentationProxy::SafeDownCast(
+      repcloneiter->first);
+    if (repr)
+      {
+      vtkSMPropertyHelper helper(repr, "ForceUseCache", true);
+      helper.Set(0);
+      repr->UpdateProperty("ForceUseCache");
+      // HACK.
+      repr->ClearMarkedModified();
+      repr->MarkDirty(NULL);
+      repcloneiter->second.MarkRepresentationsModified();
+      helper.Set(1);
+      repr->UpdateProperty("ForceUseCache");
+      }
     }
 }
 
@@ -671,7 +866,7 @@ void vtkSMComparativeViewProxy::GetViews(vtkCollection* collection)
     }
 
   vtkInternal::VectorOfViews::iterator iter;
-  for (iter = this->Internal->Views.begin(); 
+  for (iter = this->Internal->Views.begin();
        iter != this->Internal->Views.end(); ++iter)
     {
     collection->AddItem(iter->GetPointer());
@@ -679,7 +874,7 @@ void vtkSMComparativeViewProxy::GetViews(vtkCollection* collection)
 }
 
 //----------------------------------------------------------------------------
-void vtkSMComparativeViewProxy::GetRepresentationsForView(vtkSMViewProxy* view, 
+void vtkSMComparativeViewProxy::GetRepresentationsForView(vtkSMViewProxy* view,
       vtkCollection *collection)
 {
   if (!collection)
@@ -707,73 +902,60 @@ void vtkSMComparativeViewProxy::GetRepresentationsForView(vtkSMViewProxy* view,
     // Search the RepresentationData struct for a representation
     // belonging to the cloned view.
     vtkInternal::RepresentationData& data = reprIter->second;
-    vtkInternal::RepresentationData::MapOfViewToRepr::iterator cloneIter
-      = data.Clones.find(view);
+    vtkInternal::RepresentationData::VectorOfClones::iterator cloneIter
+      = data.FindRepresentationClone(view);
     if (cloneIter != data.Clones.end())
       {
       // A representation was found, so add it to the collection.
-      vtkSMRepresentationProxy* repr = cloneIter->second.GetPointer();
+      vtkSMProxy* repr = cloneIter->CloneRepresentation;
       collection->AddItem(repr);
       }
     }
 
 }
 
-
-//-----------------------------------------------------------------------------
-bool vtkSMComparativeViewProxy::GetXPropertyAndElement(vtkSMProperty *& prop, int & element)
-{
-  vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(this->GetProperty("XCues"));
-  for (unsigned int i=0; i < pp->GetNumberOfProxies(); ++i)
-    {
-    vtkSMAnimationCueProxy* cue = vtkSMAnimationCueProxy::SafeDownCast(pp->GetProxy(i));
-    if (cue && vtkSMPropertyHelper(cue, "Enabled").GetAsInt())
-      {
-      element = cue->GetAnimatedElement();
-      prop = cue->GetAnimatedProperty();
-      return true;
-      }
-    }
-  return false;
-}
-
-//-----------------------------------------------------------------------------
-bool vtkSMComparativeViewProxy::GetYPropertyAndElement(vtkSMProperty *& prop, int & element)
-{
-  vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(this->GetProperty("YCues"));
-  for (unsigned int i=0; i < pp->GetNumberOfProxies(); ++i)
-    {
-    vtkSMAnimationCueProxy* cue = vtkSMAnimationCueProxy::SafeDownCast(pp->GetProxy(i));
-    if (cue && vtkSMPropertyHelper(cue, "Enabled").GetAsInt())
-      {
-      element = cue->GetAnimatedElement();
-      prop = cue->GetAnimatedProperty();
-      return true;
-      }
-    }
-  return false;
-}
-
 //----------------------------------------------------------------------------
-const char* vtkSMComparativeViewProxy::GetSuggestedViewType(vtkIdType connectionID)
+void vtkSMComparativeViewProxy::GetRepresentations(int x, int y,
+  vtkCollection* collection)
 {
-  vtkSMViewProxy* rootView = vtkSMViewProxy::SafeDownCast(this->GetSubProxy("RootView"));
-  if (rootView)
+  if (!collection)
     {
-    vtksys_ios::ostringstream stream;
-    stream << "Comparative" << rootView->GetSuggestedViewType(connectionID);
-    this->Internal->SuggestedViewType = stream.str();
-    return this->Internal->SuggestedViewType.c_str();
+    return;
     }
 
-  return this->Superclass::GetSuggestedViewType(connectionID);
+  vtkSMViewProxy* view = this->OverlayAllComparisons?
+    this->Internal->Views[0] :
+    this->Internal->Views[y*this->Dimensions[0] + x];
+
+  int index = y * this->Dimensions[0] + x;
+
+  if (!this->OverlayAllComparisons)
+    {
+    this->GetRepresentationsForView(view, collection);
+    return;
+    }
+
+  vtkInternal::MapOfReprClones::iterator reprIter;
+  for (reprIter = this->Internal->RepresentationClones.begin();
+    reprIter != this->Internal->RepresentationClones.end(); ++reprIter)
+    {
+    vtkInternal::RepresentationData& data = reprIter->second;
+    if (index == 0)
+      {
+      collection->AddItem(reprIter->first);
+      }
+    else
+      {
+      collection->AddItem(data.Clones[index-1].CloneRepresentation);
+      }
+    }
 }
 
 //----------------------------------------------------------------------------
 void vtkSMComparativeViewProxy::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "Dimensions: " << this->Dimensions[0] 
+  os << indent << "Dimensions: " << this->Dimensions[0]
     << ", " << this->Dimensions[1] << endl;
   os << indent << "Spacing: " << this->Spacing[0] << ", "
     << this->Spacing[1] << endl;
