@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMDistanceRepresentation2DProxy.h,v $
+  Module:    vtkSMDistanceRepresentation2DProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -25,7 +25,7 @@ class VTK_EXPORT vtkSMDistanceRepresentation2DProxy : public vtkSMWidgetRepresen
 {
 public:
   static vtkSMDistanceRepresentation2DProxy* New();
-  vtkTypeRevisionMacro(vtkSMDistanceRepresentation2DProxy, vtkSMWidgetRepresentationProxy);
+  vtkTypeMacro(vtkSMDistanceRepresentation2DProxy, vtkSMWidgetRepresentationProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 //BTX
