@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMDoubleVectorProperty.cxx,v $
+  Module:    vtkSMDoubleVectorProperty.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,6 +14,8 @@
 =========================================================================*/
 #include "vtkSMDoubleVectorProperty.h"
 
+#include "vtkPVConfig.h"
+
 #include "vtkClientServerStream.h"
 #include "vtkObjectFactory.h"
 #include "vtkPVXMLElement.h"
@@ -22,7 +24,6 @@
 #include <vtkstd/vector>
 
 vtkStandardNewMacro(vtkSMDoubleVectorProperty);
-vtkCxxRevisionMacro(vtkSMDoubleVectorProperty, "$Revision: 1.44 $");
 
 struct vtkSMDoubleVectorPropertyInternals
 {
@@ -57,15 +58,14 @@ vtkSMDoubleVectorProperty::vtkSMDoubleVectorProperty()
 {
   this->Internals = new vtkSMDoubleVectorPropertyInternals;
   this->ArgumentIsArray = 0;
-  this->SetNumberCommand = 0;
   this->Initialized = false;
+  this->Precision = DEFAULT_DOUBLE_PRECISION_VALUE;
 }
 
 //---------------------------------------------------------------------------
 vtkSMDoubleVectorProperty::~vtkSMDoubleVectorProperty()
 {
   delete this->Internals;
-  this->SetSetNumberCommand(0);
 }
 
 //---------------------------------------------------------------------------
@@ -183,13 +183,13 @@ void vtkSMDoubleVectorProperty::SetNumberOfElements(unsigned int num)
 //---------------------------------------------------------------------------
 unsigned int vtkSMDoubleVectorProperty::GetNumberOfUncheckedElements()
 {
-  return this->Internals->UncheckedValues.size();
+  return static_cast<unsigned int>(this->Internals->UncheckedValues.size());
 }
 
 //---------------------------------------------------------------------------
 unsigned int vtkSMDoubleVectorProperty::GetNumberOfElements()
 {
-  return this->Internals->Values.size();
+  return static_cast<unsigned int>(this->Internals->Values.size());
 }
 
 //---------------------------------------------------------------------------
@@ -293,6 +293,47 @@ int vtkSMDoubleVectorProperty::SetElements4(
   return (retVal1 && retVal2 && retVal3 && retVal4);
 }
 
+//---------------------------------------------------------------------------
+int vtkSMDoubleVectorProperty::SetElements(const double* values,
+  unsigned int numValues)
+{
+  unsigned int numArgs = this->GetNumberOfElements();
+
+  int modified = (numArgs != numValues);
+  for (unsigned int i=0; modified == 0 && i<numArgs; i++)
+    {
+    if (this->Internals->Values[i] != values[i])
+      {
+      modified = 1;
+      break;
+      }
+    }
+  if(!modified && this->Initialized)
+    {
+    return 1;
+    }
+
+  if ( vtkSMProperty::GetCheckDomains() )
+    {
+    memcpy(&this->Internals->UncheckedValues[0], 
+           values, 
+           numValues*sizeof(double));
+    if (!this->IsInDomains())
+      {
+      return 0;
+      }
+    }
+
+  this->Internals->Values.resize(numValues, 0);
+  if (numValues > 0)
+    {
+    memcpy(&this->Internals->Values[0], values, numValues*sizeof(double));
+    }
+  this->Initialized = true;
+  this->Modified();
+  return 1;
+}
+
 //---------------------------------------------------------------------------
 int vtkSMDoubleVectorProperty::SetElements(const double* values)
 {
@@ -348,10 +389,10 @@ int vtkSMDoubleVectorProperty::ReadXMLAttributes(vtkSMProxy* proxy,
     this->SetArgumentIsArray(arg_is_array); 
     }
 
-  const char* numCommand = element->GetAttribute("set_number_command");
-  if (numCommand)
+  int precision=0;
+  if (element->GetScalarAttribute("precision", &precision))
     {
-    this->SetSetNumberCommand(numCommand);
+    this->SetPrecision(precision);
     }
 
   int numElems = this->GetNumberOfElements();
@@ -382,7 +423,7 @@ int vtkSMDoubleVectorProperty::ReadXMLAttributes(vtkSMProxy* proxy,
         this->Internals->UpdateLastPushedValues();
         this->Internals->UpdateDefaultValues();
         }
-      else
+      else if (!this->Initialized)
         {
         vtkErrorMacro("No default value is specified for property: "
                       << this->GetXMLName()
@@ -397,7 +438,7 @@ int vtkSMDoubleVectorProperty::ReadXMLAttributes(vtkSMProxy* proxy,
 
 //---------------------------------------------------------------------------
 int vtkSMDoubleVectorProperty::LoadState(vtkPVXMLElement* element,
-  vtkSMStateLoaderBase* loader, int loadLastPushedValues/*=0*/)
+  vtkSMProxyLocator* loader, int loadLastPushedValues/*=0*/)
 {
   int prevImUpdate = this->ImmediateUpdate;
 
@@ -474,14 +515,15 @@ void vtkSMDoubleVectorProperty::ChildSaveState(
     vtkPVXMLElement* elementElement = vtkPVXMLElement::New();
     elementElement->SetName("Element");
     elementElement->AddAttribute("index", i);
-    elementElement->AddAttribute("value", this->GetElement(i));
+    elementElement->AddAttribute("value", this->GetElement(i),
+      this->Precision);
     propertyElement->AddNestedElement(elementElement);
     elementElement->Delete();
     }
 
   if (saveLastPushedValues)
     {
-    size = this->Internals->LastPushedValues.size();
+    size = static_cast<unsigned int>(this->Internals->LastPushedValues.size());
     
     vtkPVXMLElement* element = vtkPVXMLElement::New();
     element->SetName("LastPushedValues");
@@ -492,7 +534,8 @@ void vtkSMDoubleVectorProperty::ChildSaveState(
       elementElement->SetName("Element");
       elementElement->AddAttribute("index", cc);
       elementElement->AddAttribute("value", 
-        this->Internals->LastPushedValues[cc]);
+        this->Internals->LastPushedValues[cc],
+        this->Precision);
       element->AddNestedElement(elementElement);
       elementElement->Delete();
       }
@@ -549,6 +592,7 @@ void vtkSMDoubleVectorProperty::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "ArgumentIsArray: " << this->ArgumentIsArray << endl;
+  os << indent << "Precision: " << this->Precision << endl;
 
   os << indent << "Values: ";
   for (unsigned int i=0; i<this->GetNumberOfElements(); i++)
