@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMInputProperty.cxx,v $
+  Module:    vtkSMInputProperty.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -20,12 +20,11 @@
 #include "vtkSMPropertyIterator.h"
 #include "vtkSMProxy.h"
 #include "vtkSMProxyIterator.h"
-#include "vtkSMStateLoaderBase.h"
+#include "vtkSMProxyLocator.h"
 
 #include <vtkstd/vector>
 
 vtkStandardNewMacro(vtkSMInputProperty);
-vtkCxxRevisionMacro(vtkSMInputProperty, "$Revision: 1.23 $");
 
 int vtkSMInputProperty::InputsUpdateImmediately = 1;
 
@@ -347,9 +346,15 @@ unsigned int vtkSMInputProperty::GetUncheckedOutputPortForConnection(
 
 //---------------------------------------------------------------------------
 int vtkSMInputProperty::LoadState(vtkPVXMLElement* element,
-                                  vtkSMStateLoaderBase* loader, 
+                                  vtkSMProxyLocator* loader, 
                                   int loadLastPushedValues/*=0*/)
 {
+  if (!loader)
+    {
+    // If no loader, leave state unchanged.
+    return 1;
+    }
+
   // NOTE: This method by-passes LoadState() of vtkSMProxyProperty and
   // re-implements a lot of it's functionality to add output ports. 
   // Therefore, care must be taken to keep the two in sync.
@@ -396,11 +401,10 @@ int vtkSMInputProperty::LoadState(vtkPVXMLElement* element,
         currentElement->GetScalarAttribute("output_port", &outputPort);
         if (id)
           {
-          vtkSMProxy* proxy = loader->NewProxy(id);
+          vtkSMProxy* proxy = loader->LocateProxy(id);
           if (proxy)
             {
             this->AddInputConnection(proxy, outputPort, 0);
-            proxy->Delete();
             }
           else
             {
@@ -425,73 +429,18 @@ int vtkSMInputProperty::LoadState(vtkPVXMLElement* element,
 }
 
 //---------------------------------------------------------------------------
-void vtkSMInputProperty::ChildSaveState(vtkPVXMLElement* propertyElement,
-                                       int saveLastPushedValues)
+vtkPVXMLElement* vtkSMInputProperty::SaveProxyElementState(
+  unsigned int idx, bool use_previous_proxies)
 {
-  this->Superclass::ChildSaveState(propertyElement, saveLastPushedValues);
-
-  // Add to the DOM built by the superclass. This makes this implementation
-  // on that of the superclass so beware of changes to vtkSMProxyProperty's
-  // ChildSaveState().
-  unsigned int numNested = propertyElement->GetNumberOfNestedElements();
-  for (unsigned int idx=0; idx<numNested; idx++)
+  vtkPVXMLElement* proxyElement = this->Superclass::SaveProxyElementState(idx,
+    use_previous_proxies);
+  if (proxyElement)
     {
-    vtkPVXMLElement* proxyElement = propertyElement->GetNestedElement(idx);
-    // For each proxy element
-    if (proxyElement->GetName() && 
-        strcmp(proxyElement->GetName(), "Proxy") == 0)
-      {
-      // Find the index of the proxy
-      const char* idasstring = proxyElement->GetAttribute("value");
-      if (idasstring)
-        {
-        unsigned int numProxies = this->GetNumberOfProxies();
-        for (unsigned int jdx=0; jdx<numProxies; jdx++)
-          {
-          vtkSMProxy* proxy = this->GetProxy(jdx);
-          // Set the appropriate output port
-          if (proxy && strcmp(idasstring, proxy->GetSelfIDAsString()) == 0)
-            {
-            proxyElement->AddAttribute("output_port", 
-                                       this->GetOutputPortForConnection(jdx));
-            }
-          }
-        }
-      }
-    }
-
-  if (saveLastPushedValues)
-    {
-    vtkPVXMLElement* lastPushedElem = 
-      propertyElement->FindNestedElementByName("LastPushedValues");
-    if (lastPushedElem)
-      {
-      numNested = lastPushedElem->GetNumberOfNestedElements();
-      for (unsigned int idx=0; idx<numNested; idx++)
-        {
-        vtkPVXMLElement* proxyElement = lastPushedElem->GetNestedElement(idx);
-        // For each proxy element
-        if (proxyElement->GetName() && 
-            strcmp(proxyElement->GetName(), "Proxy") == 0)
-          {
-          // Find the index of the proxy
-          const char* idasstring = proxyElement->GetAttribute("value");
-          if (idasstring)
-            {
-            unsigned int numProxies = this->GetNumberOfPreviousProxies();
-            for (unsigned int jdx=0; jdx<numProxies; jdx++)
-              {
-              vtkSMProxy* proxy = this->GetPreviousProxy(jdx);
-              // Set the appropriate output port
-              if (proxy && strcmp(idasstring, proxy->GetSelfIDAsString()) == 0)
-                {
-                proxyElement->AddAttribute(
-                  "output_port", this->GetPreviousOutputPortForConnection(jdx));
-                }
-              }
-            }
-          }
-        }
-      }
+    proxyElement->AddAttribute("output_port",
+      (use_previous_proxies?
+       this->GetPreviousOutputPortForConnection(idx) :
+       this->GetOutputPortForConnection(idx)));
     }
+  return proxyElement;
 }
+
