@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMNewWidgetRepresentationProxy.cxx,v $
+  Module:    vtkSMNewWidgetRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,8 +14,10 @@
 =========================================================================*/
 #include "vtkSMNewWidgetRepresentationProxy.h"
 
+#include "vtk3DWidgetRepresentation.h"
 #include "vtkAbstractWidget.h"
 #include "vtkClientServerInterpreter.h"
+#include "vtkClientServerStream.h"
 #include "vtkCommand.h"
 #include "vtkObjectFactory.h"
 #include "vtkProcessModule.h"
@@ -34,7 +36,6 @@
 #include <vtkstd/list>
 
 vtkStandardNewMacro(vtkSMNewWidgetRepresentationProxy);
-vtkCxxRevisionMacro(vtkSMNewWidgetRepresentationProxy, "$Revision: 1.11 $");
 
 class vtkSMNewWidgetRepresentationObserver : public vtkCommand
 {
@@ -62,14 +63,13 @@ struct vtkSMNewWidgetRepresentationInternals
 //----------------------------------------------------------------------------
 vtkSMNewWidgetRepresentationProxy::vtkSMNewWidgetRepresentationProxy()
 {
+  this->SetServers(vtkProcessModule::CLIENT_AND_SERVERS);
   this->RepresentationProxy = 0;
   this->WidgetProxy = 0;
   this->Widget = 0;
-  this->Enabled = 0;
   this->Observer = vtkSMNewWidgetRepresentationObserver::New();
   this->Observer->Proxy = this;
   this->Internal = new vtkSMNewWidgetRepresentationInternals;
-  this->StateLoaded = false;
 }
 
 //----------------------------------------------------------------------------
@@ -87,128 +87,6 @@ vtkSMNewWidgetRepresentationProxy::~vtkSMNewWidgetRepresentationProxy()
     }
 }
 
-//----------------------------------------------------------------------------
-bool vtkSMNewWidgetRepresentationProxy::AddToView(vtkSMViewProxy* view)
-{
-  vtkSMRenderViewProxy* renderView = vtkSMRenderViewProxy::SafeDownCast(view);
-  if (!renderView)
-    {
-    vtkErrorMacro("View must be a vtkSMRenderViewProxy.");
-    return false;
-    }
-
-  vtkAbstractWidget* widget = this->Widget;
-  if (widget)
-    {
-    widget->SetInteractor(renderView->GetInteractor());
-    }
-
-  if (this->RepresentationProxy)
-    {
-    vtkSMProxyProperty* rendererProp = 
-      vtkSMProxyProperty::SafeDownCast(
-        this->RepresentationProxy->GetProperty("Renderer"));
-
-    if (rendererProp)
-      {
-      rendererProp->RemoveAllProxies();
-      rendererProp->AddProxy(renderView->GetRendererProxy());
-      this->RepresentationProxy->UpdateProperty("Renderer");
-      }
-
-    if(this->GetSubProxy("Prop"))
-      {
-      renderView->AddPropToRenderer(this->RepresentationProxy);
-      if (widget)
-        {
-        widget->SetCurrentRenderer(renderView->GetRenderer());
-        }
-      }
-    else if(this->GetSubProxy("Prop2D"))
-      {
-      renderView->AddPropToRenderer2D(this->RepresentationProxy);
-      if (widget)
-        {
-        widget->SetCurrentRenderer(renderView->GetRenderer2D());
-        }
-      }
-    }
-
-  this->Internal->ViewProxy = renderView;
-  this->UpdateEnabled();
-  return true;
-}
-
-//----------------------------------------------------------------------------
-bool vtkSMNewWidgetRepresentationProxy::RemoveFromView(vtkSMViewProxy* view)
-{
-  vtkSMRenderViewProxy* renderView = vtkSMRenderViewProxy::SafeDownCast(view);
-  if (!renderView)
-    {
-    vtkErrorMacro("View must be a vtkSMRenderViewProxy.");
-    return false;
-    }
-
-  if (this->Widget)
-    {
-    this->Widget->SetEnabled(0);
-    this->Widget->SetCurrentRenderer(0);
-    this->Widget->SetInteractor(0);
-    }
-
-  if (this->RepresentationProxy)
-    {
-    vtkSMProxyProperty* rendererProp = 
-      vtkSMProxyProperty::SafeDownCast(
-        this->RepresentationProxy->GetProperty("Renderer"));
-    if (rendererProp)
-      {
-      rendererProp->RemoveAllProxies();
-      rendererProp->AddProxy(0);
-      this->RepresentationProxy->UpdateProperty("Renderer");
-      }
-
-    if(this->GetSubProxy("Prop"))
-      {
-      renderView->RemovePropFromRenderer(this->RepresentationProxy);
-      }
-    else if(this->GetSubProxy("Prop2D"))
-      {
-      renderView->RemovePropFromRenderer2D(this->RepresentationProxy);
-      }
-    }
-
-  this->Internal->ViewProxy = 0;
-  return this->Superclass::RemoveFromView(view);
-}
-
-//-----------------------------------------------------------------------------
-void vtkSMNewWidgetRepresentationProxy::SetEnabled(int enable)
-{
-  if (this->Enabled != enable)
-    {
-    this->Enabled = enable;
-    this->UpdateEnabled();
-    }
-}
-
-//-----------------------------------------------------------------------------
-void vtkSMNewWidgetRepresentationProxy::UpdateEnabled()
-{
-  if (this->Internal->ViewProxy && this->Widget)
-    {
-    this->Widget->SetEnabled(this->Enabled);
-    }
-}
-
-//-----------------------------------------------------------------------------
-int vtkSMNewWidgetRepresentationProxy::LoadState(vtkPVXMLElement* proxyElement, 
-                          vtkSMStateLoaderBase* loader)
-{
-  this->StateLoaded = true;
-  return this->Superclass::LoadState(proxyElement, loader);
-}
-
 //-----------------------------------------------------------------------------
 void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
 {
@@ -232,15 +110,28 @@ void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
     vtkProcessModule::RENDER_SERVER | vtkProcessModule::CLIENT);
 
   this->WidgetProxy = this->GetSubProxy("Widget");
-  if (!this->WidgetProxy)
+  if (this->WidgetProxy)
     {
-    vtkErrorMacro("A widget proxy must be defined as a Widget sub-proxy");
-    return;
+    this->WidgetProxy->SetServers(vtkProcessModule::CLIENT);
     }
-  this->WidgetProxy->SetServers(vtkProcessModule::CLIENT);
 
   this->Superclass::CreateVTKObjects();
 
+  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+  vtkClientServerStream stream;
+  stream << vtkClientServerStream::Invoke
+         << this->GetID()
+         << "SetRepresentation"
+         << this->RepresentationProxy->GetID()
+         << vtkClientServerStream::End;
+  pm->SendStream(this->ConnectionID,
+    vtkProcessModule::CLIENT|vtkProcessModule::RENDER_SERVER, stream);
+
+  if (!this->WidgetProxy)
+    {
+    return;
+    }
+
   vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(
     this->WidgetProxy->GetProperty("Representation"));
   if (pp)
@@ -249,7 +140,6 @@ void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
     }
   this->WidgetProxy->UpdateVTKObjects();
 
-  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   this->Widget = vtkAbstractWidget::SafeDownCast(
     pm->GetObjectFromID(this->WidgetProxy->GetID()));
   if (this->Widget)
@@ -262,6 +152,10 @@ void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
       vtkCommand::InteractionEvent, this->Observer);
     }
 
+  vtk3DWidgetRepresentation* clientObject =
+    vtk3DWidgetRepresentation::SafeDownCast(this->GetClientSideObject());
+  clientObject->SetWidget(this->Widget);
+
   // Since links copy values from input to output,
   // we need to make sure that input properties i.e. the info
   // properties are not empty.
@@ -273,13 +167,12 @@ void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
     vtkSMProperty* prop = piter->GetProperty();
     vtkSMProperty* info = prop->GetInformationProperty();
     if (info)
-      {
-      if (this->StateLoaded)
-        {
-        // This ensures that the property value from the loaded state is
-        // preserved.
-        info->Copy(prop);
-        }
+      {      
+      // This ensures that the property value from the loaded state is
+      // preserved, and not overwritten by the default value from 
+      // the property information
+      info->Copy(prop);
+      
       vtkSMPropertyLink* link = vtkSMPropertyLink::New();
       link->AddLinkedProperty(this, 
                               piter->GetKey(), 
@@ -292,6 +185,7 @@ void vtkSMNewWidgetRepresentationProxy::CreateVTKObjects()
       }
     }
   piter->Delete();
+
 }
 
 //-----------------------------------------------------------------------------
@@ -381,29 +275,6 @@ void vtkSMNewWidgetRepresentationProxy::UnRegister(vtkObjectBase* obj)
   this->Superclass::UnRegister(obj);
 }
 
-//----------------------------------------------------------------------------
-bool vtkSMNewWidgetRepresentationProxy::GetBounds(double bds[6])
-{
-  if (this->RepresentationProxy)
-    {
-    // since the widget representation is also present on the client, we can
-    // directly get its bounds.
-    vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-    vtkWidgetRepresentation* repr = vtkWidgetRepresentation::SafeDownCast(
-      pm->GetObjectFromID(this->RepresentationProxy->GetID()));
-    if (repr)
-      {
-      double *propBds = repr->GetBounds();
-      if (propBds)
-        {
-        memcpy(bds, propBds, 6*sizeof(double));
-        return true;
-        }
-      }
-    }
-  return false;
-}
-
 //----------------------------------------------------------------------------
 void vtkSMNewWidgetRepresentationProxy::PrintSelf(ostream& os, vtkIndent indent)
 {
