@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMNewWidgetRepresentationProxy.h,v $
+  Module:    vtkSMNewWidgetRepresentationProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -23,7 +23,7 @@
 #ifndef __vtkSMNewWidgetRepresentationProxy_h
 #define __vtkSMNewWidgetRepresentationProxy_h
 
-#include "vtkSMRepresentationProxy.h"
+#include "vtkSMProxy.h"
 class vtkSMViewProxy;
 class vtkSMNewWidgetRepresentationObserver;
 class vtkAbstractWidget;
@@ -31,30 +31,25 @@ class vtkAbstractWidget;
 struct vtkSMNewWidgetRepresentationInternals;
 //ETX
 
-class VTK_EXPORT vtkSMNewWidgetRepresentationProxy : 
-  public vtkSMRepresentationProxy
+class VTK_EXPORT vtkSMNewWidgetRepresentationProxy : public vtkSMProxy
 {
 public:
   static vtkSMNewWidgetRepresentationProxy* New();
-  vtkTypeRevisionMacro(vtkSMNewWidgetRepresentationProxy, vtkSMRepresentationProxy);
+  vtkTypeMacro(vtkSMNewWidgetRepresentationProxy, vtkSMProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
  
   // Description:
   // Break reference loop that are due to links.
   virtual void UnRegister(vtkObjectBase* o);
- 
-  // Description:
-  // Calls set enabled on the WidgetProxy.
-  virtual void SetEnabled(int enable);
-
-  // Description:
-  // Get the bounds for the representation.  Returns true if successful.
-  virtual bool GetBounds(double bounds[6]);
 
   // Description:
   // Get the widget for the representation.
   vtkGetObjectMacro(Widget, vtkAbstractWidget);
 
+  // Description:
+  // Get Representation Proxy.
+  vtkGetObjectMacro(RepresentationProxy, vtkSMProxy);
+
 //BTX
 protected:
   vtkSMNewWidgetRepresentationProxy();
@@ -65,44 +60,22 @@ protected:
   // EndCreateVTKObjects().
   virtual void CreateVTKObjects();
 
-  // Description:
-  // Called when a representation is added to a view. 
-  // Returns true on success.
-  // Currently a representation can be added to only one view.
-  virtual bool AddToView(vtkSMViewProxy* view);
-
-  // Description:
-  // Called to remove a representation from a view.
-  // Returns true on success.
-  // Currently a representation can be added to only one view.
-  virtual bool RemoveFromView(vtkSMViewProxy* view);
-
-  // Description:
-  // Updates the widget's enabled state.
-  void UpdateEnabled();
-
-  // Description:
-  // Updates state from an XML element. Returns 0 on failure.
-  virtual int LoadState(vtkPVXMLElement* element, vtkSMStateLoaderBase* loader);
-
   vtkSMProxy* RepresentationProxy;
   vtkSMProxy* WidgetProxy;
   vtkAbstractWidget* Widget;
   vtkSMNewWidgetRepresentationObserver* Observer;
   vtkSMNewWidgetRepresentationInternals* Internal;
 
-//BTX
   friend class vtkSMNewWidgetRepresentationObserver;
-//ETX
 
-  int Enabled;
+  // Description:
+  // Called every time the user interacts with the widget.
+  virtual void ExecuteEvent(unsigned long event);
+
 private:
-  void ExecuteEvent(unsigned long event);
 
   vtkSMNewWidgetRepresentationProxy(const vtkSMNewWidgetRepresentationProxy&); // Not implemented
-  void operator=(const vtkSMNewWidgetRepresentationProxy&); // Not implemented
-
-  bool StateLoaded;
+  void operator=(const vtkSMNewWidgetRepresentationProxy&); // Not implemented  
 //ETX
 };
 
