@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMNullProxy.h,v $
+  Module:    vtkSMNullProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -25,7 +25,7 @@ class VTK_EXPORT vtkSMNullProxy : public vtkSMProxy
 {
 public:
   static vtkSMNullProxy* New();
-  vtkTypeRevisionMacro(vtkSMNullProxy, vtkSMProxy);
+  vtkTypeMacro(vtkSMNullProxy, vtkSMProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 protected:
