@@ -27,10 +27,17 @@
 #include "vtkPVTemporalDataInformation.h"
 #include "vtkPVXMLElement.h"
 #include "vtkSMSourceProxy.h"
+#include "vtkTimerLog.h"
+
+#include <vtksys/ios/sstream>
 
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkSMOutputPort);
 
+bool vtkSMOutputPort::UseStreaming = false;
+int vtkSMOutputPort::DefaultPass = 0;
+int vtkSMOutputPort::DefaultNumPasses = 0;
+double vtkSMOutputPort::DefaultResolution = 0;
 
 //----------------------------------------------------------------------------
 vtkSMOutputPort::vtkSMOutputPort()
@@ -75,8 +82,8 @@ vtkSMOutputPort::~vtkSMOutputPort()
 }
 
 //----------------------------------------------------------------------------
-void vtkSMOutputPort::InitializeWithIDs(vtkClientServerID outputID, 
-                                  vtkClientServerID producerID, 
+void vtkSMOutputPort::InitializeWithIDs(vtkClientServerID outputID,
+                                  vtkClientServerID producerID,
                                   vtkClientServerID executiveID)
 {
   if (this->ObjectsCreated || outputID.IsNull() || producerID.IsNull() ||
@@ -180,7 +187,7 @@ vtkSMProxy* vtkSMOutputPort::GetDataObjectProxy(int recheck)
            << this->PortIndex
            << vtkClientServerStream::End;
     vtkClientServerID uid = pm->GetUniqueID();
-    stream << vtkClientServerStream::Assign 
+    stream << vtkClientServerStream::Assign
            << uid << vtkClientServerStream::LastResult
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID, this->Servers, stream);
@@ -195,7 +202,11 @@ vtkPVDataInformation* vtkSMOutputPort::GetDataInformation()
 {
   if (!this->DataInformationValid)
     {
+    vtksys_ios::ostringstream mystr;
+    mystr << this->GetSourceProxy()->GetXMLName() << "::GatherInformation";
+    vtkTimerLog::MarkStartEvent(mystr.str().c_str());
     this->GatherDataInformation();
+    vtkTimerLog::MarkEndEvent(mystr.str().c_str());
     }
   return this->DataInformation;
 }
@@ -246,9 +257,55 @@ void vtkSMOutputPort::GatherDataInformation()
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   pm->SendPrepareProgress(this->ConnectionID);
   this->DataInformation->Initialize();
-  pm->GatherInformation(this->ConnectionID, this->Servers, 
-                        this->DataInformation, this->GetID());
 
+  if (vtkSMOutputPort::UseStreaming)
+    {
+    vtkClientServerStream stream;
+    vtkClientServerID infoHelper =
+    pm->NewStreamObject("vtkPriorityHelper", stream);
+
+    stream
+      << vtkClientServerStream::Invoke
+      << infoHelper << "SetInputConnection" << this->GetID()
+      << vtkClientServerStream::End;
+
+    stream
+      << vtkClientServerStream::Invoke
+      << pm->GetProcessModuleID() << "GetPartitionId"
+      << vtkClientServerStream::End;
+
+    stream
+      << vtkClientServerStream::Invoke
+      << infoHelper
+      << "SetSplitUpdateExtent"
+      << this->PortIndex //algorithm's output port
+      << vtkClientServerStream::LastResult //processor
+      << pm->GetNumberOfPartitions(this->ConnectionID) //numprocessors
+      << vtkSMOutputPort::DefaultPass //pass
+      << vtkSMOutputPort::DefaultNumPasses //number of passes
+      << vtkSMOutputPort::DefaultResolution //resolution
+      << vtkClientServerStream::End;
+
+    pm->SendStream(this->ConnectionID, this->Servers, stream);
+
+    //gather the data information for that piece
+    vtkPVDataInformation *di = vtkPVDataInformation::New();
+    di->Initialize();
+    pm->GatherInformation(this->ConnectionID, this->Servers,
+                          di,
+                          infoHelper);
+
+    //merge it in
+    this->DataInformation->AddInformation(di);
+
+    di->Delete();
+    pm->DeleteStreamObject(infoHelper, stream);
+    }
+  else
+    {
+    pm->GatherInformation(this->ConnectionID, this->Servers,
+                          this->DataInformation, this->GetID());
+    }
   this->DataInformationValid = true;
 
   pm->SendCleanupPendingProgress(this->ConnectionID);
@@ -266,7 +323,7 @@ void vtkSMOutputPort::GatherTemporalDataInformation()
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   pm->SendPrepareProgress(this->ConnectionID);
   this->TemporalDataInformation->Initialize();
-  pm->GatherInformation(this->ConnectionID, this->Servers, 
+  pm->GatherInformation(this->ConnectionID, this->Servers,
                         this->TemporalDataInformation, this->GetID());
 
   this->TemporalDataInformationValid = true;
@@ -301,20 +358,20 @@ void vtkSMOutputPort::GatherClassNameInformation()
            << this->PortIndex
            << vtkClientServerStream::End;
     vtkClientServerID uid = pm->GetUniqueID();
-    stream << vtkClientServerStream::Assign 
+    stream << vtkClientServerStream::Assign
            << uid << vtkClientServerStream::LastResult
            << vtkClientServerStream::End;
 
     pm->SendStream(this->ConnectionID, this->Servers, stream);
 
-    pm->GatherInformation(this->ConnectionID, 
+    pm->GatherInformation(this->ConnectionID,
                           this->Servers,
-                          this->ClassNameInformation, 
+                          this->ClassNameInformation,
                           uid);
 
     // Unassign the id.
-    stream << vtkClientServerStream::Delete 
-           << uid 
+    stream << vtkClientServerStream::Delete
+           << uid
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID, this->Servers, stream);
     }
@@ -329,7 +386,7 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
     return;
     }
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-  
+
   const char* className = this->GetClassNameInformation()->GetVTKClassName();
   vtkClientServerStream stream;
   vtkClientServerID tempDataPiece;
@@ -346,24 +403,19 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
     if (pm->GetNumberOfPartitions(this->ConnectionID) == 1)
       {
       return;
-      }  
-    stream << vtkClientServerStream::Invoke 
+      }
+    stream << vtkClientServerStream::Invoke
            << this->GetProducerID() << "UpdateInformation"
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID, this->Servers, stream);
-    this->GatherDataInformation();
-    if (this->DataInformation->GetCompositeDataClassName())
-      {
-      return;
-      }
-    stream << vtkClientServerStream::Invoke 
-           << this->GetExecutiveID() 
+    stream << vtkClientServerStream::Invoke
+           << this->GetExecutiveID()
            << "GetMaximumNumberOfPieces"
            << this->PortIndex
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID, this->Servers, stream);
     int num =0;
-    pm->GetLastResult(this->ConnectionID, 
+    pm->GetLastResult(this->ConnectionID,
              vtkProcessModule::GetRootId(this->Servers)).GetArgument(0,0,&num);
     if (num != 1)
       { // The source can already produce pieces.
@@ -380,19 +432,19 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
       tempDataPiece = pm->NewStreamObject("vtkTransmitPolyDataPiece", stream);
 // TODO: Add observers. Move logging to process object
 //       vtkClientServerStream start;
-//       start << vtkClientServerStream::Invoke << pm->GetApplicationID() 
-//             << "LogStartEvent" << "Execute TransmitPData" 
+//       start << vtkClientServerStream::Invoke << pm->GetApplicationID()
+//             << "LogStartEvent" << "Execute TransmitPData"
 //             << vtkClientServerStream::End;
-//       stream << vtkClientServerStream::Invoke << tempDataPiece 
+//       stream << vtkClientServerStream::Invoke << tempDataPiece
 //                       << "AddObserver"
 //                       << "StartEvent"
 //                       << start
 //                       << vtkClientServerStream::End;
 //       vtkClientServerStream end;
-//       end << vtkClientServerStream::Invoke << pm->GetApplicationID() 
-//           << "LogEndEvent" << "Execute TransmitPData" 
+//       end << vtkClientServerStream::Invoke << pm->GetApplicationID()
+//           << "LogEndEvent" << "Execute TransmitPData"
 //           << vtkClientServerStream::End;
-//       stream << vtkClientServerStream::Invoke << tempDataPiece 
+//       stream << vtkClientServerStream::Invoke << tempDataPiece
 //                       << "AddObserver"
 //                       << "EndEvent"
 //                       << end
@@ -408,27 +460,22 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
       {
       return;
       }
-    stream << vtkClientServerStream::Invoke 
+    stream << vtkClientServerStream::Invoke
            << this->GetProducerID() << "UpdateInformation"
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID,
-                   this->Servers, 
+                   this->Servers,
                    stream);
-    this->GatherDataInformation();
-    if (this->DataInformation->GetCompositeDataClassName())
-      {
-      return;
-      }
-    stream << vtkClientServerStream::Invoke 
-           << this->GetExecutiveID() 
+    stream << vtkClientServerStream::Invoke
+           << this->GetExecutiveID()
            << "GetMaximumNumberOfPieces"
            << this->PortIndex
            << vtkClientServerStream::End;
-    pm->SendStream(this->ConnectionID, 
+    pm->SendStream(this->ConnectionID,
                    vtkProcessModule::GetRootId(this->Servers),
                    stream);
     int num =0;
-    pm->GetLastResult(this->ConnectionID, 
+    pm->GetLastResult(this->ConnectionID,
            vtkProcessModule::GetRootId(this->Servers)).GetArgument(0,0,&num);
     if (num != 1)
       { // The source can already produce pieces.
@@ -438,7 +485,7 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
     // Transmit is more efficient, but has the possiblity of hanging.
     // It will hang if all procs do not  call execute.
     if (getenv("PV_LOCK_SAFE") != NULL)
-      { 
+      {
       tempDataPiece = pm->NewStreamObject(
         "vtkExtractUnstructuredGridPiece", stream);
       }
@@ -448,19 +495,19 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
         "vtkTransmitUnstructuredGridPiece", stream);
 // TODO: Add observers. Move logging to process object
 //       vtkClientServerStream start;
-//       start << vtkClientServerStream::Invoke << pm->GetApplicationID() 
-//             << "LogStartEvent" << "Execute TransmitPData" 
+//       start << vtkClientServerStream::Invoke << pm->GetApplicationID()
+//             << "LogStartEvent" << "Execute TransmitPData"
 //             << vtkClientServerStream::End;
-//       stream << vtkClientServerStream::Invoke << tempDataPiece 
+//       stream << vtkClientServerStream::Invoke << tempDataPiece
 //                       << "AddObserver"
 //                       << "StartEvent"
 //                       << start
 //                       << vtkClientServerStream::End;
 //       vtkClientServerStream end;
-//       end << vtkClientServerStream::Invoke << pm->GetApplicationID() 
-//           << "LogEndEvent" << "Execute TransmitPData" 
+//       end << vtkClientServerStream::Invoke << pm->GetApplicationID()
+//           << "LogEndEvent" << "Execute TransmitPData"
 //           << vtkClientServerStream::End;
-//       stream << vtkClientServerStream::Invoke << tempDataPiece 
+//       stream << vtkClientServerStream::Invoke << tempDataPiece
 //                       << "AddObserver"
 //                       << "EndEvent"
 //                       << end
@@ -476,23 +523,22 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
       // all the data.
       return;
       }
-    stream << vtkClientServerStream::Invoke 
+    stream << vtkClientServerStream::Invoke
            << this->GetProducerID() << "UpdateInformation"
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID,
-                   this->Servers, 
+                   this->Servers,
                    stream);
-    this->GatherDataInformation();
     stream << vtkClientServerStream::Invoke
-           << this->GetExecutiveID() 
+           << this->GetExecutiveID()
            << "GetMaximumNumberOfPieces"
            << this->PortIndex
            << vtkClientServerStream::End;
     pm->SendStream(this->ConnectionID,
-                   this->Servers, 
+                   this->Servers,
                    stream);
     int num = 0;
-    pm->GetLastResult(this->ConnectionID, 
+    pm->GetLastResult(this->ConnectionID,
          vtkProcessModule::GetRootId(this->Servers)).GetArgument(0,0,&num);
     if (num != 1)
       { // The source can already produce pieces.
@@ -512,37 +558,37 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
   // Set the right executive
   vtkClientServerID execId = pm->NewStreamObject(
     "vtkCompositeDataPipeline", stream);
-  stream << vtkClientServerStream::Invoke 
-         << tempDataPiece << "SetExecutive" << execId 
+  stream << vtkClientServerStream::Invoke
+         << tempDataPiece << "SetExecutive" << execId
          << vtkClientServerStream::End;
   pm->DeleteStreamObject(execId, stream);
-  
+
   // Connect filter
-  stream << vtkClientServerStream::Invoke << tempDataPiece 
+  stream << vtkClientServerStream::Invoke << tempDataPiece
          << "SetInputConnection"
          << this->GetID()
          << vtkClientServerStream::End;
 
   // Release references to old ids
-  stream << vtkClientServerStream::Delete 
+  stream << vtkClientServerStream::Delete
          << this->GetID()
          << vtkClientServerStream::End;
-  stream << vtkClientServerStream::Delete 
+  stream << vtkClientServerStream::Delete
          << this->GetProducerID()
          << vtkClientServerStream::End;
-  stream << vtkClientServerStream::Delete 
+  stream << vtkClientServerStream::Delete
          << this->GetExecutiveID()
          << vtkClientServerStream::End;
 
   // Reassign ids to the new output filter
-  stream << vtkClientServerStream::Invoke << tempDataPiece 
+  stream << vtkClientServerStream::Invoke << tempDataPiece
          << "GetOutputPort" << 0
          << vtkClientServerStream::End;
   stream << vtkClientServerStream::Assign << this->GetID()
          << vtkClientServerStream::LastResult
          << vtkClientServerStream::End;
-  stream << vtkClientServerStream::Invoke << tempDataPiece 
-         << "GetExecutive" 
+  stream << vtkClientServerStream::Invoke << tempDataPiece
+         << "GetExecutive"
          << vtkClientServerStream::End;
   stream << vtkClientServerStream::Assign << this->GetExecutiveID()
          << vtkClientServerStream::LastResult
@@ -560,6 +606,70 @@ void vtkSMOutputPort::InsertExtractPiecesIfNecessary()
   pm->SendStream(this->ConnectionID, this->Servers, stream);
 }
 
+
+//----------------------------------------------------------------------------
+void vtkSMOutputPort::InsertPostFilterIfNecessary()
+{
+  if (this->GetID().IsNull())
+    {
+    return;
+    }
+  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+  vtkClientServerStream stream;
+  vtkClientServerID tempPostFilter;
+  tempPostFilter = pm->NewStreamObject("vtkPVPostFilter", stream);
+
+  // Set the right executive
+  vtkClientServerID execId = pm->NewStreamObject(
+    "vtkPVPostFilterExecutive", stream);
+  stream << vtkClientServerStream::Invoke
+         << tempPostFilter << "SetExecutive" << execId
+         << vtkClientServerStream::End;
+  pm->DeleteStreamObject(execId, stream);
+
+  // Connect filter
+  stream << vtkClientServerStream::Invoke << tempPostFilter
+         << "SetInputConnection"
+         << this->GetID()
+         << vtkClientServerStream::End;
+
+  // Release references to old ids
+  stream << vtkClientServerStream::Delete
+         << this->GetID()
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Delete
+         << this->GetProducerID()
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Delete
+         << this->GetExecutiveID()
+         << vtkClientServerStream::End;
+
+  // Reassign ids to the new output filter
+  stream << vtkClientServerStream::Invoke << tempPostFilter
+         << "GetOutputPort" << 0
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Assign << this->GetID()
+         << vtkClientServerStream::LastResult
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Invoke << tempPostFilter
+         << "GetExecutive"
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Assign << this->GetExecutiveID()
+         << vtkClientServerStream::LastResult
+         << vtkClientServerStream::End;
+  stream << vtkClientServerStream::Assign << this->GetProducerID()
+         << tempPostFilter
+         << vtkClientServerStream::End;
+
+  // Port index is now 0
+  this->PortIndex = 0;
+
+  // We don't have to keep reference to the filter
+  pm->DeleteStreamObject(tempPostFilter, stream);
+
+  pm->SendStream(this->ConnectionID, this->Servers, stream);
+}
+
 //----------------------------------------------------------------------------
 // Create the extent translator (sources with no inputs only).
 // Needs to be before "ExtractPieces" because translator propagates.
@@ -570,21 +680,21 @@ void vtkSMOutputPort::CreateTranslatorIfNecessary()
     return;
     }
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-  
+
   vtkClientServerStream stream;
   // Do not overwrite custom extent translators.
   // PVExtent translator should really be the default,
   // Then we would not need to do this.
   stream << vtkClientServerStream::Invoke
-         << this->GetExecutiveID() 
-         << "GetExtentTranslator" 
+         << this->GetExecutiveID()
+         << "GetExtentTranslator"
          << this->PortIndex
          << vtkClientServerStream::End
          << vtkClientServerStream::Invoke
          << vtkClientServerStream::LastResult
          << "GetClassName"
          << vtkClientServerStream::End;
-  pm->SendStream(this->ConnectionID, 
+  pm->SendStream(this->ConnectionID,
                  vtkProcessModule::GetRootId(this->Servers),
                  stream);
   char* classname = 0;
@@ -598,8 +708,8 @@ void vtkSMOutputPort::CreateTranslatorIfNecessary()
     vtkClientServerID translatorID =
       pm->NewStreamObject("vtkPVExtentTranslator", stream);
     stream << vtkClientServerStream::Invoke
-           << this->GetExecutiveID() 
-           << "SetExtentTranslator" 
+           << this->GetExecutiveID()
+           << "SetExtentTranslator"
            << this->PortIndex
            << translatorID
            << vtkClientServerStream::End;
@@ -614,7 +724,7 @@ void vtkSMOutputPort::CreateTranslatorIfNecessary()
            << vtkClientServerStream::End;
     pm->DeleteStreamObject(translatorID, stream);
     pm->SendStream(this->ConnectionID,
-                   this->Servers, 
+                   this->Servers,
                    stream);
     }
 }
@@ -632,40 +742,91 @@ void vtkSMOutputPort::UpdatePipeline(double time)
 }
 
 //----------------------------------------------------------------------------
-void vtkSMOutputPort::UpdatePipelineInternal(double time, 
+void vtkSMOutputPort::UpdatePipelineInternal(double time,
                                              bool doTime)
 {
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   vtkClientServerStream stream;
 
-  stream << vtkClientServerStream::Invoke 
+  stream << vtkClientServerStream::Invoke
          << this->GetProducerID() << "UpdateInformation"
          << vtkClientServerStream::End;
 
-  stream << vtkClientServerStream::Invoke
-         << pm->GetProcessModuleID() << "GetPartitionId"
-         << vtkClientServerStream::End
-         << vtkClientServerStream::Invoke
-         << this->GetExecutiveID() << "SetUpdateExtent" << this->PortIndex
-         << vtkClientServerStream::LastResult 
-         << pm->GetNumberOfPartitions(this->ConnectionID) << 0
-         << vtkClientServerStream::End; 
+  if (vtkSMOutputPort::UseStreaming)
+    {
+    vtkClientServerID infoHelper =
+      pm->NewStreamObject("vtkPriorityHelper", stream);
 
-  if (doTime)
+    stream
+      << vtkClientServerStream::Invoke
+      << infoHelper << "SetInputConnection" << this->GetID()
+      << vtkClientServerStream::End;
+
+    stream
+      << vtkClientServerStream::Invoke
+      << pm->GetProcessModuleID() << "GetPartitionId"
+      << vtkClientServerStream::End;
+
+    stream
+      << vtkClientServerStream::Invoke
+      << infoHelper
+      << "SetSplitUpdateExtent"
+      << this->PortIndex //algorithm's output port
+      << vtkClientServerStream::LastResult //processor
+      << pm->GetNumberOfPartitions(this->ConnectionID) //numprocessors
+      << vtkSMOutputPort::DefaultPass //pass
+      << vtkSMOutputPort::DefaultNumPasses //number of passes
+      << vtkSMOutputPort::DefaultResolution //resolution
+      << vtkClientServerStream::End;
+
+    stream << vtkClientServerStream::Invoke
+           << this->GetProducerID() << "UpdateInformation"
+           << vtkClientServerStream::End;
+
+    if (doTime)
+      {
+      stream
+        << vtkClientServerStream::Invoke
+        << this->GetExecutiveID() << "SetUpdateTimeStep"
+        << this->PortIndex << time
+        << vtkClientServerStream::End;
+      }
+
+    stream
+      << vtkClientServerStream::Invoke
+      << infoHelper << "Update"
+      << vtkClientServerStream::End;
+
+    pm->DeleteStreamObject(infoHelper, stream);
+    }
+  else
     {
     stream << vtkClientServerStream::Invoke
-           << this->GetExecutiveID() << "SetUpdateTimeStep" 
-           << this->PortIndex << time
+           << pm->GetProcessModuleID() << "GetPartitionId"
+           << vtkClientServerStream::End
+           << vtkClientServerStream::Invoke
+           << this->GetExecutiveID() << "SetUpdateExtent" << this->PortIndex
+           << vtkClientServerStream::LastResult
+           << pm->GetNumberOfPartitions(this->ConnectionID) << 0
+           << vtkClientServerStream::End;
+
+    if (doTime)
+      {
+      stream << vtkClientServerStream::Invoke
+             << this->GetExecutiveID() << "SetUpdateTimeStep"
+             << this->PortIndex << time
+             << vtkClientServerStream::End;
+      }
+
+    stream << vtkClientServerStream::Invoke
+           << this->GetProducerID() << "Update"
            << vtkClientServerStream::End;
     }
 
-  stream << vtkClientServerStream::Invoke 
-         << this->GetProducerID() << "Update"
-         << vtkClientServerStream::End;
-
   pm->SendPrepareProgress(this->ConnectionID);
   pm->SendStream(this->ConnectionID, this->Servers, stream);
   pm->SendCleanupPendingProgress(this->ConnectionID);
+
 }
 
 //----------------------------------------------------------------------------
@@ -676,6 +837,16 @@ void vtkSMOutputPort::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "SourceProxy: " << this->SourceProxy << endl;
 }
 
+//----------------------------------------------------------------------------
+void vtkSMOutputPort::SetUseStreaming(bool value)
+{
+  vtkSMOutputPort::UseStreaming = value;
+};
 
-
-
+//----------------------------------------------------------------------------
+void vtkSMOutputPort::SetDefaultPiece(int dp, int dnp, double dr)
+{
+  vtkSMOutputPort::DefaultPass = dp;
+  vtkSMOutputPort::DefaultNumPasses = dnp;
+  vtkSMOutputPort::DefaultResolution = dr;
+};
