@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMPropertyIterator.cxx,v $
+  Module:    vtkSMPropertyIterator.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -19,7 +19,6 @@
 #include "vtkSMProxyInternals.h"
 
 vtkStandardNewMacro(vtkSMPropertyIterator);
-vtkCxxRevisionMacro(vtkSMPropertyIterator, "$Revision: 1.10 $");
 
 struct vtkSMPropertyIteratorInternals
 {
@@ -167,6 +166,25 @@ const char* vtkSMPropertyIterator::GetKey()
   return 0;
 }
 
+//---------------------------------------------------------------------------
+const char* vtkSMPropertyIterator::GetPropertyLabel()
+{
+  // Self property
+  if (this->Internals->PropertyIterator != 
+      this->Proxy->Internals->Properties.end())
+    {
+    return this->GetProperty()->GetXMLLabel();
+    }
+
+  // Property of a sub-proxy
+  if (this->TraverseSubProxies)
+    {
+    return this->GetKey();
+    }
+
+  return 0;
+}
+
 //---------------------------------------------------------------------------
 vtkSMProperty* vtkSMPropertyIterator::GetProperty()
 {
