@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMProxyDefinitionIterator.h,v $
+  Module:    vtkSMProxyDefinitionIterator.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -36,7 +36,7 @@ class VTK_EXPORT vtkSMProxyDefinitionIterator : public vtkSMObject
 {
 public:
   static vtkSMProxyDefinitionIterator* New();
-  vtkTypeRevisionMacro(vtkSMProxyDefinitionIterator, vtkSMObject);
+  vtkTypeMacro(vtkSMProxyDefinitionIterator, vtkSMObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
