@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMProxyInternals.h,v $
+  Module:    vtkSMProxyInternals.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
