@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMSelectionHelper.cxx,v $
+  Module:    vtkSMSelectionHelper.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -16,6 +16,7 @@
 
 #include "vtkClientServerStream.h"
 #include "vtkCollection.h"
+#include "vtkDataRepresentation.h"
 #include "vtkDoubleArray.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformationDoubleKey.h"
@@ -27,6 +28,7 @@
 #include "vtkProcessModule.h"
 #include "vtkPVSelectionInformation.h"
 #include "vtkSelection.h"
+#include "vtkSelectionNode.h"
 #include "vtkSelectionSerializer.h"
 #include "vtkSmartPointer.h"
 #include "vtkSMDoubleVectorProperty.h"
@@ -35,15 +37,17 @@
 #include "vtkSMIntVectorProperty.h"
 #include "vtkSMOutputPort.h"
 #include "vtkSMPropertyHelper.h"
+#include "vtkSMPropertyHelper.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkUnsignedIntArray.h"
+#include "vtkView.h"
 
 #include <vtkstd/vector>
+#include <vtkstd/map>
 #include <vtksys/ios/sstream>
 
 vtkStandardNewMacro(vtkSMSelectionHelper);
-vtkCxxRevisionMacro(vtkSMSelectionHelper, "$Revision: 1.18 $");
 
 //-----------------------------------------------------------------------------
 void vtkSMSelectionHelper::PrintSelf(ostream& os, vtkIndent indent)
@@ -71,98 +75,17 @@ void vtkSMSelectionHelper::SendSelection(vtkSelection* sel, vtkSMProxy* proxy)
     stream);
 }
 
-//-----------------------------------------------------------------------------
-void vtkSMSelectionHelper::ConvertSurfaceSelectionToVolumeSelection(
-  vtkIdType connectionID,
-  vtkSelection* input,
-  vtkSelection* output)
-{
-  vtkSMSelectionHelper::ConvertSurfaceSelectionToVolumeSelectionInternal(
-    connectionID, input, output, 0);
-}
-
-//-----------------------------------------------------------------------------
-// Don't think this method is used anymore.
-void vtkSMSelectionHelper::ConvertSurfaceSelectionToGlobalIDVolumeSelection(
-  vtkIdType connectionID,
-  vtkSelection* input, vtkSelection* output)
-{
-  vtkSMSelectionHelper::ConvertSurfaceSelectionToVolumeSelectionInternal(
-    connectionID, input, output, 1);
-}
-
-//-----------------------------------------------------------------------------
-void vtkSMSelectionHelper::ConvertSurfaceSelectionToVolumeSelectionInternal(
-  vtkIdType connectionID,
-  vtkSelection* input,
-  vtkSelection* output,
-  int global_ids)
-{
-  vtkSMProxyManager* pxm = vtkSMObject::GetProxyManager();
-  vtkProcessModule* processModule = vtkProcessModule::GetProcessModule();
-
-  // Convert the selection of geometry cells to surface cells of the actual
-  // data by:
-
-  // * First sending the selection to the server
-  vtkSMProxy* selectionP = pxm->NewProxy("selection_helpers", "Selection");
-  selectionP->SetServers(vtkProcessModule::DATA_SERVER);
-  selectionP->SetConnectionID(connectionID);
-  selectionP->UpdateVTKObjects();
-  vtkSMSelectionHelper::SendSelection(input, selectionP);
-
-  // * Then converting the selection using a helper
-  vtkSMProxy* volumeSelectionP = 
-    pxm->NewProxy("selection_helpers", "Selection");
-  volumeSelectionP->SetServers(vtkProcessModule::DATA_SERVER);
-  volumeSelectionP->SetConnectionID(connectionID);
-  volumeSelectionP->UpdateVTKObjects();
-  vtkClientServerStream stream;
-  vtkClientServerID converterID =
-    processModule->NewStreamObject("vtkSelectionConverter", stream);
-  stream << vtkClientServerStream::Invoke
-         << converterID 
-         << "Convert" 
-         << selectionP->GetID() 
-         << volumeSelectionP->GetID()
-         << global_ids
-         << vtkClientServerStream::End;
-  processModule->DeleteStreamObject(converterID, stream);
-  processModule->SendStream(connectionID, 
-                            vtkProcessModule::DATA_SERVER, 
-                            stream);
-
-  // * And finally gathering the information back
-  vtkPVSelectionInformation* selInfo = vtkPVSelectionInformation::New();
-  processModule->GatherInformation(connectionID,
-                                   vtkProcessModule::DATA_SERVER, 
-                                   selInfo, 
-                                   volumeSelectionP->GetID());
-
-  output->ShallowCopy(selInfo->GetSelection());
-
-  selInfo->Delete();
-  volumeSelectionP->Delete();
-  selectionP->Delete();
-}
-
 //-----------------------------------------------------------------------------
 vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
   vtkIdType connectionID, 
-  vtkSelection* selection,
+  vtkSelectionNode* selection,
   vtkSMProxy* selSource /*=NULL*/)
 {
-  if (!selection)
+  if (!selection || !selection->GetSelectionList())
     {
     return selSource;
     }
 
-  if (selection->GetNumberOfChildren()>0)
-    {
-    vtkGenericWarningMacro("Selection trees are not supported.");
-    return selSource;
-    }
-
   vtkSMProxy* originalSelSource = selSource;
 
   vtkInformation* selProperties = selection->GetProperties();
@@ -180,21 +103,21 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
     // ContentType is not defined. Empty selection.
     return selSource;
 
-  case vtkSelection::FRUSTUM:
+  case vtkSelectionNode::FRUSTUM:
     proxyname = "FrustumSelectionSource";
     break;
 
-  case vtkSelection::INDICES:
+  case vtkSelectionNode::INDICES:
     // we need to choose between IDSelectionSource,
     // CompositeDataIDSelectionSource and HierarchicalDataIDSelectionSource.
     proxyname = "IDSelectionSource";
-    if (selProperties->Has(vtkSelection::COMPOSITE_INDEX()))
+    if (selProperties->Has(vtkSelectionNode::COMPOSITE_INDEX()))
       {
       proxyname = "CompositeDataIDSelectionSource";
       use_composite = true;
       }
-    else if (selProperties->Has(vtkSelection::HIERARCHICAL_LEVEL()) && 
-       selProperties->Has(vtkSelection::HIERARCHICAL_INDEX()))
+    else if (selProperties->Has(vtkSelectionNode::HIERARCHICAL_LEVEL()) && 
+       selProperties->Has(vtkSelectionNode::HIERARCHICAL_INDEX()))
       {
       proxyname = "HierarchicalDataIDSelectionSource";
       use_hierarchical = true;
@@ -202,11 +125,11 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
       }
     break;
 
-  case vtkSelection::GLOBALIDS:
+  case vtkSelectionNode::GLOBALIDS:
     proxyname = "GlobalIDSelectionSource";
     break;
 
-  case vtkSelection::BLOCKS:
+  case vtkSelectionNode::BLOCKS:
     proxyname = "BlockSelectionSource";
     break;
 
@@ -234,28 +157,28 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
 
 
   // Set some common property values using the state of the vtkSelection.
-  if (selProperties->Has(vtkSelection::FIELD_TYPE()))
+  if (selProperties->Has(vtkSelectionNode::FIELD_TYPE()))
     {
     vtkSMIntVectorProperty* ivp = vtkSMIntVectorProperty::SafeDownCast(
       selSource->GetProperty("FieldType"));
-    ivp->SetElement(0, selProperties->Get(vtkSelection::FIELD_TYPE()));
+    ivp->SetElement(0, selProperties->Get(vtkSelectionNode::FIELD_TYPE()));
     }
 
-  if (selProperties->Has(vtkSelection::CONTAINING_CELLS()))
+  if (selProperties->Has(vtkSelectionNode::CONTAINING_CELLS()))
     {
     vtkSMIntVectorProperty* ivp = vtkSMIntVectorProperty::SafeDownCast(
       selSource->GetProperty("ContainingCells"));
-    ivp->SetElement(0, selProperties->Get(vtkSelection::CONTAINING_CELLS()));
+    ivp->SetElement(0, selProperties->Get(vtkSelectionNode::CONTAINING_CELLS()));
     }
 
-  if (selProperties->Has(vtkSelection::INVERSE()))
+  if (selProperties->Has(vtkSelectionNode::INVERSE()))
     {
     vtkSMIntVectorProperty* ivp = vtkSMIntVectorProperty::SafeDownCast(
       selSource->GetProperty("InsideOut"));
-    ivp->SetElement(0, selProperties->Get(vtkSelection::INVERSE()));
+    ivp->SetElement(0, selProperties->Get(vtkSelectionNode::INVERSE()));
     }
 
-  if (contentType == vtkSelection::FRUSTUM)
+  if (contentType == vtkSelectionNode::FRUSTUM)
     {
     // Set the selection ids, which is the frustum vertex.
     vtkSMDoubleVectorProperty *dvp = vtkSMDoubleVectorProperty::SafeDownCast(
@@ -265,7 +188,7 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
       selection->GetSelectionList());
     dvp->SetElements(verts->GetPointer(0));
     }
-  else if (contentType == vtkSelection::GLOBALIDS)
+  else if (contentType == vtkSelectionNode::GLOBALIDS)
     {
     vtkSMIdTypeVectorProperty* ids = vtkSMIdTypeVectorProperty::SafeDownCast(
       selSource->GetProperty("IDs"));
@@ -286,7 +209,7 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
         }
       }
     }
-  else if (contentType == vtkSelection::BLOCKS)
+  else if (contentType == vtkSelectionNode::BLOCKS)
     {
     vtkSMIdTypeVectorProperty* blocks = vtkSMIdTypeVectorProperty::SafeDownCast(
       selSource->GetProperty("Blocks"));
@@ -307,12 +230,12 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
         }
       }
     }
-  else if (contentType == vtkSelection::INDICES)
+  else if (contentType == vtkSelectionNode::INDICES)
     {
     vtkIdType procID = -1;
-    if (selProperties->Has(vtkSelection::PROCESS_ID()))
+    if (selProperties->Has(vtkSelectionNode::PROCESS_ID()))
       {
-      procID = selProperties->Get(vtkSelection::PROCESS_ID());
+      procID = selProperties->Get(vtkSelectionNode::PROCESS_ID());
       }
 
     // Add the selection proc ids and cell ids to the IDs property.
@@ -341,9 +264,9 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
       else if (use_composite)
         {
         vtkIdType composite_index = 0;
-        if (selProperties->Has(vtkSelection::COMPOSITE_INDEX()))
+        if (selProperties->Has(vtkSelectionNode::COMPOSITE_INDEX()))
           {
-          composite_index = selProperties->Get(vtkSelection::COMPOSITE_INDEX());
+          composite_index = selProperties->Get(vtkSelectionNode::COMPOSITE_INDEX());
           }
 
         ids->SetNumberOfElements(curValues+numIDs*3);
@@ -356,8 +279,8 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
         }
       else if (use_hierarchical)
         {
-        vtkIdType level = selProperties->Get(vtkSelection::HIERARCHICAL_LEVEL());
-        vtkIdType dsIndex = selProperties->Get(vtkSelection::HIERARCHICAL_INDEX());
+        vtkIdType level = selProperties->Get(vtkSelectionNode::HIERARCHICAL_LEVEL());
+        vtkIdType dsIndex = selProperties->Get(vtkSelectionNode::HIERARCHICAL_INDEX());
         ids->SetNumberOfElements(curValues+numIDs*3);
         for (vtkIdType cc=0; cc < numIDs; cc++)
           {
@@ -378,20 +301,12 @@ vtkSMProxy* vtkSMSelectionHelper::NewSelectionSourceFromSelection(
   vtkSelection* selection)
 {
   vtkSMProxy* selSource= 0;
-  if (selection->GetNumberOfChildren() == 0)
+  unsigned int numNodes = selection->GetNumberOfNodes(); 
+  for (unsigned int cc=0; cc < numNodes; cc++)
     {
+    vtkSelectionNode* node = selection->GetNode(cc);
     selSource = vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
-      connectionID, selection, NULL);
-    }
-  else
-    {
-    unsigned int numChildren = selection->GetNumberOfChildren(); 
-    for (unsigned int cc=0; cc < numChildren; cc++)
-      {
-      vtkSelection* child = selection->GetChild(cc);
-      selSource = vtkSMSelectionHelper::NewSelectionSourceFromSelectionInternal(
-        connectionID, child, selSource);
-      }
+      connectionID, node, selSource);
     }
   if (selSource)
     {
@@ -410,27 +325,27 @@ vtkSMProxy* vtkSMSelectionHelper::ConvertSelection(int outputType,
   const char* outproxyname = 0;
   switch (outputType)
     {
-  case vtkSelection::GLOBALIDS:
+  case vtkSelectionNode::GLOBALIDS:
     outproxyname = "GlobalIDSelectionSource";
     break;
 
-  case vtkSelection::FRUSTUM:
+  case vtkSelectionNode::FRUSTUM:
     outproxyname = "FrustumSelectionSource";
     break;
 
-  case vtkSelection::LOCATIONS:
+  case vtkSelectionNode::LOCATIONS:
     outproxyname = "LocationSelectionSource";
     break;
 
-  case vtkSelection::THRESHOLDS:
+  case vtkSelectionNode::THRESHOLDS:
     outproxyname = "ThresholdSelectionSource";
     break;
 
-  case vtkSelection::BLOCKS:
+  case vtkSelectionNode::BLOCKS:
     outproxyname = "BlockSelectionSource";
     break;
 
-  case vtkSelection::INDICES:
+  case vtkSelectionNode::INDICES:
       {
       const char* dataName = 
         dataSource->GetOutputPort(dataPort)->GetDataClassName();
@@ -461,7 +376,7 @@ vtkSMProxy* vtkSMSelectionHelper::ConvertSelection(int outputType,
     return selectionSourceProxy;
     }
 
-  if (outputType == vtkSelection::INDICES && selectionSourceProxy)
+  if (outputType == vtkSelectionNode::INDICES && selectionSourceProxy)
     {
     vtkSMVectorProperty* ids = 0;
     ids = vtkSMVectorProperty::SafeDownCast(
@@ -474,10 +389,10 @@ vtkSMProxy* vtkSMSelectionHelper::ConvertSelection(int outputType,
       // convert from *anything* to indices.
       return vtkSMSelectionHelper::ConvertInternal(
         vtkSMSourceProxy::SafeDownCast(selectionSourceProxy),
-        dataSource, dataPort, vtkSelection::INDICES);
+        dataSource, dataPort, vtkSelectionNode::INDICES);
       }
     }
-  else if (outputType == vtkSelection::GLOBALIDS && selectionSourceProxy)
+  else if (outputType == vtkSelectionNode::GLOBALIDS && selectionSourceProxy)
     {
     vtkSMVectorProperty* ids = vtkSMVectorProperty::SafeDownCast(
       selectionSourceProxy->GetProperty("IDs"));
@@ -488,17 +403,17 @@ vtkSMProxy* vtkSMSelectionHelper::ConvertSelection(int outputType,
       // convert from *anything* to global IDs.
       return vtkSMSelectionHelper::ConvertInternal(
         vtkSMSourceProxy::SafeDownCast(selectionSourceProxy),
-        dataSource, dataPort, vtkSelection::GLOBALIDS);
+        dataSource, dataPort, vtkSelectionNode::GLOBALIDS);
       }
     }
-  else if (outputType == vtkSelection::BLOCKS && selectionSourceProxy &&
+  else if (outputType == vtkSelectionNode::BLOCKS && selectionSourceProxy &&
     (strcmp(inproxyname, "GlobalIDSelectionSource") == 0 ||
      strcmp(inproxyname, "HierarchicalDataIDSelectionSource") == 0||
      strcmp(inproxyname, "CompositeDataIDSelectionSource")==0))
     {
     return vtkSMSelectionHelper::ConvertInternal(
       vtkSMSourceProxy::SafeDownCast(selectionSourceProxy),
-      dataSource, dataPort, vtkSelection::BLOCKS);
+      dataSource, dataPort, vtkSelectionNode::BLOCKS);
     }
 
   // Conversion not possible, so simply create a new proxy of the requested
@@ -588,18 +503,18 @@ vtkSMProxy* vtkSMSelectionHelper::ConvertInternal(
 }
 
 //-----------------------------------------------------------------------------
-bool vtkSMSelectionHelper::MergeSelection(vtkSMSourceProxy* output, 
-  vtkSMSourceProxy* input)
+bool vtkSMSelectionHelper::MergeSelection(
+  vtkSMSourceProxy* output, vtkSMSourceProxy* input,
+  vtkSMSourceProxy* dataSource, int dataPort)
 {
-  // Currently only index based selections i.e. ids, global ids based selections
-  // are mergeable and that too only is input and output are identical in all
-  // respects (except the indices ofcourse).
-  if (!output || !input || 
-    strcmp(output->GetXMLName(), input->GetXMLName()) != 0)
+  if (!output || !input)
     {
     return false;
     }
 
+  // Currently only index based selections i.e. ids, global ids based selections
+  // are mergeable and that too only is input and output are identical in all
+  // respects (except the indices ofcourse).
   if (vtkSMPropertyHelper(output, "FieldType").GetAsInt() != 
     vtkSMPropertyHelper(input, "FieldType").GetAsInt())
     {
@@ -618,6 +533,45 @@ bool vtkSMSelectionHelper::MergeSelection(vtkSMSourceProxy* output,
     return false;
     }
 
+  vtkSmartPointer<vtkSMSourceProxy> tempInput;
+  if (strcmp(output->GetXMLName(), input->GetXMLName()) != 0)
+    {
+    // before totally giving up, check to see if the input selection can be
+    // converted to the same type as the output.
+    vtkstd::string inputType = input->GetXMLName();
+    vtkstd::string outputType = output->GetXMLName();
+
+    if (
+      (inputType == "GlobalIDSelectionSource" &&
+       outputType == "IDSelectionSource") || 
+      (inputType == "GlobalIDSelectionSource" &&
+       outputType == "CompositeDataIDSelectionSource") ||
+      (inputType == "IDSelectionSource" &&
+       outputType == "GlobalIDSelectionSource") ||
+      (inputType == "CompositeDataIDSelectionSource" &&
+       outputType == "GlobalIDSelectionSource"))
+      {
+      int type = vtkSelectionNode::INDICES;
+      if (outputType == "GlobalIDSelectionSource")
+        {
+        type = vtkSelectionNode::GLOBALIDS;
+        }
+
+      // Conversion is possible!.
+      tempInput.TakeReference(vtkSMSourceProxy::SafeDownCast(
+          vtkSMSelectionHelper::ConvertSelection(type,
+            input,
+            dataSource,
+            dataPort)));
+      input = tempInput;
+      }
+    else
+      {
+      return false;
+      }
+    }
+
+
   // mergs IDs or Blocks properties.
   if (output->GetProperty("IDs") && input->GetProperty("IDs"))
     {
@@ -637,6 +591,7 @@ bool vtkSMSelectionHelper::MergeSelection(vtkSMSourceProxy* output,
       ids.push_back(outputIDs.GetAsIdType(cc));
       }
     outputIDs.Set(&ids[0], static_cast<unsigned int>(ids.size()));
+    output->UpdateVTKObjects();
     return true;
     }
 
@@ -658,8 +613,98 @@ bool vtkSMSelectionHelper::MergeSelection(vtkSMSourceProxy* output,
       ids.push_back(outputIDs.GetAsIdType(cc));
       }
     outputIDs.Set(&ids[0], static_cast<unsigned int>(ids.size()));
+    output->UpdateVTKObjects();
     return true;
     }
 
   return false;
 }
+
+
+namespace
+{
+  // Splits \c selection into a collection of selections based on the
+  // SOURCE_ID().
+  void vtkSplitSelection(vtkSelection* selection,
+    vtkstd::map<int, vtkSmartPointer<vtkSelection> >& map_of_selections)
+    {
+    for (unsigned int cc=0; cc < selection->GetNumberOfNodes(); cc++)
+      {
+      vtkSelectionNode* node = selection->GetNode(cc);
+      if (node && node->GetProperties()->Has(vtkSelectionNode::SOURCE_ID()))
+        {
+        int source_id =
+          node->GetProperties()->Get(vtkSelectionNode::SOURCE_ID());
+        vtkSelection* sel = map_of_selections[source_id];
+        if (!sel)
+          {
+          sel = vtkSelection::New();
+          map_of_selections[source_id] = sel;
+          sel->FastDelete();
+          }
+        sel->AddNode(node);
+        }
+      }
+    }
+
+  vtkSMProxy* vtkLocateRepresentation(vtkSMProxy* viewProxy, int id)
+    {
+    vtkView* view = vtkView::SafeDownCast(viewProxy->GetClientSideObject());
+    if (!view)
+      {
+      vtkGenericWarningMacro("View proxy must be a proxy for vtkView.");
+      return NULL;
+      }
+
+    vtkDataRepresentation* repr = view->GetRepresentation(id);
+    // now locate the proxy for this repr.
+    vtkSMPropertyHelper helper(viewProxy, "Representations");
+    for (unsigned int cc=0; cc < helper.GetNumberOfElements(); cc++)
+      {
+      vtkSMProxy* reprProxy = helper.GetAsProxy(cc);
+      if (reprProxy && reprProxy->GetClientSideObject() == repr)
+        {
+        return reprProxy;
+        }
+      }
+    return NULL;
+    }
+};
+
+//----------------------------------------------------------------------------
+void vtkSMSelectionHelper::NewSelectionSourcesFromSelection(
+  vtkSelection* selection, vtkSMProxy* view,
+  vtkCollection* selSources, vtkCollection* selRepresentations)
+{
+  // Now selection can comprise of selection nodes for more than on
+  // representation that was selected. We now need to create selection source
+  // proxies for each representation that was selected separately.
+
+  // This relies on SOURCE_ID() defined on the selection nodes to locate the
+  // representation proxy for the representation that was selected.
+
+  vtkstd::map<int, vtkSmartPointer<vtkSelection> > selections;
+  vtkSplitSelection(selection, selections);
+
+  vtkstd::map<int, vtkSmartPointer<vtkSelection> >::iterator iter;
+  for (iter = selections.begin(); iter != selections.end(); ++iter)
+    {
+    vtkSMProxy* reprProxy = vtkLocateRepresentation(view, iter->first);
+    if (!reprProxy)
+      {
+      continue;
+      }
+
+    vtkSMProxy* selSource =
+      vtkSMSelectionHelper::NewSelectionSourceFromSelection(
+        view->GetConnectionID(), iter->second.GetPointer());
+    if (!selSource)
+      {
+      continue;
+      }
+    // locate representation proxy for this
+    selSources->AddItem(selSource);
+    selRepresentations->AddItem(reprProxy);
+    selSource->FastDelete();
+    }
+}
