@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMStateVersionController.h,v $
+  Module:    vtkSMStateVersionController.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,7 +26,7 @@ class VTK_EXPORT vtkSMStateVersionController : public vtkSMStateVersionControlle
 {
 public:
   static vtkSMStateVersionController* New();
-  vtkTypeRevisionMacro(vtkSMStateVersionController, vtkSMStateVersionControllerBase);
+  vtkTypeMacro(vtkSMStateVersionController, vtkSMStateVersionControllerBase);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -39,10 +39,14 @@ public:
 
   bool Process_3_0_To_3_2(vtkPVXMLElement* root);
   bool Process_3_2_To_3_4(vtkPVXMLElement* root);
+  bool Process_3_4_to_3_6(vtkPVXMLElement* root);
+  bool Process_3_6_to_3_8(vtkPVXMLElement* root);
+  bool Process_3_8_to_3_10(vtkPVXMLElement* root);
 
 //BTX
   bool ConvertViewModulesToViews(vtkPVXMLElement* parent);
   bool ConvertLegacyReader(vtkPVXMLElement* parent);
+  bool ConvertStreamTracer(vtkPVXMLElement* parent);
   bool ConvertPVAnimationSceneToAnimationScene(vtkPVXMLElement* parent);
 protected:
   vtkSMStateVersionController();
