@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMStringListDomain.cxx,v $
+  Module:    vtkSMStringListDomain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -23,7 +23,6 @@
 #include "vtkStdString.h"
 
 vtkStandardNewMacro(vtkSMStringListDomain);
-vtkCxxRevisionMacro(vtkSMStringListDomain, "$Revision: 1.22 $");
 
 struct vtkSMStringListDomainInternals
 {
@@ -63,23 +62,26 @@ unsigned int vtkSMStringListDomain::AddString(const char* string)
 }
 
 //---------------------------------------------------------------------------
-void vtkSMStringListDomain::RemoveString(const char* string)
+int vtkSMStringListDomain::RemoveString(const char* string)
 {
   if (!string)
     {
-    return;
+    return -1;
     }
+  int index=0;
   vtkstd::vector<vtkStdString>::iterator iter =
     this->SLInternals->Strings.begin();
-  for(; iter != this->SLInternals->Strings.end(); iter++)
+  for(; iter != this->SLInternals->Strings.end(); iter++, index++)
     {
     if (strcmp(string, iter->c_str()) == 0)
       {
       this->SLInternals->Strings.erase(iter);
       this->Modified();
-      break;
+      return index;
       }
     }
+
+  return -1;
 }
 
 //---------------------------------------------------------------------------
@@ -149,9 +151,22 @@ void vtkSMStringListDomain::Update(vtkSMProperty* prop)
     {
     this->RemoveAllStrings();
     unsigned int numStrings = svp->GetNumberOfElements();
-    for (unsigned int i=0; i<numStrings; i++)
+    if (svp->GetNumberOfElementsPerCommand()==2)
       {
-      this->AddString(svp->GetElement(i));
+      // if the information property is something like a array-status-info
+      // property on readers where the first value is the array name while the
+      // second is it's status.
+      for (unsigned int i=0; i<numStrings; i+=2)
+        {
+        this->AddString(svp->GetElement(i));
+        }
+      }
+    else
+      {
+      for (unsigned int i=0; i<numStrings; i++)
+        {
+        this->AddString(svp->GetElement(i));
+        }
       }
     this->InvokeModified();
     }
@@ -208,7 +223,7 @@ void vtkSMStringListDomain::ChildSaveState(vtkPVXMLElement* domainElement)
 
 //---------------------------------------------------------------------------
 int vtkSMStringListDomain::LoadState(vtkPVXMLElement* domainElement, 
-    vtkSMStateLoaderBase* loader)
+    vtkSMProxyLocator* loader)
 {
   this->Superclass::LoadState(domainElement, loader);
   
