@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMStringVectorProperty.h,v $
+  Module:    vtkSMStringVectorProperty.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -32,11 +32,13 @@
 struct vtkSMStringVectorPropertyInternals;
 //ETX
 
+class vtkStringList;
+
 class VTK_EXPORT vtkSMStringVectorProperty : public vtkSMVectorProperty
 {
 public:
   static vtkSMStringVectorProperty* New();
-  vtkTypeRevisionMacro(vtkSMStringVectorProperty, vtkSMVectorProperty);
+  vtkTypeMacro(vtkSMStringVectorProperty, vtkSMVectorProperty);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -58,6 +60,14 @@ public:
   // Sets multiple elements. The size of the property is changed to match count.
   int SetElements(unsigned int count, const char* values[]);
 
+  // Description:
+  // Sets multiple elements. The size of the property is changed to match count.
+  int SetElements(vtkStringList* newvalue);
+
+  // Description:
+  // Fills up the vtkStringList instance with the current value.
+  void GetElements(vtkStringList* list);
+
   // Description:
   // Returns the value of 1 element.
   const char* GetElement(unsigned int idx);
@@ -133,7 +143,7 @@ protected:
 
   // Description:
   // Updates state from an XML element. Returns 0 on failure.
-  virtual int LoadState(vtkPVXMLElement* element, vtkSMStateLoaderBase* loader,
+  virtual int LoadState(vtkPVXMLElement* element, vtkSMProxyLocator* loader,
     int loadLastPushedValues=0);
 
   virtual void ChildSaveState(vtkPVXMLElement* parent, int saveLastPushedValues);
