@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMTextWidgetRepresentationProxy.cxx,v $
+  Module:    vtkSMTextWidgetRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,14 +22,12 @@
 //----------------------------------------------------------------------------
 
 vtkStandardNewMacro(vtkSMTextWidgetRepresentationProxy);
-vtkCxxRevisionMacro(vtkSMTextWidgetRepresentationProxy, "$Revision: 1.2 $");
 
 //----------------------------------------------------------------------------
 vtkSMTextWidgetRepresentationProxy::vtkSMTextWidgetRepresentationProxy()
 {
   this->TextActorProxy = 0;
   this->TextPropertyProxy = 0;
-  this->ViewProxy = 0;
 }
 
 //----------------------------------------------------------------------------
@@ -37,31 +35,6 @@ vtkSMTextWidgetRepresentationProxy::~vtkSMTextWidgetRepresentationProxy()
 {
   this->TextActorProxy = 0;
   this->TextPropertyProxy = 0;
-  this->ViewProxy = 0;
-}
-
-//----------------------------------------------------------------------------
-bool vtkSMTextWidgetRepresentationProxy::AddToView(vtkSMViewProxy* view)
-{
-  if(!this->Superclass::AddToView(view))
-    {
-    return false;
-    }
-  
-  this->ViewProxy = view;
-  return true;
-}
-
-//----------------------------------------------------------------------------
-bool vtkSMTextWidgetRepresentationProxy::RemoveFromView(vtkSMViewProxy* view)
-{
-  if(!this->Superclass::RemoveFromView(view))
-    {
-    return false;
-    }
-  
-  this->ViewProxy = 0;
-  return true;
 }
 
 //----------------------------------------------------------------------------
