@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMVectorProperty.cxx,v $
+  Module:    vtkSMVectorProperty.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -16,7 +16,6 @@
 
 #include "vtkPVXMLElement.h"
 
-vtkCxxRevisionMacro(vtkSMVectorProperty, "$Revision: 1.12 $");
 
 //---------------------------------------------------------------------------
 vtkSMVectorProperty::vtkSMVectorProperty()
@@ -26,17 +25,19 @@ vtkSMVectorProperty::vtkSMVectorProperty()
   this->UseIndex = 0;
   this->CleanCommand = 0;
   this->IsInternal = 0;
+  this->SetNumberCommand = 0;
 }
 
 //---------------------------------------------------------------------------
 vtkSMVectorProperty::~vtkSMVectorProperty()
 {
   this->SetCleanCommand(0);
+  this->SetSetNumberCommand(0);
 }
 
 //---------------------------------------------------------------------------
 int vtkSMVectorProperty::LoadState(vtkPVXMLElement* element,
-  vtkSMStateLoaderBase* loader, int loadLastPushedValues/*=0*/)
+  vtkSMProxyLocator* loader, int loadLastPushedValues/*=0*/)
 {
   this->Superclass::LoadState(element, loader, loadLastPushedValues);
 
@@ -83,6 +84,12 @@ int vtkSMVectorProperty::ReadXMLAttributes(vtkSMProxy* parent,
     return retVal;
     }
 
+  const char* numCommand = element->GetAttribute("set_number_command");
+  if (numCommand)
+    {
+    this->SetSetNumberCommand(numCommand);
+    }
+
   int use_index;
   retVal = element->GetScalarAttribute("use_index", &use_index);
   if(retVal) 
@@ -93,7 +100,8 @@ int vtkSMVectorProperty::ReadXMLAttributes(vtkSMProxy* parent,
   retVal = element->GetScalarAttribute("repeat_command", &repeat_command);
   if(retVal) 
     { 
-    this->SetRepeatCommand(repeat_command); 
+    this->SetRepeatCommand(repeat_command);
+    this->Repeatable = repeat_command;
     }
   int numElsPerCommand;
   retVal = 
@@ -137,4 +145,6 @@ void vtkSMVectorProperty::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "CleanCommand: " << 
     (this->CleanCommand? this->CleanCommand : "(null)" ) << endl;
   os << indent << "UseIndex: " << this->UseIndex << endl;
+  os << indent << "SetNumberCommand: " <<
+    (this->SetNumberCommand? this->SetNumberCommand : "(null)") << endl;
 }
