@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   ParaView
-Module:    $RCSfile: vtkSMWriterProxy.h,v $
+Module:    vtkSMWriterProxy.h
 
 Copyright (c) Kitware, Inc.
 All rights reserved.
@@ -16,6 +16,9 @@ PURPOSE.  See the above copyright notice for more information.
 // .SECTION Description
 // vtkSMWriterProxy manages VTK writers that are created on a server using
 // the proxy pattern.
+// vtkSMWriterProxy also provides support for meta-writers. i.e. if the proxy
+// has a subproxy name "Writer" that this proxy represents a meta-writer which
+// uses the given writer as the writer to write each component.
 
 #ifndef __vtkSMWriterProxy_h
 #define __vtkSMWriterProxy_h
@@ -26,7 +29,7 @@ class VTK_EXPORT vtkSMWriterProxy : public vtkSMSourceProxy
 {
 public:
   static vtkSMWriterProxy* New();
-  vtkTypeRevisionMacro(vtkSMWriterProxy, vtkSMSourceProxy);
+  vtkTypeMacro(vtkSMWriterProxy, vtkSMSourceProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -62,9 +65,21 @@ public:
   vtkGetMacro(ParallelOnly, int);
   vtkSetMacro(ParallelOnly, int);
 
+  virtual void AddInput(unsigned int inputPort,
+                        vtkSMSourceProxy* input, 
+                        unsigned int outputPort,
+                        const char* method);
+  virtual void AddInput(vtkSMSourceProxy* input,
+                        const char* method)
+  {
+    this->AddInput(0, input, 0, method);
+  }
+
 protected:
   vtkSMWriterProxy();
-  ~vtkSMWriterProxy() {}
+  ~vtkSMWriterProxy();
+
+  virtual void CreateVTKObjects();
 
   // Description:
   // Read attributes from an XML element.
@@ -73,6 +88,13 @@ protected:
   int ErrorCode;
   int SupportsParallel;
   int ParallelOnly;
+
+  // This is the name of the method used to set the file name on the
+  // internal reader. See vtkFileSeriesReader for details.
+  vtkSetStringMacro(FileNameMethod);
+  vtkGetStringMacro(FileNameMethod);
+
+  char* FileNameMethod;
 private:
   vtkSMWriterProxy(const vtkSMWriterProxy&); // Not implemented
   void operator=(const vtkSMWriterProxy&); // Not implemented
