@@ -1,30 +1,31 @@
 /* -*- c -*- *****************************************************************
-** $Id: SimpleExample.c,v 1.6 2005-12-16 19:02:08 kmorel Exp $
-**
 ** Copyright (C) 2003 Sandia Corporation
-** Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
-** license for use of this work by or on behalf of the U.S. Government.
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that this Notice and any statement
-** of authorship are reproduced on all copies.
+** Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
+** the U.S. Government retains certain rights in this software.
 **
-** This test provides a simple example of using ICE-T to perform parallel
+** This source code is released under the New BSD License.
+**
+** This test provides a simple example of using IceT to perform parallel
 ** rendering.
 *****************************************************************************/
 
-#include <GL/ice-t.h>
+#include <IceTGL.h>
 #include "test-util.h"
 #include "test_codes.h"
-#include "glwin.h"
 
-#include <GL/gl.h>
-#include <GL/glu.h>
+#ifdef __APPLE__
+#  include <OpenGL/gl.h>
+#  include <OpenGL/glu.h>
+#else
+#  include <GL/gl.h>
+#  include <GL/glu.h>
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
 
-GLint rank;
-GLint num_proc;
+IceTInt rank;
+IceTInt num_proc;
 
 static void draw(void)
 {
@@ -43,7 +44,7 @@ static void draw(void)
    * to what is was when the function is called.  Remember, the draw
    * function may be called multiple times and transformations may be
    * commuted.  Also, the bounds of the drawn geometry must be correctly
-   * transformed before given to ICE-T.  ICE-T has no way of knowing about
+   * transformed before given to IceT.  IceT has no way of knowing about
    * transformations done here.  It is an error to change the projection
    * matrix in the draw function. */
     glPushMatrix();
@@ -53,16 +54,12 @@ static void draw(void)
     glPopMatrix();
 }
 
-int SimpleExample(int argc, char * argv[])
+static int SimpleExampleRun()
 {
     float angle;
 
-    /* To remove warning */
-    (void)argc;
-    (void)argv;
-
   /* Normally, the first thing that you do is set up your communication and
-   * then create at least one ICE-T context.  This has already been done in
+   * then create at least one IceT context.  This has already been done in
    * the calling function (i.e. icetTests_mpi.c).  See the init_mpi_comm in
    * mpi_comm.h for an example.
    */
@@ -79,14 +76,14 @@ int SimpleExample(int argc, char * argv[])
    * color blending. */
     glClearColor(0.2f, 0.5f, 0.1f, 1.0f);
 
-  /* Give ICE-T a function that will issue the OpenGL drawing commands. */
-    icetDrawFunc(draw);
+  /* Give IceT a function that will issue the OpenGL drawing commands. */
+    icetGLDrawCallback(draw);
 
-  /* Give ICE-T the bounds of the polygons that will be drawn.  Note that
+  /* Give IceT the bounds of the polygons that will be drawn.  Note that
    * we must take into account any transformation that happens within the
-   * draw function (but ICE-T will take care of any transformation that
+   * draw function (but IceT will take care of any transformation that
    * happens before icetDrawFrame). */
-    icetBoundingBoxf(-0.5f+rank, 0.5f+rank, -0.5, 0.5, -0.5, 0.5);
+    icetBoundingBoxd(-0.5+rank, 0.5+rank, -0.5, 0.5, -0.5, 0.5);
 
   /* Set up the tiled display.  Normally, the display will be fixed for a
    * given installation, but since this is a demo, we give two specific
@@ -115,13 +112,17 @@ int SimpleExample(int argc, char * argv[])
        * on top of or away from each other.
        */
         icetResetTiles();
-        icetAddTile(0,           SCREEN_HEIGHT, SCREEN_WIDTH, SCREEN_HEIGHT, 0);
-        icetAddTile(SCREEN_WIDTH,SCREEN_HEIGHT, SCREEN_WIDTH, SCREEN_HEIGHT, 1);
-        icetAddTile(0,           0,             SCREEN_WIDTH, SCREEN_HEIGHT, 2);
-        icetAddTile(SCREEN_WIDTH,0,             SCREEN_WIDTH, SCREEN_HEIGHT, 3);
+        icetAddTile(0, (IceTInt)SCREEN_HEIGHT, SCREEN_WIDTH, SCREEN_HEIGHT, 0);
+        icetAddTile((IceTInt)SCREEN_WIDTH,
+                    (IceTInt)SCREEN_HEIGHT,
+                    SCREEN_WIDTH,
+                    SCREEN_HEIGHT,
+                    1);
+        icetAddTile(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT, 2);
+        icetAddTile((IceTInt)SCREEN_WIDTH, 0, SCREEN_WIDTH, SCREEN_HEIGHT, 3);
     }
 
-  /* Tell ICE-T what strategy to use.  The REDUCE strategy is an all-around
+  /* Tell IceT what strategy to use.  The REDUCE strategy is an all-around
    * good performer. */
     icetStrategy(ICET_STRATEGY_REDUCE);
 
@@ -139,36 +140,44 @@ int SimpleExample(int argc, char * argv[])
         color[0] = (float)(rank%2);
         color[1] = (float)((rank/2)%2);
         color[2] = (float)((rank/4)%2);
-        color[3] = 1.0;
+        color[3] = 1.0f;
         glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, color);
     }
 
   /* Here is an example of an animation loop. */
     for (angle = 0; angle < 360; angle += 10) {
-      /* We can set up a modelview matrix here and ICE-T will factor this
+      /* We can set up a modelview matrix here and IceT will factor this
        * in determining the screen projection of the geometry.  Note that
-       * there is further transformation in the draw function that ICE-T
+       * there is further transformation in the draw function that IceT
        * cannot take into account.  That transformation is handled in the
        * application by deforming the bounds before giving them to
-       * ICE-T. */
+       * IceT. */
         glMatrixMode(GL_MODELVIEW);
         glLoadIdentity();
-        glRotatef(angle, 0.0, 1.0, 0.0);
-        glScalef(1.0f/num_proc, 1.0, 1.0);
-        glTranslatef(-(num_proc-1)/2.0f, 0.0, 0.0);
+        glRotated(angle, 0.0, 1.0, 0.0);
+        glScaled(1.0f/num_proc, 1.0, 1.0);
+        glTranslated(-(num_proc-1)/2.0, 0.0, 0.0);
 
       /* Instead of calling draw() directly, call it indirectly through
-       * icetDrawFrame().  ICE-T will automatically handle image
+       * icetDrawFrame().  IceT will automatically handle image
        * compositing. */
-        icetDrawFrame();
+        icetGLDrawFrame();
 
-      /* For obvious reasons, ICE-T should be run in double-buffered frame
+      /* For obvious reasons, IceT should be run in double-buffered frame
        * mode.  After calling icetDrawFrame, the application should do a
        * synchronize (a barrier is often about as good as you can do) and
        * then a swap buffers. */
         swap_buffers();
     }
 
-    finalize_test(TEST_PASSED);
     return TEST_PASSED;
 }
+
+int SimpleExample(int argc, char * argv[])
+{
+    /* To remove warning */
+    (void)argc;
+    (void)argv;
+
+    return run_test(SimpleExampleRun);
+}
