@@ -42,6 +42,7 @@ public:
 //----------------------------------------------------------------------------
 vtkClientServerInterpreter::vtkClientServerInterpreter()
 {
+  this->NextAvailableId = 0;
   this->Internal = new vtkClientServerInterpreterInternals;
   this->LastResultMessage = new vtkClientServerStream(this);
   this->LogStream = 0;
@@ -899,3 +900,8 @@ void vtkClientServerInterpreter::ClearLastResult()
 {
   this->LastResultMessage->Reset();
 }
+//----------------------------------------------------------------------------
+vtkClientServerID vtkClientServerInterpreter::GetNextAvailableId()
+{
+  return vtkClientServerID(++this->NextAvailableId);
+}
