@@ -116,10 +116,13 @@ def OpenDataFile(filename, **extraArgs):
     if  reader_factor.GetNumberOfRegisteredPrototypes() == 0:
       reader_factor.RegisterPrototypes("sources")
     cid = servermanager.ActiveConnection.ID
-    if not reader_factor.TestFileReadability(filename, cid):
-        raise RuntimeError, "File not readable: %s " % filename
-    if not reader_factor.CanReadFile(filename, cid):
-        raise RuntimeError, "File not readable. No reader found for '%s' " % filename
+    first_file = filename
+    if type(filename) == list:
+        first_file = filename[0]
+    if not reader_factor.TestFileReadability(first_file, cid):
+        raise RuntimeError, "File not readable: %s " % first_file
+    if not reader_factor.CanReadFile(first_file, cid):
+        raise RuntimeError, "File not readable. No reader found for '%s' " % first_file
     prototype = servermanager.ProxyManager().GetPrototypeProxy(
       reader_factor.GetReaderGroup(), reader_factor.GetReaderName())
     xml_name = paraview.make_name_valid(prototype.GetXMLLabel())
@@ -129,6 +132,23 @@ def OpenDataFile(filename, **extraArgs):
       reader = globals()[xml_name](FileName=filename, **extraArgs)
     return reader
 
+def CreateWriter(filename, proxy=None, **extraArgs):
+    """Creates a writer that can write the data produced by the source proxy in
+       the given file format (identified by the extension). If no source is
+       provided, then the active source is used. This doesn't actually write the
+       data, it simply creates the writer and returns it."""
+    if not filename:
+       raise RuntimeError, "filename must be specified"
+    writer_factory = servermanager.ProxyManager().GetWriterFactory()
+    if writer_factory.GetNumberOfRegisteredPrototypes() == 0:
+        writer_factory.RegisterPrototypes("writers")
+    if not proxy:
+        proxy = GetActiveSource()
+    if not proxy:
+        raise RuntimeError, "Could not locate source to write"
+    writer_proxy = writer_factory.CreateWriter(filename, proxy.SMProxy, proxy.Port)
+    return servermanager._getPyProxy(writer_proxy)
+
 def GetRenderView():
     "Returns the active view if there is one. Else creates and returns a new view."
     view = active_objects.view
@@ -347,7 +367,8 @@ def Delete(proxy=None):
     servermanager.UnRegister(proxy)
     
     # If this is a representation, remove it from all views.
-    if proxy.SMProxy.IsA("vtkSMRepresentationProxy"):
+    if proxy.SMProxy.IsA("vtkSMRepresentationProxy") or \
+        proxy.SMProxy.IsA("vtkSMNewWidgetRepresentationProxy"):
         for view in GetRenderViews():
             view.Representations.remove(proxy)
     # If this is a source, remove the representation iff it has no consumers
@@ -654,12 +675,48 @@ def GetAnimationScene():
         raise servermanager.MissingProxy, "Could not locate global AnimationScene."
     return scene
 
+def WriteAnimation(filename):
+    """Helper to automate saving an animation."""
+    scene = GetAnimationScene()
+    iw = servermanager.vtkSMAnimationSceneImageWriter()
+    iw.SetAnimationScene(scene.SMProxy)
+    iw.SetFileName(filename)
+    iw.Save()
+
+def _GetRepresentationAnimationHelper(sourceproxy):
+    """Internal method that returns the representation animation helper for a
+       source proxy. It creates a new one if none exists."""
+    # ascertain that proxy is a source proxy
+    if not sourceproxy in GetSources().values():
+        return None
+    for proxy in servermanager.ProxyManager():
+        if proxy.GetXMLName() == "RepresentationAnimationHelper" and\
+           proxy.GetProperty("Source").IsProxyAdded(sourceproxy.SMProxy):
+             return proxy
+    # create a new helper
+    proxy = servermanager.misc.RepresentationAnimationHelper(
+      Source=sourceproxy)
+    servermanager.ProxyManager().RegisterProxy(
+      "pq_helper_proxies.%s" % sourceproxy.GetSelfIDAsString(),
+      "RepresentationAnimationHelper", proxy)
+    return proxy
+
 def GetAnimationTrack(propertyname_or_property, index=None, proxy=None):
     """Returns an animation cue for the property. If one doesn't exist then a
     new one will be created.
     Typical usage:
         track = GetAnimationTrack("Center", 0, sphere) or
-        track = GetAnimationTrack(sphere.GetProperty("Radius"))
+        track = GetAnimationTrack(sphere.GetProperty("Radius")) or
+
+        # this returns the track to animate visibility of the active source in
+        # all views.
+        track = GetAnimationTrack("Visibility")
+
+     For animating properties on implicit planes etc., use the following
+     signatures:
+        track = GetAnimationTrack(slice.SliceType.GetProperty("Origin"), 0) or
+        track = GetAnimationTrack("Origin", 0, slice.SliceType)
+
     """
     if not proxy:
         proxy = GetActiveSource()
@@ -667,26 +724,35 @@ def GetAnimationTrack(propertyname_or_property, index=None, proxy=None):
         raise TypeError, "proxy must be a servermanager.Proxy instance"
     if isinstance(propertyname_or_property, str):
         propertyname = propertyname_or_property
-        prop = proxy.GetProperty(propertyname)
-    elif isinstance(propertyname, servermanager.Property):
+    elif isinstance(propertyname_or_property, servermanager.Property):
         prop = propertyname_or_property
         propertyname = prop.Name
+        proxy = prop.Proxy
     else:
         raise TypeError, "propertyname_or_property must be a string or servermanager.Property"
 
+    # To handle the case where the property is actually a "display" property, in
+    # which case we are actually animating the "RepresentationAnimationHelper"
+    # associated with the source.
+    if propertyname in ["Visibility", "Opacity"]:
+        proxy = _GetRepresentationAnimationHelper(proxy)
+    if not proxy or not proxy.GetProperty(propertyname):
+        raise AttributeError, "Failed to locate property %s" % propertyname
+
     scene = GetAnimationScene()
     for cue in scene.Cues:
         try:
-            if cue.AnimatedProxy == prop.Proxy and\
-               cue.AnimatedPropertyName == prop.Name:
+            if cue.AnimatedProxy == proxy and\
+               cue.AnimatedPropertyName == propertyname:
                 if index == None or index == cue.AnimatedElement:
                     return cue
         except AttributeError:
             pass
+
     # matching animation track wasn't found, create a new one.
     cue = KeyFrameAnimationCue()
-    cue.AnimatedProxy = prop.Proxy
-    cue.AnimatedPropertyName = prop.Name
+    cue.AnimatedProxy = proxy
+    cue.AnimatedPropertyName = propertyname
     if index != None:
         cue.AnimatedElement = index
     scene.Cues.append(cue)
