@@ -61,7 +61,7 @@ static void vtkGetDims(int exts[6], int dims[3])
 
 //----------------------------------------------------------------------------
 vtkXdmfHeavyData::vtkXdmfHeavyData(vtkXdmfDomain* domain,
-  vtkXdmfReader* reader)
+  vtkAlgorithm* reader)
 {
   this->Reader = reader;
   this->Piece = 0;
@@ -92,17 +92,17 @@ vtkDataObject* vtkXdmfHeavyData::ReadData()
   bool distribute_leaf_nodes = this->NumberOfPieces > 1;
   XdmfInt32 numChildren = this->Domain->GetNumberOfGrids();
   int number_of_leaf_nodes = 0;
-  
+
   vtkMultiBlockDataSet* mb = vtkMultiBlockDataSet::New();
   mb->SetNumberOfBlocks(numChildren);
 
   for (XdmfInt32 cc=0; cc < numChildren; cc++)
     {
-    XdmfGrid* xmfChild = this->Domain->GetGrid(cc); 
+    XdmfGrid* xmfChild = this->Domain->GetGrid(cc);
     mb->GetMetaData(cc)->Set(vtkCompositeDataSet::NAME(),
       xmfChild->GetName());
     bool child_is_leaf = (xmfChild->IsUniform() != 0);
-    if (!child_is_leaf || !distribute_leaf_nodes || 
+    if (!child_is_leaf || !distribute_leaf_nodes ||
       (number_of_leaf_nodes % this->NumberOfPieces) == this->Piece)
       {
       // it's possible that the data has way too many blocks, in which case the
@@ -135,7 +135,7 @@ vtkDataObject* vtkXdmfHeavyData::ReadData(XdmfGrid* xmfGrid)
     // sanity check-ensure that the xmfGrid is valid.
     return 0;
     }
-  
+
   XdmfInt32 gridType = (xmfGrid->GetGridType() & XDMF_GRID_MASK);
   if (gridType == XDMF_GRID_COLLECTION &&
     xmfGrid->GetCollectionType() == XDMF_GRID_COLLECTION_TEMPORAL)
@@ -177,7 +177,7 @@ vtkDataObject* vtkXdmfHeavyData::ReadComposite(XdmfGrid* xmfComposite)
     multiBlock->GetMetaData(cc)->Set(vtkCompositeDataSet::NAME(),
       xmfChild->GetName());
     bool child_is_leaf = (xmfChild->IsUniform() != 0);
-    if (!child_is_leaf || !distribute_leaf_nodes || 
+    if (!child_is_leaf || !distribute_leaf_nodes ||
       (number_of_leaf_nodes % this->NumberOfPieces) == this->Piece)
       {
       vtkDataObject* childDO = this->ReadData(xmfChild);
@@ -217,6 +217,18 @@ vtkDataObject* vtkXdmfHeavyData::ReadTemporalCollection(
       valid_children.push_back(child);
       }
     }
+  // if no child matched this timestep, handle the case where the user didn't
+  // specify any <Time /> element for the temporal collection.
+  for (XdmfInt32 cc=0;
+    valid_children.size() == 0 &&
+    cc < xmfTemporalCollection->GetNumberOfChildren(); cc++)
+    {
+    XdmfGrid* child = xmfTemporalCollection->GetChild(cc);
+    if (child && child->GetTime()->GetTimeType() == XDMF_TIME_UNSET)
+      {
+      valid_children.push_back(child);
+      }
+    }
 
   if (valid_children.size() == 0)
     {
@@ -252,7 +264,7 @@ vtkDataObject* vtkXdmfHeavyData::ReadTemporalCollection(
       }
     return mb;
     }
-  
+
   return 0;
 }
 
@@ -273,7 +285,11 @@ vtkDataObject* vtkXdmfHeavyData::ReadUniformData(XdmfGrid* xmfGrid)
 
   // Read heavy data for grid geometry/topology. This does not read any
   // data-arrays. They are read explicitly.
-  xmfGrid->Update();
+  XdmfInt32 status = xmfGrid->Update();
+  if (status == XDMF_FAIL)
+    {
+    return 0;
+    }
 
   vtkDataObject* dataObject = 0;
 
@@ -337,6 +353,8 @@ int vtkXdmfHeavyData::GetNumberOfPointsPerCell(int vtk_cell_type)
     return 6;
   case VTK_QUADRATIC_QUAD:
     return 8;
+  case VTK_BIQUADRATIC_QUAD:
+    return 9;
   case VTK_QUADRATIC_TETRA:
     return 10;
   case VTK_QUADRATIC_PYRAMID:
@@ -383,6 +401,8 @@ int vtkXdmfHeavyData::GetVTKCellType(XdmfInt32 topologyType)
     return VTK_QUADRATIC_TRIANGLE ;
   case  XDMF_QUAD_8 :
     return VTK_QUADRATIC_QUAD ;
+  case  XDMF_QUAD_9 :
+    return VTK_BIQUADRATIC_QUAD ;
   case  XDMF_TET_10 :
     return VTK_QUADRATIC_TETRA ;
   case  XDMF_PYRAMID_13 :
@@ -398,9 +418,9 @@ int vtkXdmfHeavyData::GetVTKCellType(XdmfInt32 topologyType)
   case  XDMF_HEX_27 :
     return VTK_TRIQUADRATIC_HEXAHEDRON ;
   case XDMF_MIXED :
-    return VTK_NUMBER_OF_CELL_TYPES; 
+    return VTK_NUMBER_OF_CELL_TYPES;
     }
-  // XdmfErrorMessage("Unknown Topology Type = " 
+  // XdmfErrorMessage("Unknown Topology Type = "
   //  << xmfGrid->GetTopology()->GetTopologyType());
   return VTK_EMPTY_CELL;
 }
@@ -1010,7 +1030,7 @@ vtkDataArray* vtkXdmfHeavyData::ReadAttribute(XdmfAttribute* xmfAttribute,
   int attrCenter = xmfAttribute->GetAttributeCenter();
   int numComponents = 1;
 
-  switch (attrType) 
+  switch (attrType)
     {
   case XDMF_ATTRIBUTE_TYPE_TENSOR :
     numComponents = 9;
@@ -1022,7 +1042,7 @@ vtkDataArray* vtkXdmfHeavyData::ReadAttribute(XdmfAttribute* xmfAttribute,
     numComponents = 3;
     break;
   default :
-    numComponents = 1; 
+    numComponents = 1;
     break;
     }
 
@@ -1087,7 +1107,7 @@ vtkDataArray* vtkXdmfHeavyData::ReadAttribute(XdmfAttribute* xmfAttribute,
   vtkDataArray* dataArray = xmfConvertor->FromXdmfArray(
     xmfDataItem.GetArray()->GetTagName(), 1, data_rank, numComponents, 0);
   xmfConvertor->Delete();
-  
+
   if (attrType == XDMF_ATTRIBUTE_TYPE_TENSOR6)
     {
     // convert Tensor6 to Tensor.
@@ -1238,7 +1258,7 @@ vtkMultiBlockDataSet* vtkXdmfHeavyData::ReadSets(
       }
 
     // Okay now we have an enabled set. Create a new dataset for it
-    vtkDataSet* set = 0; 
+    vtkDataSet* set = 0;
 
     XdmfInt32 setType = xmfSet->GetSetType();
     switch (setType)
@@ -1276,7 +1296,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractPoints(XdmfSet* xmfSet,
 {
   // TODO: How to handle structured datasets with update_extents/strides etc.
   // Do they too always produce vtkUniformGrid or do we want to produce
-  // structured dataset 
+  // structured dataset
 
   // Read heavy data. We cannot do anything smart if update_extents or stride
   // is specified here. We have to read the entire set and then prune it.
@@ -1351,9 +1371,9 @@ vtkDataSet* vtkXdmfHeavyData::ExtractCells(XdmfSet* xmfSet,
 {
   // TODO: How to handle structured datasets with update_extents/strides etc.
   // Do they too always produce vtkUniformGrid or do we want to produce
-  // structured dataset 
+  // structured dataset
 
-  // Read heavy data. 
+  // Read heavy data.
   xmfSet->Update();
 
   XdmfArray* xmfIds = xmfSet->GetIds();
@@ -1462,7 +1482,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractFaces(XdmfSet* xmfSet, vtkDataSet* dataSet)
         "Invalid faceId " << faceId << " on cell " << cellId);
       continue;
       }
-    
+
     // Now insert this face a new cell in the output dataset.
     vtkIdType numPoints = face->GetNumberOfPoints();
     vtkPoints* facePoints = face->GetPoints();
@@ -1473,7 +1493,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractFaces(XdmfSet* xmfSet, vtkDataSet* dataSet)
         facePoints->GetPoint(kk), outputPts[kk]);
       }
     polys->InsertNextCell(numPoints, outputPts);
-    delete [] outputPts; 
+    delete [] outputPts;
     }
 
   ids->Delete();
@@ -1499,7 +1519,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractFaces(XdmfSet* xmfSet, vtkDataSet* dataSet)
       array->Delete();
       }
     }
- 
+
   return output;
 }
 
@@ -1562,7 +1582,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractEdges(XdmfSet* xmfSet, vtkDataSet* dataSet)
         << faceId << " on cell " << cellId);
       continue;
       }
-    
+
     // Now insert this edge as a new cell in the output dataset.
     vtkIdType numPoints = edge->GetNumberOfPoints();
     vtkPoints* edgePoints = edge->GetPoints();
@@ -1573,7 +1593,7 @@ vtkDataSet* vtkXdmfHeavyData::ExtractEdges(XdmfSet* xmfSet, vtkDataSet* dataSet)
         edgePoints->GetPoint(kk), outputPts[kk]);
       }
     lines->InsertNextCell(numPoints, outputPts);
-    delete [] outputPts; 
+    delete [] outputPts;
     }
 
   ids->Delete();
@@ -1599,6 +1619,6 @@ vtkDataSet* vtkXdmfHeavyData::ExtractEdges(XdmfSet* xmfSet, vtkDataSet* dataSet)
       array->Delete();
       }
     }
- 
+
   return output;
 }
