@@ -582,4 +582,8 @@ void vtkXdmfReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
-
+//----------------------------------------------------------------------------
+vtkGraph* vtkXdmfReader::GetSIL()
+{
+  return this->XdmfDocument->GetActiveDomain()->GetSIL();
+}
