@@ -17,12 +17,14 @@
 
 #ifdef VTK_USE_QT
 # include <QApplication>
-# include "vtkQtLabelRenderStrategy.h"
+# include "vtkQtStringToImage.h"
 #endif
-#include "vtkFreeTypeLabelRenderStrategy.h"
+#include "vtkFreeTypeStringToImage.h"
 
 #include "vtkVector.h"
 #include "vtkPen.h"
+#include "vtkBrush.h"
+#include "vtkTextProperty.h"
 #include "vtkPoints2D.h"
 #include "vtkMatrix3x3.h"
 #include "vtkFloatArray.h"
@@ -41,112 +43,14 @@
 #include "vtkOpenGLRenderer.h"
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkOpenGLExtensionManager.h"
+#include "vtkShaderProgram2.h"
 #include "vtkgl.h"
 
 #include "vtkObjectFactory.h"
 #include "vtkContextBufferId.h"
+#include "vtkOpenGLContextBufferId.h"
 
-//-----------------------------------------------------------------------------
-class vtkOpenGLContextDevice2D::Private
-{
-public:
-  Private()
-  {
-    this->Texture = NULL;
-    this->SavedLighting = GL_TRUE;
-    this->SavedDepthTest = GL_TRUE;
-    this->SavedAlphaTest = GL_TRUE;
-    this->SavedStencilTest = GL_TRUE;
-    this->SavedBlend = GL_TRUE;
-    this->SavedDrawBuffer = 0;
-    this->SavedClearColor[0] = this->SavedClearColor[1] =
-                               this->SavedClearColor[2] =
-                               this->SavedClearColor[3] = 0.0f;
-    this->TextCounter = 0;
-  }
-
-  ~Private()
-  {
-    if (this->Texture)
-      {
-      this->Texture->Delete();
-      this->Texture = NULL;
-      }
-  }
-
-  void SaveGLState(bool colorBuffer = false)
-  {
-    this->SavedLighting = glIsEnabled(GL_LIGHTING);
-    this->SavedDepthTest = glIsEnabled(GL_DEPTH_TEST);
-
-    if (colorBuffer)
-      {
-      this->SavedAlphaTest = glIsEnabled(GL_ALPHA_TEST);
-      this->SavedStencilTest = glIsEnabled(GL_STENCIL_TEST);
-      this->SavedBlend = glIsEnabled(GL_BLEND);
-      glGetFloatv(GL_COLOR_CLEAR_VALUE, this->SavedClearColor);
-      glGetIntegerv(GL_DRAW_BUFFER, &this->SavedDrawBuffer);
-      }
-  }
-
-  void RestoreGLState(bool colorBuffer = false)
-  {
-    this->SetGLCapability(GL_LIGHTING, this->SavedLighting);
-    this->SetGLCapability(GL_DEPTH_TEST, this->SavedDepthTest);
-
-    if (colorBuffer)
-      {
-      this->SetGLCapability(GL_ALPHA_TEST, this->SavedAlphaTest);
-      this->SetGLCapability(GL_STENCIL_TEST, this->SavedStencilTest);
-      this->SetGLCapability(GL_BLEND, this->SavedBlend);
-
-      if(this->SavedDrawBuffer != GL_BACK_LEFT)
-        {
-        glDrawBuffer(this->SavedDrawBuffer);
-        }
-
-      int i = 0;
-      bool colorDiffer = false;
-      while(!colorDiffer && i < 4)
-        {
-        colorDiffer=this->SavedClearColor[i++] != 0.0;
-        }
-      if(colorDiffer)
-        {
-        glClearColor(this->SavedClearColor[0],
-                     this->SavedClearColor[1],
-                     this->SavedClearColor[2],
-                     this->SavedClearColor[3]);
-        }
-      }
-  }
-
-  void SetGLCapability(GLenum capability, GLboolean state)
-  {
-    if (state)
-      {
-      glEnable(capability);
-      }
-    else
-      {
-      glDisable(capability);
-      }
-  }
-
-  vtkTexture *Texture;
-  // Store the previous GL state so that we can restore it when complete
-  GLboolean SavedLighting;
-  GLboolean SavedDepthTest;
-  GLboolean SavedAlphaTest;
-  GLboolean SavedStencilTest;
-  GLboolean SavedBlend;
-  GLint SavedDrawBuffer;
-  GLfloat SavedClearColor[4];
-
-  int TextCounter;
-  vtkVector2i Dim;
-  bool OpenGL15;
-};
+#include "vtkOpenGLContextDevice2DPrivate.h"
 
 //-----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkOpenGLContextDevice2D);
@@ -155,32 +59,17 @@ vtkStandardNewMacro(vtkOpenGLContextDevice2D);
 vtkOpenGLContextDevice2D::vtkOpenGLContextDevice2D()
 {
   this->Renderer = 0;
-  this->IsTextDrawn = false;
   this->InRender = false;
-#ifdef VTK_USE_QT
-  // Can only use the QtLabelRenderStrategy if there is a QApplication
-  // instance, otherwise fallback to the FreeTypeLabelRenderStrategy.
-  if(QApplication::instance())
-    {
-    this->TextRenderer = vtkQtLabelRenderStrategy::New();
-    }
-  else
-    {
-    this->TextRenderer = vtkFreeTypeLabelRenderStrategy::New();
-    }
-#else
-  this->TextRenderer = vtkFreeTypeLabelRenderStrategy::New();
-#endif
+  this->TextRenderer = vtkFreeTypeStringToImage::New();
   this->Storage = new vtkOpenGLContextDevice2D::Private;
+  this->RenderWindow = NULL;
 }
 
 //-----------------------------------------------------------------------------
 vtkOpenGLContextDevice2D::~vtkOpenGLContextDevice2D()
 {
   this->TextRenderer->Delete();
-  this->TextRenderer = 0;
   delete this->Storage;
-  this->Storage = 0;
 }
 
 //-----------------------------------------------------------------------------
@@ -189,6 +78,9 @@ void vtkOpenGLContextDevice2D::Begin(vtkViewport* viewport)
   // Need the actual pixel size of the viewport - ask OpenGL.
   GLint vp[4];
   glGetIntegerv(GL_VIEWPORT, vp);
+  this->Storage->Offset.Set(static_cast<int>(vp[0]),
+                            static_cast<int>(vp[1]));
+
   this->Storage->Dim.Set(static_cast<int>(vp[2]),
                          static_cast<int>(vp[3]));
 
@@ -196,8 +88,9 @@ void vtkOpenGLContextDevice2D::Begin(vtkViewport* viewport)
   glMatrixMode(GL_PROJECTION);
   glPushMatrix();
   glLoadIdentity();
-  glOrtho( 0.5, vp[2]+0.5,
-           0.5, vp[3]+0.5,
+  float offset = 0.5;
+  glOrtho(offset, vp[2]+offset-1.0,
+          offset, vp[3]+offset-1.0,
           -1, 1);
 
   glMatrixMode(GL_MODELVIEW);
@@ -208,25 +101,26 @@ void vtkOpenGLContextDevice2D::Begin(vtkViewport* viewport)
   this->Storage->SaveGLState();
   glDisable(GL_LIGHTING);
   glDisable(GL_DEPTH_TEST);
+  glEnable(GL_BLEND);
 
   this->Renderer = vtkRenderer::SafeDownCast(viewport);
-  this->TextRenderer->SetRenderer(this->Renderer);
-  this->IsTextDrawn = false;
 
   vtkOpenGLRenderer *gl = vtkOpenGLRenderer::SafeDownCast(viewport);
   if (gl)
     {
-    vtkOpenGLRenderWindow *glWin = vtkOpenGLRenderWindow::SafeDownCast(
+    this->RenderWindow = vtkOpenGLRenderWindow::SafeDownCast(
         gl->GetRenderWindow());
-    if (glWin)
+    }
+
+  if (!this->Storage->GLExtensionsLoaded)
+    {
+    if (this->RenderWindow)
       {
-      this->LoadExtensions(glWin->GetExtensionManager());
+      this->LoadExtensions(this->RenderWindow->GetExtensionManager());
       }
     }
 
   this->InRender = true;
-
-  this->Modified();
 }
 
 //-----------------------------------------------------------------------------
@@ -237,28 +131,6 @@ void vtkOpenGLContextDevice2D::End()
     return;
     }
 
-  if (this->IsTextDrawn)
-    {
-    this->TextRenderer->EndFrame();
-#ifdef VTK_USE_QT
-    if (++this->Storage->TextCounter > 300)
-      {
-      // Delete and recreate the label render strategy, this is a short term
-      // fix for a bug observed in ParaView/VTK charts where memory utilization
-      // would grow and grow if the chart had a large number of unique strings.
-      // The number chosen is fairly arbitrary, and a real fix should be made in
-      // the label render strategy.
-      if (this->TextRenderer->IsA("vtkQtLabelRenderStrategy"))
-        {
-        this->TextRenderer->Delete();
-        this->TextRenderer = vtkQtLabelRenderStrategy::New();
-        this->Storage->TextCounter = 0;
-        }
-      }
-#endif
-    this->IsTextDrawn = false;
-    }
-  this->TextRenderer->SetRenderer(0);
   // push a 2D matrix on the stack
   glMatrixMode(GL_PROJECTION);
   glPopMatrix();
@@ -268,13 +140,13 @@ void vtkOpenGLContextDevice2D::End()
   // Restore the GL state that we changed
   this->Storage->RestoreGLState();
 
+  this->RenderWindow = NULL;
   this->InRender = false;
-
-  this->Modified();
 }
 
 // ----------------------------------------------------------------------------
-void vtkOpenGLContextDevice2D::BufferIdModeBegin(vtkContextBufferId *bufferId)
+void vtkOpenGLContextDevice2D::BufferIdModeBegin(
+  vtkAbstractContextBufferId *bufferId)
 {
   assert("pre: not_yet" && !this->GetBufferIdMode());
   assert("pre: bufferId_exists" && bufferId!=0);
@@ -307,9 +179,6 @@ void vtkOpenGLContextDevice2D::BufferIdModeBegin(vtkContextBufferId *bufferId)
   glDisable(GL_DEPTH_TEST);
   glDisable(GL_BLEND);
 
-  this->TextRenderer->SetRenderer(this->Renderer);
-  this->IsTextDrawn = false;
-
   assert("post: started" && this->GetBufferIdMode());
 }
 
@@ -318,44 +187,11 @@ void vtkOpenGLContextDevice2D::BufferIdModeEnd()
 {
   assert("pre: started" && this->GetBufferIdMode());
 
-  GLint savedReadBuffer;
-  glGetIntegerv(GL_READ_BUFFER,&savedReadBuffer);
-
-  glReadBuffer(GL_BACK_LEFT);
-
   // Assume the renderer has been set previously during rendering (sse Begin())
   int lowerLeft[2];
   int usize, vsize;
   this->Renderer->GetTiledSizeAndOrigin(&usize,&vsize,lowerLeft,lowerLeft+1);
-
-  // Expensive call here (memory allocation)
-  unsigned char *rgb=new unsigned char[usize*vsize*3];
-
-  glPixelStorei(GL_PACK_ALIGNMENT,1);
-
-  // Expensive call here (memory transfer, blocking)
-  glReadPixels(lowerLeft[0],lowerLeft[1],usize,vsize,GL_RGB,GL_UNSIGNED_BYTE,
-               rgb);
-  // vtkIntArray
-  // Interpret rgb into ids.
-  // We cannot just use reinterpret_cast for two reasons:
-  // 1. we don't know if the host system is little or big endian.
-  // 2. we have rgb, not rgba. if we try to grab rgba and there is not
-  // alpha comment, it would be set to 1.0 (255, 0xff). we don't want that.
-
-  // Expensive iteration.
-  vtkIdType i=0;
-  vtkIdType s=usize*vsize;
-  while(i<s)
-    {
-    vtkIdType j=i*3;
-    int value=(static_cast<int>(rgb[j])<<16)|(static_cast<int>(rgb[j+1])<<8)
-      |static_cast<int>(rgb[j+2]);
-    this->BufferId->SetValue(i,value);
-    ++i;
-    }
-
-  delete[] rgb;
+  this->BufferId->SetValues(lowerLeft[0],lowerLeft[1]);
 
   // Restore OpenGL state (only if it's different to avoid too much state
   // change).
@@ -364,13 +200,6 @@ void vtkOpenGLContextDevice2D::BufferIdModeEnd()
   glMatrixMode(GL_MODELVIEW);
   glPopMatrix();
 
-  this->TextRenderer->SetRenderer(0);
-
-  if(savedReadBuffer!=GL_BACK_LEFT)
-    {
-    glReadBuffer(savedReadBuffer);
-    }
-
   this->Storage->RestoreGLState(true);
 
   this->BufferId=0;
@@ -378,30 +207,58 @@ void vtkOpenGLContextDevice2D::BufferIdModeEnd()
 }
 
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextDevice2D::DrawPoly(float *f, int n)
+void vtkOpenGLContextDevice2D::DrawPoly(float *f, int n, unsigned char *colors,
+                                        int nc)
 {
-  if(f && n > 0)
+  assert("f must be non-null" && f != NULL);
+  assert("n must be greater than 0" && n > 0);
+
+  this->SetLineType(this->Pen->GetLineType());
+  glLineWidth(this->Pen->GetWidth());
+
+  if (colors)
     {
-    glEnableClientState(GL_VERTEX_ARRAY);
-    glVertexPointer(2, GL_FLOAT, 0, f);
-    glDrawArrays(GL_LINE_STRIP, 0, n);
-    glDisableClientState(GL_VERTEX_ARRAY);
+    glEnableClientState(GL_COLOR_ARRAY);
+    glColorPointer(nc, GL_UNSIGNED_BYTE, 0, colors);
     }
   else
     {
-    vtkWarningMacro(<< "Points supplied that were not of type float.");
+    glColor4ubv(this->Pen->GetColor());
+    }
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, f);
+  glDrawArrays(GL_LINE_STRIP, 0, n);
+  glDisableClientState(GL_VERTEX_ARRAY);
+  if (colors)
+    {
+    glDisableClientState(GL_COLOR_ARRAY);
     }
 }
 
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextDevice2D::DrawPoints(float *f, int n)
+void vtkOpenGLContextDevice2D::DrawPoints(float *f, int n, unsigned char *c,
+                                          int nc)
 {
   if (f && n > 0)
     {
+    glPointSize(this->Pen->GetWidth());
     glEnableClientState(GL_VERTEX_ARRAY);
+    if (c && nc)
+      {
+      glEnableClientState(GL_COLOR_ARRAY);
+      glColorPointer(nc, GL_UNSIGNED_BYTE, 0, c);
+      }
+    else
+      {
+      glColor4ubv(this->Pen->GetColor());
+      }
     glVertexPointer(2, GL_FLOAT, 0, f);
     glDrawArrays(GL_POINTS, 0, n);
     glDisableClientState(GL_VERTEX_ARRAY);
+    if (c && nc)
+      {
+      glDisableClientState(GL_COLOR_ARRAY);
+      }
     }
   else
     {
@@ -411,74 +268,88 @@ void vtkOpenGLContextDevice2D::DrawPoints(float *f, int n)
 
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::DrawPointSprites(vtkImageData *sprite,
-                                                float *points, int n)
+                                                float *points, int n,
+                                                unsigned char *colors,
+                                                int nc_comps)
 {
-  if (sprite && points && n > 0)
+  if (points && n > 0)
     {
-    if (!this->Storage->Texture)
+    // glColor4ubv(this->Pen->GetColor());
+    glPointSize(this->Pen->GetWidth());
+    if (sprite)
       {
-      this->Storage->Texture = vtkTexture::New();
-      this->Storage->Texture->SetRepeat(false);
-      }
-    this->Storage->Texture->SetInput(sprite);
-    this->Storage->Texture->Render(this->Renderer);
-    if (this->Storage->OpenGL15)
-      {
-      // We can actually use point sprites here
-      glEnable(vtkgl::POINT_SPRITE);
-      glTexEnvi(vtkgl::POINT_SPRITE, vtkgl::COORD_REPLACE, GL_TRUE);
-      vtkgl::PointParameteri(vtkgl::POINT_SPRITE_COORD_ORIGIN, vtkgl::LOWER_LEFT);
-
-      this->DrawPoints(points, n);
-
-      glTexEnvi(vtkgl::POINT_SPRITE, vtkgl::COORD_REPLACE, GL_FALSE);
-      glDisable(vtkgl::POINT_SPRITE);
-
-      }
-    else
-      {
-      // Must emulate the point sprites - slower but at least they see something.
-      GLfloat width = 1.0;
-      glGetFloatv(GL_POINT_SIZE, &width);
-      width /= 2.0;
-
-      // Need to get the model view matrix for scaling factors...
-      GLfloat mv[16];
-      glGetFloatv(GL_MODELVIEW_MATRIX, mv);
-      float xWidth = width / mv[0];
-      float yWidth = width / mv[5];
-
-      float p[8] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
-
-      // This will be the same everytime
-      float texCoord[] = { 0.0, 0.0,
-                           1.0, 0.0,
-                           1.0, 1.0,
-                           0.0, 1.0 };
-
-      glEnableClientState(GL_VERTEX_ARRAY);
-      glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-      glTexCoordPointer(2, GL_FLOAT, 0, texCoord);
-
-      for (int i = 0; i < n; ++i)
+      if (!this->Storage->SpriteTexture)
         {
-        p[0] = points[2*i] - xWidth;
-        p[1] = points[2*i+1] - yWidth;
-        p[2] = points[2*i] + xWidth;
-        p[3] = points[2*i+1] - yWidth;
-        p[4] = points[2*i] + xWidth;
-        p[5] = points[2*i+1] + yWidth;
-        p[6] = points[2*i] - xWidth;
-        p[7] = points[2*i+1] + yWidth;
-
-        glVertexPointer(2, GL_FLOAT, 0, p);
-        glDrawArrays(GL_QUADS, 0, 4);
+        this->Storage->SpriteTexture = vtkTexture::New();
+        this->Storage->SpriteTexture->SetRepeat(false);
         }
-      glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-      glDisableClientState(GL_VERTEX_ARRAY);
+      this->Storage->SpriteTexture->SetInput(sprite);
+      this->Storage->SpriteTexture->Render(this->Renderer);
+      }
+
+    // Must emulate the point sprites - slower but at least they see something.
+    GLfloat width = 1.0;
+    glGetFloatv(GL_POINT_SIZE, &width);
+    width /= 2.0;
+
+    // Need to get the model view matrix for scaling factors...
+    GLfloat mv[16];
+    glGetFloatv(GL_MODELVIEW_MATRIX, mv);
+    float xWidth = width / mv[0];
+    float yWidth = width / mv[5];
+
+    // Four 2D points on the quad.
+    float p[4 * 2] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
+
+    // This will be the same everytime
+    float texCoord[] = { 0.0, 0.0,
+                         1.0, 0.0,
+                         1.0, 1.0,
+                         0.0, 1.0 };
+
+    if (!colors || !nc_comps)
+      {
+      glColor4ubv(this->Pen->GetColor());
+      }
+    glEnableClientState(GL_VERTEX_ARRAY);
+    glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+    glTexCoordPointer(2, GL_FLOAT, 0, texCoord);
+
+    for (int i = 0; i < n; ++i)
+      {
+      p[0] = points[2*i] - xWidth;
+      p[1] = points[2*i+1] - yWidth;
+      p[2] = points[2*i] + xWidth;
+      p[3] = points[2*i+1] - yWidth;
+      p[4] = points[2*i] + xWidth;
+      p[5] = points[2*i+1] + yWidth;
+      p[6] = points[2*i] - xWidth;
+      p[7] = points[2*i+1] + yWidth;
+
+      // If we have a color array, set the color for each quad.
+      if (colors && nc_comps)
+        {
+        if (nc_comps == 3)
+          {
+          glColor3ubv(&colors[3 * i]);
+          }
+        else if (nc_comps == 4)
+          {
+          glColor4ubv(&colors[4 * i]);
+          }
+        }
+
+      glVertexPointer(2, GL_FLOAT, 0, p);
+      glDrawArrays(GL_QUADS, 0, 4);
+      }
+    glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+    glDisableClientState(GL_VERTEX_ARRAY);
+
+    if (sprite)
+      {
+      this->Storage->SpriteTexture->PostRender(this->Renderer);
+      glDisable(GL_TEXTURE_2D);
       }
-    this->Storage->Texture->PostRender(this->Renderer);
-    glDisable(GL_TEXTURE_2D);
     }
   else
     {
@@ -489,16 +360,95 @@ void vtkOpenGLContextDevice2D::DrawPointSprites(vtkImageData *sprite,
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::DrawQuad(float *f, int n)
 {
-  if (f && n > 0)
-    {
-    glEnableClientState(GL_VERTEX_ARRAY);
-    glVertexPointer(2, GL_FLOAT, 0, f);
-    glDrawArrays(GL_QUADS, 0, n);
-    glDisableClientState(GL_VERTEX_ARRAY);
-    }
-  else
+  if (!f || n <= 0)
     {
     vtkWarningMacro(<< "Points supplied that were not of type float.");
+    return;
+    }
+  glColor4ubv(this->Brush->GetColor());
+  float* texCoord = 0;
+  if (this->Brush->GetTexture())
+    {
+    this->SetTexture(this->Brush->GetTexture(),
+                     this->Brush->GetTextureProperties());
+    this->Storage->Texture->Render(this->Renderer);
+    glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+    texCoord = this->Storage->TexCoords(f, n);
+    glTexCoordPointer(2, GL_FLOAT, 0, &texCoord[0]);
+    }
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, f);
+  glDrawArrays(GL_QUADS, 0, n);
+  glDisableClientState(GL_VERTEX_ARRAY);
+  if (this->Storage->Texture)
+    {
+    glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+    this->Storage->Texture->PostRender(this->Renderer);
+    glDisable(GL_TEXTURE_2D);
+    delete [] texCoord;
+    }
+}
+
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::DrawQuadStrip(float *f, int n)
+{
+  if (!f || n <= 0)
+    {
+    vtkWarningMacro(<< "Points supplied that were not of type float.");
+    return;
+    }
+  glColor4ubv(this->Brush->GetColor());
+  float* texCoord = 0;
+  if (this->Brush->GetTexture())
+    {
+    this->SetTexture(this->Brush->GetTexture(),
+                     this->Brush->GetTextureProperties());
+    this->Storage->Texture->Render(this->Renderer);
+    glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+    texCoord = this->Storage->TexCoords(f, n);
+    glTexCoordPointer(2, GL_FLOAT, 0, &texCoord[0]);
+    }
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, f);
+  glDrawArrays(GL_QUAD_STRIP, 0, n);
+  glDisableClientState(GL_VERTEX_ARRAY);
+  if (this->Storage->Texture)
+    {
+    glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+    this->Storage->Texture->PostRender(this->Renderer);
+    glDisable(GL_TEXTURE_2D);
+    delete [] texCoord;
+    }
+}
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::DrawPolygon(float *f, int n)
+{
+  if (!f || n <= 0)
+    {
+    vtkWarningMacro(<< "Points supplied that were not of type float.");
+    return;
+    }
+  glColor4ubv(this->Brush->GetColor());
+  float* texCoord = 0;
+  if (this->Brush->GetTexture())
+    {
+    this->SetTexture(this->Brush->GetTexture(),
+                     this->Brush->GetTextureProperties());
+    this->Storage->Texture->Render(this->Renderer);
+    glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+    texCoord = this->Storage->TexCoords(f, n);
+    glTexCoordPointer(2, GL_FLOAT, 0, &texCoord[0]);
+    }
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, f);
+  glDrawArrays(GL_POLYGON, 0, n);
+  glDisableClientState(GL_VERTEX_ARRAY);
+  if (this->Storage->Texture)
+    {
+    glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+    this->Storage->Texture->PostRender(this->Renderer);
+    glDisable(GL_TEXTURE_2D);
+    delete [] texCoord;
     }
 }
 
@@ -557,6 +507,7 @@ void vtkOpenGLContextDevice2D::DrawEllipseWedge(float x, float y, float outRx,
     ++i;
     }
 
+  glColor4ubv(this->Brush->GetColor());
   glEnableClientState(GL_VERTEX_ARRAY);
   glVertexPointer(2, GL_FLOAT, 0, p);
   glDrawArrays(GL_TRIANGLE_STRIP, 0, 2*(iterations+1));
@@ -578,9 +529,9 @@ void vtkOpenGLContextDevice2D::DrawEllipticArc(float x, float y, float rX,
     // we make sure maxRadius will never be null.
     return;
     }
-  int iterations=this->GetNumberOfArcIterations(rX,rY,startAngle,stopAngle);
+  int iterations = this->GetNumberOfArcIterations(rX, rY, startAngle, stopAngle);
 
-  float *p=new float[2*(iterations+1)];
+  float *p = new float[2*(iterations+1)];
 
   // step in radians.
   double step =
@@ -588,22 +539,24 @@ void vtkOpenGLContextDevice2D::DrawEllipticArc(float x, float y, float rX,
 
   // step have to be lesser or equal to maxStep computed inside
   // GetNumberOfIterations()
-
   double rstart=vtkMath::RadiansFromDegrees(startAngle);
 
   // we are iterating counterclockwise
-  int i=0;
-  while(i<=iterations)
+  for(int i = 0; i <= iterations; ++i)
     {
     double a=rstart+i*step;
     p[2*i  ] = rX * cos(a) + x;
     p[2*i+1] = rY * sin(a) + y;
-    ++i;
     }
 
+  this->SetLineType(this->Pen->GetLineType());
+  glColor4ubv(this->Pen->GetColor());
+  glLineWidth(this->Pen->GetWidth());
   glEnableClientState(GL_VERTEX_ARRAY);
   glVertexPointer(2, GL_FLOAT, 0, p);
   glDrawArrays(GL_LINE_STRIP, 0, iterations+1);
+  glColor4ubv(this->Brush->GetColor());
+  glDrawArrays(GL_TRIANGLE_FAN, 0, iterations+1);
   glDisableClientState(GL_VERTEX_ARRAY);
 
   delete[] p;
@@ -620,76 +573,239 @@ int vtkOpenGLContextDevice2D::GetNumberOfArcIterations(float rX,
   assert("pre: not_both_null" && (rX>0.0 || rY>0.0));
 
 // 1.0: pixel precision. 0.5 (subpixel precision, useful with multisampling)
-  double error=4.0; // experience shows 4.0 is visually enough.
+  double error = 4.0; // experience shows 4.0 is visually enough.
 
   // The tessellation is the most visible on the biggest radius.
   double maxRadius;
-  if(rX>=rY)
+  if(rX >= rY)
     {
-    maxRadius=rX;
+    maxRadius = rX;
     }
   else
     {
-    maxRadius=rY;
+    maxRadius = rY;
     }
 
-  if(error>maxRadius)
+  if(error > maxRadius)
     {
-    error=0.5; // to make sure the argument of asin() is in a valid range.
+    // to make sure the argument of asin() is in a valid range.
+    error = maxRadius;
     }
 
   // Angle of a sector so that its chord is `error' pixels.
   // This is will be our maximum angle step.
-  double maxStep=2.0*asin(error/(2.0*maxRadius));
+  double maxStep = 2.0 * asin(error / (2.0 * maxRadius));
 
   // ceil because we want to make sure we don't underestimate the number of
   // iterations by 1.
   return static_cast<int>(
-    ceil(vtkMath::RadiansFromDegrees(stopAngle-startAngle)/maxStep));
+    ceil(vtkMath::RadiansFromDegrees(stopAngle - startAngle) / maxStep));
 }
 
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextDevice2D::DrawString(float *point, vtkTextProperty *prop,
+void vtkOpenGLContextDevice2D::AlignText(double orientation, float width,
+                                         float height, float *p)
+{
+  // Special case multiples of 90 as no transformation is required...
+  if (orientation > -0.0001 && orientation < 0.0001)
+    {
+    switch (this->TextProp->GetJustification())
+      {
+      case VTK_TEXT_LEFT:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[0] -= floor(width / 2.0);
+        break;
+      case VTK_TEXT_RIGHT:
+        p[0] -= width;
+        break;
+      }
+    switch (this->TextProp->GetVerticalJustification())
+      {
+      case VTK_TEXT_BOTTOM:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[1] -= floor(height / 2.0);
+        break;
+      case VTK_TEXT_TOP:
+        p[1] -= height;
+        break;
+      }
+    }
+  else if (orientation > 89.9999 && orientation < 90.0001)
+    {
+    switch (this->TextProp->GetJustification())
+      {
+      case VTK_TEXT_LEFT:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[1] -= floor(height / 2.0);
+        break;
+      case VTK_TEXT_RIGHT:
+        p[1] -= height;
+        break;
+      }
+    switch (this->TextProp->GetVerticalJustification())
+      {
+      case VTK_TEXT_TOP:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[0] -= floor(width / 2.0);
+        break;
+      case VTK_TEXT_BOTTOM:
+        p[0] -= width;
+        break;
+      }
+    }
+  else if (orientation > 179.9999 && orientation < 180.0001)
+    {
+    switch (this->TextProp->GetJustification())
+      {
+      case VTK_TEXT_RIGHT:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[0] -= floor(width / 2.0);
+        break;
+      case VTK_TEXT_LEFT:
+        p[0] -= width;
+        break;
+      }
+    switch (this->TextProp->GetVerticalJustification())
+      {
+      case VTK_TEXT_TOP:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[1] -= floor(height / 2.0);
+        break;
+      case VTK_TEXT_BOTTOM:
+        p[1] -= height;
+        break;
+      }
+    }
+  else if (orientation > 269.9999 && orientation < 270.0001)
+    {
+    switch (this->TextProp->GetJustification())
+      {
+      case VTK_TEXT_LEFT:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[1] -= floor(height / 2.0);
+        break;
+      case VTK_TEXT_RIGHT:
+        p[1] -= height;
+        break;
+      }
+    switch (this->TextProp->GetVerticalJustification())
+      {
+      case VTK_TEXT_BOTTOM:
+        break;
+      case VTK_TEXT_CENTERED:
+        p[0] -= floor(width / 2.0);
+        break;
+      case VTK_TEXT_TOP:
+        p[0] -= width;
+        break;
+      }
+    }
+}
+
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::DrawString(float *point,
                                           const vtkStdString &string)
 {
-  if (!this->IsTextDrawn)
+  float p[] = { floor(point[0]), floor(point[1]) };
+
+  vtkImageData *image = vtkImageData::New();
+  if (!this->TextRenderer->RenderString(this->TextProp, string, image))
     {
-    this->IsTextDrawn = true;
-    this->TextRenderer->StartFrame();
+    image->Delete();
+    return;
     }
 
-  int p[] = { static_cast<int>(point[0]),
-              static_cast<int>(point[1]) };
-  this->TextRenderer->RenderLabel(&p[0], prop, string);
+  this->SetTexture(image);
+  this->Storage->Texture->Render(this->Renderer);
+
+  float width = static_cast<float>(image->GetOrigin()[0]);
+  float height = static_cast<float>(image->GetOrigin()[1]);
+
+  float xw = static_cast<float>(image->GetSpacing()[0]);
+  float xh = static_cast<float>(image->GetSpacing()[1]);
+
+  this->AlignText(this->TextProp->GetOrientation(), width, height, p);
+
+  float points[] = { p[0]        , p[1],
+                     p[0] + width, p[1],
+                     p[0] + width, p[1] + height,
+                     p[0]        , p[1] + height };
+
+  float texCoord[] = { 0.0, 0.0,
+                       xw,  0.0,
+                       xw,  xh,
+                       0.0, xh };
+
+  glColor4ub(255, 255, 255, 255);
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, points);
+  glTexCoordPointer(2, GL_FLOAT, 0, texCoord);
+  glDrawArrays(GL_QUADS, 0, 4);
+  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+  glDisableClientState(GL_VERTEX_ARRAY);
+
+  this->Storage->Texture->PostRender(this->Renderer);
+  glDisable(GL_TEXTURE_2D);
+  image->Delete();
 }
 
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::ComputeStringBounds(const vtkStdString &string,
-                                                   vtkTextProperty *prop,
                                                    float bounds[4])
 {
-  double b[4];
-  this->TextRenderer->ComputeLabelBounds(prop, string, b);
-
-  // Go from the format used in the label render strategy (x1, x2, y1, y2)
-  // to the format specified by this function (x, y, w, h).
-  bounds[0] = static_cast<float>(b[0]);
-  bounds[1] = static_cast<float>(b[2]);
-  bounds[2] = static_cast<float>(b[1] - b[0]);
-  bounds[3] = static_cast<float>(b[3] - b[2]);
+  vtkVector2i box = this->TextRenderer->GetBounds(this->TextProp, string);
+  bounds[0] = static_cast<float>(0);
+  bounds[1] = static_cast<float>(0);
+  bounds[2] = static_cast<float>(box.X());
+  bounds[3] = static_cast<float>(box.Y());
 }
 
 //-----------------------------------------------------------------------------
-void vtkOpenGLContextDevice2D::DrawImage(float *p, int, vtkImageData *image)
+void vtkOpenGLContextDevice2D::DrawString(float *point,
+                                          const vtkUnicodeString &string)
 {
-  vtkTexture *tex =vtkTexture::New();
-  tex->SetInput(image);
-  tex->Render(this->Renderer);
+  int p[] = { static_cast<int>(point[0]),
+              static_cast<int>(point[1]) };
+
+  //TextRenderer draws in window, not viewport coords
+  p[0]+=this->Storage->Offset.GetX();
+  p[1]+=this->Storage->Offset.GetY();
+  vtkImageData *data = vtkImageData::New();
+  this->TextRenderer->RenderString(this->TextProp, string, data);
+  this->DrawImage(point, 1.0, data);
+  data->Delete();
+}
+
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::ComputeStringBounds(const vtkUnicodeString &string,
+                                                   float bounds[4])
+{
+  vtkVector2i box = this->TextRenderer->GetBounds(this->TextProp, string);
+  bounds[0] = static_cast<float>(0);
+  bounds[1] = static_cast<float>(0);
+  bounds[2] = static_cast<float>(box.X());
+  bounds[3] = static_cast<float>(box.Y());
+}
+
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::DrawImage(float p[2], float scale,
+                                         vtkImageData *image)
+{
+  this->SetTexture(image);
+  this->Storage->Texture->Render(this->Renderer);
   int *extent = image->GetExtent();
-  float points[] = { p[0]          , p[1],
-                     p[0]+extent[1], p[1],
-                     p[0]+extent[1], p[1]+extent[3],
-                     p[0]          , p[1]+extent[3] };
+  float points[] = { p[0]                    , p[1],
+                     p[0]+scale*extent[1]+1.0, p[1],
+                     p[0]+scale*extent[1]+1.0, p[1]+scale*extent[3]+1.0,
+                     p[0]                    , p[1]+scale*extent[3]+1.0 };
 
   float texCoord[] = { 0.0, 0.0,
                        1.0, 0.0,
@@ -705,9 +821,48 @@ void vtkOpenGLContextDevice2D::DrawImage(float *p, int, vtkImageData *image)
   glDisableClientState(GL_TEXTURE_COORD_ARRAY);
   glDisableClientState(GL_VERTEX_ARRAY);
 
-  tex->PostRender(this->Renderer);
+  this->Storage->Texture->PostRender(this->Renderer);
   glDisable(GL_TEXTURE_2D);
-  tex->Delete();
+}
+
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::DrawImage(const vtkRectf& pos,
+                                         vtkImageData *image)
+{
+  vtkVector2f tex(1.0, 1.0);
+  GLuint index = 0;
+  if (this->Storage->PowerOfTwoTextures)
+    {
+    index = this->Storage->TextureFromImage(image, tex);
+    }
+  else
+    {
+    index = this->Storage->TextureFromImage(image, tex);
+    }
+//  this->SetTexture(image);
+//  this->Storage->Texture->Render(this->Renderer);
+  float points[] = { pos.X()              , pos.Y(),
+                     pos.X() + pos.Width(), pos.Y(),
+                     pos.X() + pos.Width(), pos.Y() + pos.Height(),
+                     pos.X()              , pos.Y() + pos.Height() };
+
+  float texCoord[] = { 0.0   , 0.0,
+                       tex[0], 0.0,
+                       tex[0], tex[1],
+                       0.0   , tex[1] };
+
+  glColor4ub(255, 255, 255, 255);
+  glEnableClientState(GL_VERTEX_ARRAY);
+  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+  glVertexPointer(2, GL_FLOAT, 0, &points[0]);
+  glTexCoordPointer(2, GL_FLOAT, 0, &texCoord[0]);
+  glDrawArrays(GL_QUADS, 0, 4);
+  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+  glDisableClientState(GL_VERTEX_ARRAY);
+
+//  this->Storage->Texture->PostRender(this->Renderer);
+  glDisable(GL_TEXTURE_2D);
+  glDeleteTextures(1, &index);
 }
 
 //-----------------------------------------------------------------------------
@@ -722,6 +877,29 @@ void vtkOpenGLContextDevice2D::SetColor(unsigned char *color)
   glColor3ubv(color);
 }
 
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::SetTexture(vtkImageData* image, int properties)
+{
+  if (image == NULL)
+    {
+    if (this->Storage->Texture)
+      {
+      this->Storage->Texture->Delete();
+      this->Storage->Texture = 0;
+      }
+    return;
+    }
+  if (this->Storage->Texture == NULL)
+    {
+    this->Storage->Texture = vtkTexture::New();
+    }
+  this->Storage->Texture->SetInput(image);
+  this->Storage->TextureProperties = properties;
+  this->Storage->Texture->SetRepeat(properties & vtkContextDevice2D::Repeat);
+  this->Storage->Texture->SetInterpolate(properties & vtkContextDevice2D::Linear);
+  this->Storage->Texture->EdgeClampOn();
+}
+
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::SetPointSize(float size)
 {
@@ -831,6 +1009,29 @@ void vtkOpenGLContextDevice2D::SetMatrix(vtkMatrix3x3 *m)
   glLoadMatrixd(matrix);
 }
 
+//-----------------------------------------------------------------------------
+void vtkOpenGLContextDevice2D::GetMatrix(vtkMatrix3x3 *m)
+{
+  assert("pre: non_null" && m != NULL);
+  // We must construct a 4x4 matrix from the 3x3 matrix for OpenGL
+  double *M = m->GetData();
+  double matrix[16];
+  glGetDoublev(GL_MODELVIEW_MATRIX, matrix);
+
+  // Convert from row major (C++ two dimensional arrays) to OpenGL
+  M[0] = matrix[0];
+  M[1] = matrix[4];
+  M[2] = matrix[12];
+  M[3] = matrix[1];
+  M[4] = matrix[5];
+  M[5] = matrix[13];
+  M[6] = matrix[3];
+  M[7] = matrix[7];
+  M[8] = matrix[15];
+
+  m->Modified();
+}
+
 //-----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::PushMatrix()
 {
@@ -849,20 +1050,22 @@ void vtkOpenGLContextDevice2D::PopMatrix()
 void vtkOpenGLContextDevice2D::SetClipping(int *dim)
 {
   // Check the bounds, and clamp if necessary
-  int vp[4] = {0, 0, this->Storage->Dim.X(), this->Storage->Dim.Y()};
-  if (dim[0] > 0 && dim[0] < this->Storage->Dim.X())
+  GLint vp[4] = { this->Storage->Offset.GetX(), this->Storage->Offset.GetY(),
+    this->Storage->Dim.GetX(),this->Storage->Dim.GetY()};
+
+  if (dim[0] > 0 && dim[0] < vp[2] )
     {
-    vp[0] = dim[0];
+    vp[0] += dim[0];
     }
-  if (dim[1] > 0 && dim[1] < this->Storage->Dim.Y())
+  if (dim[1] > 0 && dim[1] < vp[3])
     {
-    vp[1] = dim[1];
+    vp[1] += dim[1];
     }
-  if (dim[2] > 0 && dim[2] < this->Storage->Dim.X())
+  if (dim[2] > 0 && dim[2] < vp[2])
     {
     vp[2] = dim[2];
     }
-  if (dim[3] > 0 && dim[3] < this->Storage->Dim.Y())
+  if (dim[3] > 0 && dim[3] < vp[3])
     {
     vp[3] = dim[3];
     }
@@ -882,10 +1085,10 @@ bool vtkOpenGLContextDevice2D::SetStringRendererToFreeType()
 {
 #ifdef VTK_USE_QT
   // We will likely be using the Qt rendering strategy
-  if (this->TextRenderer->IsA("vtkQtLabelRenderStrategy"))
+  if (this->TextRenderer->IsA("vtkQtStringToImage"))
     {
     this->TextRenderer->Delete();
-    this->TextRenderer = vtkFreeTypeLabelRenderStrategy::New();
+    this->TextRenderer = vtkFreeTypeStringToImage::New();
     }
 #endif
   // FreeType is the only choice - nothing to do here
@@ -897,14 +1100,14 @@ bool vtkOpenGLContextDevice2D::SetStringRendererToQt()
 {
 #ifdef VTK_USE_QT
   // We will likely be using the Qt rendering strategy
-  if (this->TextRenderer->IsA("vtkQtLabelRenderStrategy"))
+  if (this->TextRenderer->IsA("vtkQtStringToImage"))
     {
     return true;
     }
   else
     {
     this->TextRenderer->Delete();
-    this->TextRenderer = vtkQtLabelRenderStrategy::New();
+    this->TextRenderer = vtkQtStringToImage::New();
     }
 #endif
   // The Qt based strategy is not available
@@ -914,27 +1117,68 @@ bool vtkOpenGLContextDevice2D::SetStringRendererToQt()
 //----------------------------------------------------------------------------
 void vtkOpenGLContextDevice2D::ReleaseGraphicsResources(vtkWindow *window)
 {
-  this->TextRenderer->ReleaseGraphicsResources(window);
   if (this->Storage->Texture)
     {
     this->Storage->Texture->ReleaseGraphicsResources(window);
     }
+  if (this->Storage->SpriteTexture)
+    {
+    this->Storage->SpriteTexture->ReleaseGraphicsResources(window);
+    }
+}
+
+//----------------------------------------------------------------------------
+bool vtkOpenGLContextDevice2D::HasGLSL()
+{
+  return this->Storage->GLSL;
 }
 
 //-----------------------------------------------------------------------------
 bool vtkOpenGLContextDevice2D::LoadExtensions(vtkOpenGLExtensionManager *m)
 {
+  if(m->ExtensionSupported("GL_ARB_texture_non_power_of_two"))
+    {
+    m->LoadExtension("GL_ARB_texture_non_power_of_two");
+    this->Storage->PowerOfTwoTextures = false;
+    this->TextRenderer->SetScaleToPowerOfTwo(false);
+    }
+  else
+    {
+    this->Storage->PowerOfTwoTextures = true;
+    this->TextRenderer->SetScaleToPowerOfTwo(true);
+    }
   if(m->ExtensionSupported("GL_VERSION_1_5"))
     {
     m->LoadExtension("GL_VERSION_1_5");
     this->Storage->OpenGL15 = true;
-    return true;
     }
   else
     {
     this->Storage->OpenGL15 = false;
-    return false;
     }
+  if(vtkShaderProgram2::IsSupported(
+      static_cast<vtkOpenGLRenderWindow *>(m->GetRenderWindow())))
+    {
+    this->Storage->GLSL = true;
+    }
+  else
+    {
+    this->Storage->GLSL = false;
+    }
+
+  // Workaround for a bug in mesa - support for non-power of two textures is
+  // poor at best. Disable, and use power of two textures for mesa rendering.
+  const char *gl_version =
+    reinterpret_cast<const char *>(glGetString(GL_VERSION));
+  const char *mesa_version = strstr(gl_version, "Mesa");
+  if (mesa_version != 0)
+    {
+    this->Storage->PowerOfTwoTextures = true;
+    this->TextRenderer->SetScaleToPowerOfTwo(true);
+    }
+
+  this->Storage->GLExtensionsLoaded = true;
+  return true;
 }
 
 //-----------------------------------------------------------------------------
