@@ -23,8 +23,8 @@
 #include "vtkIdTypeArray.h"
 #include "vtkContextMapper2D.h"
 #include "vtkObjectFactory.h"
-
 #include "vtkStdString.h"
+#include "vtkStringArray.h"
 
 vtkCxxSetObjectMacro(vtkPlot, Selection, vtkIdTypeArray);
 vtkCxxSetObjectMacro(vtkPlot, XAxis, vtkAxis);
@@ -36,7 +36,7 @@ vtkPlot::vtkPlot()
   this->Pen = vtkPen::New();
   this->Pen->SetWidth(2.0);
   this->Brush = vtkBrush::New();
-  this->Label = NULL;
+  this->Labels = NULL;
   this->UseIndexForXSeries = false;
   this->Data = vtkContextMapper2D::New();
   this->Selection = NULL;
@@ -67,22 +67,22 @@ vtkPlot::~vtkPlot()
     this->Selection->Delete();
     this->Selection = NULL;
     }
-  this->SetLabel(NULL);
+  this->SetLabels(NULL);
   this->SetXAxis(NULL);
   this->SetYAxis(NULL);
 }
 
 //-----------------------------------------------------------------------------
-bool vtkPlot::PaintLegend(vtkContext2D*, float*)
+bool vtkPlot::PaintLegend(vtkContext2D*, const vtkRectf&, int)
 {
   return false;
 }
 
 //-----------------------------------------------------------------------------
-bool vtkPlot::GetNearestPoint(const vtkVector2f&, const vtkVector2f&,
+int vtkPlot::GetNearestPoint(const vtkVector2f&, const vtkVector2f&,
                               vtkVector2f*)
 {
-  return false;
+  return -1;
 }
 
 //-----------------------------------------------------------------------------
@@ -110,6 +110,16 @@ void vtkPlot::GetColor(double rgb[3])
   this->Pen->GetColorF(rgb);
 }
 
+//-----------------------------------------------------------------------------
+void vtkPlot::GetColor(unsigned char rgb[3])
+{
+  double rgbF[3];
+  this->GetColor(rgbF);
+  rgb[0] = static_cast<unsigned char>(255. * rgbF[0] + 0.5);
+  rgb[1] = static_cast<unsigned char>(255. * rgbF[1] + 0.5);
+  rgb[2] = static_cast<unsigned char>(255. * rgbF[2] + 0.5);
+}
+
 //-----------------------------------------------------------------------------
 void vtkPlot::SetWidth(float width)
 {
@@ -123,48 +133,108 @@ float vtkPlot::GetWidth()
 }
 
 //-----------------------------------------------------------------------------
-const char* vtkPlot::GetLabel()
+void vtkPlot::SetLabel(const vtkStdString& label)
+{
+  vtkStringArray *labels = vtkStringArray::New();
+  labels->InsertNextValue(label);
+  this->SetLabels(labels);
+  labels->Delete();
+}
+
+//-----------------------------------------------------------------------------
+
+vtkStdString vtkPlot::GetLabel()
+{
+  return this->GetLabel(0);
+}
+
+
+//-----------------------------------------------------------------------------
+
+void vtkPlot::SetLabels(vtkStringArray *labels)
+{
+  if (this->Labels == labels)
+    {
+    return;
+    }
+
+  this->Labels = labels;
+  this->Modified();
+}
+
+//-----------------------------------------------------------------------------
+vtkStringArray * vtkPlot::GetLabels()
 {
   // If the label string is empty, return the y column name
-  if (this->Label)
+  if (this->Labels)
     {
-    return this->Label;
+    return this->Labels;
+    }
+  else if (this->AutoLabels)
+    {
+    return this->AutoLabels;
     }
   else if (this->Data->GetInput() &&
            this->Data->GetInputArrayToProcess(1, this->Data->GetInput()))
     {
-    return this->Data->GetInputArrayToProcess(1, this->Data->GetInput())->GetName();
+    this->AutoLabels = vtkSmartPointer<vtkStringArray>::New();
+    this->AutoLabels->InsertNextValue(this->Data->GetInputArrayToProcess(1, this->Data->GetInput())->GetName());
+    return this->AutoLabels;
     }
   else
     {
     return NULL;
     }
 }
+//-----------------------------------------------------------------------------
+int vtkPlot::GetNumberOfLabels()
+{
+  vtkStringArray *labels = this->GetLabels();
+  if (labels)
+    {
+    return labels->GetNumberOfValues();
+    }
+  else
+    {
+    return 0;
+    }
+}
 
+//-----------------------------------------------------------------------------
+vtkStdString vtkPlot::GetLabel(vtkIdType index)
+{
+  vtkStringArray *labels = this->GetLabels();
+  if (labels && index >= 0 && index < labels->GetNumberOfValues())
+    {
+    return labels->GetValue(index);
+    }
+  else
+    {
+    return vtkStdString();
+    }
+}
 //-----------------------------------------------------------------------------
 void vtkPlot::SetInput(vtkTable *table)
 {
   this->Data->SetInput(table);
+  this->AutoLabels = 0;  // No longer valid
 }
 
 //-----------------------------------------------------------------------------
-void vtkPlot::SetInput(vtkTable *table, const char *xColumn,
-                       const char *yColumn)
+void vtkPlot::SetInput(vtkTable *table, const vtkStdString &xColumn,
+                       const vtkStdString &yColumn)
 {
-  if (!xColumn || !yColumn)
-    {
-    vtkErrorMacro(<< "Called with null arguments for X or Y column.")
-    }
-  vtkDebugMacro(<< "Setting input, X column = \"" << vtkstd::string(xColumn)
-                << "\", " << "Y column = \"" << vtkstd::string(yColumn) << "\"");
+  vtkDebugMacro(<< "Setting input, X column = \"" << xColumn.c_str()
+                << "\", " << "Y column = \"" << yColumn.c_str() << "\"");
 
   this->Data->SetInput(table);
   this->Data->SetInputArrayToProcess(0, 0, 0,
                                      vtkDataObject::FIELD_ASSOCIATION_ROWS,
-                                     xColumn);
+                                     xColumn.c_str());
   this->Data->SetInputArrayToProcess(1, 0, 0,
                                      vtkDataObject::FIELD_ASSOCIATION_ROWS,
-                                     yColumn);
+                                     yColumn.c_str());
+  this->AutoLabels = 0;  // No longer valid
 }
 
 //-----------------------------------------------------------------------------
@@ -183,11 +253,23 @@ vtkTable* vtkPlot::GetInput()
 }
 
 //-----------------------------------------------------------------------------
-void vtkPlot::SetInputArray(int index, const char *name)
+void vtkPlot::SetInputArray(int index, const vtkStdString &name)
 {
   this->Data->SetInputArrayToProcess(index, 0, 0,
                                      vtkDataObject::FIELD_ASSOCIATION_ROWS,
-                                     name);
+                                     name.c_str());
+  this->AutoLabels = 0; // No longer valid
+}
+
+//-----------------------------------------------------------------------------
+void vtkPlot::SetProperty(const vtkStdString&, const vtkVariant&)
+{
+}
+
+//-----------------------------------------------------------------------------
+vtkVariant vtkPlot::GetProperty(const vtkStdString&)
+{
+  return vtkVariant();
 }
 
 //-----------------------------------------------------------------------------
