@@ -16,21 +16,28 @@
 // .NAME vtkPlot - Abstract class for 2D plots.
 //
 // .SECTION Description
+// The base class for all plot types used in vtkChart derived charts.
 //
+// .SECTION See Also
+// vtkPlotPoints vtkPlotLine vtkPlotBar vtkChart vtkChartXY
 
 #ifndef __vtkPlot_h
 #define __vtkPlot_h
 
 #include "vtkContextItem.h"
+#include "vtkSmartPointer.h"  // Needed to hold SP ivars
 
 class vtkVariant;
 class vtkTable;
+class vtkStdString;
 class vtkIdTypeArray;
 class vtkContextMapper2D;
 class vtkPen;
 class vtkBrush;
 class vtkAxis;
 class vtkVector2f;
+class vtkRectf;
+class vtkStringArray;
 
 class VTK_CHARTS_EXPORT vtkPlot : public vtkContextItem
 {
@@ -39,19 +46,25 @@ public:
   virtual void PrintSelf(ostream &os, vtkIndent indent);
 
   // Description:
-  // Paint legend event for the XY plot, called whenever the legend needs the
+  // Paint legend event for the plot, called whenever the legend needs the
   // plot items symbol/mark/line drawn. A rect is supplied with the lower left
   // corner of the rect (elements 0 and 1) and with width x height (elements 2
-  // and 3). The plot can choose how to fill the space supplied.
-  virtual bool PaintLegend(vtkContext2D *painter, float rect[4]);
+  // and 3). The plot can choose how to fill the space supplied. The index is used
+  // by Plots that return more than one label.
+  virtual bool PaintLegend(vtkContext2D *painter, const vtkRectf& rect,
+                           int legendIndex);
 
 //BTX
   // Description:
   // Function to query a plot for the nearest point to the specified coordinate.
-  virtual bool GetNearestPoint(const vtkVector2f& point,
-                               const vtkVector2f& tolerance,
-                               vtkVector2f* location);
+  // Returns the index of the data series with which the point is associated or
+  // -1.
+  virtual int GetNearestPoint(const vtkVector2f& point,
+                              const vtkVector2f& tolerance,
+                              vtkVector2f* location);
 
+  // Description:
+  // Select all points in the specified rectangle.
   virtual bool SelectPoints(const vtkVector2f& min, const vtkVector2f& max);
 //ETX
 
@@ -61,6 +74,7 @@ public:
                         unsigned char a);
   virtual void SetColor(double r,  double g, double b);
   virtual void GetColor(double rgb[3]);
+  void GetColor(unsigned char rgb[3]);
 
   // Description:
   // Set the width of the line.
@@ -81,12 +95,28 @@ public:
   vtkGetObjectMacro(Brush, vtkBrush);
 
   // Description:
-  // Set the plot label.
-  vtkSetStringMacro(Label);
+  // Set a single label on this plot.
+  void SetLabel(const vtkStdString &label);
 
   // Description:
-  // Get the plot label.
-  const char* GetLabel();
+  // Get the single label of this plot.
+  vtkStdString GetLabel();
+
+  // Description:
+  // Set the plot labels.
+  void SetLabels(vtkStringArray *labels);
+
+  // Description:
+  // Get the plot labels.
+  virtual vtkStringArray *GetLabels();
+
+  // Description:
+  // Get the number of labels associated with this plot.
+  virtual int GetNumberOfLabels();
+
+  // Description:
+  // Get the label at the specified index.
+  vtkStdString GetLabel(vtkIdType index);
 
   // Description:
   // Get the data object that the plot will draw.
@@ -106,8 +136,8 @@ public:
   // This is a convenience function to set the input table and the x, y column
   // for the plot.
   virtual void SetInput(vtkTable *table);
-  virtual void SetInput(vtkTable *table, const char *xColumn,
-                        const char *yColumn);
+  virtual void SetInput(vtkTable *table, const vtkStdString &xColumn,
+                        const vtkStdString &yColumn);
   void SetInput(vtkTable *table, vtkIdType xColumn, vtkIdType yColumn);
 
   // Description:
@@ -115,10 +145,10 @@ public:
   virtual vtkTable* GetInput();
 
   // Description:
-  // Convenience function to set the input arrays. For most mappers index 0
+  // Convenience function to set the input arrays. For most plots index 0
   // is the x axis, and index 1 is the y axis. The name is the name of the
   // column in the vtkTable.
-  virtual void SetInputArray(int index, const char *name);
+  virtual void SetInputArray(int index, const vtkStdString &name);
 
   virtual void SetSelection(vtkIdTypeArray *id);
   vtkGetObjectMacro(Selection, vtkIdTypeArray);
@@ -133,6 +163,8 @@ public:
   vtkGetObjectMacro(YAxis, vtkAxis);
   virtual void SetYAxis(vtkAxis* axis);
 
+  // Description:
+  // Get the bounds for this plot as (Xmin, Xmax, Ymin, Ymax).
   virtual void GetBounds(double bounds[4])
   { bounds[0] = bounds[1] = bounds[2] = bounds[3] = 0.0; }
 
@@ -140,8 +172,8 @@ public:
   // Description:
   // A General setter/getter that should be overridden. It can silently drop
   // options, case is important
-  void SetProperty(const char *property, vtkVariant *var);
-  vtkVariant GetProperty(const char *property);
+  virtual void SetProperty(const vtkStdString &property, const vtkVariant &var);
+  virtual vtkVariant GetProperty(const vtkStdString &property);
 //ETX
 
 //BTX
@@ -158,8 +190,12 @@ protected:
   vtkBrush* Brush;
 
   // Description:
-  // Plot label, used by legend.
-  char *Label;
+  // Plot labels, used by legend.
+  vtkSmartPointer<vtkStringArray> Labels;
+
+  // Description:
+  // Holds Labels when they're auto-created
+  vtkSmartPointer<vtkStringArray> AutoLabels;
 
   // Description:
   // Use the Y array index for the X value. If true any X column setting will be
