@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkStreamingDemandDrivenPipeline.h,v $
+  Module:    vtkStreamingDemandDrivenPipeline.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -38,7 +38,7 @@ class VTK_FILTERING_EXPORT vtkStreamingDemandDrivenPipeline : public vtkDemandDr
 {
 public:
   static vtkStreamingDemandDrivenPipeline* New();
-  vtkTypeRevisionMacro(vtkStreamingDemandDrivenPipeline,vtkDemandDrivenPipeline);
+  vtkTypeMacro(vtkStreamingDemandDrivenPipeline,vtkDemandDrivenPipeline);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -108,20 +108,9 @@ public:
   int GetUpdateNumberOfPieces(vtkInformation *);
   int SetUpdateGhostLevel(vtkInformation *, int n);
   int GetUpdateGhostLevel(vtkInformation *);
-
-  // Description:
-  // Convenience method to set a particular minor update piece within
-  // a particular major update piece. For example, when streaming in
-  // parallel. This is needed in paraview, to let each processor set 
-  // their own piece locally, independent of processor.
-  int SetSplitUpdateExtent(int port, 
-                           int major, int minor,
-                           int numPieces, 
-                           int ghostLevel)
-  {
-    return this->SetUpdateExtent(port, major+minor, numPieces, ghostLevel);
-  }
-  
+  int SetUpdateResolution(int port, double r);
+  int SetUpdateResolution(vtkInformation *, double r);
+  double GetUpdateResolution(vtkInformation *);
 
   // Description:
   // Get/Set the update extent for output ports that use Temporal Extents
@@ -156,6 +145,14 @@ public:
   void GetWholeBoundingBox(int port, double bb[6]);
   double* GetWholeBoundingBox(int port);
 
+  // Description:
+  // Set/Get the piece bounding box of an output port data object.
+  // The piece bounding box is meta data for data sets.  It gets
+  // set by the algorithm during the update extent information pass.
+  int SetPieceBoundingBox(int port, double bb[6]);
+  void GetPieceBoundingBox(int port, double bb[6]);
+  double* GetPieceBoundingBox(int port);
+
   // Description:
   // Key defining a request to propagate the update extent upstream.
   static vtkInformationRequestKey* REQUEST_UPDATE_EXTENT();
@@ -165,6 +162,10 @@ public:
   // extent downstream.
   static vtkInformationRequestKey* REQUEST_UPDATE_EXTENT_INFORMATION();
 
+  // Description:
+  // Key defining to propagate resolution changes up the pipeline.
+  static vtkInformationRequestKey* REQUEST_RESOLUTION_PROPAGATE();
+
   // Description:
   // Key for an algorithm to store in a request to tell this executive
   // to keep executing it.
@@ -191,6 +192,12 @@ public:
   // Key to store the whole extent provided in pipeline information.
   static vtkInformationIntegerVectorKey* WHOLE_EXTENT();
 
+  // Description:
+  // This is set if the update extent is not restricted to the
+  // whole extent, for sources that can generate an extent of
+  // any requested size.
+  static vtkInformationIntegerKey* UNRESTRICTED_UPDATE_EXTENT();
+
   // Description:
   // Key to store the maximum number of pieces provided in pipeline
   // information.
@@ -223,9 +230,20 @@ public:
   static vtkInformationDoubleVectorKey* UPDATE_TIME_STEPS();
 
   // Description:
-  // Key to specify from 0 to 1 the priority of this update extent
+  // Key that specifies from 0.0 to 1.0 the pipeline computed priority 
+  // of this update extent. 0.0 means does not contribute and can 
+  // be skipped.
   static vtkInformationDoubleKey* PRIORITY();
 
+  // Description:
+  // Key that specifies a requested resolution level for this update
+  // extent. 0.0 is very low and 1.0 is full resolution.
+  static vtkInformationDoubleKey* UPDATE_RESOLUTION();
+
+  // Description:
+  // Used internally to validate meta information as it flows through pipeline
+  static vtkInformationIntegerKey* REMOVE_ATTRIBUTE_INFORMATION();
+
   // Description:
   // The following keys are meant to be used by an algorithm that 
   // works with temporal data. Rather than re-executing the pipeline
