@@ -65,24 +65,16 @@ void vtkPContingencyStatistics::PrintSelf(ostream& os, vtkIndent indent)
 }
 
 //-----------------------------------------------------------------------------
-void PackValues( const vtkstd::vector<vtkStdString>& values, 
+void PackValues( const vtkstd::vector<vtkStdString>& values,
                  vtkStdString& buffer )
 {
-#if defined(_MSC_VER) && (_MSC_VER <= 1200)
-    buffer.resize( 0 );
-#else // defined(_MSC_VER) && (_MSC_VER <= 1200)
     buffer.clear();
-#endif // defined(_MSC_VER) && (_MSC_VER <= 1200)
 
   for( vtkstd::vector<vtkStdString>::const_iterator it = values.begin();
        it != values.end(); ++ it )
     {
     buffer.append( *it );
-#if defined(_MSC_VER) && (_MSC_VER <= 1200)
-    buffer.append( 1, 0 );
-#else // defined(_MSC_VER) && (_MSC_VER <= 1200)
     buffer.push_back( 0 );
-#endif // defined(_MSC_VER) && (_MSC_VER <= 1200)
     }
 }
 
@@ -90,11 +82,7 @@ void PackValues( const vtkstd::vector<vtkStdString>& values,
 void UnpackValues( const vtkStdString& buffer,
                    vtkstd::vector<vtkStdString>& values )
 {
-#if defined(_MSC_VER) && (_MSC_VER <= 1200)
-    values.resize( 0 );
-#else // defined(_MSC_VER) && (_MSC_VER <= 1200)
     values.clear();
-#endif // defined(_MSC_VER) && (_MSC_VER <= 1200)
 
   const char* const bufferEnd = &buffer[0] + buffer.size();
 
@@ -115,14 +103,13 @@ void UnpackValues( const vtkStdString& buffer,
 // ----------------------------------------------------------------------
 void vtkPContingencyStatistics::Learn( vtkTable* inData,
                                        vtkTable* inParameters,
-                                       vtkDataObject* outMetaDO )
+                                       vtkMultiBlockDataSet* outMeta )
 {
 #if DEBUG_PARALLEL_CONTINGENCY_STATISTICS
   vtkTimerLog *timer=vtkTimerLog::New();
   timer->StartTimer();
 #endif //DEBUG_PARALLEL_CONTINGENCY_STATISTICS
 
-  vtkMultiBlockDataSet* outMeta = vtkMultiBlockDataSet::SafeDownCast( outMetaDO );
   if ( ! outMeta )
     {
 #if DEBUG_PARALLEL_CONTINGENCY_STATISTICS
@@ -232,7 +219,7 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
     }
 
   // NB: Use process 0 as sole reducer for now
-  vtkIdType reduceProc = 0; 
+  vtkIdType reduceProc = 0;
 
   // (All) gather all xy and kc sizes
   vtkIdType xySize_l = xyPacked_l.size();
@@ -273,7 +260,7 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
     xyPacked_g = new char[xySizeTotal];
     kcValues_g = new vtkIdType[kcSizeTotal];
     }
-  
+
   // Gather all xyPacked and kcValues on process reduceProc
   // NB: GatherV because the packets have variable lengths
   if ( ! com->GatherV( &(*xyPacked_l.begin()),
@@ -289,7 +276,7 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
 
     return;
     }
-  
+
   if ( ! com->GatherV( &(*kcValues_l.begin()),
                        kcValues_g,
                        kcSize_l,
@@ -344,11 +331,11 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
        << timerB->GetElapsedTime()
        << " seconds."
        << "\n";
-  
+
   timerB->Delete();
 #endif //DEBUG_PARALLEL_CONTINGENCY_STATISTICS
 
-  // Finally, fill the new, global contigency table (everyone does this so everyone ends up with the same model)
+  // Finally, fill the new, global contingency table (everyone does this so everyone ends up with the same model)
   vtkVariantArray* row4 = vtkVariantArray::New();
   row4->SetNumberOfValues( 4 );
 
@@ -377,7 +364,7 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
 
    contingencyTab->InsertNextRow( row4 );
    }
-    
+
   // Clean up
   row4->Delete();
 
@@ -401,7 +388,7 @@ void vtkPContingencyStatistics::Learn( vtkTable* inData,
        << timer->GetElapsedTime()
        << " seconds."
        << "\n";
-  
+
   timer->Delete();
 #endif //DEBUG_PARALLEL_CONTINGENCY_STATISTICS
 }
@@ -461,9 +448,9 @@ bool vtkPContingencyStatistics::Reduce( vtkIdType& xySizeTotal,
 #endif //DEBUG_PARALLEL_CONTINGENCY_STATISTICS
 
   // First, unpack the packet of strings
-  vtkstd::vector<vtkStdString> xyValues_g; 
+  vtkstd::vector<vtkStdString> xyValues_g;
   UnpackValues( vtkStdString ( xyPacked_g, xySizeTotal ), xyValues_g );
-  
+
   // Second, check consistency: we must have the same number of xy and kc entries
   if ( vtkIdType( xyValues_g.size() ) != kcSizeTotal )
     {
@@ -489,10 +476,10 @@ bool vtkPContingencyStatistics::Reduce( vtkIdType& xySizeTotal,
     contingencyTable
       [kcValues_g[i]]
       [*vit]
-      [*(vit + 1)] 
+      [*(vit + 1)]
       += kcValues_g[i + 1];
     }
-    
+
   // Fourth, prepare send buffers of (global) xy and kc values
   vtkstd::vector<vtkStdString> xyValues_l;
   kcValues_l.clear();
@@ -510,7 +497,7 @@ bool vtkPContingencyStatistics::Reduce( vtkIdType& xySizeTotal,
         // Push back x and y to list of strings
         xyValues_l.push_back( bit->first );  // x
         xyValues_l.push_back( dit->first );  // y
-          
+
         // Push back (X,Y) index and #(x,y) to list of strings
         kcValues_l.push_back( ait->first );  // k
         kcValues_l.push_back( dit->second ); // c
@@ -518,7 +505,7 @@ bool vtkPContingencyStatistics::Reduce( vtkIdType& xySizeTotal,
       }
     }
   PackValues( xyValues_l, xyPacked_l );
-    
+
   // Last, update xy and kc buffer sizes (which have changed because of the reduction)
   xySizeTotal = xyPacked_l.size();
   kcSizeTotal = kcValues_l.size();
@@ -556,7 +543,7 @@ bool vtkPContingencyStatistics::Broadcast( vtkIdType xySizeTotal,
     vtkErrorMacro("Process "
                   << com->GetLocalProcessId()
                   << " could not broadcast (x,y) buffer size.");
-    
+
     return true;
     }
 
@@ -567,10 +554,10 @@ bool vtkPContingencyStatistics::Broadcast( vtkIdType xySizeTotal,
     vtkErrorMacro("Process "
                   << com->GetLocalProcessId()
                   << " could not broadcast (k,c) buffer size.");
-    
+
     return true;
     }
-  
+
   // Resize vectors so they can receive the broadcasted xy and kc values
   xyPacked.resize( xySizeTotal );
   kcValues.resize( kcSizeTotal );
@@ -583,10 +570,10 @@ bool vtkPContingencyStatistics::Broadcast( vtkIdType xySizeTotal,
     vtkErrorMacro("Process "
                   << com->GetLocalProcessId()
                   << " could not broadcast (x,y) values.");
-    
+
     return true;
     }
-  
+
   if ( ! com->Broadcast( &(*kcValues.begin()),
                          kcSizeTotal,
                          reduceProc ) )
@@ -594,12 +581,12 @@ bool vtkPContingencyStatistics::Broadcast( vtkIdType xySizeTotal,
     vtkErrorMacro("Process "
                   << com->GetLocalProcessId()
                   << " could not broadcast (k,c) values.");
-    
+
     return true;
     }
-  
+
   // Unpack the packet of strings
   UnpackValues( xyPacked, xyValues );
 
   return false;
-} 
+}
