@@ -32,6 +32,7 @@
 #include "vtkMultiProcessController.h"
 
 #include "VPICDataSet.h"
+#include "GridExchange.h"
 #include "VPICView.h"
 
 vtkStandardNewMacro(vtkVPICReader);
@@ -47,6 +48,7 @@ vtkVPICReader::vtkVPICReader()
   this->FileName = NULL;
   this->NumberOfNodes = 0;
   this->NumberOfVariables = 0;
+  this->CurrentTimeStep = -1;
   this->PointDataArraySelection = vtkDataArraySelection::New();
 
   // Setup selection callback to modify this object when array selection changes
@@ -57,9 +59,30 @@ vtkVPICReader::vtkVPICReader()
                                              this->SelectionObserver);
   // External VPICDataSet for actually reading files
   this->vpicData = 0;
-  
+  this->exchanger = 0;
+  this->VariableName = 0;
+  this->VariableStruct = 0;
+  this->TimeSteps = 0;
+  this->dataLoaded = 0;
+  this->data = 0;
+
+  // One overlap cell on first plane and one extra on last plane
+  this->ghostLevel0 = 1;
+  this->ghostLevel1 = 2;
+
+  this->Stride[0] = 1;
+  this->Stride[1] = 1;
+  this->Stride[2] = 1;
+
+  this->XLayout[0] = 1;
+  this->YLayout[0] = 1;
+  this->ZLayout[0] = 1;
+  this->XLayout[1] = -1;
+  this->YLayout[1] = -1;
+  this->ZLayout[1] = -1;
+
   this->MPIController = vtkMultiProcessController::GetGlobalController();
-  
+
   if(this->MPIController)
     {
     this->Rank = this->MPIController->GetLocalProcessId();
@@ -70,7 +93,7 @@ vtkVPICReader::vtkVPICReader()
     this->Rank = 0;
     this->TotalRank = 1;
     }
-}  
+}
 
 //----------------------------------------------------------------------------
 // Destructor for VPIC Reader
@@ -82,9 +105,33 @@ vtkVPICReader::~vtkVPICReader()
     delete [] this->FileName;
     }
   this->PointDataArraySelection->Delete();
-  for (int var = 0; var < this->NumberOfVariables; var++) {
-      this->data[var]->Delete();
+
+  if (this->vpicData)
+    delete this->vpicData;
+  if (this->VariableName)
+    delete [] this->VariableName;
+  if (this->VariableStruct)
+    delete [] this->VariableStruct;
+  if (this->TimeSteps)
+    delete [] this->TimeSteps;
+  if (this->dataLoaded)
+    delete [] this->dataLoaded;
+
+  if (this->exchanger)
+    delete this->exchanger;
+
+  if (this->data)
+    {
+    for (int var = 0; var < this->NumberOfVariables; var++)
+      {
+      if (this->data[var])
+        {
+        this->data[var]->Delete();
+        }
+      }
+    delete [] this->data;
     }
+
   this->SelectionObserver->Delete();
 
   // Do not delete the MPIController it is Singleton like and will
@@ -99,7 +146,7 @@ int vtkVPICReader::RequestInformation(
   vtkInformation *vtkNotUsed(reqInfo),
   vtkInformationVector **vtkNotUsed(inVector),
   vtkInformationVector *outVector)
-{ 
+{
   // Verify that file exists
   if ( !this->FileName ) {
     vtkErrorMacro("No filename specified");
@@ -147,9 +194,11 @@ int vtkVPICReader::RequestInformation(
 
     // Allocate the ParaView data arrays which will hold the variable data
     this->data = new vtkFloatArray*[this->NumberOfVariables];
+    this->dataLoaded = new int[this->NumberOfVariables];
     for (int var = 0; var < this->NumberOfVariables; var++) {
       this->data[var] = vtkFloatArray::New();
       this->data[var]->SetName(VariableName[var].c_str());
+      this->dataLoaded[var] = 0;
     }
 
     // Set the overall problem file decomposition for the GUI extent range
@@ -164,10 +213,6 @@ int vtkVPICReader::RequestInformation(
     outInfo->Set(vtkStreamingDemandDrivenPipeline::MAXIMUM_NUMBER_OF_PIECES(),
                  this->NumberOfPieces);
 
-    // Set ghost cell level
-    outInfo->Set(
-      vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), 1);
-
     // Collect temporal information
     this->NumberOfTimeSteps = this->vpicData->getNumberOfTimeSteps();
     this->TimeSteps = NULL;
@@ -206,6 +251,10 @@ int vtkVPICReader::RequestInformation(
   // to 0 so that by setting to the default of 1, the partition has be to done
   if (this->vpicData->needsGridCalculation() == true) {
 
+    // If grid is recalculated all data must be realoaded
+    for (int var = 0; var < this->NumberOfVariables; var++)
+      this->dataLoaded[var] = 0;
+
     // Partitions the data between processors and sets grid extents
     this->vpicData->calculateGridExtents();
 
@@ -225,10 +274,11 @@ int vtkVPICReader::RequestInformation(
     // Some processors might not get a piece of data to render
     vtkTableExtentTranslator *extentTable = vtkTableExtentTranslator::New();
     int processorUsed = this->vpicData->getProcessorUsed();
-    
+
     if(this->MPIController)
       {
-      this->MPIController->AllReduce(&processorUsed, &this->UsedRank, 1, vtkCommunicator::SUM_OP);
+      this->MPIController->AllReduce(&processorUsed, &this->UsedRank,
+                                     1, vtkCommunicator::SUM_OP);
       }
 
     extentTable->SetNumberOfPieces(this->UsedRank);
@@ -238,28 +288,81 @@ int vtkVPICReader::RequestInformation(
       this->vpicData->getSubExtent(piece, subextent);
       extentTable->SetExtentForPiece(piece, subextent);
     }
-    extentTable->SetMaximumGhostLevel(0);
+    this->vpicData->getSubExtent(this->Rank, this->SubExtent);
+    extentTable->SetPiece(this->Rank);
+    extentTable->SetWholeExtent(this->WholeExtent);
+    extentTable->SetExtent(this->SubExtent);
+
     vtkStreamingDemandDrivenPipeline* pipeline =
       vtkStreamingDemandDrivenPipeline::SafeDownCast(this->GetExecutive());
     pipeline->SetExtentTranslator(outInfo, extentTable);
     extentTable->Delete();
 
+    // Reset the SubExtent on this processor to include ghost cells
+    // Leave the subextents in the extent table as the size without ghosts
+    for (int dim = 0; dim < DIMENSION; dim++) {
+      if (this->SubExtent[dim*2] != 0)
+        this->SubExtent[dim*2] -= 1;
+      if (this->SubExtent[dim*2+1] != this->Dimension[dim] - 1)
+        this->SubExtent[dim*2+1] += 1;
+    }
+
     // Set the subextent dimension size
-    this->vpicData->getSubExtent(this->Rank, this->SubExtent);
     if (processorUsed == 1) {
       this->SubDimension[0] = this->SubExtent[1] - this->SubExtent[0] + 1;
       this->SubDimension[1] = this->SubExtent[3] - this->SubExtent[2] + 1;
       this->SubDimension[2] = this->SubExtent[5] - this->SubExtent[4] + 1;
-   } else {
+    } else {
       this->SubDimension[0] = 0;
       this->SubDimension[1] = 0;
       this->SubDimension[2] = 0;
-   }
+    }
 
     // Total size of the subextent
     this->NumberOfTuples = 1;
     for (int dim = 0; dim < DIMENSION; dim++)
       this->NumberOfTuples *= this->SubDimension[dim];
+
+    // Set ghost cell edges
+    this->NumberOfGhostTuples = 1;
+    for (int dim = 0; dim < DIMENSION; dim++) {
+
+      // Local block dimensions for loading a component of data
+      // Different number of ghost cells are added depending on where the
+      // processor is in the problem grid
+      this->GhostDimension[dim] = this->SubDimension[dim];
+
+      // If processor is on an edge don't write a ghost cell (offset the start)
+      this->Start[dim] = 0;
+      if (SubExtent[dim*2] == 0) {
+        this->Start[dim] = this->ghostLevel0;
+        this->GhostDimension[dim] += this->ghostLevel0;
+      }
+
+      // Processors not on last plane already have one overlap cell
+      if (SubExtent[dim*2 + 1] == (this->Dimension[dim] - 1)) {
+        this->GhostDimension[dim] += this->ghostLevel1;
+      }
+
+      // Size of the local block for loading a component of data with ghosts
+      this->NumberOfGhostTuples *= this->GhostDimension[dim];
+    }
+
+#ifdef VTK_USE_MPI
+    if (this->TotalRank>1)
+      {
+      // Set up the GridExchange for sharing ghost cells on this view
+      int decomposition[DIMENSION];
+      this->vpicData->getDecomposition(decomposition);
+
+      if (this->exchanger)
+        delete this->exchanger;
+
+      this->exchanger = new GridExchange
+        (this->Rank, this->TotalRank, decomposition,
+         this->GhostDimension, this->ghostLevel0, this->ghostLevel1);
+      }
+#endif
   }
   return 1;
 }
@@ -273,13 +376,19 @@ int vtkVPICReader::RequestData(
   vtkInformationVector **vtkNotUsed(inVector),
   vtkInformationVector *outVector)
 {
-  // get the info object
   vtkInformation *outInfo = outVector->GetInformationObject(0);
-     
-  // Output will be an ImageData
   vtkImageData *output = vtkImageData::SafeDownCast(
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
+  // Even if the pipeline asks for a smaller subextent, give it the
+  // full subextent with ghosts
+  vtkStreamingDemandDrivenPipeline* pipeline =
+      vtkStreamingDemandDrivenPipeline::SafeDownCast(this->GetExecutive());
+  pipeline->SetUpdateExtent(outInfo, this->SubExtent);
+
+  // Set the subextent for this processor
+  output->SetExtent(this->SubExtent);
+
   // Ask VPICDataSet to check for additional time steps
   // If found VPICDataSet will update its structure
   this->vpicData->addNewTimeSteps();
@@ -309,7 +418,7 @@ int vtkVPICReader::RequestData(
   // Collect the time step requested
   double* requestedTimeSteps = NULL;
   int numRequestedTimeSteps = 0;
-  vtkInformationDoubleVectorKey* timeKey = 
+  vtkInformationDoubleVectorKey* timeKey =
     static_cast<vtkInformationDoubleVectorKey*>
       (vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEPS());
 
@@ -325,10 +434,17 @@ int vtkVPICReader::RequestData(
 
   // Index of the time step to request
   int timeStep = 0;
-  while (timeStep < this->NumberOfTimeSteps && 
+  while (timeStep < this->NumberOfTimeSteps &&
          this->TimeSteps[timeStep] < dTime)
     timeStep++;
 
+  // If this is a new time step read all the data from files
+  int timeChanged = 0;
+  if (this->CurrentTimeStep != timeStep) {
+    timeChanged = 1;
+    this->CurrentTimeStep = timeStep;
+  }
+
   // Get size information from the VPICDataSet to set ImageData
   double origin[DIMENSION], step[DIMENSION];
   this->vpicData->getOrigin(origin);
@@ -336,18 +452,19 @@ int vtkVPICReader::RequestData(
   output->SetSpacing(step);
   output->SetOrigin(origin);
 
-  // Set the subextent for this processor
-  outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), 
-               this->SubExtent);
-  output->SetExtent(this->SubExtent);
-
   // Examine each variable to see if it is selected
   for (int var = 0; var < this->NumberOfVariables; var++) {
 
     // Is this variable requested
     if (this->PointDataArraySelection->GetArraySetting(var)) {
-      LoadVariableData(var, timeStep);
+      if (this->dataLoaded[var] == 0 || timeChanged) {
+        LoadVariableData(var, timeStep);
+        this->dataLoaded[var] = 1;
+      }
       output->GetPointData()->AddArray(this->data[var]);
+
+    } else {
+      this->dataLoaded[var] = 0;
     }
   }
   return 1;
@@ -358,6 +475,16 @@ int vtkVPICReader::RequestData(
 //----------------------------------------------------------------------------
 void vtkVPICReader::LoadVariableData(int var, int timeStep)
 {
+  this->data[var]->Delete();
+  this->data[var] = vtkFloatArray::New();
+  this->data[var]->SetName(VariableName[var].c_str());
+
+  /*
+  if (this->Rank == 0)
+    cout << "LoadVariableData " << this->VariableName[var]
+         << " time " << timeStep << endl;
+  */
+
   // First set the number of components for this variable
   int numberOfComponents = 0;
   if (this->VariableStruct[var] == SCALAR) {
@@ -377,23 +504,26 @@ void vtkVPICReader::LoadVariableData(int var, int timeStep)
   this->data[var]->SetNumberOfTuples(this->NumberOfTuples);
 
   // For each component of the requested variable load data
-  float* block = new float[this->NumberOfTuples];
+  float* block = new float[this->NumberOfGhostTuples];
   float* varData = this->data[var]->GetPointer(0);
-  int pos;
 
   for (int comp = 0; comp < numberOfComponents; comp++) {
 
     // Fetch the data for a single component into temporary storage
-    this->vpicData->loadVariableData(block, timeStep, var, comp);
+    this->vpicData->loadVariableData(block, this->ghostLevel0,
+                                     this->GhostDimension, timeStep, var, comp);
 
-    if (this->VariableStruct[var] != TENSOR) {
-
-      // Load into the data array by tuple so place data every comp'th spot
-      pos = comp;
-      for (int index = 0; index < this->NumberOfTuples; index++) {
-         varData[pos] = block[index];
-         pos += numberOfComponents;
+    // Exchange the single component block retrieved from files to get ghosts
+#ifdef VTK_USE_MPI
+    if (this->TotalRank>1)
+      {
+      this->exchanger->exchangeGrid(block);
       }
+#endif
+
+    // Load the ghost component block into ParaView array
+    if (this->VariableStruct[var] != TENSOR) {
+      LoadComponent(varData, block, comp, numberOfComponents);
     }
 
     else {
@@ -401,61 +531,25 @@ void vtkVPICReader::LoadVariableData(int var, int timeStep)
       // (0->0) (1->4) (2->8) (3->5,7) (4->2,6) (5->1,3)
       switch (comp) {
       case 0:
-        pos = 0;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 0, TENSOR9_DIMENSION);
         break;
       case 1:
-        pos = 4;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 4, TENSOR9_DIMENSION);
         break;
       case 2:
-        pos = 8;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 8, TENSOR9_DIMENSION);
         break;
       case 3:
-        pos = 5;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
-        pos = 7;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 5, TENSOR9_DIMENSION);
+        LoadComponent(varData, block, 7, TENSOR9_DIMENSION);
         break;
       case 4:
-        pos = 2;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
-        pos = 6;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 2, TENSOR9_DIMENSION);
+        LoadComponent(varData, block, 6, TENSOR9_DIMENSION);
         break;
       case 5:
-        pos = 1;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
-        pos = 3;
-        for (int index = 0; index < this->NumberOfTuples; index++) {
-           varData[pos] = block[index];
-           pos += TENSOR9_DIMENSION;
-        }
+        LoadComponent(varData, block, 1, TENSOR9_DIMENSION);
+        LoadComponent(varData, block, 3, TENSOR9_DIMENSION);
         break;
       }
     }
@@ -463,6 +557,36 @@ void vtkVPICReader::LoadVariableData(int var, int timeStep)
   delete [] block;
 }
 
+//----------------------------------------------------------------------------
+// Load one component from the local VPIC ghost enhanced block into the
+// ParaView vtkFloatArray taking into account whether the processor is
+// on the front plane, the back plane or in the middle which affects
+// the ghost cells which can be loaded.  ParaView array is contiguous
+// memory so start at the right location and offset by number of components
+//----------------------------------------------------------------------------
+void vtkVPICReader::LoadComponent(float* varData, float* block,
+                                  int comp, int numberOfComponents)
+{
+
+  // Load into the data array by tuple so place data every comp'th spot
+  int pos = comp;
+  for (int k = 0; k < this->SubDimension[2]; k++) {
+    int kk = k + this->Start[2];
+    for (int j = 0; j < this->SubDimension[1]; j++) {
+      int jj = j + this->Start[1];
+      for (int i = 0; i < this->SubDimension[0]; i++) {
+        int ii = i + this->Start[0];
+
+        int index = (kk * this->GhostDimension[0] * this->GhostDimension[1]) +
+                    (jj * this->GhostDimension[0]) + ii;
+
+        varData[pos] = block[index];
+        pos += numberOfComponents;
+      }
+    }
+  }
+}
+
 //----------------------------------------------------------------------------
 void vtkVPICReader::SelectionCallback(vtkObject*, unsigned long vtkNotUsed(eventid),
                                       void* clientdata, void* vtkNotUsed(calldata))
@@ -491,47 +615,47 @@ vtkImageData* vtkVPICReader::GetOutput(int idx)
 
 //----------------------------------------------------------------------------
 int vtkVPICReader::GetNumberOfPointArrays()
-{   
+{
   return this->PointDataArraySelection->GetNumberOfArrays();
-}   
-    
+}
+
 //----------------------------------------------------------------------------
 void vtkVPICReader::EnableAllPointArrays()
-{     
+{
     this->PointDataArraySelection->EnableAllArrays();
 }
-  
+
 //----------------------------------------------------------------------------
 void vtkVPICReader::DisableAllPointArrays()
-{   
+{
     this->PointDataArraySelection->DisableAllArrays();
-}   
-    
+}
+
 //----------------------------------------------------------------------------
 const char* vtkVPICReader::GetPointArrayName(int index)
-{   
+{
   return this->VariableName[index].c_str();
-} 
-  
+}
+
 //----------------------------------------------------------------------------
 int vtkVPICReader::GetPointArrayStatus(const char* name)
-{ 
+{
   return this->PointDataArraySelection->ArrayIsEnabled(name);
-} 
+}
 
 //----------------------------------------------------------------------------
 void vtkVPICReader::SetPointArrayStatus(const char* name, int status)
-{           
-  if (status) 
+{
+  if (status)
     this->PointDataArraySelection->EnableArray(name);
   else
     this->PointDataArraySelection->DisableArray(name);
-}   
+}
 
 void vtkVPICReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   os << indent << "FileName: " << (this->FileName != NULL ? this->FileName : "") << endl;
-  os << indent << "Stride: {" << this->Stride[0] << ", " << this->Stride[1] 
+  os << indent << "Stride: {" << this->Stride[0] << ", " << this->Stride[1]
      << ", " << this->Stride[2] << "}" << endl;
   os << indent << "XLayout: {" << this->XLayout[0] << ", " << this->XLayout[1] << "}" << endl;
   os << indent << "YLayout: {" << this->YLayout[0] << ", " << this->YLayout[1] << "}" << endl;
