@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkInteractorStyleTrackballActor.cxx,v $
+  Module:    vtkInteractorStyleTrackballActor.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,7 +25,6 @@
 #include "vtkRenderer.h"
 #include "vtkTransform.h"
 
-vtkCxxRevisionMacro(vtkInteractorStyleTrackballActor, "$Revision: 1.35 $");
 vtkStandardNewMacro(vtkInteractorStyleTrackballActor);
 
 //----------------------------------------------------------------------------
@@ -258,25 +257,21 @@ void vtkInteractorStyleTrackballActor::Rotate()
   
   double radius = sqrt(vtkMath::Distance2BetweenPoints(disp_obj_center,
                                                        outsidept));
-  double nxf = 
-    ((double)rwi->GetEventPosition()[0] - (double)disp_obj_center[0]) / radius;
+  double nxf = (rwi->GetEventPosition()[0] - disp_obj_center[0]) / radius;
 
-  double nyf = 
-    ((double)rwi->GetEventPosition()[1] - (double)disp_obj_center[1]) / radius;
+  double nyf = (rwi->GetEventPosition()[1] - disp_obj_center[1]) / radius;
 
-  double oxf = 
-    ((double)rwi->GetLastEventPosition()[0] - (double)disp_obj_center[0]) / radius;
+  double oxf = (rwi->GetLastEventPosition()[0] - disp_obj_center[0]) / radius;
 
-  double oyf = 
-    ((double)rwi->GetLastEventPosition()[1] - (double)disp_obj_center[1]) / radius;
+  double oyf = (rwi->GetLastEventPosition()[1] - disp_obj_center[1]) / radius;
 
   if (((nxf * nxf + nyf * nyf) <= 1.0) &&
       ((oxf * oxf + oyf * oyf) <= 1.0))
     {
-    double newXAngle = asin(nxf) * vtkMath::RadiansToDegrees();
-    double newYAngle = asin(nyf) * vtkMath::RadiansToDegrees();
-    double oldXAngle = asin(oxf) * vtkMath::RadiansToDegrees();
-    double oldYAngle = asin(oyf) * vtkMath::RadiansToDegrees();
+    double newXAngle = vtkMath::DegreesFromRadians( asin( nxf ) );
+    double newYAngle = vtkMath::DegreesFromRadians( asin( nyf ) );
+    double oldXAngle = vtkMath::DegreesFromRadians( asin( oxf ) );
+    double oldYAngle = vtkMath::DegreesFromRadians( asin( oyf ) );
     
     double scale[3];
     scale[0] = scale[1] = scale[2] = 1.0;
@@ -319,7 +314,7 @@ void vtkInteractorStyleTrackballActor::Rotate()
 //----------------------------------------------------------------------------
 void vtkInteractorStyleTrackballActor::Spin()
 {
-  if (this->CurrentRenderer == NULL || this->InteractionProp == NULL)
+  if ( this->CurrentRenderer == NULL || this->InteractionProp == NULL )
     {
     return;
     }
@@ -338,12 +333,12 @@ void vtkInteractorStyleTrackballActor::Spin()
     {
     // If parallel projection, want to get the view plane normal...
     cam->ComputeViewPlaneNormal();
-    cam->GetViewPlaneNormal(motion_vector);
+    cam->GetViewPlaneNormal( motion_vector );
     }
   else
     {   
     // Perspective projection, get vector from eye to center of actor
-    cam->GetPosition(view_point);
+    cam->GetPosition( view_point );
     motion_vector[0] = view_point[0] - obj_center[0];
     motion_vector[1] = view_point[1] - obj_center[1];
     motion_vector[2] = view_point[2] - obj_center[2];
@@ -356,15 +351,12 @@ void vtkInteractorStyleTrackballActor::Spin()
                               disp_obj_center);
   
   double newAngle = 
-    atan2((double)rwi->GetEventPosition()[1] - (double)disp_obj_center[1],
-          (double)rwi->GetEventPosition()[0] - (double)disp_obj_center[0]);
+    vtkMath::DegreesFromRadians( atan2( rwi->GetEventPosition()[1] - disp_obj_center[1],
+                                        rwi->GetEventPosition()[0] - disp_obj_center[0] ) );
 
   double oldAngle = 
-    atan2((double)rwi->GetLastEventPosition()[1] - (double)disp_obj_center[1],
-          (double)rwi->GetLastEventPosition()[0] - (double)disp_obj_center[0]);
-  
-  newAngle *= vtkMath::RadiansToDegrees();
-  oldAngle *= vtkMath::RadiansToDegrees();
+    vtkMath::DegreesFromRadians( atan2( rwi->GetLastEventPosition()[1] - disp_obj_center[1],
+                                        rwi->GetLastEventPosition()[0] - disp_obj_center[0] ) );
   
   double scale[3];
   scale[0] = scale[1] = scale[2] = 1.0;
@@ -377,16 +369,16 @@ void vtkInteractorStyleTrackballActor::Spin()
   rotate[0][2] = motion_vector[1];
   rotate[0][3] = motion_vector[2];
   
-  this->Prop3DTransform(this->InteractionProp,
-                        obj_center,
-                        1, 
-                        rotate, 
-                        scale);
+  this->Prop3DTransform( this->InteractionProp,
+                         obj_center,
+                         1, 
+                         rotate, 
+                         scale );
   
   delete [] rotate[0];
   delete [] rotate;
   
-  if (this->AutoAdjustCameraClippingRange)
+  if ( this->AutoAdjustCameraClippingRange )
     {
     this->CurrentRenderer->ResetCameraClippingRange();
     }
@@ -414,13 +406,13 @@ void vtkInteractorStyleTrackballActor::Pan()
   this->ComputeWorldToDisplay(obj_center[0], obj_center[1], obj_center[2], 
                               disp_obj_center);
 
-  this->ComputeDisplayToWorld((double)rwi->GetEventPosition()[0], 
-                              (double)rwi->GetEventPosition()[1], 
+  this->ComputeDisplayToWorld(rwi->GetEventPosition()[0], 
+                              rwi->GetEventPosition()[1], 
                               disp_obj_center[2],
                               new_pick_point);
   
-  this->ComputeDisplayToWorld(double(rwi->GetLastEventPosition()[0]), 
-                              double(rwi->GetLastEventPosition()[1]), 
+  this->ComputeDisplayToWorld(rwi->GetLastEventPosition()[0], 
+                              rwi->GetLastEventPosition()[1], 
                               disp_obj_center[2],
                               old_pick_point);
   
@@ -472,8 +464,8 @@ void vtkInteractorStyleTrackballActor::Dolly()
   double *center = this->CurrentRenderer->GetCenter();
 
   int dy = rwi->GetEventPosition()[1] - rwi->GetLastEventPosition()[1];
-  double yf = (double)dy / (double)center[1] * this->MotionFactor;
-  double dollyFactor = pow((double)1.1, yf);
+  double yf = dy / center[1] * this->MotionFactor;
+  double dollyFactor = pow(1.1, yf);
   
   dollyFactor -= 1.0;
   motion_vector[0] = (view_point[0] - view_focus[0]) * dollyFactor;
@@ -518,8 +510,8 @@ void vtkInteractorStyleTrackballActor::UniformScale()
   double *obj_center = this->InteractionProp->GetCenter();
   double *center = this->CurrentRenderer->GetCenter();
 
-  double yf = (double)dy / (double)center[1] * this->MotionFactor;
-  double scaleFactor = pow((double)1.1, yf);
+  double yf = dy / center[1] * this->MotionFactor;
+  double scaleFactor = pow(1.1, yf);
   
   double **rotate = NULL;
   
