@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkOpenGLRenderWindow.cxx,v $
+  Module:    vtkOpenGLRenderWindow.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -21,19 +21,22 @@
 #include "vtkOpenGLActor.h"
 #include "vtkOpenGLCamera.h"
 #include "vtkOpenGLExtensionManager.h"
+#include "vtkOpenGLHardwareSupport.h"
 #include "vtkOpenGLLight.h"
 #include "vtkOpenGLPolyDataMapper.h"
 #include "vtkOpenGLProperty.h"
 #include "vtkOpenGLRenderer.h"
 #include "vtkOpenGLTexture.h"
 #include "vtkUnsignedCharArray.h"
+#include "vtkTextureUnitManager.h"
 
 #ifndef VTK_IMPLEMENT_MESA_CXX
 
-vtkCxxRevisionMacro(vtkOpenGLRenderWindow, "$Revision: 1.99 $");
 #endif
 
 vtkCxxSetObjectMacro(vtkOpenGLRenderWindow, ExtensionManager, vtkOpenGLExtensionManager);
+vtkCxxSetObjectMacro(vtkOpenGLRenderWindow, HardwareSupport, vtkOpenGLHardwareSupport);
+vtkCxxSetObjectMacro(vtkOpenGLRenderWindow, TextureUnitManager, vtkTextureUnitManager);
 
 #define MAX_LIGHTS 8
 
@@ -53,7 +56,10 @@ int vtkOpenGLRenderWindow::GetGlobalMaximumNumberOfMultiSamples()
 
 vtkOpenGLRenderWindow::vtkOpenGLRenderWindow()
 {
-  this->ExtensionManager = 0;
+  this->ExtensionManager = NULL;
+  this->HardwareSupport = NULL;
+  this->TextureUnitManager=0;
+  
   this->MultiSamples = vtkOpenGLRenderWindowGlobalMaximumNumberOfMultiSamples;
   this->TextureResourceIds = vtkIdList::New();
   if ( this->WindowName ) 
@@ -77,11 +83,23 @@ vtkOpenGLRenderWindow::vtkOpenGLRenderWindow()
 vtkOpenGLRenderWindow::~vtkOpenGLRenderWindow()
 {
   this->TextureResourceIds->Delete();
+  if(this->TextureUnitManager!=0)
+    {
+    this->TextureUnitManager->SetContext(0);
+    }
+  
   if (this->ExtensionManager)
     {
     this->ExtensionManager->SetRenderWindow(0);
     }
+  if (this->HardwareSupport)
+    {
+    this->HardwareSupport->SetExtensionManager(0);
+    //this->HardwareSupport->Delete();
+    }
+  this->SetTextureUnitManager(0);
   this->SetExtensionManager(0);
+  this->SetHardwareSupport(0);
 }
 
 // ----------------------------------------------------------------------------
@@ -179,6 +197,10 @@ void vtkOpenGLRenderWindow::StereoUpdate(void)
         break;      
       case VTK_STEREO_INTERLACED:
         this->StereoStatus = 1;
+        break;
+      case VTK_STEREO_CHECKERBOARD:
+        this->StereoStatus = 1;
+        break;
       }
     }
   else if ((!this->StereoRender) && this->StereoStatus)
@@ -200,6 +222,9 @@ void vtkOpenGLRenderWindow::StereoUpdate(void)
       case VTK_STEREO_INTERLACED:
         this->StereoStatus = 0;
         break;
+      case VTK_STEREO_CHECKERBOARD:
+        this->StereoStatus = 0;
+        break;
       }
     }
 }
@@ -207,9 +232,10 @@ void vtkOpenGLRenderWindow::StereoUpdate(void)
 
 void vtkOpenGLRenderWindow::OpenGLInit()
 {
-  // When a new OpenGL context is created, we want to get rid of the old OpenGL
-  // extension manager, if any.
-  this->SetExtensionManager(0);
+  // When a new OpenGL context is created, force an update
+  // of the extension manager by calling modified on it.
+  vtkOpenGLExtensionManager *extensions = this->GetExtensionManager();
+  extensions->Modified();
 
   this->ContextCreationTime.Modified();
   glMatrixMode( GL_MODELVIEW );
@@ -226,7 +252,6 @@ void vtkOpenGLRenderWindow::OpenGLInit()
   vtkgl::BlendFuncSeparate=0;
   
   // Try to initialize vtkgl::BlendFuncSeparate() if available.
-  vtkOpenGLExtensionManager *extensions = this->GetExtensionManager();
   if (extensions->ExtensionSupported("GL_VERSION_1_4"))
     {
     extensions->LoadExtension("GL_VERSION_1_4");
@@ -280,6 +305,16 @@ void vtkOpenGLRenderWindow::OpenGLInit()
   glEnable(GL_NORMALIZE);
   glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE);
   glAlphaFunc(GL_GREATER,0);
+  
+  // Default OpenGL is 4 bytes but it is only safe with RGBA format.
+  // If format is RGB, row alignment is 4 bytes only if the width is divisible
+  // by 4. Let's do it the safe way: 1-byte alignment.
+  // If an algorithm really need 4 bytes alignment, it should set it itself,
+  // this is the recommended way in "Avoiding 16 Common OpenGL Pitfalls",
+  // section 7:
+  // http://www.opengl.org/resources/features/KilgardTechniques/oglpitfall/
+  glPixelStorei(GL_UNPACK_ALIGNMENT,1);
+  glPixelStorei(GL_PACK_ALIGNMENT,1);
 }
 
 
@@ -577,13 +612,16 @@ int vtkOpenGLRenderWindow::SetPixelData(int x1, int y1, int x2, int y2,
     ;
     }
 
+  GLint buffer;
+  glGetIntegerv(GL_DRAW_BUFFER, &buffer);
+
   if (front)
     {
-    glDrawBuffer(GL_FRONT);
+    glDrawBuffer(this->GetFrontBuffer());
     }
   else
     {
-    glDrawBuffer(GL_BACK);
+    glDrawBuffer(this->GetBackBuffer());
     }
 
   if (y1 < y2)
@@ -687,6 +725,8 @@ int vtkOpenGLRenderWindow::SetPixelData(int x1, int y1, int x2, int y2,
   // This seems to be necessary for the image to show up
   glFlush();  
 #endif
+
+  glDrawBuffer(buffer);
   
   if (glGetError() != GL_NO_ERROR)
     {
@@ -917,13 +957,16 @@ int vtkOpenGLRenderWindow::SetRGBAPixelData(int x1, int y1, int x2, int y2,
     ;
     }  
 
+  GLint buffer;
+  glGetIntegerv(GL_DRAW_BUFFER, &buffer);
+
   if (front)
     {
-    glDrawBuffer(GL_FRONT);
+    glDrawBuffer(this->GetFrontBuffer());
     }
   else
     {
-    glDrawBuffer(GL_BACK);
+    glDrawBuffer(this->GetBackBuffer());
     }
 
   if (y1 < y2)
@@ -984,6 +1027,8 @@ int vtkOpenGLRenderWindow::SetRGBAPixelData(int x1, int y1, int x2, int y2,
   // This seems to be necessary for the image to show up
   glFlush();  
 
+  glDrawBuffer(buffer);
+
   if (glGetError() != GL_NO_ERROR)
     {
     return VTK_ERROR;
@@ -1221,13 +1266,16 @@ int vtkOpenGLRenderWindow::SetRGBACharPixelData(int x1, int y1, int x2,
     ;
     }
 
+  GLint buffer;
+  glGetIntegerv(GL_DRAW_BUFFER, &buffer);
+
   if (front)
     {
-    glDrawBuffer(GL_FRONT);
+    glDrawBuffer(this->GetFrontBuffer());
     }
   else
     {
-    glDrawBuffer(GL_BACK);
+    glDrawBuffer(this->GetBackBuffer());
     }
 
 
@@ -1305,6 +1353,8 @@ int vtkOpenGLRenderWindow::SetRGBACharPixelData(int x1, int y1, int x2,
   // This seems to be necessary for the image to show up
   glFlush();  
 
+  glDrawBuffer(buffer);
+
   if (glGetError() != GL_NO_ERROR)
     {
     return VTK_ERROR;
@@ -1882,3 +1932,50 @@ vtkOpenGLExtensionManager* vtkOpenGLRenderWindow::GetExtensionManager()
     }
   return this->ExtensionManager;
 }
+
+// ----------------------------------------------------------------------------
+// Description:
+// Returns an Hardware Support object. A new one will be created if one hasn't
+// already been set up.
+vtkOpenGLHardwareSupport* vtkOpenGLRenderWindow::GetHardwareSupport()
+{
+  if (!this->HardwareSupport)
+    {
+    vtkOpenGLHardwareSupport* hardware = vtkOpenGLHardwareSupport::New();
+    
+    // This does not form a reference loop since vtkOpenGLHardwareSupport does
+    // not keep a reference to the render window.
+    hardware->SetExtensionManager(this->GetExtensionManager());
+    this->SetHardwareSupport(hardware);
+    hardware->Delete();
+    }
+  return this->HardwareSupport;
+}
+
+// ----------------------------------------------------------------------------
+// Description:
+// Returns its texture unit manager object. A new one will be created if one
+// hasn't already been set up.
+vtkTextureUnitManager *vtkOpenGLRenderWindow::GetTextureUnitManager()
+{
+  if(this->TextureUnitManager==0)
+    {
+    vtkTextureUnitManager *manager=vtkTextureUnitManager::New();
+    
+    // This does not form a reference loop since vtkOpenGLHardwareSupport does
+    // not keep a reference to the render window.
+    manager->SetContext(this);
+    this->SetTextureUnitManager(manager);
+    manager->Delete();
+    }
+  return this->TextureUnitManager;
+}
+
+// ----------------------------------------------------------------------------
+// Description:
+// Block the thread until the actual rendering is finished().
+// Useful for measurement only.
+void vtkOpenGLRenderWindow::WaitForCompletion()
+{
+  glFinish();
+}
