@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  MetaIO
+  Copyright 2000-2010 Insight Software Consortium
 
-  Program:   MetaIO
-  Module:    metaUtils.cxx
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) Insight Software Consortium. All rights reserved.
-  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #ifdef _MSC_VER
 #pragma warning(disable:4702)
 #pragma warning(disable:4996)
@@ -510,7 +505,7 @@ METAIO_STL::streamoff MET_UncompressStream(METAIO_STREAM::ifstream * stream,
     d_stream->zalloc = (alloc_func)0;
     d_stream->zfree = (free_func)0;
     d_stream->opaque = (voidpf)0;
-    inflateInit(d_stream);
+    inflateInit2(d_stream,47); // allow both gzip and zlib compression headers
     compressionTable->compressedStream = d_stream;
     compressionTable->buffer = new char[1001];
     compressionTable->bufferSize = 0;
@@ -597,7 +592,11 @@ METAIO_STL::streamoff MET_UncompressStream(METAIO_STREAM::ifstream * stream,
     d_stream->avail_in = stream->gcount();
     d_stream->next_out = outdata;
 
-    inflate(d_stream, Z_NO_FLUSH);
+    int inflate_error = inflate(d_stream, Z_NO_FLUSH);
+    if(inflate_error < 0)
+      {
+      return -1;
+      }
 
     METAIO_STL::streampos previousSeekpos = seekpos;
 
@@ -769,7 +768,7 @@ bool MET_PerformUncompression(const unsigned char * sourceCompressed,
   d_stream.zfree = (free_func)0;
   d_stream.opaque = (voidpf)0;
 
-  inflateInit(&d_stream);
+  inflateInit2(&d_stream,47); // allow both gzip and zlib compression headers
   d_stream.next_in  = const_cast<unsigned char *>(sourceCompressed);
   d_stream.avail_in = (uInt)sourceCompressedSize;
   
@@ -876,20 +875,22 @@ bool MET_GetFilePath(const char *_fName, char *_fPath)
   size_t l = strlen(_fName);
 
   for(i=(long)l-1; i>=0; i--)
+    {
     if(_fName[i] == '\\' || _fName[i] == '/')
       break;
+    }
 
-    if(i >= 0 && (_fName[i] == '/' || _fName[i] == '\\'))
-      {
-      strcpy(_fPath, _fName);
-      _fPath[i+1] = '\0';
-      return true;
-      }
-    else
-      {
-      _fPath[0] = '\0';
-      return false;
-      }
+  if(i >= 0 && (_fName[i] == '/' || _fName[i] == '\\'))
+    {
+    strcpy(_fPath, _fName);
+    _fPath[i+1] = '\0';
+    return true;
+    }
+  else
+    {
+    _fPath[0] = '\0';
+    return false;
+    }
   }
 
 //
@@ -1034,7 +1035,8 @@ bool MET_IsComplete(METAIO_STL::vector<MET_FieldRecordType *> * fields)
 //
 bool MET_Read(METAIO_STREAM::istream &fp,
               METAIO_STL::vector<MET_FieldRecordType *> * fields,
-              char _MET_SeperatorChar, bool oneLine, bool display_warnings)
+              char _MET_SeperatorChar, bool oneLine, bool display_warnings,
+              METAIO_STL::vector<MET_FieldRecordType *> * newFields)
   {
 
   char s[1024];
@@ -1053,11 +1055,11 @@ bool MET_Read(METAIO_STREAM::istream &fp,
     i = 0;
     c = fp.get();
     while(!fp.eof() && c != MET_SeperatorChar && c != ':'
-          && (c == '\n' || isspace(c)))
+          && (c == '\r' || c == '\n' || isspace(c)))
       {
       c = fp.get();
       }
-    while(!fp.eof() && c != MET_SeperatorChar && c != ':' && c != '\n' && i<500)
+    while(!fp.eof() && c != MET_SeperatorChar && c != ':' && c != '\r' && c != '\n' && i<500)
       {
       s[i++] = c;
       c = fp.get();
@@ -1241,12 +1243,34 @@ bool MET_Read(METAIO_STREAM::istream &fp,
       }
     if(!found)
       {
-      if(display_warnings)
+      if( newFields != NULL )
         {
-        METAIO_STREAM::cerr << "Skipping unrecognized field "
-                            << s << METAIO_STREAM::endl;
+        MET_SkipToVal(fp);
+        if(fp.eof())
+          {
+          break;
+          }
+        MET_FieldRecordType * mF = new MET_FieldRecordType;
+        MET_InitReadField(mF, s, MET_STRING, false);
+        MET_CHAR_TYPE * str = (MET_CHAR_TYPE *)(mF->value);
+        fp.getline( str, 500 );
+        j = strlen(str) - 1;
+        while(!isprint(str[j]) || isspace(str[j]))
+          {
+          str[j--] = '\0';
+          }
+        mF->length = static_cast<int>( strlen( str ) );
+        newFields->push_back(mF);
+        }
+      else
+        {
+        if(display_warnings)
+          {
+          METAIO_STREAM::cerr << "Skipping unrecognized field "
+                              << s << METAIO_STREAM::endl;
+          }
+        fp.getline( s, 500 );
         }
-      fp.getline( s, 500 );
       }
     if(oneLine)
       {
