@@ -102,7 +102,7 @@ void vtkDistanceRepresentation2D::SetPoint1DisplayPosition(double x[3])
   double p[3];
   this->Point1Representation->GetWorldPosition(p);
   this->Point1Representation->SetWorldPosition(p);
-  this->AxisActor->GetPoint1Coordinate()->SetValue(p);
+  this->BuildRepresentation();
 }
 
 //----------------------------------------------------------------------
@@ -112,7 +112,7 @@ void vtkDistanceRepresentation2D::SetPoint2DisplayPosition(double x[3])
   double p[3];
   this->Point2Representation->GetWorldPosition(p);
   this->Point2Representation->SetWorldPosition(p);
-  this->AxisActor->GetPoint2Coordinate()->SetValue(p);
+  this->BuildRepresentation();
 }
 
 //----------------------------------------------------------------------
@@ -121,7 +121,7 @@ void vtkDistanceRepresentation2D::SetPoint1WorldPosition(double x[3])
   if (this->Point1Representation)
     {
     this->Point1Representation->SetWorldPosition(x);
-    this->AxisActor->GetPoint1Coordinate()->SetValue(x);
+    this->BuildRepresentation();
     }
 }
 
@@ -131,7 +131,7 @@ void vtkDistanceRepresentation2D::SetPoint2WorldPosition(double x[3])
   if (this->Point2Representation)
     {
     this->Point2Representation->SetWorldPosition(x);
-    this->AxisActor->GetPoint2Coordinate()->SetValue(x);
+    this->BuildRepresentation();
     }
 }
 
@@ -171,6 +171,13 @@ void vtkDistanceRepresentation2D::BuildRepresentation()
     this->Point1Representation->GetWorldPosition(p1);
     this->Point2Representation->GetWorldPosition(p2);
     this->Distance = sqrt(vtkMath::Distance2BetweenPoints(p1,p2));
+
+      this->AxisActor->GetPoint1Coordinate()->SetValue(p1);
+    this->AxisActor->GetPoint2Coordinate()->SetValue(p2);
+    this->AxisActor->SetRulerMode(this->RulerMode);
+    this->AxisActor->SetRulerDistance(this->RulerDistance);
+    this->AxisActor->SetNumberOfLabels(this->NumberOfRulerTicks);
+
     char string[512];
     sprintf(string, this->LabelFormat, this->Distance);
     this->AxisActor->SetTitle(string);
